(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    643699,      19228]*)
(*NotebookOutlinePosition[    644405,      19252]*)
(*  CellTagsIndexPosition[    644361,      19248]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\( (*\(\(**\)\(**\)\)*\ 
        Program\ for\ the\ \(paper\  : \ 
          Nonparametric\ Identification\ and\ Estimation\ of\ a\ Class\ of\ \
Common\ Value\ Auction\ Models\ by\ P . \ 
              Fevrier\ \  **  **  **  **  **  ** \)*****) \)\(\n\)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\( (*\ 
      1. \ Construction\ of\ the\ theoretical\ bid\ function, \ 
      its\ derivatives\ and\ its\ inverse\ *) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(n = 3; \  (*\ 
      number\ of\ players\ *) \[IndentingNewLine]b[s_] := 
      4 - 32/s + 
        16*8/s^2*
          Log[1 + s/
                4]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      the\ bid\ function\ *) \[IndentingNewLine]bprime[s_] := 
      32/s^2 - 16*16/s^3*Log[1 + s/4] + 
        16*2/s^2*1/\((1 + 
                s/4)\); \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      its\ derivative\ *) \[IndentingNewLine]bsecond[
        s_] := \(-\(64\/s\^3\)\) - 128\/\(\((1 + s\/4)\)\ s\^3\) - 
        8\/\(\((1 + s\/4)\)\^2\ s\^2\) + \(768\ Log[1 + s\/4]\)\/s\^4; \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      its\ second\ derivative\ *) \[IndentingNewLine]bmax = 
      N[b[4]];\[IndentingNewLine]
    \(\(bmoins1[
        x_] := \(FindRoot[b[u] \[Equal] x, {u, 0.5}]\)[\([1, 
          2]\)]\)\(;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\( \
(*\ its\ inverse\ *) \)\(\ \)\(\[IndentingNewLine]\)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\
\( (*\ 2. \ Construction\ of\ all\ the\ functions\ defined\ in\ the\ paper\ \
for\ the\ estimation\ using\ kernel\ methods\ *) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\( (*\ 
      the\ kernel\ *) \)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\(K[
          u_] := If[\(-1\) < u < 1, 3/4*\((1 - u^2)\), 
          0];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[IndentingNewLine]
    \(k[u_] := 
        If[\(-1\) < u < 1, \(-3\)/2*u, 0];\)\ \ \ \ \ \ \ \[IndentingNewLine]
    \(ind[u_] := 
        If[u <= 0, 1, 
          0];\)\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ dF/ds1 \((s1, 
          s2)\)\ defined\ page\ 9\ *) \[IndentingNewLine]\[IndentingNewLine]
    \(dFds1[x_, y_] := 
        1/\((n*\((n - 1)\)*l*h1)\)*
          Sum[K[\((B[\([i, 1]\)] - x)\)/h1]*ind[B[\([i, 2]\)] - y] + 
              K[\((B[\([i, 1]\)] - x)\)/h1]*ind[B[\([i, 3]\)] - y] + 
              K[\((B[\([i, 2]\)] - x)\)/h1]*ind[B[\([i, 1]\)] - y] + 
              K[\((B[\([i, 2]\)] - x)\)/h1]*ind[B[\([i, 3]\)] - y] + 
              K[\((B[\([i, 3]\)] - x)\)/h1]*ind[B[\([i, 1]\)] - y] + 
              K[\((B[\([i, 3]\)] - x)\)/h1]*ind[B[\([i, 2]\)] - y], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ Phi \((s, 
          s')\)\ defined\ page\ 9\ *) \[IndentingNewLine]\[IndentingNewLine]
    \(FSSV[x_, y_] := 
        dFds1[y, x]/dFds1[y, y];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ f_S \((s1)\)\ defined\ page\ 10\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(fS[x_] := 
        1/\((n*l*h1)\)*
          Sum[K[\((B[\([i, 1]\)] - x)\)/h1] + K[\((B[\([i, 2]\)] - x)\)/h1] + 
              K[\((B[\([i, 3]\)] - x)\)/h1], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ f_S \((s1, 
          s2)\)\ defined\ page\ 10\ *) \[IndentingNewLine]\[IndentingNewLine]
    \(fS2[x_, y_] := 
        1/\((n*\((n - 1)\)*l*h2^2)\)*
          Sum[K[\((B[\([i, 1]\)] - x)\)/h2]*K[\((B[\([i, 2]\)] - y)\)/h2] + 
              K[\((B[\([i, 1]\)] - x)\)/h2]*K[\((B[\([i, 3]\)] - y)\)/h2] + 
              K[\((B[\([i, 2]\)] - x)\)/h2]*K[\((B[\([i, 1]\)] - y)\)/h2] + 
              K[\((B[\([i, 2]\)] - x)\)/h2]*K[\((B[\([i, 3]\)] - y)\)/h2] + 
              K[\((B[\([i, 3]\)] - x)\)/h2]*K[\((B[\([i, 1]\)] - y)\)/h2] + 
              K[\((B[\([i, 3]\)] - x)\)/h2]*
                K[\((B[\([i, 2]\)] - y)\)/h2], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ F_S \((s1)\)\ defined\ page\ 10\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(FS[x_] := 
        1/\((n*l)\)*
          Sum[ind[B[\([i, 1]\)] - x] + ind[B[\([i, 2]\)] - x] + 
              ind[B[\([i, 3]\)] - x], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ Psi \((s)\)\ defined\ page\ 10\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(FSV[x_] = 
        FS[x] - fS[x]*
            dFds1[x, x]/
              fS2[x, x];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ F_Smax \((s1)\)\ defined\ page\ 10\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(FYS[x_] := 
        1/l*Sum[ind[Max[B[\([i, All]\)]] - x], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ f' _S \((s1)\)\ defined\ page\ 10\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(fpS[x_] := \(-1\)/\((n*l*h1p^2)\)*
          Sum[k[\((B[\([i, 1]\)] - x)\)/h1p] + 
              k[\((B[\([i, 2]\)] - x)\)/h1p] + 
              k[\((B[\([i, 3]\)] - x)\)/h1p], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ d2F/d2s1 \((s1, 
          s2)\)\ defined\ page\ 10\ *) \[IndentingNewLine]\[IndentingNewLine]
    \(d2Fds12[x_, y_] := \(-1\)/\((n*\((n - 1)\)*l*h1p^2)\)*
          Sum[k[\((B[\([i, 1]\)] - x)\)/h1p]*ind[B[\([i, 2]\)] - y] + 
              k[\((B[\([i, 1]\)] - x)\)/h1p]*ind[B[\([i, 3]\)] - y] + 
              k[\((B[\([i, 2]\)] - x)\)/h1p]*ind[B[\([i, 1]\)] - y] + 
              k[\((B[\([i, 2]\)] - x)\)/h1p]*ind[B[\([i, 3]\)] - y] + 
              k[\((B[\([i, 3]\)] - x)\)/h1p]*ind[B[\([i, 1]\)] - y] + 
              k[\((B[\([i, 3]\)] - x)\)/h1p]*ind[B[\([i, 2]\)] - y], {i, 1, 
              l}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      estimation\ of\ the\ function\ T^{\(-1\)} \((s)\)\ defined\ page\ 11\ \
*) \[IndentingNewLine]\[IndentingNewLine]
    \(Smoins1[s_] := 
        s + dFds1[s, 
              s]/\((\((n - 1)\)*
                fS2[s, s])\) + \((\((FYS[s, s] - FSV[s])\)/\((n - 
                    1)\))\)*\((d2Fds12[s, s] - fpS[s] - n*fS[s] + 
                  n*fS[s]*fS2[s, s]/dFds1[s, s])\)/\((fS[s]*d2Fds12[s, s] - 
                  fpS[s]*dFds1[s, 
                      s])\);\)\[IndentingNewLine]\[IndentingNewLine]
    \)\)\)], "Input"],

Cell[BoxData[{
    \(\(\(<< Statistics`DescriptiveStatistics`\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SeedRandom[1];\)\), "\[IndentingNewLine]", 
    \(\(z = 400;\)\  (*\ 
      number\ of\ replications\ *) \), "\[IndentingNewLine]", 
    \(l = 500; \  (*\ number\ of\ auctions\ *) \[IndentingNewLine]y = 
      100;\  (*\ 
      discretization\ *) \[IndentingNewLine]\[IndentingNewLine] (*\ 
      construction\ of\ all\ the\ tables, \ 
      uninitialized\ at\ this\ stage\ *) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(TableFSV = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableFSSV = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableSmoins1 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableSmoins12 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableS = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableFSVV = 
        Table[0, {i, 1, z}, {j, 1, y + 1}\ ];\)\), "\[IndentingNewLine]", 
    \(\(TableFV = 
        Table[0, {i, 1, z}, {j, 1, 
            y + 1}\ ];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(TableFS = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TabledFds1 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Table2dFds1 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Tabled2Fds12 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TablefS = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TablefpS = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TablefS2 = 
        Table[0, {i, 1, z}, {j, 1, y + 1}];\)\), "\[IndentingNewLine]", 
    \(\(TableFYS = 
        Table[0, {i, 1, z}, {j, 1, 
            y + 1}];\)\[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine] (*\ 
      Monte\ carlo\ simulations\ *) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(For[r = 1, 
      r < z + 1, \(r++\), \[IndentingNewLine]For[t = 0, 
          t < y + 1, \(t++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            construction\ of\ the\ simulated\ values, \ 
            signals\ and\ bids\ *) \[IndentingNewLine]\[IndentingNewLine]V = 
            Table[2*Random[], {i, 1, l}]; \[IndentingNewLine]S = 
            Table[2*V[\([i]\)]*Random[], {i, 1, l}, {j, 1, 
                n}]; \[IndentingNewLine]B = 
            Table[b[S[\([i, j]\)]], {i, 1, l}, {j, 1, 
                n}]; \[IndentingNewLine]\[IndentingNewLine]h1 = 
            1.06*StandardDeviation[
                Flatten[
                  B]]*\((l/Log[l])\)^\((\(-1\)/
                    5)\)\ ; \ \ \ \ \ \ \ \[IndentingNewLine]h2 = 
            1.06*StandardDeviation[
                Flatten[
                  B]]*\((l/Log[l])\)^\((\(-1\)/
                    6)\)\ ; \[IndentingNewLine]h1p = 
            1.06*StandardDeviation[
                Flatten[
                  B]]*\((l/Log[l])\)^\((\(-1\)/
                    7)\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            estimation\ of\ the\ functions\ of\ interest\ at\ different\ \
points\ following\ the\ estimation\ procedure*) \[IndentingNewLine]\
\[IndentingNewLine]TableFS[\([r, t + 1]\)] = 
            FS[b[4]*t/y]; \[IndentingNewLine]TabledFds1[\([r, t + 1]\)] = 
            dFds1[b[4]*t/y, 
              b[4]*t/y]; \[IndentingNewLine]Table2dFds1[\([r, t + 1]\)] = 
            dFds1[b[3.6], b[4]*t/y]; \[IndentingNewLine]const = 
            dFds1[b[3.6], 
              b[3.6]]; \[IndentingNewLine]Tabled2Fds12[\([r, t + 1]\)] = 
            d2Fds12[b[4]*t/y, 
              b[4]*t/y]; \[IndentingNewLine]TablefS[\([r, t + 1]\)] = 
            fS[b[4]*t/y]; \[IndentingNewLine]TablefpS[\([r, t + 1]\)] = 
            fpS[b[4]*t/y]; \[IndentingNewLine]TablefS2[\([r, t + 1]\)] = 
            fS2[b[4]*t/y, 
              b[4]*t/y]; \ \ \ \[IndentingNewLine]TableFYS[\([r, t + 1]\)] = 
            FYS[b[4]*
                t/y]; \[IndentingNewLine]\[IndentingNewLine]TableFSSV[\([r, 
                t + 1]\)] = 
            Table2dFds1[\([r, t + 1]\)]/
              const; \[IndentingNewLine]TableFSV[\([r, t + 1]\)] = 
            TableFS[\([r, t + 1]\)] - 
              TablefS[\([r, t + 1]\)]*
                TabledFds1[\([r, t + 1]\)]/\((TablefS2[\([r, t + 1]\)] + 
                      0.0000000001)\); \[IndentingNewLine]TableSmoins1[\([r, 
                t + 1]\)] = 
            b[4]*t/y + 
              TabledFds1[\([r, 
                    t + 1]\)]/\((\((n - 1)\)*TablefS2[\([r, t + 1]\)] + 
                    0.0000000001)\) + \((\((TableFYS[\([r, t + 1]\)] - 
                        TableFSV[\([r, t + 1]\)])\)/\((n - 
                        1)\))\)*\((Tabled2Fds12[\([r, t + 1]\)] - 
                      TablefpS[\([r, t + 1]\)] - n*TablefS[\([r, t + 1]\)] + 
                      n*TablefS[\([r, t + 1]\)]*
                        TablefS2[\([r, 
                              t + 1]\)]/\((TabledFds1[\([r, t + 1]\)] + 
                              0.0000000001)\))\)/\((TablefS[\([r, t + 1]\)]*
                        Tabled2Fds12[\([r, t + 1]\)] - 
                      TablefpS[\([r, t + 1]\)]*TabledFds1[\([r, t + 1]\)] + 
                      0.0000000001)\); \[IndentingNewLine]If[
            TableSmoins1[\([r, t + 1]\)] == Indeterminate, \ 
            TableSmoins1[\([r, t + 1]\)] = 0]; \[IndentingNewLine]If[
            TableSmoins1[\([r, t + 1]\)] > 3, \ 
            TableSmoins1[\([r, t + 1]\)] = 3]; \[IndentingNewLine]If[
            TableSmoins1[\([r, t + 1]\)] < 0, \ 
            TableSmoins1[\([r, t + 1]\)] = 
              0]\[IndentingNewLine]]\[IndentingNewLine]\[IndentingNewLine]\(g \
= Array[u, y + 1]\); \n
      c = Table[
          u[i] \[LessEqual] u[i + 1], {i, 1, 
            y}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
        estimation\ of\ the\ functions\ T \((s)\), \ 
        F_V \((v)\)\ and\ F_ {S\\V} \((s\\v)\)\ defined\ page\ 11\ \
*) \[IndentingNewLine]\n
      TableSmoins12[\([r, 
            All]\)] = \(NMinimize[{Sum[\((u[i] - 
                      TableSmoins1[\([r, i]\)])\)^2, {i, 1, y + 1}], c}, 
            g]\)[\([2, All, 2]\)]; \[IndentingNewLine]For[t = 0, 
          t < y + 1, \(t++\), \[IndentingNewLine]TableS[\([r, t + 1]\)] = 
            Max[Min[Table[
                    w*ind[2*t/y - TableSmoins12[\([r, w + 1]\)]], {w, 0, 
                      y}] + y*\((1 - 
                        Table[ind[2*t/y - TableSmoins12[\([r, w + 1]\)]], {w, 
                            0, y}])\)], 
              1]; \[IndentingNewLine]TableFV[\([r, t + 1]\)] = 
            TableFSV[\([r, 
                TableS[\([r, 
                    t + 1]\)]]\)];\[IndentingNewLine]]\[IndentingNewLine]For[
          t = 0, t < 
            y + 1, \(t++\), \[IndentingNewLine]\(TableFSVV[\([r, t + 1]\)] = 
              dFds1[TableS[\([r, 3.6/2*50]\)]*b[4]/y, 
                  b[4]*t/y]/\((dFds1[TableS[\([r, 3.6/2*50]\)]*b[4]/y, 
                    TableS[\([r, 3.6/2*50]\)]*
                      b[4]/y])\);\)\[IndentingNewLine]]\[IndentingNewLine]]\),\
 "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    "\[IndentingNewLine]", 
      "\[IndentingNewLine]", \( (*\ 
        3. \ graphs\ of\ the\ estimated\ function\ and\ of\ the\ true\ \
function\ *) \), "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{\(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(moyFSV = 
            Table[Sum[TableFSV[\([i, j]\)]/z, {i, 1, z}], {j, 1, y + 1}];\), 
        "\[IndentingNewLine]", \(moyFSSV = 
            Table[Sum[TableFSSV[\([i, j]\)]/z, {i, 1, z}], {j, 1, y + 1}];\), 
        "\[IndentingNewLine]", \(moySmoins12 = 
            Table[Sum[TableSmoins12[\([i, j]\)]/z, {i, 1, z}], {j, 1, 
                y + 1}];\), 
        "\[IndentingNewLine]", \(moyS = 
            Table[Sum[TableS[\([i, j]\)]/z, {i, 1, z}], {j, 1, y + 1}];\), 
        "\[IndentingNewLine]", \(moyFV = 
            Table[Sum[TableFV[\([i, j]\)]/z, {i, 1, z}], {j, 1, y + 1}];\), 
        "\[IndentingNewLine]", \(moyFSVV = 
            Table[Sum[TableFSVV[\([i, j]\)]/z, {i, 1, z}], {j, 1, y + 1}];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(q5FSV = \(Table[
                Sort[TableFSV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), 
        "\[IndentingNewLine]", \(q5FSSV = \(Table[
                Sort[TableFSSV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), 
        "\[IndentingNewLine]", \(q5Smoins12 = \(Table[
                Sort[TableSmoins12[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), 
        "\[IndentingNewLine]", \(q5S = \(Table[
                Sort[TableS[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), 
        "\[IndentingNewLine]", \(q5FV = \(Table[
                Sort[TableFV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), 
        "\[IndentingNewLine]", \(q5FSVV = \(Table[
                Sort[TableFSVV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*5]\)];\), "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(q95FSV = \(Table[
                Sort[TableFSV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), 
        "\[IndentingNewLine]", \(q95FSSV = \(Table[
                Sort[TableFSSV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), 
        "\[IndentingNewLine]", \(q95Smoins12 = \(Table[
                Sort[TableSmoins12[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), 
        "\[IndentingNewLine]", \(q95S = \(Table[
                Sort[TableS[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), 
        "\[IndentingNewLine]", \(q95FV = \(Table[
                Sort[TableFV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), 
        "\[IndentingNewLine]", \(q95FSVV = \(Table[
                Sort[TableFSVV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*95]\)];\), "\[IndentingNewLine]", "\[IndentingNewLine]",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{\(p1 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[moyFSV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}]\), ";", Cell[""]}], 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, bmoins1[b[4]*\((i - 1)\)/y]/4}, {i, 
                  1, y + 1}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[q5FSV]\)[\([i]\)]}, {i, 1, 
                  1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[q95FSV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{\(p1 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[moyFSSV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}]\), ";", Cell[""]}], 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, 
                  bmoins1[b[4]*\((i - 1)\)/y]/3.6}, {i, 1, y + 1}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[q5FSSV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[q95FSSV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{\(p1 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[moyS]\)[\([i]\)]*b[4]/y}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1.54}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}]\), ";", Cell[""]}], 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, b[4*\((i - 1)\)/y]}, {i, 1, y + 1}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1.54}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[q5S]\)[\([i]\)]*b[4]/y}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1.54}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[q95S]\)[\([i]\)]*b[4]/y}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1.54}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p1 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[
                      moySmoins12]\)[\([i]\)]}, {i, 1, 1 + y}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 2}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, bmoins1[b[4]*\((i - 1)\)/y]/2}, {i, 
                  1, y + 1}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 2}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[
                      q5Smoins12]\)[\([i]\)]}, {i, 1, 1 + y}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 2}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{b[4]*\((i - 1)\)/y, \(Flatten[
                      q95Smoins12]\)[\([i]\)]}, {i, 1, 1 + y}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[4]}, {\(-0.2\), 2}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(q50FV = \(Table[
                Sort[TableFV[\([All, j]\)]], {j, 1, y + 1}]\)[\([All, 
                z/100*50]\)];\), "\[IndentingNewLine]", "\[IndentingNewLine]",
         "\[IndentingNewLine]", 
        RowBox[{\(p1 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[q50FV]\)[\([i]\)]}, {i, 1, 
                  1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}]\), ";", Cell[""]}], 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[Table[{2*\((i - 1)\)/y, \((i - 1)\)/y}, {i, 1, y + 1}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[q5FV]\)[\([i]\)]}, {i, 1, 
                  1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{2*\((i - 1)\)/y, \(Flatten[q95FV]\)[\([i]\)]}, {i, 1, 
                  1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, 2}, {\(-0.2\), 1}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{\(p1 = 
            ListPlot[
              Table[{b[3.6]*\((i - 1)\)/y, \(Flatten[
                      moyFSVV]\)[\([i]\)]}, {i, 1, 1 + y}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1.3}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.001, 0.008}]}]\), ";", Cell[""]}], 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p2 = 
            ListPlot[
              Table[{b[3.6]*\((i - 1)\)/y, 
                  bmoins1[b[3.6]*\((i - 1)\)/y]/3.6}, {i, 1, y + 1}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1.3}}, 
              PlotStyle \[Rule] {Thickness[0.003]}];\), "\[IndentingNewLine]",
         "\[IndentingNewLine]", \(p3 = 
            ListPlot[
              Table[{b[3.6]*\((i - 1)\)/y, \(Flatten[q5FSVV]\)[\([i]\)]}, {i, 
                  1, 1 + y}], PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1.3}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(p4 = 
            ListPlot[
              Table[{b[3.6]*\((i - 1)\)/y, \(Flatten[
                      q95FSVV]\)[\([i]\)]}, {i, 1, 1 + y}], 
              PlotJoined \[Rule] True, 
              PlotRange \[Rule] {{0, b[3.6]}, {\(-0.2\), 1.3}}, 
              PlotStyle \[Rule] {Thickness[0.001], 
                  Dashing[{0.005, 0.015}]}];\), 
        "\[IndentingNewLine]", \(Show[p1, p2, p3, p4];\), 
        "\[IndentingNewLine]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.103006 0.515028 [
[.12943 .09051 -9 -9 ]
[.12943 .09051 9 0 ]
[.25887 .09051 -9 -9 ]
[.25887 .09051 9 0 ]
[.3883 .09051 -9 -9 ]
[.3883 .09051 9 0 ]
[.51774 .09051 -9 -9 ]
[.51774 .09051 9 0 ]
[.64717 .09051 -3 -9 ]
[.64717 .09051 3 0 ]
[.77661 .09051 -9 -9 ]
[.77661 .09051 9 0 ]
[.90604 .09051 -9 -9 ]
[.90604 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .10301 m
.12943 .10926 L
s
[(0.2)] .12943 .09051 0 1 Mshowa
.25887 .10301 m
.25887 .10926 L
s
[(0.4)] .25887 .09051 0 1 Mshowa
.3883 .10301 m
.3883 .10926 L
s
[(0.6)] .3883 .09051 0 1 Mshowa
.51774 .10301 m
.51774 .10926 L
s
[(0.8)] .51774 .09051 0 1 Mshowa
.64717 .10301 m
.64717 .10926 L
s
[(1)] .64717 .09051 0 1 Mshowa
.77661 .10301 m
.77661 .10926 L
s
[(1.2)] .77661 .09051 0 1 Mshowa
.90604 .10301 m
.90604 .10926 L
s
[(1.4)] .90604 .09051 0 1 Mshowa
.125 Mabswid
.03236 .10301 m
.03236 .10676 L
s
.06472 .10301 m
.06472 .10676 L
s
.09708 .10301 m
.09708 .10676 L
s
.16179 .10301 m
.16179 .10676 L
s
.19415 .10301 m
.19415 .10676 L
s
.22651 .10301 m
.22651 .10676 L
s
.29123 .10301 m
.29123 .10676 L
s
.32359 .10301 m
.32359 .10676 L
s
.35595 .10301 m
.35595 .10676 L
s
.42066 .10301 m
.42066 .10676 L
s
.45302 .10301 m
.45302 .10676 L
s
.48538 .10301 m
.48538 .10676 L
s
.5501 .10301 m
.5501 .10676 L
s
.58246 .10301 m
.58246 .10676 L
s
.61482 .10301 m
.61482 .10676 L
s
.67953 .10301 m
.67953 .10676 L
s
.71189 .10301 m
.71189 .10676 L
s
.74425 .10301 m
.74425 .10676 L
s
.80897 .10301 m
.80897 .10676 L
s
.84133 .10301 m
.84133 .10676 L
s
.87369 .10301 m
.87369 .10676 L
s
.9384 .10301 m
.9384 .10676 L
s
.97076 .10301 m
.97076 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .103 m
.01 .09094 L
.02 .08485 L
.03 .08025 L
.04 .07726 L
.05 .07517 L
.06 .07422 L
.07 .07485 L
.08 .07681 L
.09 .08056 L
.1 .08722 L
.11 .09675 L
.12 .10587 L
.13 .11104 L
.14 .11492 L
.15 .11889 L
.16 .12297 L
.17 .12686 L
.18 .13026 L
.19 .13562 L
.2 .1377 L
.21 .14254 L
.22 .14603 L
.23 .14942 L
.24 .15393 L
.25 .15749 L
.26 .16202 L
.27 .16561 L
.28 .16958 L
.29 .17413 L
.3 .17587 L
.31 .18176 L
.32 .1857 L
.33 .19 L
.34 .19434 L
.35 .19895 L
.36 .20303 L
.37 .20578 L
.38 .21102 L
.39 .21548 L
.4 .21862 L
.41 .2235 L
.42 .22949 L
.43 .23321 L
.44 .23651 L
.45 .24215 L
.46 .24609 L
.47 .25216 L
.48 .2564 L
.49 .25991 L
Mistroke
.5 .263 L
.51 .27041 L
.52 .27443 L
.53 .27973 L
.54 .28466 L
.55 .28929 L
.56 .29332 L
.57 .29927 L
.58 .30465 L
.59 .30924 L
.6 .31717 L
.61 .32066 L
.62 .32515 L
.63 .33119 L
.64 .33521 L
.65 .33969 L
.66 .34515 L
.67 .35345 L
.68 .35956 L
.69 .3646 L
.7 .36909 L
.71 .37321 L
.72 .38288 L
.73 .38723 L
.74 .3944 L
.75 .39979 L
.76 .40733 L
.77 .41078 L
.78 .41869 L
.79 .42256 L
.8 .43045 L
.81 .43822 L
.82 .44282 L
.83 .44753 L
.84 .45506 L
.85 .46185 L
.86 .46827 L
.87 .47308 L
.88 .48216 L
.89 .48458 L
.9 .49076 L
.91 .49843 L
.92 .50252 L
.93 .51069 L
.94 .51393 L
.95 .51148 L
.96 .52171 L
Mfstroke
.96 .52171 m
.96 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00T0oooo00080?oo
o`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`3f0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo0P00003g0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0
oooo0?H0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?oo
o`090?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000m`3oool00`00
0000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00T0
oooo000K0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`8000000`3oool4000001<0oooo
0P0000040?ooo`8000001@3oool300000180oooo0P0000040?ooo`8000000`3oool3000001<0oooo
0P0000040?ooo`800000103oool2000001T0oooo1@00000F0?ooo`D000000P3oool2000000<0oooo
1000000B0?ooo`D000000P3oool2000000D0oooo0`00000A0?ooo`006`3oool00`000000oooo0?oo
o`0F0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool001/0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo0180oooo00@000000?ooo`3oool00000203oool500000140oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000006P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`D000004@3oool001/0oooo00<0
00000?ooo`3oool05P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000B0?ooo`040000003oool0oooo
000000P0oooo0`00000B0?ooo`040000003oool0oooo000000T0oooo0P00000K0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`090?ooo`006`3o
ool00`000000oooo0?ooo`0:0?ooo`80000000@0oooo0000003oool000001P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000B0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000001@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0000000B0?ooo`006`3oool2000000L0oooo00<000000?ooo`00
0000203oool2000000@0oooo0P00000:0?ooo`800000503oool2000000/0oooo0P00000C0?ooo`80
00002P3oool300000180oooo0P00000:0?ooo`8000006P3oool2000001T0oooo0P00000:0?ooo`80
0000503oool2000000/0oooo0P00000B0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`090?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0j@3o
ool001/0oooo00@000000?ooo`3oool000005P3oool200000=d0oooo00<000000?ooo`3oool02@3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool2000001X0oooo00<000000?oo
o`3oool0fP3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0>@0oooo000K0?ooool000001P00000001/0oooo00<000000?ooo`3oool07@3o
ool200000240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`3P0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000
0=80oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0000003L0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`800000c@3oool00`000000oooo
0?ooo`090?ooo`006`3oool2000002/0oooo00<000000?ooo`3oool0e@3oool001/0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`3C0?ooo`006`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool000000<D0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3o
ool0<P3oool200000<h0oooo000K0?ooo`030000003oool0oooo03@0oooo0P0000300?ooo`030000
003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0b03o
ool001/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo00T0oooo000K0?ooo`800000?03oool00`000000oooo0?ooo`340?ooo`006`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool000000<80oooo000K0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`000000/`3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0;/0oooo000K0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`180?oo
o`040000003oool0000000000;H0oooo000K0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`090?ooo`006`3oool2000004h0oooo0P00002c0?ooo`00
6`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool000000;00oooo000K0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`090?ooo`006`3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0:X0oooo00080?ooo`800000103oool20000
00<0oooo100000040?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0W03oool00`00
0000oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2V0?ooo`001`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P00001L0?ooo`800000V@3oool00`00
0000oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2Q0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`2O0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo
0680oooo00<000000?ooo`000000T@3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo09T0oooo000K0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo09L0oooo000K0?ooo`800000J`3oool4000008P0oooo00<00000
0?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0SP3oool001/0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0RP3o
ool001/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00T0oooo000K0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0QP3oool001/0
oooo0P00001l0?ooo`800000N@3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02@3oool001/0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`1o0?ooo`006`3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`1k0?ooo`006`3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool001/0oooo0P0000290?ooo`030000
003oool0oooo07L0oooo000K0?ooo`030000003oool0oooo08X0oooo0P00001Z0?ooo`030000003o
ool0oooo00T0oooo000K0?ooo`030000003oool0oooo08`0oooo0P00001X0?ooo`030000003oool0
oooo00T0oooo000K0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0L03oool001/0
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0
oooo00080?ooo`800000103oool2000000D0oooo0`0000030?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0KP3oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`090?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`D000000`3oool2000009H0oooo
00<000000?ooo`3oool0JP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00T0
oooo00080?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`1T0?ooo`006`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1P
0?ooo`006`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool02@3oool001/0oooo0P00002T0?ooo`030000003oool0oooo05`0oooo000K0?ooo`030000
003oool0oooo0:D0oooo0P00001?0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003o
ool0oooo0:L0oooo0P00001=0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0EP3oool001/0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool0E03oool001/0oooo0P00002^0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?oo
o`1@0?ooo`006`3oool00`000000oooo0?ooo`2a0?ooo`800000@`3oool00`000000oooo0?ooo`09
0?ooo`006`3oool00`000000oooo0?ooo`2c0?ooo`800000@@3oool00`000000oooo0?ooo`090?oo
o`006`3oool00`000000oooo0?ooo`2e0?ooo`800000B`3oool001/0oooo00<000000?ooo`3oool0
mP3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo04P0oooo000K0?ooo`800000^P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00T0oooo000K0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0A03oool001/0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0
oooo000K0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo0400oooo0008
0?ooo`800000103oool2000000<0oooo0`0000050?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0l0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
0P0000360?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool000L0oooo00@0
00000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0h0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool0=03oool001/0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00T0oooo000K0?ooo`800000d03oool00`000000oooo0?ooo`0`0?ooo`00
6`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0000002@0oooo00<000000?ooo`3oool0
2@3oool001/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0000000^0?ooo`006`3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool0
01/0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00T0oooo000K0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0:03oool001/0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo
000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`0R0?ooo`006`3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0h@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0>40oooo00<0
00000?ooo`0000007P3oool001/0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00T0oooo000K0?ooo`800000j03oool00`000000oooo0?ooo`0H0?oo
o`006`3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02@3oool001/0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`0F0?ooo`006`3o
ool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool001/0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00080?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
0>h0oooo00<000000?ooo`3oool04@3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0>l0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00T0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool200000?H0oooo00<000000?ooo`3oool02P3oool000L0oooo00@0
00000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0mP3oool00`000000oooo
0?ooo`090?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000X0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000C0?ooo`D000000`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`800000o`3oool40?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001@0oooo0P00
003o0?ooo`/0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162091, -0.261311, \
0.0059487, 0.00747503}}],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(FindRoot :: \\\"lstol\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.103006 0.515028 [
[.12943 .09051 -9 -9 ]
[.12943 .09051 9 0 ]
[.25887 .09051 -9 -9 ]
[.25887 .09051 9 0 ]
[.3883 .09051 -9 -9 ]
[.3883 .09051 9 0 ]
[.51774 .09051 -9 -9 ]
[.51774 .09051 9 0 ]
[.64717 .09051 -3 -9 ]
[.64717 .09051 3 0 ]
[.77661 .09051 -9 -9 ]
[.77661 .09051 9 0 ]
[.90604 .09051 -9 -9 ]
[.90604 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .10301 m
.12943 .10926 L
s
[(0.2)] .12943 .09051 0 1 Mshowa
.25887 .10301 m
.25887 .10926 L
s
[(0.4)] .25887 .09051 0 1 Mshowa
.3883 .10301 m
.3883 .10926 L
s
[(0.6)] .3883 .09051 0 1 Mshowa
.51774 .10301 m
.51774 .10926 L
s
[(0.8)] .51774 .09051 0 1 Mshowa
.64717 .10301 m
.64717 .10926 L
s
[(1)] .64717 .09051 0 1 Mshowa
.77661 .10301 m
.77661 .10926 L
s
[(1.2)] .77661 .09051 0 1 Mshowa
.90604 .10301 m
.90604 .10926 L
s
[(1.4)] .90604 .09051 0 1 Mshowa
.125 Mabswid
.03236 .10301 m
.03236 .10676 L
s
.06472 .10301 m
.06472 .10676 L
s
.09708 .10301 m
.09708 .10676 L
s
.16179 .10301 m
.16179 .10676 L
s
.19415 .10301 m
.19415 .10676 L
s
.22651 .10301 m
.22651 .10676 L
s
.29123 .10301 m
.29123 .10676 L
s
.32359 .10301 m
.32359 .10676 L
s
.35595 .10301 m
.35595 .10676 L
s
.42066 .10301 m
.42066 .10676 L
s
.45302 .10301 m
.45302 .10676 L
s
.48538 .10301 m
.48538 .10676 L
s
.5501 .10301 m
.5501 .10676 L
s
.58246 .10301 m
.58246 .10676 L
s
.61482 .10301 m
.61482 .10676 L
s
.67953 .10301 m
.67953 .10676 L
s
.71189 .10301 m
.71189 .10676 L
s
.74425 .10301 m
.74425 .10676 L
s
.80897 .10301 m
.80897 .10676 L
s
.84133 .10301 m
.84133 .10676 L
s
.87369 .10301 m
.87369 .10676 L
s
.9384 .10301 m
.9384 .10676 L
s
.97076 .10301 m
.97076 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
0 .10301 m
.01 .106 L
.02 .10903 L
.03 .11208 L
.04 .11515 L
.05 .11826 L
.06 .12139 L
.07 .12455 L
.08 .12774 L
.09 .13095 L
.1 .1342 L
.11 .13748 L
.12 .14078 L
.13 .14412 L
.14 .14748 L
.15 .15088 L
.16 .1543 L
.17 .15776 L
.18 .16126 L
.19 .16478 L
.2 .16834 L
.21 .17193 L
.22 .17555 L
.23 .17921 L
.24 .1829 L
.25 .18663 L
.26 .1904 L
.27 .1942 L
.28 .19803 L
.29 .20191 L
.3 .20582 L
.31 .20977 L
.32 .21376 L
.33 .21779 L
.34 .22185 L
.35 .22596 L
.36 .23011 L
.37 .2343 L
.38 .23853 L
.39 .24281 L
.4 .24713 L
.41 .25149 L
.42 .2559 L
.43 .26035 L
.44 .26485 L
.45 .26939 L
.46 .27399 L
.47 .27863 L
.48 .28331 L
.49 .28805 L
Mistroke
.5 .29284 L
.51 .29768 L
.52 .30257 L
.53 .30751 L
.54 .31251 L
.55 .31756 L
.56 .32266 L
.57 .32783 L
.58 .33304 L
.59 .33832 L
.6 .34365 L
.61 .34904 L
.62 .3545 L
.63 .36001 L
.64 .36559 L
.65 .37122 L
.66 .37693 L
.67 .3827 L
.68 .38853 L
.69 .39443 L
.7 .4004 L
.71 .40644 L
.72 .41255 L
.73 .41874 L
.74 .42499 L
.75 .43132 L
.76 .43773 L
.77 .44421 L
.78 .45077 L
.79 .45741 L
.8 .46414 L
.81 .47094 L
.82 .47783 L
.83 .4848 L
.84 .49186 L
.85 .49901 L
.86 .50625 L
.87 .51358 L
.88 .521 L
.89 .52852 L
.9 .53614 L
.91 .54385 L
.92 .55167 L
.93 .55958 L
.94 .56761 L
.95 .57573 L
.96 .58397 L
.97 .59231 L
.98 .60077 L
.99 .60934 L
Mistroke
1 .61803 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`8000000`3oool4000001<0oooo
0P0000040?ooo`8000001@3oool300000180oooo0P0000040?ooo`8000000`3oool3000001<0oooo
0P0000040?ooo`800000103oool2000001T0oooo1@00000F0?ooo`D000000P3oool2000000<0oooo
1000000B0?ooo`D000000P3oool2000000D0oooo0`00000A0?ooo`006`3oool00`000000oooo0?oo
o`0F0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003o
ool0oooo01H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0B0?ooo`040000
003oool0oooo000000P0oooo1@00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000004@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01`3oool500000140oooo000K0?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`<000004P3oool0
10000000oooo0?ooo`0000090?ooo`8000006`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo00000180oooo000K0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000B0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000004P3oool001/0oooo0P00000H0?ooo`8000002P3oool2000001@0oooo
0P00000;0?ooo`8000004`3oool2000000X0oooo0`00000B0?ooo`8000002P3oool2000001X0oooo
0P00000I0?ooo`8000002P3oool2000001@0oooo0P00000;0?ooo`8000004P3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool010000000oooo0?ooo`3oool3000001X0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool05`3oool001/0oooo00<000000?ooo`3oool0103oool200000?`0oooo000K0?ooo`03
0000003oool0oooo00H0oooo1@00003g0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`<00000
m03oool001/0oooo00<000000?ooo`3oool03P3oool300000?40oooo000K0?ooo`8000004P3oool2
00000>l0oooo000K0?ooo`030000003oool0oooo01<0oooo0`00003/0?ooo`006`3oool00`000000
oooo0?ooo`0F0?ooo`D00000i`3oool001/0oooo00<000000?ooo`3oool06`3oool300000>@0oooo
000K0?ooo`030000003oool0oooo01h0oooo0P00003R0?ooo`006`3oool00`000000oooo0?ooo`0P
0?ooo`<00000g`3oool001/0oooo00<000000?ooo`3oool08`3oool200000=d0oooo000K0?ooo`80
00009P3oool300000=X0oooo000K0?ooo`030000003oool0oooo02P0oooo0`00003G0?ooo`006`3o
ool00`000000oooo0?ooo`0[0?ooo`800000e@3oool001/0oooo00<000000?ooo`3oool0;@3oool5
00000=00oooo000K0?ooo`030000003oool0oooo0380oooo0`00003=0?ooo`006`3oool00`000000
oooo0?ooo`0e0?ooo`800000b`3oool001/0oooo00<000000?ooo`3oool0=`3oool300000<P0oooo
000K0?ooo`800000>`3oool300000<D0oooo000K0?ooo`030000003oool0oooo03d0oooo0P000033
0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`<00000`03oool001/0oooo00<000000?ooo`3o
ool0@P3oool200000;h0oooo00080?ooo`800000103oool2000000<0oooo100000040?ooo`030000
003oool0oooo04@0oooo0`00002k0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0A`3oool300000;P0oooo00070?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000004/0oooo0P00002f0?ooo`001`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
C03oool300000;<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1?0?ooo`800000/@3oool000P0oooo0P00000:0?ooo`800000
1@3oool00`000000oooo0?ooo`1A0?ooo`<00000[P3oool001/0oooo00<000000?ooo`3oool0E03o
ool300000:/0oooo000K0?ooo`030000003oool0oooo05L0oooo0P00002Y0?ooo`006`3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0:H0oooo000K0?ooo`800000F`3oool200000:H0
oooo000K0?ooo`030000003oool0oooo05`0oooo0P00002T0?ooo`006`3oool00`000000oooo0?oo
o`1N0?ooo`<00000X@3oool001/0oooo00<000000?ooo`3oool0H@3oool3000009h0oooo000K0?oo
o`030000003oool0oooo06@0oooo0P00002L0?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`<0
0000V@3oool001/0oooo00<000000?ooo`3oool0J@3oool2000009L0oooo000K0?ooo`800000K03o
ool2000009D0oooo000K0?ooo`030000003oool0oooo06d0oooo0P00002C0?ooo`006`3oool00`00
0000oooo0?ooo`1_0?ooo`800000T@3oool001/0oooo00<000000?ooo`3oool0L@3oool2000008l0
oooo000K0?ooo`030000003oool0oooo07<0oooo0`00002<0?ooo`006`3oool00`000000oooo0?oo
o`1f0?ooo`800000RP3oool001/0oooo0P00001i0?ooo`800000R03oool001/0oooo00<000000?oo
o`3oool0NP3oool2000008H0oooo000K0?ooo`030000003oool0oooo07`0oooo0P0000240?ooo`00
6`3oool00`000000oooo0?ooo`1n0?ooo`800000PP3oool001/0oooo00<000000?ooo`3oool0P03o
ool3000007l0oooo00080?ooo`800000103oool2000000D0oooo0`0000030?ooo`030000003oool0
oooo08<0oooo0P00001m0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1j0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`D000000`3oool2000008L0oooo0P00001j0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0R03o
ool3000007L0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`2;0?ooo`800000M@3oool000P0oooo0P00000;0?ooo`800000103oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0780oooo000K0?ooo`030000003oool0oooo
08h0oooo0P00001b0?ooo`006`3oool00`000000oooo0?ooo`2@0?ooo`800000L03oool001/0oooo
00<000000?ooo`3oool0TP3oool2000006h0oooo000K0?ooo`800000U@3oool2000006`0oooo000K
0?ooo`030000003oool0oooo09H0oooo0P00001Z0?ooo`006`3oool00`000000oooo0?ooo`2H0?oo
o`800000J03oool001/0oooo00<000000?ooo`3oool0VP3oool2000006H0oooo000K0?ooo`030000
003oool0oooo09`0oooo0P00001T0?ooo`006`3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo0640oooo000K0?ooo`800000X03oool200000640oooo000K0?ooo`030000003oool0oooo
0:40oooo0P00001O0?ooo`006`3oool00`000000oooo0?ooo`2S0?ooo`800000G@3oool001/0oooo
00<000000?ooo`3oool0Y@3oool2000005/0oooo000K0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool0F03oool001/0oooo00<000000?ooo`3oool0Z03oool2000005P0oooo000K0?oo
o`030000003oool0oooo0:X0oooo0P00001F0?ooo`006`3oool200000:d0oooo00<000000?ooo`3o
ool0D`3oool001/0oooo00<000000?ooo`3oool0[@3oool2000005<0oooo000K0?ooo`030000003o
ool0oooo0:l0oooo0P00001A0?ooo`006`3oool00`000000oooo0?ooo`2a0?ooo`800000C`3oool0
01/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`1<0?ooo`00203oool2000000@0
oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`2d0?ooo`800000C03oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0;H0oooo0P00001:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo0P00002i0?ooo`030000003oool0oooo04L0oooo00070?ooo`040000003oool0oooo
000000P0oooo0`0000050?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0AP3oool0
00L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;X0oooo0P0000160?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo
0;`0oooo0P0000140?ooo`006`3oool00`000000oooo0?ooo`2n0?ooo`800000@P3oool001/0oooo
00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0o0?ooo`006`3oool200000<80oooo0P00
000o0?ooo`006`3oool00`000000oooo0?ooo`330?ooo`800000?@3oool001/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0j0?ooo`006`3oool00`000000oooo0?ooo`360?ooo`03
0000003oool0oooo03T0oooo000K0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
>03oool001/0oooo00<000000?ooo`3oool0b03oool2000003P0oooo000K0?ooo`030000003oool0
oooo0<X0oooo0P00000f0?ooo`006`3oool200000<d0oooo0P00000d0?ooo`006`3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo0340oooo000K0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool0<03oool001/0oooo00<000000?ooo`3oool0d03oool200000300oooo000K
0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?oo
o`3oool0d`3oool00`000000oooo0?ooo`0/0?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`03
0000003oool0oooo02/0oooo000K0?ooo`800000eP3oool2000002/0oooo000K0?ooo`030000003o
ool0oooo0=L0oooo0P00000Y0?ooo`006`3oool00`000000oooo0?ooo`3I0?ooo`8000009`3oool0
01/0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0T0?ooo`006`3oool00`000000
oooo0?ooo`3L0?ooo`030000003oool0oooo02<0oooo00080?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0=d0oooo0P00000S0?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0g`3oool00`000000
oooo0?ooo`0P0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo0P00003Q0?ooo`030000003oool0oooo01l0oooo00070?ooo`040000003oool0oooo0000
00T0oooo0P0000050?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool07P3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0>80oooo0P00000N0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo
0>@0oooo00<000000?ooo`3oool06`3oool001/0oooo00<000000?ooo`3oool0i@3oool2000001/0
oooo000K0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0603oool001/0oooo0P00
003Y0?ooo`030000003oool0oooo01L0oooo000K0?ooo`030000003oool0oooo0>T0oooo00<00000
0?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0jP3oool2000001H0oooo000K0?ooo`03
0000003oool0oooo0>`0oooo00<000000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0
k@3oool00`000000oooo0?ooo`0B0?ooo`006`3oool00`000000oooo0?ooo`3^0?ooo`030000003o
ool0oooo0140oooo000K0?ooo`030000003oool0oooo0>l0oooo0P00000A0?ooo`006`3oool20000
0?80oooo00<000000?ooo`3oool03P3oool001/0oooo00<000000?ooo`3oool0lP3oool2000000h0
oooo000K0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool0m@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`3f
0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0?L0oooo00<000000?oo
o`3oool0203oool001/0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`070?ooo`00
6`3oool200000?X0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool0nP3o
ool00`000000oooo0?ooo`050?ooo`006`3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0
oooo00@0oooo000K0?ooo`030000003oool0oooo0?`0oooo0P0000040?ooo`004`3oool5000000<0
oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0oooo0P0000010?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`800000o`3oool30?ooo`400000000E0?ooo`030000003oool0oooo0?l0oooo2@3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool200000?l0oooo2`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162091, -0.261311, \
0.0059487, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.103006 0.515028 [
[.12943 .09051 -9 -9 ]
[.12943 .09051 9 0 ]
[.25887 .09051 -9 -9 ]
[.25887 .09051 9 0 ]
[.3883 .09051 -9 -9 ]
[.3883 .09051 9 0 ]
[.51774 .09051 -9 -9 ]
[.51774 .09051 9 0 ]
[.64717 .09051 -3 -9 ]
[.64717 .09051 3 0 ]
[.77661 .09051 -9 -9 ]
[.77661 .09051 9 0 ]
[.90604 .09051 -9 -9 ]
[.90604 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .10301 m
.12943 .10926 L
s
[(0.2)] .12943 .09051 0 1 Mshowa
.25887 .10301 m
.25887 .10926 L
s
[(0.4)] .25887 .09051 0 1 Mshowa
.3883 .10301 m
.3883 .10926 L
s
[(0.6)] .3883 .09051 0 1 Mshowa
.51774 .10301 m
.51774 .10926 L
s
[(0.8)] .51774 .09051 0 1 Mshowa
.64717 .10301 m
.64717 .10926 L
s
[(1)] .64717 .09051 0 1 Mshowa
.77661 .10301 m
.77661 .10926 L
s
[(1.2)] .77661 .09051 0 1 Mshowa
.90604 .10301 m
.90604 .10926 L
s
[(1.4)] .90604 .09051 0 1 Mshowa
.125 Mabswid
.03236 .10301 m
.03236 .10676 L
s
.06472 .10301 m
.06472 .10676 L
s
.09708 .10301 m
.09708 .10676 L
s
.16179 .10301 m
.16179 .10676 L
s
.19415 .10301 m
.19415 .10676 L
s
.22651 .10301 m
.22651 .10676 L
s
.29123 .10301 m
.29123 .10676 L
s
.32359 .10301 m
.32359 .10676 L
s
.35595 .10301 m
.35595 .10676 L
s
.42066 .10301 m
.42066 .10676 L
s
.45302 .10301 m
.45302 .10676 L
s
.48538 .10301 m
.48538 .10676 L
s
.5501 .10301 m
.5501 .10676 L
s
.58246 .10301 m
.58246 .10676 L
s
.61482 .10301 m
.61482 .10676 L
s
.67953 .10301 m
.67953 .10676 L
s
.71189 .10301 m
.71189 .10676 L
s
.74425 .10301 m
.74425 .10676 L
s
.80897 .10301 m
.80897 .10676 L
s
.84133 .10301 m
.84133 .10676 L
s
.87369 .10301 m
.87369 .10676 L
s
.9384 .10301 m
.9384 .10676 L
s
.97076 .10301 m
.97076 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01 .08477 L
.02 .07844 L
.03 .07283 L
.04 .07009 L
.05 .06836 L
.06 .06757 L
.07 .06794 L
.08 .07095 L
.09 .07344 L
.1 .08102 L
.11 .08842 L
.12 .09685 L
.13 .10165 L
.14 .10336 L
.15 .10699 L
.16 .10983 L
.17 .11277 L
.18 .11458 L
.19 .11944 L
.2 .11898 L
.21 .12472 L
.22 .12832 L
.23 .12957 L
.24 .13444 L
.25 .13501 L
.26 .13687 L
.27 .14295 L
.28 .14656 L
.29 .1486 L
.3 .14885 L
.31 .15511 L
.32 .1585 L
.33 .16338 L
.34 .1681 L
.35 .17016 L
.36 .1711 L
.37 .17688 L
.38 .18076 L
.39 .18645 L
.4 .18626 L
.41 .19099 L
.42 .19475 L
.43 .20156 L
.44 .19847 L
.45 .20635 L
.46 .20592 L
.47 .21159 L
.48 .22014 L
.49 .22385 L
Mistroke
.5 .22567 L
.51 .22901 L
.52 .23577 L
.53 .23558 L
.54 .24407 L
.55 .24953 L
.56 .25035 L
.57 .25674 L
.58 .26383 L
.59 .26517 L
.6 .27541 L
.61 .2787 L
.62 .28091 L
.63 .29286 L
.64 .29319 L
.65 .29576 L
.66 .29627 L
.67 .3137 L
.68 .31394 L
.69 .31397 L
.7 .32668 L
.71 .32784 L
.72 .33831 L
.73 .34534 L
.74 .35118 L
.75 .3526 L
.76 .36666 L
.77 .37234 L
.78 .37849 L
.79 .37651 L
.8 .38323 L
.81 .38718 L
.82 .39494 L
.83 .40134 L
.84 .40528 L
.85 .40546 L
.86 .41836 L
.87 .42237 L
.88 .42896 L
.89 .43304 L
.9 .43838 L
.91 .4359 L
.92 .43534 L
.93 .4568 L
.94 .44781 L
.95 .44453 L
.96 .43281 L
.97 .45114 L
.98 .44258 L
.99 .31096 L
Mistroke
Mfstroke
.99 .31096 m
.99406 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`4000000@3oool10?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool100000040oooo0@3oool0
00P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`4000000@3oool10?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0@000001
0?ooo`40oooo000K0?ooo`030000003oool0oooo0?l0oooo0@0000010?ooo`40oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0@000001
0?ooo`40oooo000K0?ooo`800000o`3oool10?ooo`4000000@3oool10?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`800000
0`3oool4000001<0oooo0P0000040?ooo`8000001@3oool300000180oooo0P0000040?ooo`800000
0`3oool3000001<0oooo0P0000040?ooo`800000103oool2000001T0oooo1@00000F0?ooo`D00000
0P3oool2000000<0oooo1000000B0?ooo`D000000P3oool2000000D0oooo0`00000A0?ooo`006`3o
ool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
4`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000006P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo
000K0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000140oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo1@00000>0?ooo`400000
0@3oool10?ooo`006`3oool00`000000oooo0?ooo`070?ooo`<00000203oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`000008
0?ooo`<000004P3oool010000000oooo0?ooo`0000090?ooo`8000006`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000l0oooo0@0000010?ooo`40oooo000K0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool000000180oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0A
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`080?ooo`030000003oool000000180oooo000K0?ooo`800000103oool00`000000oooo
0?ooo`0@0?ooo`<000002P3oool2000001@0oooo0P00000;0?ooo`8000004`3oool2000000X0oooo
0`00000B0?ooo`8000002P3oool2000001X0oooo0P00000I0?ooo`8000002P3oool2000001@0oooo
0P00000;0?ooo`8000004P3oool001/0oooo00@000000?ooo`3oool000005P3oool00`000000oooo
0?ooo`3X0?ooo`006`3oool00`000000oooo0000003o0?ooo`4000000@3oool10?ooo`006`3oool0
0`000000oooo0000003o0?ooo`4000000@3oool10?ooo`006`3oool00`000000oooo0?ooo`0J0?oo
o`800000iP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`0O0?ooo`800000h@3oool001/0ooooo`000006000000006`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00<0oooo0P00000J0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool10?ooo`006`3oool00`00
0000oooo0?ooo`0Y0?ooo`800000e03oool100000040oooo0@3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`800000dP3oool001/0oooo00<0
00000?ooo`3oool0<`3oool200000<d0oooo000K0?ooo`800000>03oool200000<H0oooo0@000001
0?ooo`40oooo000K0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000``3oool001/0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2n0?ooo`006`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0;d0oooo000K0?ooo`030000003oool0oooo04H0oooo0P00002f
0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo04/0oooo0P00002a0?oo
o`030000003oool0oooo0040oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0:l0oooo000K0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0[P3oool001/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo05H0oooo00D000000?oo
o`3oool0oooo0000002S0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0Y03oool001/0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`2Q0?ooo`006`3oool200000600oooo00<000000?ooo`3oool0X03oool001/0oooo00<0
00000?ooo`3oool0H`3oool2000009T0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0oP3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1X0?oo
o`800000V03oool000P0oooo0P0000040?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0K03oool3000009<0oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool200000780oooo0P00002;0?ooo`030000003oool0oooo0040
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00@3oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`010?ooo`00203oool2000000X0
oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`250?ooo`006`3oool00`000000oooo0?ooo`1k0?ooo`<00000P03o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000230?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0Q@3oool3000007X0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`2:0?ooo`800000LP3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`1_0?ooo`00
6`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0T`3oool2000006d0oooo000K
0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0I`3oool001/0oooo00<000000?ooo`3oool0
W03oool00`000000oooo0?ooo`1S0?ooo`006`3oool2000009h0oooo00<000000?ooo`3oool0HP3o
ool001/0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`010?ooo`006`3oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0X03oool2000000<0oooo00<000000?ooo`3oool0FP3oool001/0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1I0?ooo`00203oool2000000@0oooo0P00
00050?ooo`<000000`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo05H0oooo0007
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00@3oool000L0oooo00@00000
0?ooo`3oool00000203oool5000000<0oooo0P00003o0?ooo`030000003oool0oooo0040oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`2/0?ooo`<00000C`3oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203o
ool2000000/0oooo0P0000040?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0CP3o
ool001/0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0040oooo000K0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo04T0
oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0;T0oooo0P0000120?ooo`030000003oool0oooo0080oooo000K0?oo
o`030000003oool0oooo0?d0oooo00<000000?ooo`3oool00P3oool001/0oooo00<000000?ooo`3o
ool0_P3oool200000480oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool00P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo03X0oooo000K0?ooo`030000003o
ool0oooo0<H0oooo0P0000020?ooo`800000=P3oool001/0oooo00<000000?ooo`3oool0o03oool0
0`000000oooo0?ooo`030?ooo`006`3oool200000=00oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo02`0oooo000K0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool0:`3oool000P0oooo0P0000040?ooo`8000000`3oool30000
00D0oooo00<000000?ooo`3oool0f03oool200000280oooo00<000000?ooo`3oool00`3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?`0oooo00<000000?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`800000o`3oool40?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`<000001@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo02<0oooo0007
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo0280oooo00080?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool0h03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0>40oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000iP3oool2000000<0oooo
0P0000090?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo0?@0oooo00@0
00000?ooo`3oool000002P3oool001/0oooo00<000000?ooo`3oool0n03oool010000000oooo0?oo
o`0000060?ooo`006`3oool00`000000oooo0?ooo`3]0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`050?ooo`006`3oool00`000000oooo0?ooo`3^0?ooo`030000003o
ool000000140oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo0P00003o0?ooo`@0oooo00070?ooo`040000
003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0?l0oooo0`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<00000
0?ooo`3oool00`3oool200000?l0oooo103oool001D0oooo00<000000?ooo`3oool0o`3oool90?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`800000o`3oool;0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162091, -0.261311, \
0.0059487, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.103006 0.515028 [
[.12943 .09051 -9 -9 ]
[.12943 .09051 9 0 ]
[.25887 .09051 -9 -9 ]
[.25887 .09051 9 0 ]
[.3883 .09051 -9 -9 ]
[.3883 .09051 9 0 ]
[.51774 .09051 -9 -9 ]
[.51774 .09051 9 0 ]
[.64717 .09051 -3 -9 ]
[.64717 .09051 3 0 ]
[.77661 .09051 -9 -9 ]
[.77661 .09051 9 0 ]
[.90604 .09051 -9 -9 ]
[.90604 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .10301 m
.12943 .10926 L
s
[(0.2)] .12943 .09051 0 1 Mshowa
.25887 .10301 m
.25887 .10926 L
s
[(0.4)] .25887 .09051 0 1 Mshowa
.3883 .10301 m
.3883 .10926 L
s
[(0.6)] .3883 .09051 0 1 Mshowa
.51774 .10301 m
.51774 .10926 L
s
[(0.8)] .51774 .09051 0 1 Mshowa
.64717 .10301 m
.64717 .10926 L
s
[(1)] .64717 .09051 0 1 Mshowa
.77661 .10301 m
.77661 .10926 L
s
[(1.2)] .77661 .09051 0 1 Mshowa
.90604 .10301 m
.90604 .10926 L
s
[(1.4)] .90604 .09051 0 1 Mshowa
.125 Mabswid
.03236 .10301 m
.03236 .10676 L
s
.06472 .10301 m
.06472 .10676 L
s
.09708 .10301 m
.09708 .10676 L
s
.16179 .10301 m
.16179 .10676 L
s
.19415 .10301 m
.19415 .10676 L
s
.22651 .10301 m
.22651 .10676 L
s
.29123 .10301 m
.29123 .10676 L
s
.32359 .10301 m
.32359 .10676 L
s
.35595 .10301 m
.35595 .10676 L
s
.42066 .10301 m
.42066 .10676 L
s
.45302 .10301 m
.45302 .10676 L
s
.48538 .10301 m
.48538 .10676 L
s
.5501 .10301 m
.5501 .10676 L
s
.58246 .10301 m
.58246 .10676 L
s
.61482 .10301 m
.61482 .10676 L
s
.67953 .10301 m
.67953 .10676 L
s
.71189 .10301 m
.71189 .10676 L
s
.74425 .10301 m
.74425 .10676 L
s
.80897 .10301 m
.80897 .10676 L
s
.84133 .10301 m
.84133 .10676 L
s
.87369 .10301 m
.87369 .10676 L
s
.9384 .10301 m
.9384 .10676 L
s
.97076 .10301 m
.97076 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01 .09728 L
.02 .0912 L
.03 .08722 L
.04 .08386 L
.05 .08203 L
.06 .08131 L
.07 .08104 L
.08 .08272 L
.09 .08699 L
.1 .09427 L
.11 .10621 L
.12 .11627 L
.13 .1215 L
.14 .12716 L
.15 .1306 L
.16 .13613 L
.17 .13989 L
.18 .14623 L
.19 .15164 L
.2 .1541 L
.21 .16107 L
.22 .1632 L
.23 .16846 L
.24 .17317 L
.25 .17746 L
.26 .182 L
.27 .18686 L
.28 .1944 L
.29 .19778 L
.3 .20125 L
.31 .20579 L
.32 .21427 L
.33 .21649 L
.34 .219 L
.35 .22596 L
.36 .23311 L
.37 .23434 L
.38 .23908 L
.39 .24567 L
.4 .24701 L
.41 .25468 L
.42 .26024 L
.43 .26459 L
.44 .27326 L
.45 .27642 L
.46 .27759 L
.47 .28345 L
.48 .28648 L
.49 .29471 L
Mistroke
.5 .2979 L
.51 .30306 L
.52 .30952 L
.53 .32148 L
.54 .3177 L
.55 .3277 L
.56 .33359 L
.57 .33827 L
.58 .34198 L
.59 .3488 L
.6 .35449 L
.61 .35689 L
.62 .36608 L
.63 .36739 L
.64 .37524 L
.65 .37818 L
.66 .38475 L
.67 .39137 L
.68 .39561 L
.69 .4055 L
.7 .40744 L
.71 .41141 L
.72 .42197 L
.73 .42563 L
.74 .43459 L
.75 .43876 L
.76 .44327 L
.77 .44809 L
.78 .4546 L
.79 .46119 L
.8 .46835 L
.81 .47822 L
.82 .47949 L
.83 .48334 L
.84 .49566 L
.85 .5036 L
.86 .50587 L
.87 .51361 L
.88 .52275 L
.89 .52447 L
.9 .53102 L
.91 .53879 L
.92 .54498 L
.93 .54952 L
.94 .55742 L
.95 .56772 L
.96 .56834 L
.97 .57649 L
.98 .58104 L
.99 .58979 L
Mistroke
1 .59305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`8000000`3oool4000001<0oooo
0P0000040?ooo`8000001@3oool300000180oooo0P0000040?ooo`8000000`3oool3000001<0oooo
0P0000040?ooo`800000103oool2000001T0oooo1@00000F0?ooo`D000000P3oool2000000<0oooo
1000000B0?ooo`D000000P3oool2000000D0oooo0`00000A0?ooo`006`3oool00`000000oooo0?oo
o`0F0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003o
ool0oooo01H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0B0?ooo`040000
003oool0oooo000000P0oooo1@00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000004@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01`3oool500000140oooo000K0?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`<000004P3oool0
10000000oooo0?ooo`0000090?ooo`8000006`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo00000180oooo000K0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000B0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000004P3oool001/0oooo0P00000H0?ooo`8000002P3oool2000001@0oooo
0P00000;0?ooo`8000004`3oool2000000X0oooo0`00000B0?ooo`8000002P3oool2000001X0oooo
0P00000I0?ooo`8000002P3oool2000001@0oooo0P00000;0?ooo`8000004P3oool001/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool0k@3o
ool001/0oooo00<000000?ooo`3oool01`3oool2000000X0oooo00<000000?ooo`3oool0k03oool0
01/0oooo00<000000?ooo`3oool00P3oool300000?d0oooo000K0?ooo`030000003oool0oooo01H0
oooo0P00003Z0?ooo`006`3oool00`000000oooo0000000G0?ooo`030000003oool0oooo0>P0oooo
000K0?ooo`800000o`3oool40?ooo`006`3ooooo000000H00000000K0?ooo`030000003oool0oooo
01X0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0>@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool07P3oool200000>80oooo000K0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0h03oool001/0oooo0P00000S0?ooo`030000003oool0oooo0=d0oooo000K0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0g03oool001/0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`3H0?ooo`006`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0=L0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0;03oool200000=@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo0P00000a0?ooo`800000d03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`0e0?ooo`800000b`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0<D0oooo000K0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0a03oool001/0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`310?ooo`006`3oool200000400oooo0P0000310?ooo`006`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo0;`0oooo000K0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0^`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`170?ooo`<00000
^03oool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`040?ooo`800000C@3oool200000;@0oooo00070?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0D@3oool200000:l0oooo
000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0Z@3oool001/0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`2X0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`800000F`3oool200000:H0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0G`3oool200000:40oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0H`3oool3000009`0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`2G0?ooo`006`3oool2000006X0oooo00<000000?ooo`3oool0UP3oool001/0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`2C0?ooo`006`3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo0980oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2>0?ooo`006`3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo08d0oooo000K0?ooo`800000M`3oool2000008X0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`250?ooo`006`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo08@0oooo
000K0?ooo`030000003oool0oooo07h0oooo0P0000220?ooo`00203oool2000000@0oooo0P000005
0?ooo`<000000`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo07`0oooo00070?ooo`040000003oool0oooo000000P0oooo1@0000030?ooo`800000Q@3oool0
0`000000oooo0?ooo`1k0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2
000000/0oooo0P0000040?ooo`030000003oool0oooo08H0oooo0P00001j0?ooo`006`3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo07D0oooo000K0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0M03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool200000900oooo0P00001a0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo09<0oooo0`00001/0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0I`3oool001/0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`1V0?ooo`006`3oool200000?l0oooo103oool0
01/0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`1S0?ooo`006`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo0680oooo000K0?ooo`030000003oool0oooo0:40oooo
0P00001O0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`1H0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
ZP3oool2000005H0oooo000K0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0E03o
ool001/0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1A0?ooo`006`3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo0500oooo00080?ooo`800000103oool2000000<0
oooo0`0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0;<0oooo0P00001=0?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00003o
0?ooo`@0oooo00070?ooo`040000003oool0oooo000000P0oooo0`0000050?ooo`030000003oool0
oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0;L0oooo0P0000190?ooo`00203oool2000000X0oooo0`0000040?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`140?ooo`006`3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo04<0oooo
000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`300?ooo`800000@03oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`340?ooo`80
0000?03oool001/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0j0?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool0=P3oool001/0oooo0P00003;0?ooo`030000003oool0oooo03D0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`0b0?ooo`006`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0340oooo000K
0?ooo`030000003oool0oooo0=40oooo0P00000_0?ooo`006`3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
0P00003G0?ooo`030000003oool0oooo02T0oooo000K0?ooo`030000003oool0oooo0=H0oooo00<0
00000?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3I0?ooo`030000003oool0oooo02H0oooo000K0?ooo`030000003oool0oooo0=X0
oooo00<000000?ooo`3oool09@3oool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0gP3oool200000280oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool200000?l0oooo103oool000L0
oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0hP3oool2000001h0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo01P0
oooo000K0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0>/0oooo0P00000E0?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3o
ool0403oool001/0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`0?0?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo0P00003d0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3h0?ooo`030000003oool0oooo00L0oooo000K0?ooo`030000003o
ool0oooo0?T0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool0o03oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo
0080oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`80oooo
0P00000001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001<0oooo1@0000030?ooo`03
0000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo0P00003o0?ooo`@0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?oo
o`00503oool200000?l0oooo2`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162091, -0.261311, \
0.0059487, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.103006 0.515028 [
[.12943 .09051 -9 -9 ]
[.12943 .09051 9 0 ]
[.25887 .09051 -9 -9 ]
[.25887 .09051 9 0 ]
[.3883 .09051 -9 -9 ]
[.3883 .09051 9 0 ]
[.51774 .09051 -9 -9 ]
[.51774 .09051 9 0 ]
[.64717 .09051 -3 -9 ]
[.64717 .09051 3 0 ]
[.77661 .09051 -9 -9 ]
[.77661 .09051 9 0 ]
[.90604 .09051 -9 -9 ]
[.90604 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .10301 m
.12943 .10926 L
s
[(0.2)] .12943 .09051 0 1 Mshowa
.25887 .10301 m
.25887 .10926 L
s
[(0.4)] .25887 .09051 0 1 Mshowa
.3883 .10301 m
.3883 .10926 L
s
[(0.6)] .3883 .09051 0 1 Mshowa
.51774 .10301 m
.51774 .10926 L
s
[(0.8)] .51774 .09051 0 1 Mshowa
.64717 .10301 m
.64717 .10926 L
s
[(1)] .64717 .09051 0 1 Mshowa
.77661 .10301 m
.77661 .10926 L
s
[(1.2)] .77661 .09051 0 1 Mshowa
.90604 .10301 m
.90604 .10926 L
s
[(1.4)] .90604 .09051 0 1 Mshowa
.125 Mabswid
.03236 .10301 m
.03236 .10676 L
s
.06472 .10301 m
.06472 .10676 L
s
.09708 .10301 m
.09708 .10676 L
s
.16179 .10301 m
.16179 .10676 L
s
.19415 .10301 m
.19415 .10676 L
s
.22651 .10301 m
.22651 .10676 L
s
.29123 .10301 m
.29123 .10676 L
s
.32359 .10301 m
.32359 .10676 L
s
.35595 .10301 m
.35595 .10676 L
s
.42066 .10301 m
.42066 .10676 L
s
.45302 .10301 m
.45302 .10676 L
s
.48538 .10301 m
.48538 .10676 L
s
.5501 .10301 m
.5501 .10676 L
s
.58246 .10301 m
.58246 .10676 L
s
.61482 .10301 m
.61482 .10676 L
s
.67953 .10301 m
.67953 .10676 L
s
.71189 .10301 m
.71189 .10676 L
s
.74425 .10301 m
.74425 .10676 L
s
.80897 .10301 m
.80897 .10676 L
s
.84133 .10301 m
.84133 .10676 L
s
.87369 .10301 m
.87369 .10676 L
s
.9384 .10301 m
.9384 .10676 L
s
.97076 .10301 m
.97076 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .103 m
.01 .09094 L
.02 .08485 L
.03 .08025 L
.04 .07726 L
.05 .07517 L
.06 .07422 L
.07 .07485 L
.08 .07681 L
.09 .08056 L
.1 .08722 L
.11 .09675 L
.12 .10587 L
.13 .11104 L
.14 .11492 L
.15 .11889 L
.16 .12297 L
.17 .12686 L
.18 .13026 L
.19 .13562 L
.2 .1377 L
.21 .14254 L
.22 .14603 L
.23 .14942 L
.24 .15393 L
.25 .15749 L
.26 .16202 L
.27 .16561 L
.28 .16958 L
.29 .17413 L
.3 .17587 L
.31 .18176 L
.32 .1857 L
.33 .19 L
.34 .19434 L
.35 .19895 L
.36 .20303 L
.37 .20578 L
.38 .21102 L
.39 .21548 L
.4 .21862 L
.41 .2235 L
.42 .22949 L
.43 .23321 L
.44 .23651 L
.45 .24215 L
.46 .24609 L
.47 .25216 L
.48 .2564 L
.49 .25991 L
Mistroke
.5 .263 L
.51 .27041 L
.52 .27443 L
.53 .27973 L
.54 .28466 L
.55 .28929 L
.56 .29332 L
.57 .29927 L
.58 .30465 L
.59 .30924 L
.6 .31717 L
.61 .32066 L
.62 .32515 L
.63 .33119 L
.64 .33521 L
.65 .33969 L
.66 .34515 L
.67 .35345 L
.68 .35956 L
.69 .3646 L
.7 .36909 L
.71 .37321 L
.72 .38288 L
.73 .38723 L
.74 .3944 L
.75 .39979 L
.76 .40733 L
.77 .41078 L
.78 .41869 L
.79 .42256 L
.8 .43045 L
.81 .43822 L
.82 .44282 L
.83 .44753 L
.84 .45506 L
.85 .46185 L
.86 .46827 L
.87 .47308 L
.88 .48216 L
.89 .48458 L
.9 .49076 L
.91 .49843 L
.92 .50252 L
.93 .51069 L
.94 .51393 L
.95 .51148 L
.96 .52171 L
Mfstroke
.96 .52171 m
.96 0 L
s
.003 w
[ ] 0 setdash
0 .10301 m
.01 .106 L
.02 .10903 L
.03 .11208 L
.04 .11515 L
.05 .11826 L
.06 .12139 L
.07 .12455 L
.08 .12774 L
.09 .13095 L
.1 .1342 L
.11 .13748 L
.12 .14078 L
.13 .14412 L
.14 .14748 L
.15 .15088 L
.16 .1543 L
.17 .15776 L
.18 .16126 L
.19 .16478 L
.2 .16834 L
.21 .17193 L
.22 .17555 L
.23 .17921 L
.24 .1829 L
.25 .18663 L
.26 .1904 L
.27 .1942 L
.28 .19803 L
.29 .20191 L
.3 .20582 L
.31 .20977 L
.32 .21376 L
.33 .21779 L
.34 .22185 L
.35 .22596 L
.36 .23011 L
.37 .2343 L
.38 .23853 L
.39 .24281 L
.4 .24713 L
.41 .25149 L
.42 .2559 L
.43 .26035 L
.44 .26485 L
.45 .26939 L
.46 .27399 L
.47 .27863 L
.48 .28331 L
.49 .28805 L
Mistroke
.5 .29284 L
.51 .29768 L
.52 .30257 L
.53 .30751 L
.54 .31251 L
.55 .31756 L
.56 .32266 L
.57 .32783 L
.58 .33304 L
.59 .33832 L
.6 .34365 L
.61 .34904 L
.62 .3545 L
.63 .36001 L
.64 .36559 L
.65 .37122 L
.66 .37693 L
.67 .3827 L
.68 .38853 L
.69 .39443 L
.7 .4004 L
.71 .40644 L
.72 .41255 L
.73 .41874 L
.74 .42499 L
.75 .43132 L
.76 .43773 L
.77 .44421 L
.78 .45077 L
.79 .45741 L
.8 .46414 L
.81 .47094 L
.82 .47783 L
.83 .4848 L
.84 .49186 L
.85 .49901 L
.86 .50625 L
.87 .51358 L
.88 .521 L
.89 .52852 L
.9 .53614 L
.91 .54385 L
.92 .55167 L
.93 .55958 L
.94 .56761 L
.95 .57573 L
.96 .58397 L
.97 .59231 L
.98 .60077 L
.99 .60934 L
Mistroke
1 .61803 L
Mfstroke
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01 .08477 L
.02 .07844 L
.03 .07283 L
.04 .07009 L
.05 .06836 L
.06 .06757 L
.07 .06794 L
.08 .07095 L
.09 .07344 L
.1 .08102 L
.11 .08842 L
.12 .09685 L
.13 .10165 L
.14 .10336 L
.15 .10699 L
.16 .10983 L
.17 .11277 L
.18 .11458 L
.19 .11944 L
.2 .11898 L
.21 .12472 L
.22 .12832 L
.23 .12957 L
.24 .13444 L
.25 .13501 L
.26 .13687 L
.27 .14295 L
.28 .14656 L
.29 .1486 L
.3 .14885 L
.31 .15511 L
.32 .1585 L
.33 .16338 L
.34 .1681 L
.35 .17016 L
.36 .1711 L
.37 .17688 L
.38 .18076 L
.39 .18645 L
.4 .18626 L
.41 .19099 L
.42 .19475 L
.43 .20156 L
.44 .19847 L
.45 .20635 L
.46 .20592 L
.47 .21159 L
.48 .22014 L
.49 .22385 L
Mistroke
.5 .22567 L
.51 .22901 L
.52 .23577 L
.53 .23558 L
.54 .24407 L
.55 .24953 L
.56 .25035 L
.57 .25674 L
.58 .26383 L
.59 .26517 L
.6 .27541 L
.61 .2787 L
.62 .28091 L
.63 .29286 L
.64 .29319 L
.65 .29576 L
.66 .29627 L
.67 .3137 L
.68 .31394 L
.69 .31397 L
.7 .32668 L
.71 .32784 L
.72 .33831 L
.73 .34534 L
.74 .35118 L
.75 .3526 L
.76 .36666 L
.77 .37234 L
.78 .37849 L
.79 .37651 L
.8 .38323 L
.81 .38718 L
.82 .39494 L
.83 .40134 L
.84 .40528 L
.85 .40546 L
.86 .41836 L
.87 .42237 L
.88 .42896 L
.89 .43304 L
.9 .43838 L
.91 .4359 L
.92 .43534 L
.93 .4568 L
.94 .44781 L
.95 .44453 L
.96 .43281 L
.97 .45114 L
.98 .44258 L
.99 .31096 L
Mistroke
Mfstroke
.99 .31096 m
.99406 0 L
s
0 .10301 m
.01 .09728 L
.02 .0912 L
.03 .08722 L
.04 .08386 L
.05 .08203 L
.06 .08131 L
.07 .08104 L
.08 .08272 L
.09 .08699 L
.1 .09427 L
.11 .10621 L
.12 .11627 L
.13 .1215 L
.14 .12716 L
.15 .1306 L
.16 .13613 L
.17 .13989 L
.18 .14623 L
.19 .15164 L
.2 .1541 L
.21 .16107 L
.22 .1632 L
.23 .16846 L
.24 .17317 L
.25 .17746 L
.26 .182 L
.27 .18686 L
.28 .1944 L
.29 .19778 L
.3 .20125 L
.31 .20579 L
.32 .21427 L
.33 .21649 L
.34 .219 L
.35 .22596 L
.36 .23311 L
.37 .23434 L
.38 .23908 L
.39 .24567 L
.4 .24701 L
.41 .25468 L
.42 .26024 L
.43 .26459 L
.44 .27326 L
.45 .27642 L
.46 .27759 L
.47 .28345 L
.48 .28648 L
.49 .29471 L
Mistroke
.5 .2979 L
.51 .30306 L
.52 .30952 L
.53 .32148 L
.54 .3177 L
.55 .3277 L
.56 .33359 L
.57 .33827 L
.58 .34198 L
.59 .3488 L
.6 .35449 L
.61 .35689 L
.62 .36608 L
.63 .36739 L
.64 .37524 L
.65 .37818 L
.66 .38475 L
.67 .39137 L
.68 .39561 L
.69 .4055 L
.7 .40744 L
.71 .41141 L
.72 .42197 L
.73 .42563 L
.74 .43459 L
.75 .43876 L
.76 .44327 L
.77 .44809 L
.78 .4546 L
.79 .46119 L
.8 .46835 L
.81 .47822 L
.82 .47949 L
.83 .48334 L
.84 .49566 L
.85 .5036 L
.86 .50587 L
.87 .51361 L
.88 .52275 L
.89 .52447 L
.9 .53102 L
.91 .53879 L
.92 .54498 L
.93 .54952 L
.94 .55742 L
.95 .56772 L
.96 .56834 L
.97 .57649 L
.98 .58104 L
.99 .58979 L
Mistroke
1 .59305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`4000000@3oool10?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`06
0?ooo`4000000@3oool10?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo0@0000010?ooo`40oooo000K0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3o
ool02@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?L0oooo00<0
00000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`06
0?ooo`4000000@3oool10?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`4000000@3oool10?oo
o`006`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?oo
o`090?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`4000000@3oool10?ooo`006`3oool20000
0?L0oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool001/0oooo00<000000?ooo`3o
ool0mP3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`800000
103oool2000000<0oooo1000000C0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000
103oool2000000<0oooo0`00000C0?ooo`800000103oool2000000@0oooo0P00000I0?ooo`D00000
5P3oool500000080oooo0P0000030?ooo`@000004P3oool500000080oooo0P0000050?ooo`<00000
4@3oool001/0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo01<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo00d0oooo0P00
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool04P3oool010000000oooo
0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000140oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000J0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00L0oooo1@00000>0?ooo`4000000@3oool10?ooo`006`3oool00`000000oooo0?oo
o`070?ooo`<00000203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000004P3oool010000000oooo0?ooo`0000080?ooo`<000004P3oool010000000oooo0?ooo`00
00090?ooo`8000006`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool01P3oool100000040oooo0@3oool001/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`80000000@0oooo0000003oool000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000004P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000180oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool00000503oool00`000000oooo0?ooo`080?ooo`030000003oool000000180oooo000K0?ooo`80
0000103oool01P000000oooo0?ooo`000000oooo000000P0oooo0P0000030?ooo`<000002P3oool2
000001@0oooo0P00000;0?ooo`8000004`3oool2000000X0oooo0`00000B0?ooo`8000002P3oool2
000001X0oooo0P00000I0?ooo`8000002P3oool2000001@0oooo0P00000;0?ooo`8000004P3oool0
01/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0=`0oooo00<00000
0?ooo`3oool02@3oool001/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`8000002P3oool010000000oooo0?ooo`00003X0?ooo`4000000@3oool10?ooo`006`3oool01@00
0000oooo000000000000oooo00<000004P3oool200000=d0oooo00<000000?ooo`3oool01P3oool1
00000040oooo0@3oool001/0oooo00<000000?ooo`3oool05P3oool200000080oooo0P00003V0?oo
o`006`3oool3000001L0oooo00<000000?ooo`000000g03oool00`000000oooo0?ooo`090?ooo`00
6`3oool2000001`0oooo00@000000?ooo`3oool0oooo0P00003Q0?ooo`006`3ooooo000000H00000
000K0?ooo`040000003oool0oooo0?ooo`<000005P3oool00`000000oooo0?ooo`02000000D0oooo
0P00000J0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo000K0?ooo`030000003o
ool0oooo00@0oooo0P00000E0?ooo`050000003oool0oooo0?ooo`0000002@3oool200000=@0oooo
0@0000010?ooo`40oooo000K0?ooo`030000003oool0oooo00H0oooo1@00000F0?ooo`030000003o
ool000000=80oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool02`3oool3
00000100oooo0P0000030?ooo`030000003oool0000000P0oooo0P00003B0?ooo`006`3oool00`00
0000oooo0?ooo`0>0?ooo`<000003P3oool00`000000oooo0?ooo`050?ooo`8000002P3oool20000
0<40oooo00<000000?ooo`3oool02@3oool001/0oooo0P00000B0?ooo`8000003`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P0000360?ooo`4000000@3oool10?ooo`00
6`3oool00`000000oooo0?ooo`0C0?ooo`<000003@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`0F0?ooo`D00000303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0000000/0oooo0`00002g0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0
oooo01/0oooo0`00000:0?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`030000003oool0
oooo0;h0oooo000K0?ooo`030000003oool0oooo01h0oooo0P00000D0?ooo`800000303oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0200
oooo0`0000090?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`800000]P3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`800000503oool00`000000oooo
0?ooo`0?0?ooo`800000Z@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo
000K0?ooo`8000009P3oool3000000P0oooo0P0000090?ooo`030000003oool0oooo0<@0oooo000K
0?ooo`030000003oool0oooo02P0oooo0`00000B0?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool0[`3oool001/0oooo00<000000?ooo`3oool0:`3oool2000000P0oooo0P0000090?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`090?oo
o`006`3oool00`000000oooo0?ooo`0]0?ooo`D000004P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
<P3oool3000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`000000V`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo03D0oooo0P0000040?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`2T0?ooo`006`3oool00`000000oooo
0?ooo`0g0?ooo`<00000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`090?ooo`006`3oool2000003/0oooo0`00
00020?ooo`800000303oool200000100oooo00<000000?ooo`3oool0X03oool001/0oooo00<00000
0?ooo`3oool0?@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000A
0?ooo`800000V@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0o0?oo
o`<000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:00oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`120?ooo`80
00004@3oool00`000000oooo0?ooo`0@0?ooo`800000V03oool000P0oooo0P0000040?ooo`800000
0`3oool4000000@0oooo00<000000?ooo`3oool0A03oool6000000d0oooo00<000000?ooo`3oool0
W03oool00`000000oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0A`3oool3000000l0oooo00<000000?ooo`3oool0
403oool3000009<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool2000004/0oooo1000000=0?ooo`800000503oool2000008<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool3000000l0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0040oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1?0?ooo`80
00003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool00@3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`1A0?ooo`<00000
3P3oool00`000000oooo0000002A0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003o
ool0oooo05@0oooo0`00000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0Q@3o
ool001/0oooo00<000000?ooo`3oool0E`3oool2000000l0oooo00<000000?ooo`3oool0403oool3
000007P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000F`3oool2000000h0
oooo1000000D0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`8000004@3oool00`000000oooo
0?ooo`0C0?ooo`<00000KP3oool00`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?oo
o`1N0?ooo`<00000403oool00`000000oooo0?ooo`2>0?ooo`006`3oool00`000000oooo0?ooo`1Q
0?ooo`<000003`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00T0oooo000K0?oo
o`030000003oool0oooo06<0oooo0`00000?0?ooo`030000003oool0oooo0180oooo0P00001b0?oo
o`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06H0oooo0`00000>0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06P0oooo0`00000>0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0K`3oool001/0oooo0P00001Z0?ooo`040000003o
ool00000000000h0oooo0P00001i0?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003o
ool0oooo06`0oooo0`00000?0?ooo`030000003oool0oooo0180oooo0P00001Q0?ooo`030000003o
ool0oooo00T0oooo000K0?ooo`030000003oool0oooo06d0oooo00@000000?ooo`00000000003`3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo0740oooo0P00000?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`0000000P00000>0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0I`3oool001/0oooo00<000000?ooo`3oool0LP3oool010000000oooo0?ooo`3oool20000
00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00T0oooo000K0?ooo`800000M`3oool4000000h0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1R0?ooo`006`3oool00`000000oooo0?ooo`1j0?ooo`8000003P3oool2000006X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`1j0?ooo`040000003oool00000000000h0oooo0P00000B0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`1k0?ooo`030000003oool0oooo008000003`3oool00`000000oooo0?ooo`0>0?ooo`8000000`3o
ool00`000000oooo0?ooo`1J0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`D000003P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool02@3oool0
00P0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0P`3oool20000
00`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1F0?ooo`001`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo0000
00P0oooo1@0000030?ooo`800000Q@3oool010000000oooo00000000000=0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo08P0oooo0`00000<0?ooo`030000003o
ool0oooo0180oooo0`0000170?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3o
ool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo08/0oooo0P00000<0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02@3o
ool000P0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`260?ooo`8000001@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0CP3oool0
01/0oooo00<000000?ooo`3oool0RP3oool010000000oooo0?ooo`3oool2000000d0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`020?oo
o`8000003@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0TP3oool2000000d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00T0oooo000K0?ooo`800000
T03oool2000000<0oooo0P00000=0?ooo`030000003oool0oooo05`0oooo000K0?ooo`030000003o
ool0oooo09H0oooo0P00000=0?ooo`800000C`3oool00`000000oooo0?ooo`090?ooo`006`3oool0
0`000000oooo0?ooo`2C0?ooo`<000000P3oool2000000d0oooo0P00000@0?ooo`800000>`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0oooo
09X0oooo0P00000=0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool001/0
oooo00<000000?ooo`3oool0V03oool010000000oooo0?ooo`3oool2000000/0oooo00<000000?oo
o`3oool04P3oool2000003H0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3o
ool0V@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0E03oool001/0oooo0P00002P0?ooo`800000303oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool00P3o
ool2000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0080oooo000K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool2
000000`0oooo0P00000?0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`2Q0?ooo`8000000P3oool20000
00`0oooo0P0000110?ooo`030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool02`3oool2000000h0oooo00<000000?ooo`3oool0>P3oool001/0oooo
00<000000?ooo`3oool0YP3oool010000000oooo00000000000L0?ooo`8000000P3oool2000002X0
oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`02000000/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`030?ooo`006`3o
ool200000:d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`2Z0?ooo`80000000<0oooo000000000000303oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool0Z`3oool010000000oooo0?ooo`3oool2000000`0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
00800000303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool02@3oool001/0oooo00<000000?ooo`3oool0[`3oool01@000000oooo0?ooo`3oool00000
00/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0[0?ooo`00203oool2000000@0
oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`2d0?ooo`8000002`3oool00`000000
oooo0?ooo`0D0?ooo`800000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`2c0?ooo`80000000<0oooo0000000000002`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool200000;T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00T0oooo00070?ooo`040000003oool0oooo000000P0oooo0`000005
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2g0?ooo`80000000<0oooo0000000000003@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool0
00P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`2l0?ooo`8000003@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0080
00002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool0_03oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`006`3oool200000<80oooo
0P00000<0?ooo`030000003oool0oooo01<0oooo0P0000030?ooo`8000002@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`300?ooo`80000000<0oooo0000000000002P3o
ool00`000000oooo0000000R0?ooo`040000003oool00000000000X0oooo000K0?ooo`030000003o
ool0oooo0<D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000T0?ooo`040000003o
ool0oooo000000H0oooo000K0?ooo`030000003oool0oooo0<@0oooo0`00000<0?ooo`030000003o
ool0oooo01L0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
00001`3oool001/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0000000=0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`090?ooo`006`3o
ool00`000000oooo0?ooo`380?ooo`8000003@3oool00`000000oooo0?ooo`0X0?ooo`006`3oool0
0`000000oooo0?ooo`390?ooo`<000003@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00T0oooo000K0?ooo`800000b`3oool010000000oooo00000000000d0?ooo`006`3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0000000d0
oooo00<000000?ooo`3oool08P3oool001/0oooo00<000000?ooo`3oool0cP3oool010000000oooo
00000000000=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool001/0oooo
00<000000?ooo`3oool0d@3oool2000000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`3B0?ooo`8000003@3oool00`000000oooo0000
000N0?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`006`3oool200000=H0oooo0P00000@0?oo
o`030000003oool0oooo01P0oooo000K0?ooo`030000003oool0oooo0=H0oooo0`00000>0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool001/0oooo00<000000?ooo`3oool0
f@3oool2000000h0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool001/0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0000000@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool000P0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0g@3oool2000000l0oooo00<000000?ooo`3oool04@3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0=h0oooo0P00000?0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`090?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
0P00003Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool000L0oooo00@0
00000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0h@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3R0?ooo`8000007P3oool000P0oooo
0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo01/0oooo
000K0?ooo`030000003oool0oooo0>D0oooo0`00000J0?ooo`006`3oool00`000000oooo0?ooo`3W
0?ooo`8000006@3oool001/0oooo0P00003Y0?ooo`030000003oool0oooo01L0oooo000K0?ooo`03
0000003oool0oooo0>T0oooo00@000000?ooo`00000000005@3oool001/0oooo00<000000?ooo`3o
ool0jP3oool2000001H0oooo000K0?ooo`030000003oool0oooo0>`0oooo00@000000?ooo`3oool0
00004P3oool001/0oooo00<000000?ooo`3oool0k@3oool010000000oooo0?ooo`00000A0?ooo`00
6`3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo0140oooo000K0?ooo`030000003o
ool0oooo0>l0oooo0P00000A0?ooo`006`3oool200000?80oooo00@000000?ooo`00000000003@3o
ool001/0oooo00<000000?ooo`3oool0lP3oool2000000h0oooo000K0?ooo`030000003oool0oooo
0?@0oooo00D000000?ooo`3oool0oooo000000090?ooo`006`3oool00`000000oooo0?ooo`3e0?oo
o`050000003oool0oooo0?ooo`000000203oool001/0oooo00<000000?ooo`3oool0mP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0?L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo
0?ooo`3h0?ooo`030000003oool0oooo00L0oooo000K0?ooo`800000nP3oool00`000000oooo0?oo
o`040?ooo`800000000K0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool01@3oool0
01/0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`040?ooo`006`3oool00`000000
oooo0?ooo`3l0?ooo`800000103oool001<0oooo1@0000030?ooo`030000003oool0oooo0?h0oooo
00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool00`3oool200000?l0oooo0`3oool1
000000005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001@0oooo0P00003o0?ooo`/0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.162091, -0.261311, \
0.0059487, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.103006 0.515028 [
[.13789 .09051 -9 -9 ]
[.13789 .09051 9 0 ]
[.27578 .09051 -9 -9 ]
[.27578 .09051 9 0 ]
[.41368 .09051 -9 -9 ]
[.41368 .09051 9 0 ]
[.55157 .09051 -9 -9 ]
[.55157 .09051 9 0 ]
[.68946 .09051 -3 -9 ]
[.68946 .09051 3 0 ]
[.82735 .09051 -9 -9 ]
[.82735 .09051 9 0 ]
[.96525 .09051 -9 -9 ]
[.96525 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .10301 m
.13789 .10926 L
s
[(0.2)] .13789 .09051 0 1 Mshowa
.27578 .10301 m
.27578 .10926 L
s
[(0.4)] .27578 .09051 0 1 Mshowa
.41368 .10301 m
.41368 .10926 L
s
[(0.6)] .41368 .09051 0 1 Mshowa
.55157 .10301 m
.55157 .10926 L
s
[(0.8)] .55157 .09051 0 1 Mshowa
.68946 .10301 m
.68946 .10926 L
s
[(1)] .68946 .09051 0 1 Mshowa
.82735 .10301 m
.82735 .10926 L
s
[(1.2)] .82735 .09051 0 1 Mshowa
.96525 .10301 m
.96525 .10926 L
s
[(1.4)] .96525 .09051 0 1 Mshowa
.125 Mabswid
.03447 .10301 m
.03447 .10676 L
s
.06895 .10301 m
.06895 .10676 L
s
.10342 .10301 m
.10342 .10676 L
s
.17237 .10301 m
.17237 .10676 L
s
.20684 .10301 m
.20684 .10676 L
s
.24131 .10301 m
.24131 .10676 L
s
.31026 .10301 m
.31026 .10676 L
s
.34473 .10301 m
.34473 .10676 L
s
.3792 .10301 m
.3792 .10676 L
s
.44815 .10301 m
.44815 .10676 L
s
.48262 .10301 m
.48262 .10676 L
s
.5171 .10301 m
.5171 .10676 L
s
.58604 .10301 m
.58604 .10676 L
s
.62051 .10301 m
.62051 .10676 L
s
.65499 .10301 m
.65499 .10676 L
s
.72393 .10301 m
.72393 .10676 L
s
.75841 .10301 m
.75841 .10676 L
s
.79288 .10301 m
.79288 .10676 L
s
.86183 .10301 m
.86183 .10676 L
s
.8963 .10301 m
.8963 .10676 L
s
.93077 .10301 m
.93077 .10676 L
s
.99972 .10301 m
.99972 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .10301 m
.01065 .10664 L
.02131 .1104 L
.03196 .11339 L
.04261 .11696 L
.05327 .11988 L
.06392 .12254 L
.07457 .12726 L
.08523 .13108 L
.09588 .13501 L
.10653 .13821 L
.11719 .14145 L
.12784 .14565 L
.13849 .15075 L
.14915 .15361 L
.1598 .15629 L
.17045 .16138 L
.18111 .16567 L
.19176 .16871 L
.20241 .17425 L
.21307 .17713 L
.22372 .18317 L
.23437 .18573 L
.24503 .18919 L
.25568 .19578 L
.26633 .19571 L
.27699 .20199 L
.28764 .20467 L
.2983 .21182 L
.30895 .2153 L
.3196 .21988 L
.33026 .22515 L
.34091 .23003 L
.35156 .23206 L
.36222 .23704 L
.37287 .24366 L
.38352 .2466 L
.39418 .25249 L
.40483 .25347 L
.41548 .26238 L
.42614 .26682 L
.43679 .26959 L
.44744 .27364 L
.4581 .28279 L
.46875 .28713 L
.4794 .29243 L
.49006 .29682 L
.50071 .30256 L
.51136 .30829 L
.52202 .31371 L
Mistroke
.53267 .31859 L
.54332 .32333 L
.55398 .32747 L
.56463 .33439 L
.57528 .34177 L
.58594 .34455 L
.59659 .354 L
.60724 .35798 L
.6179 .36486 L
.62855 .37004 L
.6392 .37531 L
.64986 .38271 L
.66051 .39129 L
.67116 .39437 L
.68182 .40281 L
.69247 .40686 L
.70312 .41227 L
.71378 .41983 L
.72443 .4273 L
.73508 .43428 L
.74574 .43971 L
.75639 .44753 L
.76704 .45388 L
.7777 .46097 L
.78835 .46715 L
.799 .47609 L
.80966 .48294 L
.82031 .49112 L
.83096 .49921 L
.84162 .50449 L
.85227 .5152 L
.86292 .51788 L
.87358 .52823 L
.88423 .53783 L
.89489 .54393 L
.90554 .55041 L
.91619 .56007 L
.92685 .57009 L
.9375 .57628 L
.94815 .58364 L
.95881 .59103 L
.96946 .59882 L
.98011 .60566 L
.99077 .61294 L
Mfstroke
.99077 .61294 m
.99993 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo
0P0000040?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo
0P0000040?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo
1000000C0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool00`000000oooo0?oo
o`0I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo000000P0oooo1@00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool500000080oooo000K0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`0000080?ooo`<000005@3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000<0oooo000K0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool001/0oooo0P00000K0?ooo`8000002P3oool2000001D0oooo
0P00000;0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo
0P00000L0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool01@000000oooo0?ooo`3oool0000001l0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000003k
0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?L0oooo000K0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`000000m@3oool001/0oooo00<000000?ooo`3oool0
3P3oool200000?80oooo000K0?ooo`8000004@3oool200000?00oooo000K0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0k03oool001/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0000003Z0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`800000i`3oool001/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3S0?ooo`006`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0>40oooo000K0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`000000g`3oool001/0oooo0P00000U0?ooo`80000000<0oooo0000003oool0f@3oool001/0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3H0?ooo`006`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool000000=H0oooo000K0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`000000e03oool001/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3@
0?ooo`006`3oool00`000000oooo0?ooo`0a0?ooo`800000c`3oool001/0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`3;0?ooo`006`3oool2000003L0oooo00<000000?ooo`3oool0
b@3oool001/0oooo00<000000?ooo`3oool0>03oool00`000000oooo000000370?ooo`006`3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0<<0oooo000K0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0`@3oool000P0oooo0P0000040?ooo`8000000`3oool4000000@0
oooo00<000000?ooo`3oool0@03oool2000000030?ooo`000000oooo0;d0oooo00070?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0;X0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool2000004P0oooo00<000000?ooo`3oool0^03oool000L0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0]P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0]03oool000P0oooo0P00000:0?ooo`80
00001@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0;80oooo000K0?ooo`030000
003oool0oooo04l0oooo0P00002a0?ooo`006`3oool00`000000oooo0?ooo`1A0?ooo`800000[`3o
ool001/0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2[0?ooo`006`3oool20000
05L0oooo00<000000?ooo`000000Z@3oool001/0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`2U0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0:<0oooo
000K0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0X@3oool001/0oooo00<00000
0?ooo`3oool0H03oool200000:00oooo000K0?ooo`030000003oool0oooo0680oooo0P00002N0?oo
o`006`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0000009X0oooo000K0?ooo`800000
J03oool00`000000oooo0?ooo`2H0?ooo`006`3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo09H0oooo000K0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0U03oool0
01/0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0000002B0?ooo`006`3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo08h0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo0P00001d0?ooo`030000003oool0oooo08`0oooo000K0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0RP3oool001/0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`280?ooo`006`3oool00`000000oooo0?ooo`1i0?ooo`800000Q`3oool001/0oooo
00<000000?ooo`3oool0N`3oool2000008D0oooo00080?ooo`800000103oool2000000D0oooo0`00
00030?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0P@3oool000L0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0O`3oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00
00230?ooo`030000003oool0oooo07d0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo07/0oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo07T0oooo00080?ooo`8000002`3oool2000000@0oooo00<0
00000?ooo`3oool0R03oool2000007P0oooo000K0?ooo`030000003oool0oooo08X0oooo0P00001f
0?ooo`006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0780oooo000K0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0L03oool001/0oooo0P00002B0?ooo`030000
003oool0oooo06h0oooo000K0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0KP3o
ool001/0oooo00<000000?ooo`3oool0TP3oool2000000030?ooo`000000oooo06/0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`1X0?ooo`006`3oool00`000000oooo0?ooo`2H0?ooo`800000J03oool001/0oooo0P00
002L0?ooo`030000003oool0oooo06@0oooo000K0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0HP3oool001/0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1P0?oo
o`006`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo05h0oooo000K0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0G03oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo05X0oooo000K0?oo
o`800000Z03oool00`000000oooo0?ooo`1H0?ooo`006`3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo05L0oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`000000
EP3oool001/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`1B0?ooo`006`3oool0
0`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0580oooo00080?ooo`800000103oool20000
00<0oooo0`0000050?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0D03oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool0CP3oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`800000]03oool00`000000oooo0?ooo`1<0?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo04X0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo04P0oooo00080?ooo`8000002P3oool3
000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo04H0oooo000K0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3o
ool0A03oool001/0oooo0P00002n0?ooo`030000003oool0oooo0480oooo000K0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0@03oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`300?ooo`800000@03oool001/0oooo00<000000?ooo`3o
ool0`P3oool2000003h0oooo000K0?ooo`030000003oool0oooo0<@0oooo0P00000l0?ooo`006`3o
ool00`000000oooo0?ooo`360?ooo`800000>P3oool001/0oooo0P0000390?ooo`030000003oool0
oooo03L0oooo000K0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0=P3oool001/0
oooo00<000000?ooo`3oool0bP3oool2000003H0oooo000K0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool0<`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0340oooo000K0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool0;`3oool001/0oooo0P00003C0?ooo`030000003oool0oooo02d0
oooo000K0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0;@3oool001/0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`0[0?ooo`006`3oool00`000000oooo0?ooo`3F
0?ooo`030000003oool0oooo02T0oooo000K0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`3oool09`3oool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0f@3oool2000002L0oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool200000=`0oooo0P00000U0?ooo`001`3oool01000
0000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`3M0?ooo`8000008`3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0=l0oooo00<000000?ooo`3oool0803oool000P0oooo0P00000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0200oooo000K0?ooo`030000003oool0oooo
0>40oooo00<000000?ooo`3oool07P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool200000>@0oooo00<000000?ooo`3oool0703oool001/0oooo00<000000?ooo`3oool0i@3o
ool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0
oooo01P0oooo000K0?ooo`030000003oool0oooo0>P0oooo0P00000H0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`3oool0
5@3oool001/0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0C0?ooo`006`3oool2
00000>d0oooo00<000000?ooo`3oool04`3oool001/0oooo00<000000?ooo`3oool0kP3oool00`00
0000oooo0?ooo`0A0?ooo`006`3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo00l0
oooo000K0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool03@3oool001/0oooo00<0
00000?ooo`3oool0lP3oool00`000000oooo0?ooo`0=0?ooo`006`3oool00`000000oooo0?ooo`3d
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo0?D0oooo0P00000;0?oo
o`006`3oool200000?P0oooo00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0
n03oool00`000000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`3i0?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0103oool0
01<0oooo1@0000030?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool00P3oool001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3m0?ooo`8000000`3oool001D0oooo
00<000000?ooo`3oool00`3oool200000?l0oooo0P3oool100000040oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool20000
0?l0oooo2`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.261311, \
0.00558385, 0.00747503}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(FindRoot :: \\\"lstol\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.103006 0.515028 [
[.13789 .09051 -9 -9 ]
[.13789 .09051 9 0 ]
[.27578 .09051 -9 -9 ]
[.27578 .09051 9 0 ]
[.41368 .09051 -9 -9 ]
[.41368 .09051 9 0 ]
[.55157 .09051 -9 -9 ]
[.55157 .09051 9 0 ]
[.68946 .09051 -3 -9 ]
[.68946 .09051 3 0 ]
[.82735 .09051 -9 -9 ]
[.82735 .09051 9 0 ]
[.96525 .09051 -9 -9 ]
[.96525 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .10301 m
.13789 .10926 L
s
[(0.2)] .13789 .09051 0 1 Mshowa
.27578 .10301 m
.27578 .10926 L
s
[(0.4)] .27578 .09051 0 1 Mshowa
.41368 .10301 m
.41368 .10926 L
s
[(0.6)] .41368 .09051 0 1 Mshowa
.55157 .10301 m
.55157 .10926 L
s
[(0.8)] .55157 .09051 0 1 Mshowa
.68946 .10301 m
.68946 .10926 L
s
[(1)] .68946 .09051 0 1 Mshowa
.82735 .10301 m
.82735 .10926 L
s
[(1.2)] .82735 .09051 0 1 Mshowa
.96525 .10301 m
.96525 .10926 L
s
[(1.4)] .96525 .09051 0 1 Mshowa
.125 Mabswid
.03447 .10301 m
.03447 .10676 L
s
.06895 .10301 m
.06895 .10676 L
s
.10342 .10301 m
.10342 .10676 L
s
.17237 .10301 m
.17237 .10676 L
s
.20684 .10301 m
.20684 .10676 L
s
.24131 .10301 m
.24131 .10676 L
s
.31026 .10301 m
.31026 .10676 L
s
.34473 .10301 m
.34473 .10676 L
s
.3792 .10301 m
.3792 .10676 L
s
.44815 .10301 m
.44815 .10676 L
s
.48262 .10301 m
.48262 .10676 L
s
.5171 .10301 m
.5171 .10676 L
s
.58604 .10301 m
.58604 .10676 L
s
.62051 .10301 m
.62051 .10676 L
s
.65499 .10301 m
.65499 .10676 L
s
.72393 .10301 m
.72393 .10676 L
s
.75841 .10301 m
.75841 .10676 L
s
.79288 .10301 m
.79288 .10676 L
s
.86183 .10301 m
.86183 .10676 L
s
.8963 .10301 m
.8963 .10676 L
s
.93077 .10301 m
.93077 .10676 L
s
.99972 .10301 m
.99972 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
0 .10301 m
.01065 .10634 L
.02131 .1097 L
.03196 .11308 L
.04261 .1165 L
.05327 .11995 L
.06392 .12343 L
.07457 .12694 L
.08523 .13049 L
.09588 .13406 L
.10653 .13767 L
.11719 .14131 L
.12784 .14498 L
.13849 .14868 L
.14915 .15242 L
.1598 .1562 L
.17045 .16 L
.18111 .16385 L
.19176 .16773 L
.20241 .17164 L
.21307 .1756 L
.22372 .17958 L
.23437 .18361 L
.24503 .18768 L
.25568 .19178 L
.26633 .19592 L
.27699 .2001 L
.28764 .20433 L
.2983 .20859 L
.30895 .2129 L
.3196 .21724 L
.33026 .22163 L
.34091 .22606 L
.35156 .23054 L
.36222 .23506 L
.37287 .23962 L
.38352 .24423 L
.39418 .24889 L
.40483 .25359 L
.41548 .25834 L
.42614 .26314 L
.43679 .26799 L
.44744 .27289 L
.4581 .27783 L
.46875 .28283 L
.4794 .28788 L
.49006 .29298 L
.50071 .29814 L
.51136 .30335 L
.52202 .30861 L
Mistroke
.53267 .31393 L
.54332 .31931 L
.55398 .32474 L
.56463 .33024 L
.57528 .33579 L
.58594 .3414 L
.59659 .34707 L
.60724 .35281 L
.6179 .3586 L
.62855 .36446 L
.6392 .37039 L
.64986 .37638 L
.66051 .38244 L
.67116 .38857 L
.68182 .39476 L
.69247 .40103 L
.70312 .40736 L
.71378 .41377 L
.72443 .42026 L
.73508 .42681 L
.74574 .43345 L
.75639 .44016 L
.76704 .44695 L
.7777 .45382 L
.78835 .46077 L
.799 .4678 L
.80966 .47492 L
.82031 .48212 L
.83096 .48941 L
.84162 .49679 L
.85227 .50426 L
.86292 .51182 L
.87358 .51948 L
.88423 .52722 L
.89489 .53507 L
.90554 .54301 L
.91619 .55105 L
.92685 .5592 L
.9375 .56745 L
.94815 .5758 L
.95881 .58426 L
.96946 .59284 L
.98011 .60152 L
.99077 .61032 L
Mfstroke
.99077 .61032 m
.99999 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo
0P0000040?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo
0P0000040?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo
1000000C0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool00`000000oooo0?oo
o`0I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo000000P0oooo1@00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool500000080oooo000K0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`0000080?ooo`<000005@3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000<0oooo000K0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool001/0oooo0P00000K0?ooo`8000002P3oool2000001D0oooo
0P00000;0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo
0P00000L0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool010000000oooo0?ooo`3oool3000001d0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0103oool300000?/0oooo000K0?ooo`03
0000003oool0oooo00L0oooo0`00003h0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`800000
mP3oool001/0oooo00<000000?ooo`3oool0303oool300000?<0oooo000K0?ooo`800000403oool3
00000?00oooo000K0?ooo`030000003oool0oooo0180oooo0`00003]0?ooo`006`3oool00`000000
oooo0?ooo`0E0?ooo`800000j`3oool001/0oooo00<000000?ooo`3oool05`3oool600000>D0oooo
000K0?ooo`030000003oool0oooo01d0oooo0`00003R0?ooo`006`3oool00`000000oooo0?ooo`0P
0?ooo`800000h03oool001/0oooo00<000000?ooo`3oool08P3oool300000=d0oooo000K0?ooo`80
00009P3oool300000=X0oooo000K0?ooo`030000003oool0oooo02P0oooo0`00003G0?ooo`006`3o
ool00`000000oooo0?ooo`0[0?ooo`<00000e03oool001/0oooo00<000000?ooo`3oool0;P3oool2
00000=80oooo000K0?ooo`030000003oool0oooo0300oooo0`00003?0?ooo`006`3oool00`000000
oooo0?ooo`0c0?ooo`<00000c03oool001/0oooo00<000000?ooo`3oool0=P3oool300000<T0oooo
000K0?ooo`800000>P3oool200000<L0oooo000K0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0a03oool001/0oooo00<000000?ooo`3oool0?03oool200000<@0oooo000K0?ooo`03
0000003oool0oooo03h0oooo0`0000310?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
103oool00`000000oooo0?ooo`110?ooo`<00000_P3oool000L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo0P00002l0?ooo`001`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P0000170?ooo`<00000
^@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04T0oooo0`00002f0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0C03oool300000;<0oooo00080?ooo`800000
2P3oool2000000D0oooo00<000000?ooo`3oool0C`3oool300000;00oooo000K0?ooo`030000003o
ool0oooo0580oooo0P00002^0?ooo`006`3oool00`000000oooo0?ooo`1D0?ooo`800000[03oool0
01/0oooo00<000000?ooo`3oool0EP3oool200000:X0oooo000K0?ooo`800000F@3oool200000:P0
oooo000K0?ooo`030000003oool0oooo05X0oooo0`00002U0?ooo`006`3oool00`000000oooo0?oo
o`1M0?ooo`800000X`3oool001/0oooo00<000000?ooo`3oool0G`3oool300000:00oooo000K0?oo
o`030000003oool0oooo0680oooo0P00002N0?ooo`006`3oool00`000000oooo0?ooo`1T0?ooo`80
0000W03oool001/0oooo00<000000?ooo`3oool0IP3oool2000009X0oooo000K0?ooo`800000J@3o
ool2000009P0oooo000K0?ooo`030000003oool0oooo06X0oooo0`00002E0?ooo`006`3oool00`00
0000oooo0?ooo`1]0?ooo`800000T`3oool001/0oooo00<000000?ooo`3oool0K`3oool200000940
oooo000K0?ooo`030000003oool0oooo0740oooo0P00002?0?ooo`006`3oool00`000000oooo0?oo
o`1c0?ooo`<00000S03oool001/0oooo0P00001g0?ooo`800000RP3oool001/0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`270?ooo`006`3oool00`000000oooo0?ooo`1i0?ooo`80
0000Q`3oool001/0oooo00<000000?ooo`3oool0N`3oool3000008@0oooo000K0?ooo`030000003o
ool0oooo07h0oooo0P0000220?ooo`00203oool2000000@0oooo0P0000050?ooo`<000000`3oool0
0`000000oooo0?ooo`200?ooo`800000P03oool000L0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0O@3oool0
00L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P0000240?ooo`<00000O03oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo08H0oooo0P00001j0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0R03oool2000007P0oooo00080?ooo`8000002`3oool2
000000@0oooo00<000000?ooo`3oool0RP3oool2000007H0oooo000K0?ooo`030000003oool0oooo
08`0oooo0P00001d0?ooo`006`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0740
oooo000K0?ooo`030000003oool0oooo08l0oooo0P00001a0?ooo`006`3oool200000980oooo0`00
001^0?ooo`006`3oool00`000000oooo0?ooo`2D0?ooo`800000K03oool001/0oooo00<000000?oo
o`3oool0UP3oool2000006X0oooo000K0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool0I`3oool001/0oooo00<000000?ooo`3oool0V@3oool2000006L0oooo000K0?ooo`030000003o
ool0oooo09/0oooo0P00001U0?ooo`006`3oool2000009h0oooo0P00001S0?ooo`006`3oool00`00
0000oooo0?ooo`2O0?ooo`800000H@3oool001/0oooo00<000000?ooo`3oool0X@3oool2000005l0
oooo000K0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0G03oool001/0oooo00<0
00000?ooo`3oool0Y03oool2000005`0oooo000K0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0Y`3oool2000005T0oooo000K0?ooo`80
0000ZP3oool2000005L0oooo000K0?ooo`030000003oool0oooo0:/0oooo0P00001E0?ooo`006`3o
ool00`000000oooo0?ooo`2]0?ooo`800000D`3oool001/0oooo00<000000?ooo`3oool0[`3oool2
00000540oooo000K0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0CP3oool000P0
oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`1=0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0/`3oool2000004d0oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool200000;H0oooo0P00001;0?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`2g0?ooo`800000B@3oool0
00L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0AP3oool000P0oooo0P00000:0?ooo`<00000103oool00`00
0000oooo0?ooo`2j0?ooo`800000AP3oool001/0oooo00<000000?ooo`3oool0_03oool00`000000
oooo0?ooo`130?ooo`006`3oool00`000000oooo0?ooo`2m0?ooo`800000@`3oool001/0oooo0P00
00300?ooo`800000@@3oool001/0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0n
0?ooo`006`3oool00`000000oooo0?ooo`320?ooo`800000?P3oool001/0oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`0k0?ooo`006`3oool00`000000oooo0?ooo`350?ooo`800000
>`3oool001/0oooo00<000000?ooo`3oool0a`3oool2000003T0oooo000K0?ooo`030000003oool0
oooo0<T0oooo0P00000g0?ooo`006`3oool200000<`0oooo00<000000?ooo`3oool0=03oool001/0
oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0c0?ooo`006`3oool00`000000oooo
0?ooo`3=0?ooo`800000<`3oool001/0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`0`0?ooo`006`3oool00`000000oooo0?ooo`3@0?ooo`800000<03oool001/0oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`3C0?ooo`80
0000;@3oool001/0oooo0P00003F0?ooo`030000003oool0oooo02X0oooo000K0?ooo`030000003o
ool0oooo0=H0oooo00<000000?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0e`3oool0
0`000000oooo0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`3H0?ooo`800000:03oool001/0
oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`0U0?ooo`00203oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3K0?ooo`8000009@3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool08P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000040?ooo`800000g`3oool200000280oooo00070?ooo`040000003oool0oooo0000
00T0oooo0P0000050?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool07`3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0>40oooo00<000000?ooo`3oool07P3oool000P0oooo0P00000:0?ooo`8000001@3oool00`00
0000oooo0?ooo`3R0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo0><0
oooo0P00000M0?ooo`006`3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo01X0oooo
000K0?ooo`800000i`3oool2000001X0oooo000K0?ooo`030000003oool0oooo0>P0oooo00<00000
0?ooo`3oool05`3oool001/0oooo00<000000?ooo`3oool0j@3oool2000001L0oooo000K0?ooo`03
0000003oool0oooo0>/0oooo00<000000?ooo`3oool0503oool001/0oooo00<000000?ooo`3oool0
k03oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`3]0?ooo`030000003o
ool0oooo0180oooo000K0?ooo`030000003oool0oooo0>h0oooo0P00000B0?ooo`006`3oool20000
0?40oooo00<000000?ooo`3oool03`3oool001/0oooo00<000000?ooo`3oool0l@3oool2000000l0
oooo000K0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0303oool001/0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`3e
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo0?H0oooo00<000000?oo
o`3oool02@3oool001/0oooo00<000000?ooo`3oool0m`3oool2000000T0oooo000K0?ooo`800000
nP3oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo00D0oooo000K0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0103oool0
01/0oooo00<000000?ooo`3oool0o03oool2000000@0oooo000C0?ooo`D000000`3oool00`000000
oooo0?ooo`3n0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0o`3oool100000040oooo0@3oool001D0oooo00<000000?ooo`3oool00`3o
ool200000?l0oooo0P3oool100000040oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00503oool200000?l0oooo2`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.261311, \
0.00558385, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.103006 0.515028 [
[.13789 .09051 -9 -9 ]
[.13789 .09051 9 0 ]
[.27578 .09051 -9 -9 ]
[.27578 .09051 9 0 ]
[.41368 .09051 -9 -9 ]
[.41368 .09051 9 0 ]
[.55157 .09051 -9 -9 ]
[.55157 .09051 9 0 ]
[.68946 .09051 -3 -9 ]
[.68946 .09051 3 0 ]
[.82735 .09051 -9 -9 ]
[.82735 .09051 9 0 ]
[.96525 .09051 -9 -9 ]
[.96525 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .10301 m
.13789 .10926 L
s
[(0.2)] .13789 .09051 0 1 Mshowa
.27578 .10301 m
.27578 .10926 L
s
[(0.4)] .27578 .09051 0 1 Mshowa
.41368 .10301 m
.41368 .10926 L
s
[(0.6)] .41368 .09051 0 1 Mshowa
.55157 .10301 m
.55157 .10926 L
s
[(0.8)] .55157 .09051 0 1 Mshowa
.68946 .10301 m
.68946 .10926 L
s
[(1)] .68946 .09051 0 1 Mshowa
.82735 .10301 m
.82735 .10926 L
s
[(1.2)] .82735 .09051 0 1 Mshowa
.96525 .10301 m
.96525 .10926 L
s
[(1.4)] .96525 .09051 0 1 Mshowa
.125 Mabswid
.03447 .10301 m
.03447 .10676 L
s
.06895 .10301 m
.06895 .10676 L
s
.10342 .10301 m
.10342 .10676 L
s
.17237 .10301 m
.17237 .10676 L
s
.20684 .10301 m
.20684 .10676 L
s
.24131 .10301 m
.24131 .10676 L
s
.31026 .10301 m
.31026 .10676 L
s
.34473 .10301 m
.34473 .10676 L
s
.3792 .10301 m
.3792 .10676 L
s
.44815 .10301 m
.44815 .10676 L
s
.48262 .10301 m
.48262 .10676 L
s
.5171 .10301 m
.5171 .10676 L
s
.58604 .10301 m
.58604 .10676 L
s
.62051 .10301 m
.62051 .10676 L
s
.65499 .10301 m
.65499 .10676 L
s
.72393 .10301 m
.72393 .10676 L
s
.75841 .10301 m
.75841 .10676 L
s
.79288 .10301 m
.79288 .10676 L
s
.86183 .10301 m
.86183 .10676 L
s
.8963 .10301 m
.8963 .10676 L
s
.93077 .10301 m
.93077 .10676 L
s
.99972 .10301 m
.99972 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01065 .10301 L
.02131 .10301 L
.03196 .10301 L
.04261 .10301 L
.05327 .10404 L
.06392 .10625 L
.07457 .10796 L
.08523 .10951 L
.09588 .11438 L
.10653 .11502 L
.11719 .11823 L
.12784 .12136 L
.13849 .12419 L
.14915 .12618 L
.1598 .12849 L
.17045 .13243 L
.18111 .13394 L
.19176 .13839 L
.20241 .14182 L
.21307 .14524 L
.22372 .14652 L
.23437 .15031 L
.24503 .15119 L
.25568 .16106 L
.26633 .16076 L
.27699 .16528 L
.28764 .16776 L
.2983 .17409 L
.30895 .17535 L
.3196 .17993 L
.33026 .18058 L
.34091 .18558 L
.35156 .19185 L
.36222 .19304 L
.37287 .19999 L
.38352 .20157 L
.39418 .20907 L
.40483 .20957 L
.41548 .21828 L
.42614 .2206 L
.43679 .22803 L
.44744 .22018 L
.4581 .23726 L
.46875 .23519 L
.4794 .24166 L
.49006 .24578 L
.50071 .25585 L
.51136 .25989 L
.52202 .26366 L
Mistroke
.53267 .26708 L
.54332 .27587 L
.55398 .27589 L
.56463 .28308 L
.57528 .28788 L
.58594 .29887 L
.59659 .30099 L
.60724 .30673 L
.6179 .31128 L
.62855 .31614 L
.6392 .3262 L
.64986 .32829 L
.66051 .33887 L
.67116 .34646 L
.68182 .35122 L
.69247 .3529 L
.70312 .35652 L
.71378 .37145 L
.72443 .37367 L
.73508 .38433 L
.74574 .38677 L
.75639 .39698 L
.76704 .39788 L
.7777 .40687 L
.78835 .41344 L
.799 .41966 L
.80966 .43458 L
.82031 .43877 L
.83096 .44781 L
.84162 .45402 L
.85227 .46658 L
.86292 .46863 L
.87358 .48444 L
.88423 .49421 L
.89489 .49801 L
.90554 .50695 L
.91619 .51952 L
.92685 .53226 L
.9375 .53548 L
.94815 .55021 L
.95881 .56408 L
.96946 .57328 L
.98011 .58672 L
.99077 .59992 L
Mfstroke
.99077 .59992 m
1 .61562 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo
0P0000040?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo
0P0000040?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo
1000000C0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool00`000000oooo0?oo
o`0I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo000000P0oooo1@00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool500000080oooo000K0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`0000080?ooo`<000005@3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000<0oooo000K0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool001/0oooo0P00000K0?ooo`8000002P3oool2000001D0oooo
0P00000;0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo
0P00000L0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool00`000000oooo0?ooo`0?0?ooo`800000403oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`080?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`800000k03oool001/0oooo
00<000000?ooo`3oool06@3oool200000>L0oooo000K0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0h@3oool001/0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3o
ool000000=h0oooo000K0?ooo`800000903oool200000=d0oooo000K0?ooo`030000003oool0oooo
02P0oooo0P00003H0?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=80
oooo000K0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0d@3oool001/0oooo00<0
00000?ooo`3oool0<P3oool200000<h0oooo000K0?ooo`030000003oool0oooo03L0oooo0P000039
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0<<0oooo000K0?ooo`80
0000?P3oool00`000000oooo0?ooo`320?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0400oooo0P0000300?ooo`006`3oool00`000000oooo0?ooo`15
0?ooo`800000^`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`1:0?ooo`800000]P3oool001/0oooo00<000000?ooo`3oool0C`3oool200000;40oooo
000K0?ooo`800000D@3oool01@000000oooo0?ooo`3oool000000:d0oooo000K0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0ZP3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`1H0?ooo`<00000Y`3oool000P0oooo0P0000040?ooo`80
00000`3oool4000000@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2R0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`2Q0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo0P00001S0?ooo`030000003oool0oooo09d0oooo00070?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo09`0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09P0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2G0?ooo`00
6`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
S`3oool001/0oooo00<000000?ooo`3oool0K03oool010000000oooo0?ooo`00002B0?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000M03oool00`000000oooo0?ooo`2<
0?ooo`006`3oool00`000000oooo0?ooo`1c0?ooo`050000003oool0oooo0?ooo`000000RP3oool0
01/0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`270?ooo`006`3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo08@0oooo000K0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool0P`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000P03oool300000800oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`1h0?ooo`006`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo07L0oooo000K
0?ooo`030000003oool0oooo08/0oooo0P00001e0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`800000T@3oool00`000000oooo0?ooo`1_0?ooo`006`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo06h0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1[0?ooo`006`3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo06X0oooo00080?ooo`800000103oool2000000D0
oooo0`0000030?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0IP3oool000L0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0I@3oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0
oooo0P00003o0?ooo`@0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`2M0?ooo`800000H`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo0`3oool000P0
oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo05d0
oooo000K0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0G03oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo05T0oooo000K0?ooo`800000Z03oool00`000000oooo0?ooo`1H0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
E@3oool001/0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1D0?ooo`006`3oool0
0`000000oooo0?ooo`2_0?ooo`800000D@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool200000;D0oooo00<000000?ooo`3oool0B`3oool001/0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`1;0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0B03oool001/0oooo00<000000?oo
o`3oool0^03oool00`000000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0A03oool001/0oooo0P00
002m0?ooo`030000003oool0oooo04<0oooo000K0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool0?`3oool001/0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0o0?oo
o`006`3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03/0oooo000K0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool0>P3oool000P0oooo0P0000040?ooo`8000000`3o
ool3000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0b03oool00`000000oooo
0?ooo`0g0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo0P00003:0?ooo`030000003oool0oooo03H0oooo00070?ooo`040000003oool0oooo000000P0
oooo0`0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3o
ool0<P3oool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3=0?ooo`030000
003oool0oooo0380oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool200000=40oooo0P00000`0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0e03oool2000002`0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3H0?ooo`03
0000003oool0oooo02L0oooo000K0?ooo`800000fP3oool00`000000oooo0?ooo`0V0?ooo`006`3o
ool00`000000oooo0?ooo`3L0?ooo`800000903oool001/0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`0R0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0h03oool00`000000oooo
0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo01l0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0>@0oooo0P00000L0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool05`3oool000P0oooo0P000004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`0F
0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo0P00003o0?ooo`@0oooo00070?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0503oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>`0
oooo00<000000?ooo`3oool04`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0k`3oool200000140oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0
303oool001/0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0<0?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`090?ooo`006`3oool200000?P0oooo
00<000000?ooo`3oool0203oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?T0oooo00<000000?oo
o`3oool01P3oool001/0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`050?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo0P00003n0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0oooo
0?d0oooo00<000000?ooo`3oool00P3oool001/0oooo00<000000?ooo`3oool0oP3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`4000000@3oool10?ooo`004`3o
ool5000000<0oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool20000
0?l0oooo103oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000D0?ooo`800000o`3oool;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.261311, \
0.00558385, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.103006 0.515028 [
[.13789 .09051 -9 -9 ]
[.13789 .09051 9 0 ]
[.27578 .09051 -9 -9 ]
[.27578 .09051 9 0 ]
[.41368 .09051 -9 -9 ]
[.41368 .09051 9 0 ]
[.55157 .09051 -9 -9 ]
[.55157 .09051 9 0 ]
[.68946 .09051 -3 -9 ]
[.68946 .09051 3 0 ]
[.82735 .09051 -9 -9 ]
[.82735 .09051 9 0 ]
[.96525 .09051 -9 -9 ]
[.96525 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .10301 m
.13789 .10926 L
s
[(0.2)] .13789 .09051 0 1 Mshowa
.27578 .10301 m
.27578 .10926 L
s
[(0.4)] .27578 .09051 0 1 Mshowa
.41368 .10301 m
.41368 .10926 L
s
[(0.6)] .41368 .09051 0 1 Mshowa
.55157 .10301 m
.55157 .10926 L
s
[(0.8)] .55157 .09051 0 1 Mshowa
.68946 .10301 m
.68946 .10926 L
s
[(1)] .68946 .09051 0 1 Mshowa
.82735 .10301 m
.82735 .10926 L
s
[(1.2)] .82735 .09051 0 1 Mshowa
.96525 .10301 m
.96525 .10926 L
s
[(1.4)] .96525 .09051 0 1 Mshowa
.125 Mabswid
.03447 .10301 m
.03447 .10676 L
s
.06895 .10301 m
.06895 .10676 L
s
.10342 .10301 m
.10342 .10676 L
s
.17237 .10301 m
.17237 .10676 L
s
.20684 .10301 m
.20684 .10676 L
s
.24131 .10301 m
.24131 .10676 L
s
.31026 .10301 m
.31026 .10676 L
s
.34473 .10301 m
.34473 .10676 L
s
.3792 .10301 m
.3792 .10676 L
s
.44815 .10301 m
.44815 .10676 L
s
.48262 .10301 m
.48262 .10676 L
s
.5171 .10301 m
.5171 .10676 L
s
.58604 .10301 m
.58604 .10676 L
s
.62051 .10301 m
.62051 .10676 L
s
.65499 .10301 m
.65499 .10676 L
s
.72393 .10301 m
.72393 .10676 L
s
.75841 .10301 m
.75841 .10676 L
s
.79288 .10301 m
.79288 .10676 L
s
.86183 .10301 m
.86183 .10676 L
s
.8963 .10301 m
.8963 .10676 L
s
.93077 .10301 m
.93077 .10676 L
s
.99972 .10301 m
.99972 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01065 .11693 L
.02131 .12531 L
.03196 .1288 L
.04261 .13402 L
.05327 .1384 L
.06392 .144 L
.07457 .14829 L
.08523 .15492 L
.09588 .16351 L
.10653 .1659 L
.11719 .17001 L
.12784 .17269 L
.13849 .18062 L
.14915 .18204 L
.1598 .18829 L
.17045 .19851 L
.18111 .20041 L
.19176 .20202 L
.20241 .21146 L
.21307 .21385 L
.22372 .22481 L
.23437 .22262 L
.24503 .22966 L
.25568 .23328 L
.26633 .23441 L
.27699 .24639 L
.28764 .24805 L
.2983 .25398 L
.30895 .25566 L
.3196 .26087 L
.33026 .26924 L
.34091 .27502 L
.35156 .2779 L
.36222 .28412 L
.37287 .28664 L
.38352 .29648 L
.39418 .29896 L
.40483 .30107 L
.41548 .30994 L
.42614 .31205 L
.43679 .31988 L
.44744 .32457 L
.4581 .33297 L
.46875 .34126 L
.4794 .34645 L
.49006 .34974 L
.50071 .35108 L
.51136 .35337 L
.52202 .36242 L
Mistroke
.53267 .36709 L
.54332 .37713 L
.55398 .37863 L
.56463 .38288 L
.57528 .38779 L
.58594 .39144 L
.59659 .40589 L
.60724 .40741 L
.6179 .42411 L
.62855 .42002 L
.6392 .42634 L
.64986 .42976 L
.66051 .43947 L
.67116 .44562 L
.68182 .45405 L
.69247 .45286 L
.70312 .46369 L
.71378 .47055 L
.72443 .47461 L
.73508 .48509 L
.74574 .48867 L
.75639 .48995 L
.76704 .50922 L
.7777 .50884 L
.78835 .51254 L
.799 .52445 L
.80966 .52683 L
.82031 .53687 L
.83096 .54521 L
.84162 .55166 L
.85227 .56043 L
.86292 .56345 L
.87358 .57398 L
.88423 .57842 L
.89489 .58573 L
.90554 .58972 L
.91619 .59477 L
.92685 .60231 L
.9375 .60786 L
.94815 .60824 L
.95881 .61222 L
.96946 .61803 L
.98011 .61803 L
.99077 .61803 L
Mfstroke
.99077 .61803 m
.99077 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo
0P0000040?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo
0P0000040?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo
1000000C0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool00`000000oooo0?oo
o`0I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo000000P0oooo1@00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool500000080oooo000K0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`0000080?ooo`<000005@3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000<0oooo000K0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool001/0oooo0P00000K0?ooo`8000002P3oool2000001D0oooo
0P00000;0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo
0P00000L0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00P0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00@000000?ooo`3oool0
0000o`3oool20?ooo`006`3oool01@000000oooo0?ooo`3oool000000?l0oooo0@3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool2000000D0oooo0P00003l0?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0mP3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3e0?ooo`00
6`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?40oooo000K0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0l03oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool2000001<0oooo0P00003^0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0j03oool001/0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`3W0?ooo`006`3oool00`000000oooo0?ooo`0L
0?ooo`800000i03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0=l0oooo000K0?ooo`8000008P3oool00`000000oooo
0?ooo`3N0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0=X0oooo000K
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0f@3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0=H0oooo00070?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0?oo
o`800000dP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?oo
o`800000<03oool00`000000oooo0?ooo`3@0?ooo`001`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<P3oool2
00000<h0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo03H0oooo
0P00003:0?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`800000a@3oool001/0oooo0P000011
0?ooo`030000003oool0oooo0;l0oooo000K0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0_P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0;/0oooo000K0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0^P3oool001/0oooo00<000000?ooo`3oool0B@3oool200000;L0oooo000K0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0/P3oool001/0oooo0P00001?0?ooo`80
0000/P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0:d0oooo000K0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0[03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`1F0?ooo`<00000Z@3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003o
ool0oooo05/0oooo0P00002U0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0X03oool001/0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`2O0?ooo`00203oool2000000@0oooo0P0000050?ooo`<00000
0`3oool00`000000oooo0?ooo`1T0?ooo`<00000V`3oool000L0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@0
00000?ooo`3oool00000203oool5000000<0oooo0P00001Z0?ooo`030000003oool0oooo09H0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo09D0oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0980
oooo00080?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`2A0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0780oooo00<000000?ooo`3oool0S@3oool001/0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`2<0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
MP3oool2000008X0oooo000K0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0R03o
ool001/0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`240?ooo`006`3oool00`00
0000oooo0?ooo`1l0?ooo`040000003oool0oooo0?ooo`800000P03oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
Q03oool2000007`0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`1f0?ooo`006`3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo07H0oooo000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0LP3oool001/0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1a0?ooo`006`3o
ool2000009<0oooo00<000000?ooo`3oool0K@3oool001/0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`1/0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0J@3oool001/0oooo00<000000?ooo`3oool0
U`3oool00`000000oooo0?ooo`1X0?ooo`00203oool2000000@0oooo0P0000030?ooo`<000001@3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo06D0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool2000009`0
oooo00<000000?ooo`3oool0I03oool000L0oooo00@000000?ooo`3oool00000203oool3000000D0
oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000X0oooo
0`0000040?ooo`030000003oool0oooo09d0oooo0P0000030?ooo`030000003oool0oooo05d0oooo
000K0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0G03oool001/0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`1I0?ooo`006`3oool200000:P0oooo00<000000?oo
o`3oool0F03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo05D0oooo000K0?ooo`030000003oool0oooo0:/0oooo0P00
001E0?ooo`006`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo04l0oooo000K0?oo
o`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0D03oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool200000;@0oooo00<000000?ooo`3oool0C03oool001/0oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`1;0?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0;L0oooo0`0000180?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0^`3oool3000004@0oooo000K0?ooo`800000`@3oool200000400oooo000K0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool0?P3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?03oool000P0oooo0P0000040?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0a03oool01@000000oooo0?ooo`3oool0000003T0oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo03H0oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool200000?l0oooo103oool000L0oooo00@000000?ooo`3oool0
00002@3oool2000000D0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0c0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0c03oool2000003@0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo02l0oooo
000K0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0;P3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0=@0oooo0P00000/0?ooo`006`3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo02X0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0W0?ooo`006`3oool0
0`000000oooo0?ooo`3I0?ooo`030000003oool0oooo02H0oooo000K0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool08P3oool001/0oooo0P00003O0?ooo`030000003oool0oooo0240
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0h@3o
ool00`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0
oooo01d0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0i@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`3V0?ooo`800000
6P3oool001/0oooo0P00003[0?ooo`8000005P3oool001/0oooo00<000000?ooo`3oool0j`3oool0
0`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0>l0oooo0P00000A0?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool0
m03oool2000000`0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`800000n@3oool300000080oooo0P000003
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001@0oooo0P00003o0?ooo`/0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.261311, \
0.00558385, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.103006 0.515028 [
[.13789 .09051 -9 -9 ]
[.13789 .09051 9 0 ]
[.27578 .09051 -9 -9 ]
[.27578 .09051 9 0 ]
[.41368 .09051 -9 -9 ]
[.41368 .09051 9 0 ]
[.55157 .09051 -9 -9 ]
[.55157 .09051 9 0 ]
[.68946 .09051 -3 -9 ]
[.68946 .09051 3 0 ]
[.82735 .09051 -9 -9 ]
[.82735 .09051 9 0 ]
[.96525 .09051 -9 -9 ]
[.96525 .09051 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .10301 m
.13789 .10926 L
s
[(0.2)] .13789 .09051 0 1 Mshowa
.27578 .10301 m
.27578 .10926 L
s
[(0.4)] .27578 .09051 0 1 Mshowa
.41368 .10301 m
.41368 .10926 L
s
[(0.6)] .41368 .09051 0 1 Mshowa
.55157 .10301 m
.55157 .10926 L
s
[(0.8)] .55157 .09051 0 1 Mshowa
.68946 .10301 m
.68946 .10926 L
s
[(1)] .68946 .09051 0 1 Mshowa
.82735 .10301 m
.82735 .10926 L
s
[(1.2)] .82735 .09051 0 1 Mshowa
.96525 .10301 m
.96525 .10926 L
s
[(1.4)] .96525 .09051 0 1 Mshowa
.125 Mabswid
.03447 .10301 m
.03447 .10676 L
s
.06895 .10301 m
.06895 .10676 L
s
.10342 .10301 m
.10342 .10676 L
s
.17237 .10301 m
.17237 .10676 L
s
.20684 .10301 m
.20684 .10676 L
s
.24131 .10301 m
.24131 .10676 L
s
.31026 .10301 m
.31026 .10676 L
s
.34473 .10301 m
.34473 .10676 L
s
.3792 .10301 m
.3792 .10676 L
s
.44815 .10301 m
.44815 .10676 L
s
.48262 .10301 m
.48262 .10676 L
s
.5171 .10301 m
.5171 .10676 L
s
.58604 .10301 m
.58604 .10676 L
s
.62051 .10301 m
.62051 .10676 L
s
.65499 .10301 m
.65499 .10676 L
s
.72393 .10301 m
.72393 .10676 L
s
.75841 .10301 m
.75841 .10676 L
s
.79288 .10301 m
.79288 .10676 L
s
.86183 .10301 m
.86183 .10676 L
s
.8963 .10301 m
.8963 .10676 L
s
.93077 .10301 m
.93077 .10676 L
s
.99972 .10301 m
.99972 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .10301 m
.01065 .10664 L
.02131 .1104 L
.03196 .11339 L
.04261 .11696 L
.05327 .11988 L
.06392 .12254 L
.07457 .12726 L
.08523 .13108 L
.09588 .13501 L
.10653 .13821 L
.11719 .14145 L
.12784 .14565 L
.13849 .15075 L
.14915 .15361 L
.1598 .15629 L
.17045 .16138 L
.18111 .16567 L
.19176 .16871 L
.20241 .17425 L
.21307 .17713 L
.22372 .18317 L
.23437 .18573 L
.24503 .18919 L
.25568 .19578 L
.26633 .19571 L
.27699 .20199 L
.28764 .20467 L
.2983 .21182 L
.30895 .2153 L
.3196 .21988 L
.33026 .22515 L
.34091 .23003 L
.35156 .23206 L
.36222 .23704 L
.37287 .24366 L
.38352 .2466 L
.39418 .25249 L
.40483 .25347 L
.41548 .26238 L
.42614 .26682 L
.43679 .26959 L
.44744 .27364 L
.4581 .28279 L
.46875 .28713 L
.4794 .29243 L
.49006 .29682 L
.50071 .30256 L
.51136 .30829 L
.52202 .31371 L
Mistroke
.53267 .31859 L
.54332 .32333 L
.55398 .32747 L
.56463 .33439 L
.57528 .34177 L
.58594 .34455 L
.59659 .354 L
.60724 .35798 L
.6179 .36486 L
.62855 .37004 L
.6392 .37531 L
.64986 .38271 L
.66051 .39129 L
.67116 .39437 L
.68182 .40281 L
.69247 .40686 L
.70312 .41227 L
.71378 .41983 L
.72443 .4273 L
.73508 .43428 L
.74574 .43971 L
.75639 .44753 L
.76704 .45388 L
.7777 .46097 L
.78835 .46715 L
.799 .47609 L
.80966 .48294 L
.82031 .49112 L
.83096 .49921 L
.84162 .50449 L
.85227 .5152 L
.86292 .51788 L
.87358 .52823 L
.88423 .53783 L
.89489 .54393 L
.90554 .55041 L
.91619 .56007 L
.92685 .57009 L
.9375 .57628 L
.94815 .58364 L
.95881 .59103 L
.96946 .59882 L
.98011 .60566 L
.99077 .61294 L
Mfstroke
.99077 .61294 m
.99993 .61803 L
s
.003 w
[ ] 0 setdash
0 .10301 m
.01065 .10634 L
.02131 .1097 L
.03196 .11308 L
.04261 .1165 L
.05327 .11995 L
.06392 .12343 L
.07457 .12694 L
.08523 .13049 L
.09588 .13406 L
.10653 .13767 L
.11719 .14131 L
.12784 .14498 L
.13849 .14868 L
.14915 .15242 L
.1598 .1562 L
.17045 .16 L
.18111 .16385 L
.19176 .16773 L
.20241 .17164 L
.21307 .1756 L
.22372 .17958 L
.23437 .18361 L
.24503 .18768 L
.25568 .19178 L
.26633 .19592 L
.27699 .2001 L
.28764 .20433 L
.2983 .20859 L
.30895 .2129 L
.3196 .21724 L
.33026 .22163 L
.34091 .22606 L
.35156 .23054 L
.36222 .23506 L
.37287 .23962 L
.38352 .24423 L
.39418 .24889 L
.40483 .25359 L
.41548 .25834 L
.42614 .26314 L
.43679 .26799 L
.44744 .27289 L
.4581 .27783 L
.46875 .28283 L
.4794 .28788 L
.49006 .29298 L
.50071 .29814 L
.51136 .30335 L
.52202 .30861 L
Mistroke
.53267 .31393 L
.54332 .31931 L
.55398 .32474 L
.56463 .33024 L
.57528 .33579 L
.58594 .3414 L
.59659 .34707 L
.60724 .35281 L
.6179 .3586 L
.62855 .36446 L
.6392 .37039 L
.64986 .37638 L
.66051 .38244 L
.67116 .38857 L
.68182 .39476 L
.69247 .40103 L
.70312 .40736 L
.71378 .41377 L
.72443 .42026 L
.73508 .42681 L
.74574 .43345 L
.75639 .44016 L
.76704 .44695 L
.7777 .45382 L
.78835 .46077 L
.799 .4678 L
.80966 .47492 L
.82031 .48212 L
.83096 .48941 L
.84162 .49679 L
.85227 .50426 L
.86292 .51182 L
.87358 .51948 L
.88423 .52722 L
.89489 .53507 L
.90554 .54301 L
.91619 .55105 L
.92685 .5592 L
.9375 .56745 L
.94815 .5758 L
.95881 .58426 L
.96946 .59284 L
.98011 .60152 L
.99077 .61032 L
Mfstroke
.99077 .61032 m
.99999 .61803 L
s
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01065 .10301 L
.02131 .10301 L
.03196 .10301 L
.04261 .10301 L
.05327 .10404 L
.06392 .10625 L
.07457 .10796 L
.08523 .10951 L
.09588 .11438 L
.10653 .11502 L
.11719 .11823 L
.12784 .12136 L
.13849 .12419 L
.14915 .12618 L
.1598 .12849 L
.17045 .13243 L
.18111 .13394 L
.19176 .13839 L
.20241 .14182 L
.21307 .14524 L
.22372 .14652 L
.23437 .15031 L
.24503 .15119 L
.25568 .16106 L
.26633 .16076 L
.27699 .16528 L
.28764 .16776 L
.2983 .17409 L
.30895 .17535 L
.3196 .17993 L
.33026 .18058 L
.34091 .18558 L
.35156 .19185 L
.36222 .19304 L
.37287 .19999 L
.38352 .20157 L
.39418 .20907 L
.40483 .20957 L
.41548 .21828 L
.42614 .2206 L
.43679 .22803 L
.44744 .22018 L
.4581 .23726 L
.46875 .23519 L
.4794 .24166 L
.49006 .24578 L
.50071 .25585 L
.51136 .25989 L
.52202 .26366 L
Mistroke
.53267 .26708 L
.54332 .27587 L
.55398 .27589 L
.56463 .28308 L
.57528 .28788 L
.58594 .29887 L
.59659 .30099 L
.60724 .30673 L
.6179 .31128 L
.62855 .31614 L
.6392 .3262 L
.64986 .32829 L
.66051 .33887 L
.67116 .34646 L
.68182 .35122 L
.69247 .3529 L
.70312 .35652 L
.71378 .37145 L
.72443 .37367 L
.73508 .38433 L
.74574 .38677 L
.75639 .39698 L
.76704 .39788 L
.7777 .40687 L
.78835 .41344 L
.799 .41966 L
.80966 .43458 L
.82031 .43877 L
.83096 .44781 L
.84162 .45402 L
.85227 .46658 L
.86292 .46863 L
.87358 .48444 L
.88423 .49421 L
.89489 .49801 L
.90554 .50695 L
.91619 .51952 L
.92685 .53226 L
.9375 .53548 L
.94815 .55021 L
.95881 .56408 L
.96946 .57328 L
.98011 .58672 L
.99077 .59992 L
Mfstroke
.99077 .59992 m
1 .61562 L
s
0 .10301 m
.01065 .11693 L
.02131 .12531 L
.03196 .1288 L
.04261 .13402 L
.05327 .1384 L
.06392 .144 L
.07457 .14829 L
.08523 .15492 L
.09588 .16351 L
.10653 .1659 L
.11719 .17001 L
.12784 .17269 L
.13849 .18062 L
.14915 .18204 L
.1598 .18829 L
.17045 .19851 L
.18111 .20041 L
.19176 .20202 L
.20241 .21146 L
.21307 .21385 L
.22372 .22481 L
.23437 .22262 L
.24503 .22966 L
.25568 .23328 L
.26633 .23441 L
.27699 .24639 L
.28764 .24805 L
.2983 .25398 L
.30895 .25566 L
.3196 .26087 L
.33026 .26924 L
.34091 .27502 L
.35156 .2779 L
.36222 .28412 L
.37287 .28664 L
.38352 .29648 L
.39418 .29896 L
.40483 .30107 L
.41548 .30994 L
.42614 .31205 L
.43679 .31988 L
.44744 .32457 L
.4581 .33297 L
.46875 .34126 L
.4794 .34645 L
.49006 .34974 L
.50071 .35108 L
.51136 .35337 L
.52202 .36242 L
Mistroke
.53267 .36709 L
.54332 .37713 L
.55398 .37863 L
.56463 .38288 L
.57528 .38779 L
.58594 .39144 L
.59659 .40589 L
.60724 .40741 L
.6179 .42411 L
.62855 .42002 L
.6392 .42634 L
.64986 .42976 L
.66051 .43947 L
.67116 .44562 L
.68182 .45405 L
.69247 .45286 L
.70312 .46369 L
.71378 .47055 L
.72443 .47461 L
.73508 .48509 L
.74574 .48867 L
.75639 .48995 L
.76704 .50922 L
.7777 .50884 L
.78835 .51254 L
.799 .52445 L
.80966 .52683 L
.82031 .53687 L
.83096 .54521 L
.84162 .55166 L
.85227 .56043 L
.86292 .56345 L
.87358 .57398 L
.88423 .57842 L
.89489 .58573 L
.90554 .58972 L
.91619 .59477 L
.92685 .60231 L
.9375 .60786 L
.94815 .60824 L
.95881 .61222 L
.96946 .61803 L
.98011 .61803 L
.99077 .61803 L
Mfstroke
.99077 .61803 m
.99077 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool20000
00D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo
0P0000040?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo
0P0000040?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo
1000000C0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool00`000000oooo0?oo
o`0I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo000000P0oooo1@00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool500000080oooo000K0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`0000080?ooo`<000005@3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000<0oooo000K0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`000000503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool001/0oooo0P00000K0?ooo`8000002P3oool2000001D0oooo
0P00000;0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo
0P00000L0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000006000000006`3oool010000000oooo0?ooo`3oool3000000/0oooo0P00000@
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0oooo00<0oooo1000000=0?oo
o`800000k03oool001/0oooo00@000000?ooo`3oool000001P3oool3000000l0oooo0P00003W0?oo
o`006`3oool01@000000oooo0?ooo`3oool0000000P0oooo0`00000A0?ooo`030000003oool0oooo
0>40oooo000K0?ooo`030000003oool0oooo00`0oooo1000000?0?ooo`050000003oool0oooo0?oo
o`000000gP3oool001/0oooo0P0000050?ooo`8000002@3oool300000140oooo0P00003M0?ooo`00
6`3oool00`000000oooo0?ooo`0B0?ooo`<000004`3oool200000=P0oooo000K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool3000001D0oooo00<000000?ooo`3oool0dP3o
ool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`H000004@3oool0
0`000000oooo0?ooo`3A0?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00/0oooo1000000B0?ooo`800000cP3oool001/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0<0?ooo`040000003oool00000000001D0oooo0P0000390?ooo`006`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool00000008000005`3oool00`000000oooo0?ooo`330?ooo`00
6`3oool2000001<0oooo0P00000@0?ooo`@000005@3oool00`000000oooo0?ooo`320?ooo`006`3o
ool00`000000oooo0?ooo`0W0?ooo`@00000e`3oool001/0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool00000008000004P3oool200000<00oooo000K0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo000000020000
01D0oooo0P00002k0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`8000004@3oool400000<l0
oooo000K0?ooo`030000003oool0oooo0340oooo1@00000D0?ooo`800000]P3oool001/0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000008000005P3o
ool200000;40oooo000K0?ooo`8000008P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo008000005@3oool01@000000oooo0?ooo`3oool000000:d0oooo000K0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0403oool010000000oooo00000000000I0?ooo`030000003o
ool0oooo0:X0oooo000K0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool2
00000<@0oooo000K0?ooo`030000003oool0oooo03h0oooo0`00000G0?ooo`<00000Y`3oool000P0
oooo0P0000040?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0D0?ooo`@000006@3oool00`000000oooo0?ooo`2R0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool010000000
oooo0?ooo`3oool2000001@0oooo0P00000H0?ooo`030000003oool0oooo0:40oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool200000300oooo00<000000?oo
o`3oool0503oool3000001T0oooo00<000000?ooo`3oool0W@3oool000L0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04T0oooo0`00000G0?oo
o`030000003oool0oooo09`0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`8000005`3oool4000001P0oooo00<00000
0?ooo`3oool0V03oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool00000008000005P3oool00`000000oooo0?ooo`2G0?ooo`006`3oool00`000000
oooo0?ooo`1?0?ooo`80000000<0oooo0000000000005`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo08l0oooo000K0?ooo`030000003oool0oooo03H0oooo0P00000I0?ooo`800000
00<0oooo0000000000005P3oool010000000oooo0?ooo`00002B0?ooo`006`3oool00`000000oooo
0?ooo`0k0?ooo`8000005`3oool010000000oooo00000000002Z0?ooo`006`3oool200000440oooo
00<000000?ooo`3oool04`3oool010000000oooo00000000000I0?ooo`030000003oool0oooo08`0
oooo000K0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool05P3oool3000001H0oooo
00D000000?ooo`3oool0oooo0000002:0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`<00000
6@3oool00`000000oooo0?ooo`270?ooo`006`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo01L0oooo1000000I0?ooo`030000003oool0oooo08@0oooo000K0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0603oool4000001P0oooo00<000000?ooo`3oool0P`3oool0
01/0oooo00<000000?ooo`3oool0B@3oool2000001L0oooo1000002L0?ooo`006`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo01D0oooo0`00002J0?ooo`006`3oool2000004l0oooo
0P00000G0?ooo`<000005@3oool300000800oooo000K0?ooo`030000003oool0oooo06T0oooo1000
002E0?ooo`006`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`0000000000603oool00`000000oooo0?ooo`1h0?ooo`006`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`00000000005`3oool00`000000oooo0?oo
o`1g0?ooo`006`3oool00`000000oooo0?ooo`1a0?ooo`800000603oool2000007D0oooo000K0?oo
o`030000003oool0oooo05H0oooo0`00000J0?ooo`<00000S03oool001/0oooo0P00001d0?ooo`03
0000003oool0oooo00800000603oool00`000000oooo0?ooo`1_0?ooo`006`3oool00`000000oooo
0?ooo`1K0?ooo`800000603oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo06h0
oooo000K0?ooo`030000003oool0oooo07L0oooo00@000000?ooo`0000000000Q`3oool001/0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G0?ooo`D000005P3oool00`000000oooo
0?ooo`1[0?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01P0oooo0P00
00000`3oool000000000000E0?ooo`030000003oool0oooo06X0oooo00080?ooo`800000103oool2
000000D0oooo0`0000030?ooo`030000003oool0oooo06@0oooo0`00000G0?ooo`040000003oool0
0000000001L0oooo00<000000?ooo`3oool0IP3oool000L0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0800oooo00<000000?ooo`0000005`3o
ool00`000000oooo0?ooo`1U0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`D000000`3o
ool2000006X0oooo00<000000?ooo`3oool05P3oool4000007`0oooo00070?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo01L0oooo00@000000?ooo`00000000005@3oool2000006<0oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`0000000000N03oool000P0oooo0P00000;0?ooo`80
0000103oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01L0oooo1000000F0?ooo`03
0000003oool0oooo05d0oooo000K0?ooo`030000003oool0oooo08X0oooo1000000E0?ooo`030000
003oool0oooo05`0oooo000K0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0603o
ool2000007<0oooo000K0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool06@3oool2
000001D0oooo00<000000?ooo`3oool0F@3oool001/0oooo0P00002B0?ooo`<000004`3oool00`00
0000oooo0?ooo`1H0?ooo`006`3oool00`000000oooo0?ooo`1f0?ooo`8000006@3oool00`000000
oooo0?ooo`02000006`0oooo000K0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
603oool2000000040?ooo`000000000000000180oooo00<000000?ooo`3oool0E@3oool001/0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0E03oool001/0oooo00<000000?ooo`3oool0O03oool010000000oooo0?oo
o`3oool2000001D0oooo00@000000?ooo`0000000000503oool200000540oooo000K0?ooo`030000
003oool0oooo09P0oooo0P0000000`3oool000000000001U0?ooo`006`3oool2000009`0oooo00@0
00000?ooo`00000000005@3oool00`000000oooo0?ooo`1;0?ooo`006`3oool00`000000oooo0?oo
o`240?ooo`8000005`3oool010000000oooo00000000000C0?ooo`030000003oool0oooo04/0oooo
000K0?ooo`030000003oool0oooo09l0oooo00@000000?ooo`0000000000G`3oool001/0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000001<0oooo00<0
00000?ooo`3oool0B03oool001/0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0G
0?ooo`<000004P3oool00`000000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0000000000180oooo00<000000?oo
o`3oool0A03oool001/0oooo0P00002C0?ooo`030000003oool0oooo0180oooo00@000000?ooo`00
000000004@3oool00`000000oooo0?ooo`130?ooo`006`3oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool00P00000C0?ooo`030000003oool0oooo03l0
oooo000K0?ooo`030000003oool0oooo0:T0oooo00@000000?ooo`000000oooo0P00000A0?ooo`03
0000003oool0oooo03l0oooo000K0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
503oool010000000oooo00000000000C0?ooo`030000003oool0oooo03/0oooo000K0?ooo`030000
003oool0oooo09L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000001<0
oooo00<000000?ooo`3oool0>P3oool000P0oooo0P0000040?ooo`8000000`3oool3000000D0oooo
00<000000?ooo`3oool0[`3oool010000000oooo0?ooo`00001?0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`0D0?ooo`040000003oool00000000001<0oooo00<000000?ooo`3oool0=`3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`800000W03o
ool00`000000oooo0?ooo`0E0?ooo`040000003oool0000000000180oooo00<000000?ooo`3oool0
=P3oool000L0oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool0
]@3oool010000000oooo0000000000190?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0000000C0?ooo`03
0000003oool0oooo0380oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0
W@3oool2000000<0oooo00<000000?ooo`3oool05@3oool200000140oooo00<000000?ooo`3oool0
<P3oool001/0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo000004D0oooo000K0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool04P3o
ool010000000oooo0000000000130?ooo`006`3oool200000:P0oooo00<000000?ooo`3oool04`3o
ool010000000oooo00000000000?0?ooo`800000<03oool001/0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo000000100?ooo`006`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo01D0oooo0P00000n0?ooo`006`3oool00`000000oooo0?ooo`2[0?ooo`8000004`3oool20000
0080oooo00<000000?ooo`3oool03@3oool2000002`0oooo000K0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000000003/0oooo000K0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000000003T0oooo
000K0?ooo`030000003oool0oooo0<H0oooo0P0000000`3oool000000000000=0?ooo`030000003o
ool0oooo02L0oooo000K0?ooo`800000]03oool00`000000oooo0?ooo`0B0?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool09P3oool001/0oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000l0oooo0P00000T0?ooo`006`3oool0
0`000000oooo0?ooo`3:0?ooo`80000000<0oooo0000000000003P3oool00`000000oooo0?ooo`0R
0?ooo`006`3oool00`000000oooo0?ooo`2g0?ooo`<000004P3oool010000000oooo0?ooo`00000b
0?ooo`006`3oool00`000000oooo0?ooo`3@0?ooo`800000<03oool001/0oooo00<000000?ooo`3o
ool0cP3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool07`3oool001/0
oooo00<000000?ooo`3oool0^`3oool300000180oooo00<000000?ooo`3oool00P00000;0?ooo`03
0000003oool0oooo01l0oooo000K0?ooo`800000`@3oool200000100oooo00@000000?ooo`3oool0
0000;03oool001/0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0>0?ooo`050000
003oool0oooo0?ooo`000000:`3oool001/0oooo00<000000?ooo`3oool0e03oool010000000oooo
0?ooo`00000<0?ooo`800000703oool001/0oooo00<000000?ooo`3oool0eP3oool010000000oooo
00000000000X0?ooo`006`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0180oooo
00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0G0?ooo`00203oool2000000@0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`340?ooo`050000003oool0oooo0?ooo`000000
4P3oool2000000`0oooo00<000000?ooo`3oool05P3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3o
ool03@3oool200000080oooo00<000000?ooo`3oool08P3oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`800000g03oool2000000030?ooo`0000000000
0280oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool03P3oool2000000030?ooo`000000oooo00T0oooo00<000000?oo
o`3oool0503oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0<`0oooo0P00000A0?ooo`030000003oool0000000X0oooo00<00000
0?ooo`3oool04`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3O0?oo
o`040000003oool0oooo000001l0oooo000K0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool03P3oool010000000oooo00000000000M0?ooo`006`3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool200000140oooo000K0?ooo`80
0000i03oool00`000000oooo0?ooo`02000001X0oooo000K0?ooo`030000003oool0oooo0=@0oooo
0P00000?0?ooo`040000003oool0oooo000001T0oooo000K0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool03`3oool010000000oooo0000000000080?ooo`030000003oool0oooo00`0
oooo000K0?ooo`030000003oool0oooo0>P0oooo0P0000000`3oool000000?ooo`060?ooo`030000
003oool0oooo00`0oooo000K0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
oooo00h0oooo00@000000?ooo`3oool00000503oool001/0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool02@3o
ool001/0oooo0P00003O0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0oooo0>h0oooo00<00000
0?ooo`3oool00P00000?0?ooo`006`3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo
00`0oooo00@000000?ooo`3oool000003P3oool001/0oooo00<000000?ooo`3oool0hP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01P3oool001/0
oooo00<000000?ooo`3oool0lP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00D0oooo000K0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0000000;0?ooo`006`3oool00`000000oooo0?ooo`3V0?ooo`8000003@3oool4000000T0oooo
000K0?ooo`800000j`3oool2000000/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`006`3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`3i0?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3o
ool0k`3oool2000000X0oooo0`0000000`3oool000000?ooo`010?ooo`004`3oool5000000<0oooo
00<000000?ooo`3oool0m03oool2000000L0oooo0P0000030?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?d0oooo0`0000020?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`800000n@3oool300000080oooo0P0000010?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`800000
o`3oool;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.261311, \
0.00558385, 0.00747503}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.0710384 0.355192 [
[.125 .05854 -12 -9 ]
[.125 .05854 12 0 ]
[.25 .05854 -9 -9 ]
[.25 .05854 9 0 ]
[.375 .05854 -12 -9 ]
[.375 .05854 12 0 ]
[.5 .05854 -3 -9 ]
[.5 .05854 3 0 ]
[.625 .05854 -12 -9 ]
[.625 .05854 12 0 ]
[.75 .05854 -9 -9 ]
[.75 .05854 9 0 ]
[.875 .05854 -12 -9 ]
[.875 .05854 12 0 ]
[1 .05854 -3 -9 ]
[1 .05854 3 0 ]
[-0.0125 .15984 -24 -4.5 ]
[-0.0125 .15984 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33743 -24 -4.5 ]
[-0.0125 .33743 0 4.5 ]
[-0.0125 .42623 -6 -4.5 ]
[-0.0125 .42623 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .60383 -18 -4.5 ]
[-0.0125 .60383 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .07104 m
.125 .07729 L
s
[(0.25)] .125 .05854 0 1 Mshowa
.25 .07104 m
.25 .07729 L
s
[(0.5)] .25 .05854 0 1 Mshowa
.375 .07104 m
.375 .07729 L
s
[(0.75)] .375 .05854 0 1 Mshowa
.5 .07104 m
.5 .07729 L
s
[(1)] .5 .05854 0 1 Mshowa
.625 .07104 m
.625 .07729 L
s
[(1.25)] .625 .05854 0 1 Mshowa
.75 .07104 m
.75 .07729 L
s
[(1.5)] .75 .05854 0 1 Mshowa
.875 .07104 m
.875 .07729 L
s
[(1.75)] .875 .05854 0 1 Mshowa
1 .07104 m
1 .07729 L
s
[(2)] 1 .05854 0 1 Mshowa
.125 Mabswid
.025 .07104 m
.025 .07479 L
s
.05 .07104 m
.05 .07479 L
s
.075 .07104 m
.075 .07479 L
s
.1 .07104 m
.1 .07479 L
s
.15 .07104 m
.15 .07479 L
s
.175 .07104 m
.175 .07479 L
s
.2 .07104 m
.2 .07479 L
s
.225 .07104 m
.225 .07479 L
s
.275 .07104 m
.275 .07479 L
s
.3 .07104 m
.3 .07479 L
s
.325 .07104 m
.325 .07479 L
s
.35 .07104 m
.35 .07479 L
s
.4 .07104 m
.4 .07479 L
s
.425 .07104 m
.425 .07479 L
s
.45 .07104 m
.45 .07479 L
s
.475 .07104 m
.475 .07479 L
s
.525 .07104 m
.525 .07479 L
s
.55 .07104 m
.55 .07479 L
s
.575 .07104 m
.575 .07479 L
s
.6 .07104 m
.6 .07479 L
s
.65 .07104 m
.65 .07479 L
s
.675 .07104 m
.675 .07479 L
s
.7 .07104 m
.7 .07479 L
s
.725 .07104 m
.725 .07479 L
s
.775 .07104 m
.775 .07479 L
s
.8 .07104 m
.8 .07479 L
s
.825 .07104 m
.825 .07479 L
s
.85 .07104 m
.85 .07479 L
s
.9 .07104 m
.9 .07479 L
s
.925 .07104 m
.925 .07479 L
s
.95 .07104 m
.95 .07479 L
s
.975 .07104 m
.975 .07479 L
s
.25 Mabswid
0 .07104 m
1 .07104 L
s
0 .15984 m
.00625 .15984 L
s
[(0.25)] -0.0125 .15984 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33743 m
.00625 .33743 L
s
[(0.75)] -0.0125 .33743 1 0 Mshowa
0 .42623 m
.00625 .42623 L
s
[(1)] -0.0125 .42623 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(1.25)] -0.0125 .51503 1 0 Mshowa
0 .60383 m
.00625 .60383 L
s
[(1.5)] -0.0125 .60383 1 0 Mshowa
.125 Mabswid
0 .0888 m
.00375 .0888 L
s
0 .10656 m
.00375 .10656 L
s
0 .12432 m
.00375 .12432 L
s
0 .14208 m
.00375 .14208 L
s
0 .1776 m
.00375 .1776 L
s
0 .19536 m
.00375 .19536 L
s
0 .21312 m
.00375 .21312 L
s
0 .23087 m
.00375 .23087 L
s
0 .26639 m
.00375 .26639 L
s
0 .28415 m
.00375 .28415 L
s
0 .30191 m
.00375 .30191 L
s
0 .31967 m
.00375 .31967 L
s
0 .35519 m
.00375 .35519 L
s
0 .37295 m
.00375 .37295 L
s
0 .39071 m
.00375 .39071 L
s
0 .40847 m
.00375 .40847 L
s
0 .44399 m
.00375 .44399 L
s
0 .46175 m
.00375 .46175 L
s
0 .47951 m
.00375 .47951 L
s
0 .49727 m
.00375 .49727 L
s
0 .53279 m
.00375 .53279 L
s
0 .55055 m
.00375 .55055 L
s
0 .56831 m
.00375 .56831 L
s
0 .58607 m
.00375 .58607 L
s
0 .05328 m
.00375 .05328 L
s
0 .03552 m
.00375 .03552 L
s
0 .01776 m
.00375 .01776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .08395 m
.01 .15011 L
.02 .16005 L
.03 .17337 L
.04 .18513 L
.05 .19571 L
.06 .20269 L
.07 .20904 L
.08 .2161 L
.09 .22232 L
.1 .22883 L
.11 .23466 L
.12 .23964 L
.13 .24625 L
.14 .25325 L
.15 .25965 L
.16 .26472 L
.17 .27021 L
.18 .27537 L
.19 .28153 L
.2 .28666 L
.21 .29144 L
.22 .29643 L
.23 .3031 L
.24 .30792 L
.25 .31357 L
.26 .3172 L
.27 .32172 L
.28 .32756 L
.29 .33165 L
.3 .33704 L
.31 .34021 L
.32 .3445 L
.33 .34776 L
.34 .35155 L
.35 .35623 L
.36 .36059 L
.37 .36488 L
.38 .36822 L
.39 .37179 L
.4 .37646 L
.41 .38118 L
.42 .38416 L
.43 .38784 L
.44 .39134 L
.45 .39532 L
.46 .39947 L
.47 .40317 L
.48 .4066 L
.49 .4092 L
Mistroke
.5 .41328 L
.51 .41637 L
.52 .42048 L
.53 .42388 L
.54 .42792 L
.55 .43125 L
.56 .4338 L
.57 .43673 L
.58 .44021 L
.59 .44287 L
.6 .44589 L
.61 .44884 L
.62 .45241 L
.63 .45473 L
.64 .4579 L
.65 .46094 L
.66 .46326 L
.67 .46621 L
.68 .46914 L
.69 .47231 L
.7 .47493 L
.71 .47818 L
.72 .48225 L
.73 .48527 L
.74 .49016 L
.75 .49381 L
.76 .49836 L
.77 .5032 L
.78 .50607 L
.79 .50935 L
.8 .51356 L
.81 .51955 L
.82 .5232 L
.83 .52811 L
.84 .53225 L
.85 .5372 L
.86 .54191 L
.87 .54719 L
.88 .5522 L
.89 .55486 L
.9 .55917 L
.91 .56304 L
.92 .56703 L
.93 .5728 L
.94 .57568 L
.95 .58036 L
.96 .58552 L
.97 .59136 L
.98 .59428 L
.99 .59552 L
Mistroke
1 .59747 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000l0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`800000503oool500000180oooo1@0000020?ooo`8000000`3oool4
000000<0oooo0P00000>0?ooo`D000000P3oool2000000@0oooo0P00000>0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000001D0oooo100000020?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00@000000?ooo`3oool000002@3o
ool2000000h0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo000K0?ooo`030000003oool0
oooo01<0oooo0P00000:0?ooo`800000103oool3000000h0oooo0P00000:0?ooo`<000003P3oool2
000000T0oooo100000030?ooo`<00000503oool2000001D0oooo0P00000:0?ooo`800000103oool3
000000h0oooo0P00000:0?ooo`<000003P3oool2000000T0oooo100000030?ooo`<000005@3oool2
000000<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooool000000`0000030?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`80
0000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3o
ool40?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool300000?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0000003o0?ooo`<0oooo00020?ooo`800000103oool2000000<0oooo100000030?ooo`80
00001@3oool00`000000oooo0000003o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00800000o`3oool10?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool200000?l0oooo103oool000050?ooo`000000oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3oool0
0080oooo0P00000:0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool00`3oool20000
0?d0oooo000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0nP3oool001/0oooo
0P0000060?ooo`030000003oool0oooo0?X0oooo000K0?ooo`030000003oool0oooo00H0oooo0P00
003j0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0m`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0m@3oool001/0oooo00<000000?ooo`3oool02`3o
ool200000?D0oooo000K0?ooo`030000003oool0oooo00d0oooo0P00003c0?ooo`006`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?00oooo000K0?ooo`8000004@3oool00`000000
oooo0?ooo`3_0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0>h0oooo
000K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0k03oool001/0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`3Z0?ooo`006`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0>P0oooo000K0?ooo`800000603oool00`000000oooo0?ooo`3X0?ooo`00
6`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>H0oooo00080?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0i03o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0hP3oool000L0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`800000803oool00`000000oooo0?ooo`3P0?ooo`001`3o
ool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0=h0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0=h0oooo00080?ooo`8000002P3o
ool3000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3L0?ooo`006`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0=X0oooo000K0?ooo`800000:03oool00`00
0000oooo0?ooo`3H0?ooo`006`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=H0
oooo000K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0e03oool001/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`3B0?ooo`006`3oool200000300oooo00<00000
0?ooo`3oool0d03oool001/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3>0?oo
o`006`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0<`0oooo000K0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0bP3oool001/0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`3:0?ooo`006`3oool2000003P0oooo00<000000?ooo`3oool0b03oool0
01/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`360?ooo`006`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0<@0oooo000K0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0`P3oool001/0oooo0P0000100?ooo`800000`@3oool001/0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`2m0?ooo`006`3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0;/0oooo00020?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool00P3oool2000000D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2i0?ooo`00
00D0oooo0000003oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0]`3oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0P00001;0?ooo`030000003oool0oooo0;D0oooo00001@3oool000000?ooo`3oool00000
00/0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`000000/`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0CP3oool010000000oooo0000
0000002`0?ooo`000P3oool2000000T0oooo100000030?ooo`<00000103oool00`000000oooo0?oo
o`1B0?ooo`800000[P3oool001/0oooo0P00001F0?ooo`030000003oool0oooo0:X0oooo000K0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0Z03oool001/0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`2V0?ooo`006`3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool000000:@0oooo000K0?ooo`030000003oool0oooo05d0oooo00@000000?ooo`0000000000
X@3oool001/0oooo0P00001R0?ooo`800000W`3oool001/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`2K0?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
09T0oooo000K0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`000000U`3oool001/0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0000002E0?ooo`006`3oool2000006l0oooo0P00
002B0?ooo`006`3oool00`000000oooo0?ooo`1`0?ooo`800000T03oool001/0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`2<0?ooo`006`3oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0000008X0oooo000K0?ooo`800000NP3oool00`000000oooo0?ooo`260?ooo`006`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo08<0oooo000K0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`000000P@3oool001<0oooo1@0000030?ooo`030000003oool0oooo
0840oooo0`00001n0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0NP3oool001D0oooo00<000000?ooo`3oool00`3oool2000008P0oooo
00<000000?ooo`3oool0N03oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`290?ooo`030000003oool0000007H0oooo000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0S@3oool2000007<0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0000006l0oooo000K0?ooo`800000U@3oool00`000000oooo0?ooo`1[0?ooo`00
6`3oool00`000000oooo0?ooo`2F0?ooo`@00000J03oool001/0oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`1T0?ooo`006`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
00000680oooo000K0?ooo`030000003oool0oooo0:40oooo0P00001O0?ooo`006`3oool200000:D0
oooo00<000000?ooo`000000F`3oool001/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0000001G0?ooo`006`3oool00`000000oooo0?ooo`2Z0?ooo`040000003oool00000000005@0oooo
000K0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`000000D03oool001/0oooo0P00002d
0?ooo`030000003oool0oooo04`0oooo000K0?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool0BP3oool001/0oooo00<000000?ooo`3oool0]`3oool2000004T0oooo000K0?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`000000A@3oool001/0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo000000130?ooo`006`3oool200000<40oooo00<000000?ooo`3oool0?`3oool0
01/0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0m0?ooo`006`3oool00`000000
oooo0?ooo`340?ooo`030000003oool0oooo03/0oooo00000`3oool000000000000300000080oooo
0P0000030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0aP3oool2000003X0oooo
00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`000000=P3oool000<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00
003<0?ooo`030000003oool0oooo03@0oooo00030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0000000b
0?ooo`000`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3?0?ooo`030000003oool000000300oooo00020?oo
o`8000002P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`000000;P3oool001/0oooo0P00003F0?ooo`030000003oool0oooo02X0oooo000K0?ooo`030000
003oool0oooo0=L0oooo00<000000?ooo`3oool0:03oool001/0oooo00<000000?ooo`3oool0f@3o
ool2000002L0oooo000K0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0903oool0
01/0oooo00<000000?ooo`3oool0g03oool2000002@0oooo000K0?ooo`800000g`3oool00`000000
oooo0000000Q0?ooo`006`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo01d0oooo
000K0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool06`3oool001/0oooo00<00000
0?ooo`3oool0iP3oool00`000000oooo0?ooo`0I0?ooo`006`3oool200000>T0oooo00<000000?oo
o`3oool05`3oool001/0oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`0E0?ooo`00
6`3oool00`000000oooo0?ooo`3/0?ooo`@000004P3oool001/0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0>0?ooo`006`3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0
oooo00`0oooo000K0?ooo`800000mP3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`3e0?ooo`030000003oool0000000X0oooo00070?ooo`D000000P3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0?T0oooo00@000000?ooo`3oool000001@3oool000T0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?d0
oooo00<000000?ooo`3oool00P3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`800000o`3oool40?ooo`002@3oool00`000000oooo0?ooo`080?ooo`8000001@3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo00090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool30000
00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.295284, \
0.00778854, 0.0109638}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Graphics::"gptn"\), \(\(:\)\(\ \)\), "\<\"Coordinate \
\\!\\(Indeterminate\\) in \\!\\({0, Indeterminate}\\) is not a floating-point \
number. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Graphics::gptn\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.0710384 0.355192 [
[.125 .05854 -12 -9 ]
[.125 .05854 12 0 ]
[.25 .05854 -9 -9 ]
[.25 .05854 9 0 ]
[.375 .05854 -12 -9 ]
[.375 .05854 12 0 ]
[.5 .05854 -3 -9 ]
[.5 .05854 3 0 ]
[.625 .05854 -12 -9 ]
[.625 .05854 12 0 ]
[.75 .05854 -9 -9 ]
[.75 .05854 9 0 ]
[.875 .05854 -12 -9 ]
[.875 .05854 12 0 ]
[1 .05854 -3 -9 ]
[1 .05854 3 0 ]
[-0.0125 .15984 -24 -4.5 ]
[-0.0125 .15984 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33743 -24 -4.5 ]
[-0.0125 .33743 0 4.5 ]
[-0.0125 .42623 -6 -4.5 ]
[-0.0125 .42623 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .60383 -18 -4.5 ]
[-0.0125 .60383 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .07104 m
.125 .07729 L
s
[(0.25)] .125 .05854 0 1 Mshowa
.25 .07104 m
.25 .07729 L
s
[(0.5)] .25 .05854 0 1 Mshowa
.375 .07104 m
.375 .07729 L
s
[(0.75)] .375 .05854 0 1 Mshowa
.5 .07104 m
.5 .07729 L
s
[(1)] .5 .05854 0 1 Mshowa
.625 .07104 m
.625 .07729 L
s
[(1.25)] .625 .05854 0 1 Mshowa
.75 .07104 m
.75 .07729 L
s
[(1.5)] .75 .05854 0 1 Mshowa
.875 .07104 m
.875 .07729 L
s
[(1.75)] .875 .05854 0 1 Mshowa
1 .07104 m
1 .07729 L
s
[(2)] 1 .05854 0 1 Mshowa
.125 Mabswid
.025 .07104 m
.025 .07479 L
s
.05 .07104 m
.05 .07479 L
s
.075 .07104 m
.075 .07479 L
s
.1 .07104 m
.1 .07479 L
s
.15 .07104 m
.15 .07479 L
s
.175 .07104 m
.175 .07479 L
s
.2 .07104 m
.2 .07479 L
s
.225 .07104 m
.225 .07479 L
s
.275 .07104 m
.275 .07479 L
s
.3 .07104 m
.3 .07479 L
s
.325 .07104 m
.325 .07479 L
s
.35 .07104 m
.35 .07479 L
s
.4 .07104 m
.4 .07479 L
s
.425 .07104 m
.425 .07479 L
s
.45 .07104 m
.45 .07479 L
s
.475 .07104 m
.475 .07479 L
s
.525 .07104 m
.525 .07479 L
s
.55 .07104 m
.55 .07479 L
s
.575 .07104 m
.575 .07479 L
s
.6 .07104 m
.6 .07479 L
s
.65 .07104 m
.65 .07479 L
s
.675 .07104 m
.675 .07479 L
s
.7 .07104 m
.7 .07479 L
s
.725 .07104 m
.725 .07479 L
s
.775 .07104 m
.775 .07479 L
s
.8 .07104 m
.8 .07479 L
s
.825 .07104 m
.825 .07479 L
s
.85 .07104 m
.85 .07479 L
s
.9 .07104 m
.9 .07479 L
s
.925 .07104 m
.925 .07479 L
s
.95 .07104 m
.95 .07479 L
s
.975 .07104 m
.975 .07479 L
s
.25 Mabswid
0 .07104 m
1 .07104 L
s
0 .15984 m
.00625 .15984 L
s
[(0.25)] -0.0125 .15984 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33743 m
.00625 .33743 L
s
[(0.75)] -0.0125 .33743 1 0 Mshowa
0 .42623 m
.00625 .42623 L
s
[(1)] -0.0125 .42623 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(1.25)] -0.0125 .51503 1 0 Mshowa
0 .60383 m
.00625 .60383 L
s
[(1.5)] -0.0125 .60383 1 0 Mshowa
.125 Mabswid
0 .0888 m
.00375 .0888 L
s
0 .10656 m
.00375 .10656 L
s
0 .12432 m
.00375 .12432 L
s
0 .14208 m
.00375 .14208 L
s
0 .1776 m
.00375 .1776 L
s
0 .19536 m
.00375 .19536 L
s
0 .21312 m
.00375 .21312 L
s
0 .23087 m
.00375 .23087 L
s
0 .26639 m
.00375 .26639 L
s
0 .28415 m
.00375 .28415 L
s
0 .30191 m
.00375 .30191 L
s
0 .31967 m
.00375 .31967 L
s
0 .35519 m
.00375 .35519 L
s
0 .37295 m
.00375 .37295 L
s
0 .39071 m
.00375 .39071 L
s
0 .40847 m
.00375 .40847 L
s
0 .44399 m
.00375 .44399 L
s
0 .46175 m
.00375 .46175 L
s
0 .47951 m
.00375 .47951 L
s
0 .49727 m
.00375 .49727 L
s
0 .53279 m
.00375 .53279 L
s
0 .55055 m
.00375 .55055 L
s
0 .56831 m
.00375 .56831 L
s
0 .58607 m
.00375 .58607 L
s
0 .05328 m
.00375 .05328 L
s
0 .03552 m
.00375 .03552 L
s
0 .01776 m
.00375 .01776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
.01 .08044 m
.02 .0897 L
.03 .09883 L
.04 .10782 L
.05 .11669 L
.06 .12543 L
.07 .13404 L
.08 .14254 L
.09 .15092 L
.1 .15918 L
.11 .16733 L
.12 .17536 L
.13 .18329 L
.14 .19112 L
.15 .19884 L
.16 .20646 L
.17 .21398 L
.18 .2214 L
.19 .22872 L
.2 .23596 L
.21 .2431 L
.22 .25015 L
.23 .25712 L
.24 .264 L
.25 .27079 L
.26 .2775 L
.27 .28413 L
.28 .29068 L
.29 .29715 L
.3 .30355 L
.31 .30987 L
.32 .31611 L
.33 .32229 L
.34 .32839 L
.35 .33442 L
.36 .34039 L
.37 .34628 L
.38 .35211 L
.39 .35788 L
.4 .36358 L
.41 .36922 L
.42 .37479 L
.43 .38031 L
.44 .38577 L
.45 .39116 L
.46 .3965 L
.47 .40179 L
.48 .40702 L
.49 .41219 L
.5 .41731 L
Mistroke
.51 .42238 L
.52 .42739 L
.53 .43235 L
.54 .43727 L
.55 .44213 L
.56 .44694 L
.57 .45171 L
.58 .45643 L
.59 .4611 L
.6 .46572 L
.61 .47031 L
.62 .47484 L
.63 .47933 L
.64 .48378 L
.65 .48819 L
.66 .49256 L
.67 .49688 L
.68 .50116 L
.69 .50541 L
.7 .50961 L
.71 .51378 L
.72 .5179 L
.73 .52199 L
.74 .52604 L
.75 .53006 L
.76 .53404 L
.77 .53798 L
.78 .54189 L
.79 .54576 L
.8 .5496 L
.81 .55341 L
.82 .55718 L
.83 .56092 L
.84 .56462 L
.85 .5683 L
.86 .57194 L
.87 .57556 L
.88 .57914 L
.89 .58269 L
.9 .58621 L
.91 .5897 L
.92 .59317 L
.93 .5966 L
.94 .60001 L
.95 .60339 L
.96 .60674 L
.97 .61006 L
.98 .61336 L
.99 .61663 L
Mfstroke
.99 .61663 m
.99433 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000l0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`800000503oool500000180oooo1@0000020?ooo`8000000`3oool4
000000<0oooo0P00000>0?ooo`D000000P3oool2000000@0oooo0P00000>0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000001D0oooo100000020?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00@000000?ooo`3oool000002@3o
ool2000000h0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo000K0?ooo`030000003oool0
oooo01<0oooo0P00000:0?ooo`800000103oool3000000h0oooo0P00000:0?ooo`<000003P3oool2
000000T0oooo100000030?ooo`<00000503oool2000001D0oooo0P00000:0?ooo`800000103oool3
000000h0oooo0P00000:0?ooo`<000003P3oool2000000T0oooo100000030?ooo`<000005@3oool2
000000<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooool000000`0000030?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`030000003oool0oooo00800000o`3oool1
0?ooo`006`3oool2000000<0oooo00<000000?ooo`3oool0o@3oool001/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3l0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?`0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0n`3o
ool001/0oooo00<000000?ooo`3oool01@3oool200000?/0oooo000K0?ooo`800000203oool00`00
0000oooo0?ooo`3h0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`800000n03oool001/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3e0?ooo`006`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?@0oooo000K0?ooo`8000003@3oool00`000000oooo0?ooo`3c
0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?80oooo000K0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0l@3oool001/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3`0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0>l0oooo000K0?ooo`8000004P3oool00`000000oooo0?ooo`3^0?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`800000kP3oool00080oooo0P0000040?ooo`8000000`3oool4000000<0
oooo0P0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0j`3oool000050?oo
o`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3Z0?ooo`0000D0oooo0000003o
ool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool20000
01L0oooo00<000000?ooo`3oool0j@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0G0?ooo`800000j@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3V0?ooo`000P3oool20000
00X0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0J0?ooo`800000iP3oool001/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3S0?ooo`006`3oool2000001h0oooo
00<000000?ooo`3oool0hP3oool001/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3Q0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`800000h@3oool001/0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`3N0?ooo`006`3oool2000002<0oooo00<000000?ooo`3o
ool0g@3oool001/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3L0?ooo`006`3o
ool00`000000oooo0?ooo`0T0?ooo`800000g03oool001/0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`3I0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0=P0oooo000K0?ooo`800000:@3oool00`000000oooo0?ooo`3G0?ooo`006`3oool00`000000oooo
0?ooo`0Y0?ooo`800000e`3oool001/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`3D0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`800000e03oool001/0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3A0?ooo`006`3oool200000300oooo00<000000?ooo`3o
ool0d03oool001/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3?0?ooo`00203o
ool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0a0?ooo`800000c`3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0c03oool000L0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`800000=@3oool200000<`0oooo00070?ooo`040000003o
ool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo03H0oooo0P00003:0?ooo`001`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`370?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0aP3oool001/0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`350?ooo`006`3oool2000003`0oooo0P0000350?ooo`006`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0<80oooo000K0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0`@3oool001/0oooo00<000000?ooo`3oool0?`3oool200000<40oooo000K
0?ooo`800000@P3oool200000;l0oooo000K0?ooo`030000003oool0oooo04<0oooo0P00002m0?oo
o`006`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0;X0oooo000K0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0^@3oool001/0oooo00<000000?ooo`3oool0A`3o
ool200000;T0oooo000K0?ooo`800000BP3oool200000;L0oooo000K0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0]03oool001/0oooo00<000000?ooo`3oool0C03oool200000;@0
oooo000K0?ooo`030000003oool0oooo04h0oooo0P00002b0?ooo`006`3oool200000540oooo00<0
00000?ooo`3oool0[`3oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2^
0?ooo`006`3oool00`000000oooo0?ooo`1B0?ooo`800000[P3oool00080oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`1D0?ooo`80
0000[03oool000050?ooo`000000oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`800000ZP3oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0P00001I0?ooo`030000003oool0oooo0:L0oooo00001@3oool000000?ooo`3oool00000
00/0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo05T0oooo0P00002W
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1K0?ooo`800000Y@3oool00080oooo0P000009
0?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2R
0?ooo`006`3oool2000005l0oooo0P00002R0?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`80
0000X03oool001/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2M0?ooo`006`3o
ool00`000000oooo0?ooo`1S0?ooo`800000W@3oool001/0oooo00<000000?ooo`3oool0I@3oool3
000009X0oooo000K0?ooo`800000J@3oool2000009P0oooo000K0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0U@3oool001/0oooo00<000000?ooo`3oool0J`3oool2000009D0oooo
000K0?ooo`030000003oool0oooo06d0oooo0P00002C0?ooo`006`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0900oooo000K0?ooo`800000L@3oool200000900oooo000K0?ooo`03
0000003oool0oooo0780oooo0P00002>0?ooo`006`3oool00`000000oooo0?ooo`1d0?ooo`800000
S03oool001/0oooo00<000000?ooo`3oool0MP3oool2000008X0oooo000K0?ooo`800000N@3oool2
000008P0oooo000K0?ooo`030000003oool0oooo07X0oooo0P0000260?ooo`006`3oool00`000000
oooo0?ooo`1l0?ooo`800000Q03oool001<0oooo1@0000030?ooo`030000003oool0oooo07h0oooo
0P0000220?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool00`3oool200000880oooo0`00001n
0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08@0oooo0P00001l0?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0N@3oool001@0oooo0P0000050?ooo`030000003oool0oooo08L0oooo0P00001i0?ooo`006`3o
ool2000008X0oooo0`00001f0?ooo`006`3oool00`000000oooo0?ooo`2<0?ooo`800000M03oool0
01/0oooo00<000000?ooo`3oool0SP3oool300000740oooo000K0?ooo`030000003oool0oooo0940
oooo0P00001_0?ooo`006`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo06`0oooo
000K0?ooo`800000U@3oool2000006`0oooo000K0?ooo`030000003oool0oooo09H0oooo0P00001Z
0?ooo`006`3oool00`000000oooo0?ooo`2H0?ooo`<00000I`3oool001/0oooo00<000000?ooo`3o
ool0V`3oool2000006D0oooo000K0?ooo`800000WP3oool300000680oooo000K0?ooo`030000003o
ool0oooo0:00oooo0P00001P0?ooo`006`3oool00`000000oooo0?ooo`2R0?ooo`800000GP3oool0
01/0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1K0?ooo`006`3oool00`000000
oooo0?ooo`2U0?ooo`<00000FP3oool001/0oooo0P00002Y0?ooo`800000F03oool001/0oooo00<0
00000?ooo`3oool0ZP3oool3000005D0oooo000K0?ooo`030000003oool0oooo0:d0oooo0P00001C
0?ooo`0000<0oooo0000000000000`0000020?ooo`8000000`3oool4000000<0oooo0P0000050?oo
o`030000003oool0oooo0:l0oooo0`00001@0?ooo`000`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2b0?oo
o`<00000C@3oool000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo0P00002f0?ooo`800000B`3oool000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`2g0?ooo`<00000
B03oool000<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0^P3oool2000004H0oooo00020?ooo`8000002P3o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo0;`0oooo0`0000130?ooo`006`3oool2
00000<00oooo0P0000110?ooo`006`3oool00`000000oooo0?ooo`310?ooo`<00000?P3oool001/0
oooo00<000000?ooo`3oool0a03oool3000003/0oooo000K0?ooo`030000003oool0oooo0<L0oooo
0P00000i0?ooo`006`3oool00`000000oooo0?ooo`390?ooo`<00000=P3oool001/0oooo0P00003=
0?ooo`800000=03oool001/0oooo00<000000?ooo`3oool0cP3oool300000340oooo000K0?ooo`03
0000003oool0oooo0=40oooo0P00000_0?ooo`006`3oool00`000000oooo0?ooo`3C0?ooo`<00000
;03oool001/0oooo0P00003G0?ooo`<00000:@3oool001/0oooo00<000000?ooo`3oool0f@3oool2
000002L0oooo000K0?ooo`030000003oool0oooo0=/0oooo0`00000T0?ooo`006`3oool00`000000
oooo0?ooo`3N0?ooo`8000008P3oool001/0oooo00<000000?ooo`3oool0h03oool3000001l0oooo
000K0?ooo`800000i03oool2000001d0oooo000K0?ooo`030000003oool0oooo0>D0oooo0`00000J
0?ooo`001`3oool500000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3X0?oo
o`D000005@3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0>d0oooo0`00000B0?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo0P00003a0?ooo`800000403oool000T0oooo00<000000?ooo`3oool0
203oool2000000D0oooo00<000000?ooo`3oool0lP3oool3000000d0oooo00090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3e0?ooo`8000002`3o
ool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3g0?ooo`<00000203oool0
01/0oooo00<000000?ooo`3oool0nP3oool3000000D0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.295284, \
0.00778854, 0.0109638}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.0710384 0.355192 [
[.125 .05854 -12 -9 ]
[.125 .05854 12 0 ]
[.25 .05854 -9 -9 ]
[.25 .05854 9 0 ]
[.375 .05854 -12 -9 ]
[.375 .05854 12 0 ]
[.5 .05854 -3 -9 ]
[.5 .05854 3 0 ]
[.625 .05854 -12 -9 ]
[.625 .05854 12 0 ]
[.75 .05854 -9 -9 ]
[.75 .05854 9 0 ]
[.875 .05854 -12 -9 ]
[.875 .05854 12 0 ]
[1 .05854 -3 -9 ]
[1 .05854 3 0 ]
[-0.0125 .15984 -24 -4.5 ]
[-0.0125 .15984 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33743 -24 -4.5 ]
[-0.0125 .33743 0 4.5 ]
[-0.0125 .42623 -6 -4.5 ]
[-0.0125 .42623 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .60383 -18 -4.5 ]
[-0.0125 .60383 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .07104 m
.125 .07729 L
s
[(0.25)] .125 .05854 0 1 Mshowa
.25 .07104 m
.25 .07729 L
s
[(0.5)] .25 .05854 0 1 Mshowa
.375 .07104 m
.375 .07729 L
s
[(0.75)] .375 .05854 0 1 Mshowa
.5 .07104 m
.5 .07729 L
s
[(1)] .5 .05854 0 1 Mshowa
.625 .07104 m
.625 .07729 L
s
[(1.25)] .625 .05854 0 1 Mshowa
.75 .07104 m
.75 .07729 L
s
[(1.5)] .75 .05854 0 1 Mshowa
.875 .07104 m
.875 .07729 L
s
[(1.75)] .875 .05854 0 1 Mshowa
1 .07104 m
1 .07729 L
s
[(2)] 1 .05854 0 1 Mshowa
.125 Mabswid
.025 .07104 m
.025 .07479 L
s
.05 .07104 m
.05 .07479 L
s
.075 .07104 m
.075 .07479 L
s
.1 .07104 m
.1 .07479 L
s
.15 .07104 m
.15 .07479 L
s
.175 .07104 m
.175 .07479 L
s
.2 .07104 m
.2 .07479 L
s
.225 .07104 m
.225 .07479 L
s
.275 .07104 m
.275 .07479 L
s
.3 .07104 m
.3 .07479 L
s
.325 .07104 m
.325 .07479 L
s
.35 .07104 m
.35 .07479 L
s
.4 .07104 m
.4 .07479 L
s
.425 .07104 m
.425 .07479 L
s
.45 .07104 m
.45 .07479 L
s
.475 .07104 m
.475 .07479 L
s
.525 .07104 m
.525 .07479 L
s
.55 .07104 m
.55 .07479 L
s
.575 .07104 m
.575 .07479 L
s
.6 .07104 m
.6 .07479 L
s
.65 .07104 m
.65 .07479 L
s
.675 .07104 m
.675 .07479 L
s
.7 .07104 m
.7 .07479 L
s
.725 .07104 m
.725 .07479 L
s
.775 .07104 m
.775 .07479 L
s
.8 .07104 m
.8 .07479 L
s
.825 .07104 m
.825 .07479 L
s
.85 .07104 m
.85 .07479 L
s
.9 .07104 m
.9 .07479 L
s
.925 .07104 m
.925 .07479 L
s
.95 .07104 m
.95 .07479 L
s
.975 .07104 m
.975 .07479 L
s
.25 Mabswid
0 .07104 m
1 .07104 L
s
0 .15984 m
.00625 .15984 L
s
[(0.25)] -0.0125 .15984 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33743 m
.00625 .33743 L
s
[(0.75)] -0.0125 .33743 1 0 Mshowa
0 .42623 m
.00625 .42623 L
s
[(1)] -0.0125 .42623 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(1.25)] -0.0125 .51503 1 0 Mshowa
0 .60383 m
.00625 .60383 L
s
[(1.5)] -0.0125 .60383 1 0 Mshowa
.125 Mabswid
0 .0888 m
.00375 .0888 L
s
0 .10656 m
.00375 .10656 L
s
0 .12432 m
.00375 .12432 L
s
0 .14208 m
.00375 .14208 L
s
0 .1776 m
.00375 .1776 L
s
0 .19536 m
.00375 .19536 L
s
0 .21312 m
.00375 .21312 L
s
0 .23087 m
.00375 .23087 L
s
0 .26639 m
.00375 .26639 L
s
0 .28415 m
.00375 .28415 L
s
0 .30191 m
.00375 .30191 L
s
0 .31967 m
.00375 .31967 L
s
0 .35519 m
.00375 .35519 L
s
0 .37295 m
.00375 .37295 L
s
0 .39071 m
.00375 .39071 L
s
0 .40847 m
.00375 .40847 L
s
0 .44399 m
.00375 .44399 L
s
0 .46175 m
.00375 .46175 L
s
0 .47951 m
.00375 .47951 L
s
0 .49727 m
.00375 .49727 L
s
0 .53279 m
.00375 .53279 L
s
0 .55055 m
.00375 .55055 L
s
0 .56831 m
.00375 .56831 L
s
0 .58607 m
.00375 .58607 L
s
0 .05328 m
.00375 .05328 L
s
0 .03552 m
.00375 .03552 L
s
0 .01776 m
.00375 .01776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .07653 m
.01 .14239 L
.02 .14239 L
.03 .14788 L
.04 .15885 L
.05 .16983 L
.06 .18081 L
.07 .18629 L
.08 .19178 L
.09 .20276 L
.1 .20825 L
.11 .21374 L
.12 .21374 L
.13 .21922 L
.14 .22471 L
.15 .23569 L
.16 .23569 L
.17 .24118 L
.18 .24667 L
.19 .25215 L
.2 .25764 L
.21 .26313 L
.22 .26313 L
.23 .26862 L
.24 .2796 L
.25 .2796 L
.26 .28508 L
.27 .29057 L
.28 .29606 L
.29 .30155 L
.3 .30704 L
.31 .30704 L
.32 .31253 L
.33 .31253 L
.34 .31801 L
.35 .3235 L
.36 .32899 L
.37 .32899 L
.38 .33448 L
.39 .33448 L
.4 .34546 L
.41 .34546 L
.42 .35094 L
.43 .35094 L
.44 .35094 L
.45 .35643 L
.46 .36192 L
.47 .36741 L
.48 .3729 L
.49 .3729 L
Mistroke
.5 .37839 L
.51 .37839 L
.52 .38387 L
.53 .38936 L
.54 .38936 L
.55 .38936 L
.56 .38936 L
.57 .39485 L
.58 .40034 L
.59 .40583 L
.6 .41132 L
.61 .41132 L
.62 .4168 L
.63 .4168 L
.64 .42229 L
.65 .42229 L
.66 .42778 L
.67 .42778 L
.68 .43327 L
.69 .43327 L
.7 .43327 L
.71 .43876 L
.72 .43876 L
.73 .44425 L
.74 .44425 L
.75 .44425 L
.76 .44973 L
.77 .44973 L
.78 .44973 L
.79 .45522 L
.8 .45522 L
.81 .46071 L
.82 .4662 L
.83 .4662 L
.84 .4662 L
.85 .47169 L
.86 .47169 L
.87 .47718 L
.88 .47718 L
.89 .47718 L
.9 .48266 L
.91 .48266 L
.92 .48266 L
.93 .48815 L
.94 .48815 L
.95 .49364 L
.96 .49913 L
.97 .49913 L
.98 .50462 L
.99 .50462 L
Mistroke
1 .50462 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000l0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`800000503oool500000180oooo1@0000020?ooo`8000000`3oool4
000000<0oooo0P00000>0?ooo`D000000P3oool2000000@0oooo0P00000>0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000001D0oooo100000020?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00@000000?ooo`3oool000002@3o
ool2000000h0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo000K0?ooo`030000003oool0
oooo01<0oooo0P00000:0?ooo`800000103oool3000000h0oooo0P00000:0?ooo`<000003P3oool2
000000T0oooo100000030?ooo`<00000503oool2000001D0oooo0P00000:0?ooo`800000103oool3
000000h0oooo0P00000:0?ooo`<000003P3oool2000000T0oooo100000030?ooo`<000005@3oool2
000000<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooool000000`0000030?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`000000o`3oool30?ooo`006`3o
ool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`800000103oool00`000000oooo0?ooo`3l
0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?/0oooo00020?ooo`80
0000103oool2000000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool000050?ooo`000000oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0000070?oo
o`800000nP3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo0`3oool00080oooo0P00000:0?ooo`800000103oool3000000@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3e0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0?@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo00h0oooo0P00003b0?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`8000004`3oool00`000000oooo0?ooo`3]0?ooo`00
6`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0>`0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`0F0?ooo`800000jP3oool001/0oooo0P00000L0?ooo`800000i@3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0>00oooo000K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0g`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo
00<000000?ooo`3oool08`3oool200000=d0oooo00080?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0e`3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0eP3oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`020?ooo`800000;@3oool00`000000oooo0?ooo`3C0?ooo`001`3oool010000000oooo0?oo
o`0000090?ooo`8000001@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=80oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0<@3o
ool200000<l0oooo000K0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0b@3oool0
01/0oooo0P00000h0?ooo`030000003oool0oooo0<P0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`350?ooo`006`3o
ool00`000000oooo0?ooo`0j0?ooo`800000aP3oool001/0oooo0P00000o0?ooo`800000`P3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo0;`0oooo000K0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
^`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool2000004P0oooo0P00002i
0?ooo`006`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0;<0oooo000K0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0/P3oool001/0oooo00<000000?ooo`3oool0
D@3oool200000:l0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`1E
0?ooo`800000Z`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo05X0
oooo0P00002V0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05l0oooo0P00002Q0?oo
o`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool200000?l0oooo103oool000050?ooo`000000oooo0?ooo`0000002`3oool01000
0000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2L
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1S0?ooo`800000W@3oool00080oooo0P000009
0?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool0J03oool2000000<0oooo0P00002C
0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`2>0?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08d0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0MP3oool2
000008X0oooo000K0?ooo`800000N`3oool2000008H0oooo000K0?ooo`030000003oool0oooo07`0
oooo0P0000240?ooo`006`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo07h0oooo
000K0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0O@3oool001/0oooo00<00000
0?ooo`3oool0Q@3oool300000080oooo0`00001e0?ooo`006`3oool200000?l0oooo103oool001/0
oooo00<000000?ooo`3oool0S`3oool200000740oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1[0?ooo`006`3oool2
000009H0oooo00<000000?ooo`3oool0JP3oool001/0oooo00<000000?ooo`3oool0V03oool30000
06L0oooo000K0?ooo`030000003oool0oooo09d0oooo0P00001S0?ooo`004`3oool5000000<0oooo
00<000000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0:80oooo0P00001N0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`800000Z03oool2
000005T0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:/0oooo0`0000030?ooo`80
0000C`3oool001@0oooo0P0000050?ooo`030000003oool0oooo0;D0oooo0`00001:0?ooo`006`3o
ool200000;/0oooo0P0000160?ooo`006`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0
oooo0400oooo000K0?ooo`030000003oool0oooo0<00oooo00@000000?ooo`3oool0oooo0P00000l
0?ooo`006`3oool00`000000oooo0?ooo`390?ooo`800000=`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool200000<l0oooo00<000000?ooo`3oool0<@3oool001/0oooo00<0
00000?ooo`3oool0c`3oool00`000000oooo0?ooo`03000002d0oooo000K0?ooo`030000003oool0
oooo0=L0oooo0P00000Y0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`80
0000g@3oool2000000<0oooo0P00000O0?ooo`006`3oool00`000000oooo0?ooo`3V0?ooo`800000
6P3oool001/0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0D0?ooo`006`3oool0
0`000000oooo0?ooo`3/0?ooo`050000003oool0oooo0?ooo`0000004@3oool001/0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`0>0?ooo`006`3oool200000?D0oooo0P00000<0?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?T0oooo
0P000000103oool000000000000000030?ooo`0000<0oooo0000000000000`0000020?ooo`800000
0`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0o`3oool30?ooo`000`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000?l0oooo103oool000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo00030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3oool00080oooo0P00000:0?oo
o`800000103oool3000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0
oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo1@0000020?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`002@3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`002@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00003o0?ooo`@0oooo0009
0?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool0
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo0`3oool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.295284, \
0.00778854, 0.0109638}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.0710384 0.355192 [
[.125 .05854 -12 -9 ]
[.125 .05854 12 0 ]
[.25 .05854 -9 -9 ]
[.25 .05854 9 0 ]
[.375 .05854 -12 -9 ]
[.375 .05854 12 0 ]
[.5 .05854 -3 -9 ]
[.5 .05854 3 0 ]
[.625 .05854 -12 -9 ]
[.625 .05854 12 0 ]
[.75 .05854 -9 -9 ]
[.75 .05854 9 0 ]
[.875 .05854 -12 -9 ]
[.875 .05854 12 0 ]
[1 .05854 -3 -9 ]
[1 .05854 3 0 ]
[-0.0125 .15984 -24 -4.5 ]
[-0.0125 .15984 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33743 -24 -4.5 ]
[-0.0125 .33743 0 4.5 ]
[-0.0125 .42623 -6 -4.5 ]
[-0.0125 .42623 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .60383 -18 -4.5 ]
[-0.0125 .60383 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .07104 m
.125 .07729 L
s
[(0.25)] .125 .05854 0 1 Mshowa
.25 .07104 m
.25 .07729 L
s
[(0.5)] .25 .05854 0 1 Mshowa
.375 .07104 m
.375 .07729 L
s
[(0.75)] .375 .05854 0 1 Mshowa
.5 .07104 m
.5 .07729 L
s
[(1)] .5 .05854 0 1 Mshowa
.625 .07104 m
.625 .07729 L
s
[(1.25)] .625 .05854 0 1 Mshowa
.75 .07104 m
.75 .07729 L
s
[(1.5)] .75 .05854 0 1 Mshowa
.875 .07104 m
.875 .07729 L
s
[(1.75)] .875 .05854 0 1 Mshowa
1 .07104 m
1 .07729 L
s
[(2)] 1 .05854 0 1 Mshowa
.125 Mabswid
.025 .07104 m
.025 .07479 L
s
.05 .07104 m
.05 .07479 L
s
.075 .07104 m
.075 .07479 L
s
.1 .07104 m
.1 .07479 L
s
.15 .07104 m
.15 .07479 L
s
.175 .07104 m
.175 .07479 L
s
.2 .07104 m
.2 .07479 L
s
.225 .07104 m
.225 .07479 L
s
.275 .07104 m
.275 .07479 L
s
.3 .07104 m
.3 .07479 L
s
.325 .07104 m
.325 .07479 L
s
.35 .07104 m
.35 .07479 L
s
.4 .07104 m
.4 .07479 L
s
.425 .07104 m
.425 .07479 L
s
.45 .07104 m
.45 .07479 L
s
.475 .07104 m
.475 .07479 L
s
.525 .07104 m
.525 .07479 L
s
.55 .07104 m
.55 .07479 L
s
.575 .07104 m
.575 .07479 L
s
.6 .07104 m
.6 .07479 L
s
.65 .07104 m
.65 .07479 L
s
.675 .07104 m
.675 .07479 L
s
.7 .07104 m
.7 .07479 L
s
.725 .07104 m
.725 .07479 L
s
.775 .07104 m
.775 .07479 L
s
.8 .07104 m
.8 .07479 L
s
.825 .07104 m
.825 .07479 L
s
.85 .07104 m
.85 .07479 L
s
.9 .07104 m
.9 .07479 L
s
.925 .07104 m
.925 .07479 L
s
.95 .07104 m
.95 .07479 L
s
.975 .07104 m
.975 .07479 L
s
.25 Mabswid
0 .07104 m
1 .07104 L
s
0 .15984 m
.00625 .15984 L
s
[(0.25)] -0.0125 .15984 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33743 m
.00625 .33743 L
s
[(0.75)] -0.0125 .33743 1 0 Mshowa
0 .42623 m
.00625 .42623 L
s
[(1)] -0.0125 .42623 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(1.25)] -0.0125 .51503 1 0 Mshowa
0 .60383 m
.00625 .60383 L
s
[(1.5)] -0.0125 .60383 1 0 Mshowa
.125 Mabswid
0 .0888 m
.00375 .0888 L
s
0 .10656 m
.00375 .10656 L
s
0 .12432 m
.00375 .12432 L
s
0 .14208 m
.00375 .14208 L
s
0 .1776 m
.00375 .1776 L
s
0 .19536 m
.00375 .19536 L
s
0 .21312 m
.00375 .21312 L
s
0 .23087 m
.00375 .23087 L
s
0 .26639 m
.00375 .26639 L
s
0 .28415 m
.00375 .28415 L
s
0 .30191 m
.00375 .30191 L
s
0 .31967 m
.00375 .31967 L
s
0 .35519 m
.00375 .35519 L
s
0 .37295 m
.00375 .37295 L
s
0 .39071 m
.00375 .39071 L
s
0 .40847 m
.00375 .40847 L
s
0 .44399 m
.00375 .44399 L
s
0 .46175 m
.00375 .46175 L
s
0 .47951 m
.00375 .47951 L
s
0 .49727 m
.00375 .49727 L
s
0 .53279 m
.00375 .53279 L
s
0 .55055 m
.00375 .55055 L
s
0 .56831 m
.00375 .56831 L
s
0 .58607 m
.00375 .58607 L
s
0 .05328 m
.00375 .05328 L
s
0 .03552 m
.00375 .03552 L
s
0 .01776 m
.00375 .01776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .12043 m
.01 .16434 L
.02 .19178 L
.03 .20276 L
.04 .21374 L
.05 .21922 L
.06 .22471 L
.07 .23569 L
.08 .24118 L
.09 .24667 L
.1 .25764 L
.11 .26313 L
.12 .26862 L
.13 .27411 L
.14 .28508 L
.15 .29057 L
.16 .29606 L
.17 .30155 L
.18 .30704 L
.19 .31801 L
.2 .31801 L
.21 .32899 L
.22 .32899 L
.23 .33997 L
.24 .34546 L
.25 .35643 L
.26 .35643 L
.27 .35643 L
.28 .36741 L
.29 .3729 L
.3 .3729 L
.31 .3729 L
.32 .37839 L
.33 .38936 L
.34 .39485 L
.35 .39485 L
.36 .40583 L
.37 .40583 L
.38 .41132 L
.39 .41132 L
.4 .4168 L
.41 .42229 L
.42 .42778 L
.43 .42778 L
.44 .42778 L
.45 .43876 L
.46 .44425 L
.47 .44425 L
.48 .44973 L
.49 .44973 L
Mistroke
.5 .45522 L
.51 .45522 L
.52 .46071 L
.53 .4662 L
.54 .47169 L
.55 .47169 L
.56 .47718 L
.57 .47718 L
.58 .48266 L
.59 .48266 L
.6 .48815 L
.61 .49364 L
.62 .49913 L
.63 .49913 L
.64 .49913 L
.65 .49913 L
.66 .50462 L
.67 .51011 L
.68 .51011 L
.69 .51559 L
.7 .51559 L
.71 .52108 L
.72 .53206 L
.73 .53755 L
Mfstroke
.73 .53755 m
.73978 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000l0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`800000503oool500000180oooo1@0000020?ooo`8000000`3oool4
000000<0oooo0P00000>0?ooo`D000000P3oool2000000@0oooo0P00000>0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000001D0oooo100000020?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00@000000?ooo`3oool000002@3o
ool2000000h0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo000K0?ooo`030000003oool0
oooo01<0oooo0P00000:0?ooo`800000103oool3000000h0oooo0P00000:0?ooo`<000003P3oool2
000000T0oooo100000030?ooo`<00000503oool2000001D0oooo0P00000:0?ooo`800000103oool3
000000h0oooo0P00000:0?ooo`<000003P3oool2000000T0oooo100000030?ooo`<000005@3oool2
000000<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooool000000`0000030?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool200000?l0oooo103oool00080oooo0P0000040?ooo`80
00000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000050?oo
o`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`0000D0oooo0000003oool0oooo000000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000?l0oooo103oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0000003o0?ooo`<0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000?l0oooo0P3o
ool00080oooo0P00000:0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`00
6`3oool01@000000oooo0?ooo`3oool000000?l0oooo0@3oool001/0oooo00D000000?ooo`3oool0
oooo0000003o0?ooo`40oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o03oool0
01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3k0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
00080?ooo`030000003oool0oooo0?P0oooo000K0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0m`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`0;0?ooo`800000m@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3`
0?ooo`00203oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0>l0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0>/0oooo00070?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool2000001D0oooo00<00000
0?ooo`3oool0j`3oool000L0oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000X0oooo0`0000040?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0j03oool001/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`3W0?ooo`006`3oool2000001d0oooo00<000000?ooo`3oool0
h`3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3R0?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo0P00000Q0?ooo`800000h03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=/0oooo000K0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0fP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool2000002T0oooo0`00003G0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`3B0?ooo`006`3oool2000002h0oooo00<000000?ooo`3oool0dP3oool001/0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3>0?ooo`006`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0<d0oooo00020?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`3:0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
b@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0P00003o0?ooo`@0oooo00001@3oool000000?ooo`3oool0000000/0oooo
00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0aP3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`350?oo
o`000P3oool2000000T0oooo100000030?ooo`<00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`0m0?ooo`8000000`3o
ool200000;h0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0;X0
oooo000K0?ooo`800000A`3oool200000080oooo0`00002e0?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0/03oool0
01/0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2_0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000E03oool00`000000oooo0?ooo`2/0?ooo`006`3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0:/0oooo000K0?ooo`030000003oool0
oooo05L0oooo0P00002Y0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
0:<0oooo000K0?ooo`800000GP3oool00`000000oooo0?ooo`2R0?ooo`006`3oool00`000000oooo
0?ooo`1P0?ooo`<00000W`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`004`3oool5
000000<0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`2J0?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0V@3oool001D0
oooo00<000000?ooo`3oool00`3oool2000006/0oooo0P00002F0?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0T@3oool001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0900oooo000D
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000L`3oool30000
08d0oooo000K0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0R03oool001/0oooo
00<000000?ooo`3oool0N03oool010000000oooo0?ooo`0000260?ooo`006`3oool00`000000oooo
0?ooo`1l0?ooo`050000003oool0oooo0?ooo`000000P@3oool001/0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`1n0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<00000
0?ooo`3oool0Q@3oool2000007/0oooo000K0?ooo`030000003oool0oooo08T0oooo0P00001g0?oo
o`006`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07D0oooo000K0?ooo`800000
S`3oool200000780oooo000K0?ooo`030000003oool0oooo09<0oooo0P00001]0?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0I`3oool001/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1V0?ooo`00
6`3oool2000009d0oooo0P0000030?ooo`800000G`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`800000FP3oool000030?ooo`0000000000
00<000000P3oool2000000<0oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo05@0oooo00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:`0oooo00<000000?oo
o`3oool0D`3oool000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo0P00002`0?ooo`<00000D03oool000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
00030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0B`3oool00080oooo0P00
000:0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`1:0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo04L0
oooo000K0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0A`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`160?ooo`006`3oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo04H0oooo000K0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0
AP3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo04H0oooo000K0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
A@3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
00L0oooo1@0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?oo
o`002@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`150?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo0P00002k0?ooo`030000003oool0oooo04D0oooo00090?ooo`030000
003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3o
ool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0A03oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.295284, \
0.00778854, 0.0109638}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(Graphics::"gptn"\), \(\(:\)\(\ \)\), "\<\"Coordinate \
\\!\\(Indeterminate\\) in \\!\\({0, Indeterminate}\\) is not a floating-point \
number. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Graphics::gptn\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.0710384 0.355192 [
[.125 .05854 -12 -9 ]
[.125 .05854 12 0 ]
[.25 .05854 -9 -9 ]
[.25 .05854 9 0 ]
[.375 .05854 -12 -9 ]
[.375 .05854 12 0 ]
[.5 .05854 -3 -9 ]
[.5 .05854 3 0 ]
[.625 .05854 -12 -9 ]
[.625 .05854 12 0 ]
[.75 .05854 -9 -9 ]
[.75 .05854 9 0 ]
[.875 .05854 -12 -9 ]
[.875 .05854 12 0 ]
[1 .05854 -3 -9 ]
[1 .05854 3 0 ]
[-0.0125 .15984 -24 -4.5 ]
[-0.0125 .15984 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33743 -24 -4.5 ]
[-0.0125 .33743 0 4.5 ]
[-0.0125 .42623 -6 -4.5 ]
[-0.0125 .42623 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .60383 -18 -4.5 ]
[-0.0125 .60383 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .07104 m
.125 .07729 L
s
[(0.25)] .125 .05854 0 1 Mshowa
.25 .07104 m
.25 .07729 L
s
[(0.5)] .25 .05854 0 1 Mshowa
.375 .07104 m
.375 .07729 L
s
[(0.75)] .375 .05854 0 1 Mshowa
.5 .07104 m
.5 .07729 L
s
[(1)] .5 .05854 0 1 Mshowa
.625 .07104 m
.625 .07729 L
s
[(1.25)] .625 .05854 0 1 Mshowa
.75 .07104 m
.75 .07729 L
s
[(1.5)] .75 .05854 0 1 Mshowa
.875 .07104 m
.875 .07729 L
s
[(1.75)] .875 .05854 0 1 Mshowa
1 .07104 m
1 .07729 L
s
[(2)] 1 .05854 0 1 Mshowa
.125 Mabswid
.025 .07104 m
.025 .07479 L
s
.05 .07104 m
.05 .07479 L
s
.075 .07104 m
.075 .07479 L
s
.1 .07104 m
.1 .07479 L
s
.15 .07104 m
.15 .07479 L
s
.175 .07104 m
.175 .07479 L
s
.2 .07104 m
.2 .07479 L
s
.225 .07104 m
.225 .07479 L
s
.275 .07104 m
.275 .07479 L
s
.3 .07104 m
.3 .07479 L
s
.325 .07104 m
.325 .07479 L
s
.35 .07104 m
.35 .07479 L
s
.4 .07104 m
.4 .07479 L
s
.425 .07104 m
.425 .07479 L
s
.45 .07104 m
.45 .07479 L
s
.475 .07104 m
.475 .07479 L
s
.525 .07104 m
.525 .07479 L
s
.55 .07104 m
.55 .07479 L
s
.575 .07104 m
.575 .07479 L
s
.6 .07104 m
.6 .07479 L
s
.65 .07104 m
.65 .07479 L
s
.675 .07104 m
.675 .07479 L
s
.7 .07104 m
.7 .07479 L
s
.725 .07104 m
.725 .07479 L
s
.775 .07104 m
.775 .07479 L
s
.8 .07104 m
.8 .07479 L
s
.825 .07104 m
.825 .07479 L
s
.85 .07104 m
.85 .07479 L
s
.9 .07104 m
.9 .07479 L
s
.925 .07104 m
.925 .07479 L
s
.95 .07104 m
.95 .07479 L
s
.975 .07104 m
.975 .07479 L
s
.25 Mabswid
0 .07104 m
1 .07104 L
s
0 .15984 m
.00625 .15984 L
s
[(0.25)] -0.0125 .15984 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33743 m
.00625 .33743 L
s
[(0.75)] -0.0125 .33743 1 0 Mshowa
0 .42623 m
.00625 .42623 L
s
[(1)] -0.0125 .42623 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(1.25)] -0.0125 .51503 1 0 Mshowa
0 .60383 m
.00625 .60383 L
s
[(1.5)] -0.0125 .60383 1 0 Mshowa
.125 Mabswid
0 .0888 m
.00375 .0888 L
s
0 .10656 m
.00375 .10656 L
s
0 .12432 m
.00375 .12432 L
s
0 .14208 m
.00375 .14208 L
s
0 .1776 m
.00375 .1776 L
s
0 .19536 m
.00375 .19536 L
s
0 .21312 m
.00375 .21312 L
s
0 .23087 m
.00375 .23087 L
s
0 .26639 m
.00375 .26639 L
s
0 .28415 m
.00375 .28415 L
s
0 .30191 m
.00375 .30191 L
s
0 .31967 m
.00375 .31967 L
s
0 .35519 m
.00375 .35519 L
s
0 .37295 m
.00375 .37295 L
s
0 .39071 m
.00375 .39071 L
s
0 .40847 m
.00375 .40847 L
s
0 .44399 m
.00375 .44399 L
s
0 .46175 m
.00375 .46175 L
s
0 .47951 m
.00375 .47951 L
s
0 .49727 m
.00375 .49727 L
s
0 .53279 m
.00375 .53279 L
s
0 .55055 m
.00375 .55055 L
s
0 .56831 m
.00375 .56831 L
s
0 .58607 m
.00375 .58607 L
s
0 .05328 m
.00375 .05328 L
s
0 .03552 m
.00375 .03552 L
s
0 .01776 m
.00375 .01776 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .08395 m
.01 .15011 L
.02 .16005 L
.03 .17337 L
.04 .18513 L
.05 .19571 L
.06 .20269 L
.07 .20904 L
.08 .2161 L
.09 .22232 L
.1 .22883 L
.11 .23466 L
.12 .23964 L
.13 .24625 L
.14 .25325 L
.15 .25965 L
.16 .26472 L
.17 .27021 L
.18 .27537 L
.19 .28153 L
.2 .28666 L
.21 .29144 L
.22 .29643 L
.23 .3031 L
.24 .30792 L
.25 .31357 L
.26 .3172 L
.27 .32172 L
.28 .32756 L
.29 .33165 L
.3 .33704 L
.31 .34021 L
.32 .3445 L
.33 .34776 L
.34 .35155 L
.35 .35623 L
.36 .36059 L
.37 .36488 L
.38 .36822 L
.39 .37179 L
.4 .37646 L
.41 .38118 L
.42 .38416 L
.43 .38784 L
.44 .39134 L
.45 .39532 L
.46 .39947 L
.47 .40317 L
.48 .4066 L
.49 .4092 L
Mistroke
.5 .41328 L
.51 .41637 L
.52 .42048 L
.53 .42388 L
.54 .42792 L
.55 .43125 L
.56 .4338 L
.57 .43673 L
.58 .44021 L
.59 .44287 L
.6 .44589 L
.61 .44884 L
.62 .45241 L
.63 .45473 L
.64 .4579 L
.65 .46094 L
.66 .46326 L
.67 .46621 L
.68 .46914 L
.69 .47231 L
.7 .47493 L
.71 .47818 L
.72 .48225 L
.73 .48527 L
.74 .49016 L
.75 .49381 L
.76 .49836 L
.77 .5032 L
.78 .50607 L
.79 .50935 L
.8 .51356 L
.81 .51955 L
.82 .5232 L
.83 .52811 L
.84 .53225 L
.85 .5372 L
.86 .54191 L
.87 .54719 L
.88 .5522 L
.89 .55486 L
.9 .55917 L
.91 .56304 L
.92 .56703 L
.93 .5728 L
.94 .57568 L
.95 .58036 L
.96 .58552 L
.97 .59136 L
.98 .59428 L
.99 .59552 L
Mistroke
1 .59747 L
Mfstroke
.003 w
[ ] 0 setdash
.01 .08044 m
.02 .0897 L
.03 .09883 L
.04 .10782 L
.05 .11669 L
.06 .12543 L
.07 .13404 L
.08 .14254 L
.09 .15092 L
.1 .15918 L
.11 .16733 L
.12 .17536 L
.13 .18329 L
.14 .19112 L
.15 .19884 L
.16 .20646 L
.17 .21398 L
.18 .2214 L
.19 .22872 L
.2 .23596 L
.21 .2431 L
.22 .25015 L
.23 .25712 L
.24 .264 L
.25 .27079 L
.26 .2775 L
.27 .28413 L
.28 .29068 L
.29 .29715 L
.3 .30355 L
.31 .30987 L
.32 .31611 L
.33 .32229 L
.34 .32839 L
.35 .33442 L
.36 .34039 L
.37 .34628 L
.38 .35211 L
.39 .35788 L
.4 .36358 L
.41 .36922 L
.42 .37479 L
.43 .38031 L
.44 .38577 L
.45 .39116 L
.46 .3965 L
.47 .40179 L
.48 .40702 L
.49 .41219 L
.5 .41731 L
Mistroke
.51 .42238 L
.52 .42739 L
.53 .43235 L
.54 .43727 L
.55 .44213 L
.56 .44694 L
.57 .45171 L
.58 .45643 L
.59 .4611 L
.6 .46572 L
.61 .47031 L
.62 .47484 L
.63 .47933 L
.64 .48378 L
.65 .48819 L
.66 .49256 L
.67 .49688 L
.68 .50116 L
.69 .50541 L
.7 .50961 L
.71 .51378 L
.72 .5179 L
.73 .52199 L
.74 .52604 L
.75 .53006 L
.76 .53404 L
.77 .53798 L
.78 .54189 L
.79 .54576 L
.8 .5496 L
.81 .55341 L
.82 .55718 L
.83 .56092 L
.84 .56462 L
.85 .5683 L
.86 .57194 L
.87 .57556 L
.88 .57914 L
.89 .58269 L
.9 .58621 L
.91 .5897 L
.92 .59317 L
.93 .5966 L
.94 .60001 L
.95 .60339 L
.96 .60674 L
.97 .61006 L
.98 .61336 L
.99 .61663 L
Mfstroke
.99 .61663 m
.99433 .61803 L
s
.001 w
[ .005 .015 ] 0 setdash
0 .07653 m
.01 .14239 L
.02 .14239 L
.03 .14788 L
.04 .15885 L
.05 .16983 L
.06 .18081 L
.07 .18629 L
.08 .19178 L
.09 .20276 L
.1 .20825 L
.11 .21374 L
.12 .21374 L
.13 .21922 L
.14 .22471 L
.15 .23569 L
.16 .23569 L
.17 .24118 L
.18 .24667 L
.19 .25215 L
.2 .25764 L
.21 .26313 L
.22 .26313 L
.23 .26862 L
.24 .2796 L
.25 .2796 L
.26 .28508 L
.27 .29057 L
.28 .29606 L
.29 .30155 L
.3 .30704 L
.31 .30704 L
.32 .31253 L
.33 .31253 L
.34 .31801 L
.35 .3235 L
.36 .32899 L
.37 .32899 L
.38 .33448 L
.39 .33448 L
.4 .34546 L
.41 .34546 L
.42 .35094 L
.43 .35094 L
.44 .35094 L
.45 .35643 L
.46 .36192 L
.47 .36741 L
.48 .3729 L
.49 .3729 L
Mistroke
.5 .37839 L
.51 .37839 L
.52 .38387 L
.53 .38936 L
.54 .38936 L
.55 .38936 L
.56 .38936 L
.57 .39485 L
.58 .40034 L
.59 .40583 L
.6 .41132 L
.61 .41132 L
.62 .4168 L
.63 .4168 L
.64 .42229 L
.65 .42229 L
.66 .42778 L
.67 .42778 L
.68 .43327 L
.69 .43327 L
.7 .43327 L
.71 .43876 L
.72 .43876 L
.73 .44425 L
.74 .44425 L
.75 .44425 L
.76 .44973 L
.77 .44973 L
.78 .44973 L
.79 .45522 L
.8 .45522 L
.81 .46071 L
.82 .4662 L
.83 .4662 L
.84 .4662 L
.85 .47169 L
.86 .47169 L
.87 .47718 L
.88 .47718 L
.89 .47718 L
.9 .48266 L
.91 .48266 L
.92 .48266 L
.93 .48815 L
.94 .48815 L
.95 .49364 L
.96 .49913 L
.97 .49913 L
.98 .50462 L
.99 .50462 L
Mistroke
1 .50462 L
Mfstroke
0 .12043 m
.01 .16434 L
.02 .19178 L
.03 .20276 L
.04 .21374 L
.05 .21922 L
.06 .22471 L
.07 .23569 L
.08 .24118 L
.09 .24667 L
.1 .25764 L
.11 .26313 L
.12 .26862 L
.13 .27411 L
.14 .28508 L
.15 .29057 L
.16 .29606 L
.17 .30155 L
.18 .30704 L
.19 .31801 L
.2 .31801 L
.21 .32899 L
.22 .32899 L
.23 .33997 L
.24 .34546 L
.25 .35643 L
.26 .35643 L
.27 .35643 L
.28 .36741 L
.29 .3729 L
.3 .3729 L
.31 .3729 L
.32 .37839 L
.33 .38936 L
.34 .39485 L
.35 .39485 L
.36 .40583 L
.37 .40583 L
.38 .41132 L
.39 .41132 L
.4 .4168 L
.41 .42229 L
.42 .42778 L
.43 .42778 L
.44 .42778 L
.45 .43876 L
.46 .44425 L
.47 .44425 L
.48 .44973 L
.49 .44973 L
Mistroke
.5 .45522 L
.51 .45522 L
.52 .46071 L
.53 .4662 L
.54 .47169 L
.55 .47169 L
.56 .47718 L
.57 .47718 L
.58 .48266 L
.59 .48266 L
.6 .48815 L
.61 .49364 L
.62 .49913 L
.63 .49913 L
.64 .49913 L
.65 .49913 L
.66 .50462 L
.67 .51011 L
.68 .51011 L
.69 .51559 L
.7 .51559 L
.71 .52108 L
.72 .53206 L
.73 .53755 L
Mfstroke
.73 .53755 m
.73978 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool04`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2
000000l0oooo0P0000040?ooo`800000103oool2000000l0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`800000503oool500000180oooo1@0000020?ooo`8000000`3oool4
000000<0oooo0P00000>0?ooo`D000000P3oool2000000@0oooo0P00000>0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000001D0oooo100000020?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`020?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool2000000h0oooo00@000000?ooo`3oool000002@3o
ool2000000h0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo000K0?ooo`030000003oool0
oooo01<0oooo0P00000:0?ooo`800000103oool3000000h0oooo0P00000:0?ooo`<000003P3oool2
000000T0oooo100000030?ooo`<00000503oool2000001D0oooo0P00000:0?ooo`800000103oool3
000000h0oooo0P00000:0?ooo`<000003P3oool2000000T0oooo100000030?ooo`<000005@3oool2
000000<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooool000000`0000030?oo
o`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`030000003oool0oooo00800000o`3oool1
0?ooo`006`3oool2000000<0oooo00<000000?ooo`3oool0o@3oool001/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3l0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?`0oooo000K0?ooo`8000001@3oool00`000000oooo0?ooo`3k0?ooo`006`3oool0
0`000000oooo0?ooo`050?ooo`800000n`3oool001/0oooo0P0000080?ooo`030000003oool0oooo
0?P0oooo000K0?ooo`8000002@3oool200000?P0oooo000K0?ooo`8000002`3oool00`000000oooo
0?ooo`3e0?ooo`006`3oool2000000`0oooo00<000000?ooo`3oool0m03oool001/0oooo0P00000=
0?ooo`030000003oool0oooo0?<0oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0lP3oool001/0oooo0`00000>0?ooo`030000003oool0oooo0?40oooo000K0?ooo`030000
003oool0000000l0oooo00<000000?ooo`3oool0l03oool001/0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`3_0?ooo`006`3oool2000000@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`3^0?ooo`006`3oool3000000@0oooo00<000000?ooo`3oool02`3oool20000
0>h0oooo00020?ooo`800000103oool2000000<0oooo100000030?ooo`8000001@3oool00`000000
oooo0000000D0?ooo`030000003oool0oooo0>/0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
008000004`3oool00`000000oooo0?ooo`3Z0?ooo`0000D0oooo0000003oool0oooo000000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P00000>0?oo
o`030000003oool0oooo0>T0oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?oo
o`800000j@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?oo
o`3V0?ooo`000P3oool2000000X0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`03
0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`800000iP3oool001/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0h`3oool001/0oooo0P0000060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0hP3oool001/0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000005P3oool00`000000
oooo0?ooo`3Q0?ooo`006`3oool01@000000oooo0?ooo`3oool0000000`0oooo0P00000?0?ooo`80
0000h@3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0=h0oooo000K0?ooo`8000004`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0=d0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0g03oool0
01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`8000005`3oool20000
0=`0oooo000K0?ooo`030000003oool0oooo00d0oooo0P00000G0?ooo`030000003oool0oooo0=T0
oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool2000000l0oooo
00<000000?ooo`3oool0f03oool001/0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool2000000/0oooo00<000000?ooo`3oool0e`3oool001/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo0P00003G
0?ooo`006`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3D0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`80
0000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0P00003D0?ooo`00
6`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
d@3oool001/0oooo0P00000H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0d03o
ool001/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo0P00000;0?ooo`030000003oool0oooo0<l0oooo00080?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo0P00003?0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3<0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`800000c03oool000L0oooo00@000000?ooo`3oool000002@3oool2
000000D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00H0oooo0P00003:0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0<L0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo0P0000060?ooo`030000003oool0oooo
0<H0oooo000K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000a`3oool001/0oooo0P00000M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`3oool20000
0<D0oooo000K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0<80oooo000K0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000<<0oooo000K0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool2000000<0oooo0P0000310?ooo`006`3o
ool200000240oooo0P00000=0?ooo`030000003oool0oooo00`0oooo0P0000000`3oool000000000
002o0?ooo`006`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00l0oooo0P00002m
0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000002l0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0000002k0?ooo`00
6`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00l0oooo0P00002i0?ooo`006`3o
ool2000002T0oooo0`00000<0?ooo`030000003oool0oooo00d0oooo1000002g0?ooo`006`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00l0oooo0P00002e0?ooo`006`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00h0oooo0P00002d0?ooo`006`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool200000003
0?ooo`00000000000:l0oooo000K0?ooo`800000;P3oool00`000000oooo0?ooo`0?0?ooo`800000
3`3oool00`000000oooo0?ooo`2_0?ooo`006`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool200000:/0oooo
000K0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0;0?ooo`800000[P3oool00080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02`3oool2000000@0oooo0P00002V0?ooo`0000D0oooo0000003oool0oooo0000000:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`8000001`3o
ool200000:40oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`800000B`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0:L0oooo00001@3oool000000?ooo`3oool0000000/0oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0000000:0?ooo`800000203oool00`000000oooo0?ooo`2L0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo00@000000?ooo`00000000002@3oool20000
00H0oooo0P00002M0?ooo`000P3oool2000000T0oooo100000030?ooo`<00000103oool00`000000
oooo0?ooo`1B0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000`3oool2000009<0
oooo000K0?ooo`800000EP3oool00`000000oooo0?ooo`060?ooo`800000XP3oool001/0oooo00<0
00000?ooo`3oool0?@3oool2000000<0oooo0P00000C0?ooo`030000003oool0oooo00H0oooo0P00
000?0?ooo`030000003oool0oooo08h0oooo000K0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08d0oooo000K0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`0000001@3oool2000009d0oooo000K0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool010000000oooo0000000000040?oo
o`<000003P3oool2000008X0oooo000K0?ooo`800000A`3oool200000080oooo0`00000D0?ooo`80
00001@3oool200000100oooo0P0000260?ooo`006`3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool2000008@0oooo000K0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`800000503o
ool00`000000oooo0?ooo`1n0?ooo`006`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`0000000P3oool2000001<0oooo00<000000?ooo`3oool0O@3oool0
01/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo000000020?ooo`030000003oool0oooo
01<0oooo0`0000020?ooo`<00000M@3oool001/0oooo0P00001D0?ooo`030000003oool0oooo01P0
oooo1000002@0?ooo`006`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo
1000000K0?ooo`800000L@3oool001/0oooo00<000000?ooo`3oool0E`3oool2000001X0oooo0`00
002<0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01H0oooo0`00000L
0?ooo`030000003oool0oooo06/0oooo000K0?ooo`800000GP3oool00`000000oooo0?ooo`0H0?oo
o`8000006`3oool00`000000oooo0?ooo`1Z0?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`<0
00005`3oool3000001/0oooo0`00001W0?ooo`006`3oool00`000000oooo0?ooo`1l0?ooo`<00000
00<0oooo0000003oool06`3oool2000006<0oooo000C0?ooo`D000000`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo01H0oooo0P000000103oool0000000000000001n0?ooo`005@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0P00001N0?ooo`005@3oool0
0`000000oooo0?ooo`030?ooo`800000J`3oool2000001D0oooo0`0000030?ooo`030000003oool0
oooo01d0oooo0P00001I0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool04`3oool2000000<0oooo00<000000?ooo`000000MP3oool001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool2000001`0oooo0`0000030?ooo`800000C`3oool001@0oooo
0P0000050?ooo`030000003oool0oooo08L0oooo0P0000070?ooo`030000003oool000000280oooo
0`00001:0?ooo`006`3oool2000007<0oooo0`00000D0?ooo`<00000203oool00`000000oooo0?oo
o`0S0?ooo`800000AP3oool001/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0B
0?ooo`800000203oool4000002D0oooo00<000000?ooo`3oool0@03oool001/0oooo00<000000?oo
o`3oool0N03oool010000000oooo0?ooo`00000B0?ooo`<000002P3oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo0?ooo`800000?03oool001/0oooo00<000000?ooo`3oool0O03oool0
1@000000oooo0?ooo`3oool000000100oooo0P00000:0?ooo`030000003oool0000002T0oooo0P00
000g0?ooo`006`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool02`3oool2000005l0oooo000K0?ooo`800000U@3oool2000000h0oooo00<000000?oo
o`0000009`3oool00`000000oooo0?ooo`0a0?ooo`006`3oool00`000000oooo0?ooo`250?ooo`80
00003`3oool200000100oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`03000002d0
oooo000K0?ooo`030000003oool0oooo08T0oooo0P00000=0?ooo`<000003`3oool010000000oooo
00000000000Y0?ooo`800000:@3oool001/0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0>0?ooo`8000004P3oool00`000000oooo0000001@0?ooo`006`3oool2000008l0oooo0P00
000=0?ooo`<000004`3oool00`000000oooo0?ooo`0V0?ooo`8000000`3oool2000001l0oooo000K
0?ooo`030000003oool0oooo09<0oooo0P00000;0?ooo`8000004`3oool00`000000oooo0?ooo`0^
0?ooo`8000006P3oool001/0oooo00<000000?ooo`3oool0XP3oool2000001<0oooo0P00000b0?oo
o`030000003oool0oooo01@0oooo000K0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0000002l0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`006`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00T0
oooo0`00000D0?ooo`030000003oool000000380oooo00<000000?ooo`3oool03P3oool001/0oooo
0P00002M0?ooo`8000000`3oool2000000D0oooo0P00000F0?ooo`030000003oool0oooo0340oooo
0P00000<0?ooo`006`3oool00`000000oooo0?ooo`2Z0?ooo`<000005@3oool00`000000oooo0?oo
o`0m0?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`8000001@3oool2000001D0oooo00<00000
0?ooo`3oool0<P3oool2000000040?ooo`0000000000000000<0oooo00000`3oool0000000000003
00000080oooo0P0000030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0Z`3oool0
10000000oooo0?ooo`3oool3000001@0oooo0P00000j0?ooo`000`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo00<0oooo0`00000D0?ooo`030000003oool0000003H0oooo0003
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`800000/03oool3000000<0oooo0P00000D0?ooo`030000003oool0oooo03@0oooo00030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?oo
o`3oool0]`3oool3000001<0oooo00<000000?ooo`000000<P3oool000<0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`030?ooo`8000004`3oool00`000000oooo0000000`0?oo
o`000P3oool2000000X0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo00@0oooo0`00000B0?ooo`030000003oool0000002h0oooo000K0?ooo`800000
`03oool2000001@0oooo00<000000?ooo`3oool0:P3oool001/0oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`060?ooo`<000004`3oool00`000000oooo0?ooo`0X0?ooo`006`3oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo00T0oooo0`00000B0?ooo`8000009`3oool0
01/0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0<0?ooo`8000004P3oool00`00
0000oooo0?ooo`0T0?ooo`006`3oool00`000000oooo0?ooo`390?ooo`<00000403oool2000002@0
oooo000K0?ooo`800000c@3oool200000100oooo00<000000?ooo`0000008@3oool001/0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0B0?ooo`<000004@3oool00`000000oooo0?oo
o`0M0?ooo`006`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01D0oooo0P00000A
0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool05`3oool300000100oooo00<000000?ooo`3oool06@3oool001/0oooo0P00003G0?ooo`<0
00003`3oool00`000000oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`3I0?ooo`800000
3`3oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`3K0?ooo`<000003P3o
ool400000180oooo000K0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool08P3oool2
00000140oooo00<000000?ooo`3oool03P3oool001/0oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0S0?ooo`<00000403oool00`000000oooo0?ooo`0<0?ooo`006`3oool200000>@0
oooo0P00000@0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo0>D0oooo
0`00000=0?ooo`030000003oool0000000X0oooo00070?ooo`D000000P3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0>P0oooo1@00000<0?ooo`040000003oool0oooo000000D0oooo
00090?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo0300oooo0`00000=0?ooo`030000003oool0oooo0080oooo
00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool200000;/0oooo00<0
00000?ooo`3oool0<`3oool200000100oooo00090?ooo`030000003oool0oooo00P0oooo0P000005
0?ooo`030000003oool0oooo0?80oooo0`00000=0?ooo`002@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0m@3oool2000000/0oooo00080?ooo`80
00002P3oool3000000@0oooo00<000000?ooo`3oool0m`3oool3000000P0oooo000K0?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool0?03oool3000000D0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.295284, \
0.00778854, 0.0109638}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.0561849 0.280925 [
[.12943 .04368 -9 -9 ]
[.12943 .04368 9 0 ]
[.25887 .04368 -9 -9 ]
[.25887 .04368 9 0 ]
[.3883 .04368 -9 -9 ]
[.3883 .04368 9 0 ]
[.51774 .04368 -9 -9 ]
[.51774 .04368 9 0 ]
[.64717 .04368 -3 -9 ]
[.64717 .04368 3 0 ]
[.77661 .04368 -9 -9 ]
[.77661 .04368 9 0 ]
[.90604 .04368 -9 -9 ]
[.90604 .04368 9 0 ]
[-0.0125 .19665 -18 -4.5 ]
[-0.0125 .19665 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .05618 m
.12943 .06243 L
s
[(0.2)] .12943 .04368 0 1 Mshowa
.25887 .05618 m
.25887 .06243 L
s
[(0.4)] .25887 .04368 0 1 Mshowa
.3883 .05618 m
.3883 .06243 L
s
[(0.6)] .3883 .04368 0 1 Mshowa
.51774 .05618 m
.51774 .06243 L
s
[(0.8)] .51774 .04368 0 1 Mshowa
.64717 .05618 m
.64717 .06243 L
s
[(1)] .64717 .04368 0 1 Mshowa
.77661 .05618 m
.77661 .06243 L
s
[(1.2)] .77661 .04368 0 1 Mshowa
.90604 .05618 m
.90604 .06243 L
s
[(1.4)] .90604 .04368 0 1 Mshowa
.125 Mabswid
.03236 .05618 m
.03236 .05993 L
s
.06472 .05618 m
.06472 .05993 L
s
.09708 .05618 m
.09708 .05993 L
s
.16179 .05618 m
.16179 .05993 L
s
.19415 .05618 m
.19415 .05993 L
s
.22651 .05618 m
.22651 .05993 L
s
.29123 .05618 m
.29123 .05993 L
s
.32359 .05618 m
.32359 .05993 L
s
.35595 .05618 m
.35595 .05993 L
s
.42066 .05618 m
.42066 .05993 L
s
.45302 .05618 m
.45302 .05993 L
s
.48538 .05618 m
.48538 .05993 L
s
.5501 .05618 m
.5501 .05993 L
s
.58246 .05618 m
.58246 .05993 L
s
.61482 .05618 m
.61482 .05993 L
s
.67953 .05618 m
.67953 .05993 L
s
.71189 .05618 m
.71189 .05993 L
s
.74425 .05618 m
.74425 .05993 L
s
.80897 .05618 m
.80897 .05993 L
s
.84133 .05618 m
.84133 .05993 L
s
.87369 .05618 m
.87369 .05993 L
s
.9384 .05618 m
.9384 .05993 L
s
.97076 .05618 m
.97076 .05993 L
s
.25 Mabswid
0 .05618 m
1 .05618 L
s
0 .19665 m
.00625 .19665 L
s
[(0.5)] -0.0125 .19665 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(1)] -0.0125 .33711 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(1.5)] -0.0125 .47757 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05632 L
.13 .059 L
.14 .06547 L
.15 .0677 L
.16 .06923 L
.17 .07115 L
.18 .07343 L
.19 .07573 L
.2 .07818 L
.21 .08098 L
.22 .08464 L
.23 .08885 L
.24 .09314 L
.25 .09765 L
.26 .10223 L
.27 .10765 L
.28 .11355 L
.29 .11781 L
.3 .12293 L
.31 .1287 L
.32 .13366 L
.33 .13832 L
.34 .14368 L
.35 .14859 L
.36 .15434 L
.37 .1601 L
.38 .16534 L
.39 .17147 L
.4 .17832 L
.41 .18407 L
.42 .18888 L
.43 .19553 L
.44 .20141 L
.45 .20783 L
.46 .21397 L
.47 .22252 L
.48 .22958 L
.49 .23663 L
Mistroke
.5 .24442 L
.51 .25199 L
.52 .25829 L
.53 .26509 L
.54 .2738 L
.55 .28198 L
.56 .28992 L
.57 .29641 L
.58 .30521 L
.59 .31496 L
.6 .3215 L
.61 .33119 L
.62 .34003 L
.63 .3485 L
.64 .35823 L
.65 .36911 L
.66 .37879 L
.67 .38715 L
.68 .39872 L
.69 .41065 L
.7 .4204 L
.71 .43214 L
.72 .44247 L
.73 .4549 L
.74 .46583 L
.75 .47619 L
.76 .48595 L
.77 .49866 L
.78 .5114 L
.79 .52247 L
.8 .53286 L
.81 .54147 L
.82 .54768 L
.83 .55389 L
.84 .55724 L
.85 .56058 L
.86 .56346 L
.87 .56554 L
.88 .56689 L
.89 .56802 L
.9 .57002 L
.91 .57084 L
.92 .57157 L
.93 .57163 L
.94 .57163 L
.95 .5719 L
.96 .57208 L
.97 .57208 L
.98 .57208 L
.99 .57208 L
Mistroke
1 .57417 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000000<0
oooo1000000D0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000103oool2000000<0
oooo0`00000D0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`D000005`3oool500000080
oooo0P0000030?ooo`@000004`3oool500000080oooo0P0000050?ooo`<000004@3oool001D0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`00
5@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo1@00000A0?ooo`005@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203o
ool3000001<0oooo00@000000?ooo`3oool000002@3oool2000001`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000B0?ooo`005@3oool2000001P0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004P3oool001D0oooo00<000000?ooo`3oool0603oool2000000X0
oooo0P00000E0?ooo`8000002`3oool2000001<0oooo0P00000:0?ooo`<000004`3oool2000000X0
oooo0P00000K0?ooo`8000006P3oool2000000X0oooo0P00000E0?ooo`8000002`3oool200000180
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooool000003000000001D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool2
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`005@3oool00`00
0000oooo0?ooo`0Q0?ooo`80000000<0oooo0000003oool0hP3oool001D0oooo00<000000?ooo`3o
ool0903oool010000000oooo0000003oool200000=h0oooo000E0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`000000fP3oool001D0oooo00<000000?ooo`3oool0;`3oool2000000030?oo
o`000000oooo0=@0oooo000E0?ooo`030000003oool0oooo0380oooo00<000000?ooo`000000d`3o
ool001D0oooo0P00000g0?ooo`800000d03oool001D0oooo00<000000?ooo`3oool0>03oool20000
0<h0oooo000E0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0bP3oool001D0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`380?ooo`005@3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0<H0oooo000E0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0a03oool001D0oooo00<000000?ooo`3oool0@`3oool200000<<0oooo000E0?ooo`03
0000003oool0oooo04D0oooo0P0000310?ooo`005@3oool2000004T0oooo00<000000?ooo`3oool0
_@3oool001D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2k0?ooo`005@3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0;T0oooo000E0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0]`3oool001D0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`2e0?ooo`005@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;<0oooo
000E0?ooo`030000003oool0oooo0580oooo00<000000?ooo`000000/`3oool001D0oooo0P00001F
0?ooo`030000003oool0oooo0;00oooo000E0?ooo`030000003oool0oooo05H0oooo0P00002`0?oo
o`005@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:`0oooo000E0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0ZP3oool001D0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`2X0?ooo`005@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0:H0oooo000E0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0Y03oool001D0
oooo0P00001T0?ooo`030000003oool0oooo0:80oooo000E0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0XP3oool001D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`2P0?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09h0oooo000E0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0W03oool001D0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`2J0?ooo`000P3oool2000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1]0?ooo`800000V@3oool000050?oo
o`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`800000L03oool2000009L0
oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000050?ooo`030000003oool0oooo0740
oooo0P00002E0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0L`3oool2000009<0oooo00020?ooo`8000002P3oool3000000@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1e0?ooo`800000T@3o
ool001D0oooo00<000000?ooo`3oool0M`3oool2000008l0oooo000E0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0S03oool001D0oooo0P00001j0?ooo`030000003oool0oooo08`0
oooo000E0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0RP3oool001D0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`280?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0Q@3oool001D0
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`250?ooo`005@3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo08<0oooo000E0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0P@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`1m0?ooo`005@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07/0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`1i0?ooo`005@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
07P0oooo000E0?ooo`800000S`3oool00`000000oooo0?ooo`1g0?ooo`005@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo07H0oooo000E0?ooo`030000003oool0oooo0940oooo00<0
00000?ooo`3oool0M03oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1d
0?ooo`005@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0780oooo000E0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0L03oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo06h0oooo000E
0?ooo`800000VP3oool00`000000oooo0?ooo`1/0?ooo`005@3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo06`0oooo000E0?ooo`030000003oool0oooo09X0oooo0P00001/0?ooo`00
5@3oool00`000000oooo0?ooo`2L0?ooo`800000JP3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`003@3oool5000000<0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`1W
0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool000l0
oooo00<000000?ooo`3oool00`3oool200000:40oooo00<000000?ooo`3oool0I@3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo06<0oooo
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3oool2
000000D0oooo00<000000?ooo`3oool0X`3oool2000006<0oooo000E0?ooo`030000003oool0oooo
0:D0oooo00<000000?ooo`3oool0H03oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo05h0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo0P00002Z0?ooo`030000003oool0oooo05`0oooo000E0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0F`3oool001D0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`1K0?ooo`005@3oool00`000000oooo0?ooo`2/0?ooo`030000
003oool0oooo05T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`1G0?ooo`005@3oool00`000000oooo0?ooo`2_0?oo
o`030000003oool0oooo05H0oooo000E0?ooo`800000/@3oool00`000000oooo0?ooo`1E0?ooo`00
5@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo05@0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`1B
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0D@3oool001D0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`1?0?ooo`005@3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo04l0oooo000E
0?ooo`800000^03oool2000004l0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`1<0?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0BP3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2l0?oo
o`030000003oool0oooo04T0oooo000E0?ooo`800000_`3oool00`000000oooo0?ooo`170?ooo`00
5@3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo04L0oooo000E0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0AP3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo04@0oooo000E0?ooo`03
0000003oool0oooo0?l0oooo2@3oool000030?ooo`000000000000<000000P3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0@P3oool000<0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<@0oooo
00<000000?ooo`3oool0@@3oool000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`800000a@3oool00`000000oooo0?ooo`110?ooo`000`3oool00`000000oooo0?ooo`08
0?ooo`8000001@3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03l0oooo00030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00020?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0b03oool00`000000
oooo0?ooo`0m0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool0?03oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool200000</0oooo0P00000l0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0>@3oool001D0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0g0?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0=P3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000=80oooo00<000000?ooo`3oool0
=03oool001D0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`0b0?ooo`005@3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo0380oooo000E0?ooo`030000003oool0oooo
0=@0oooo0P00000b0?ooo`005@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo02h0
oooo000E0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0;03oool001D0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo0000000/0?ooo`005@3oool00`000000oooo0?ooo`3M
0?ooo`030000003oool0oooo02P0oooo000E0?ooo`800000h03oool2000000030?ooo`000000oooo
02@0oooo000E0?ooo`030000003oool0oooo0>80oooo00@000000?ooo`000000oooo0P00000P0?oo
o`005@3oool00`000000oooo0?ooo`3Y0?ooo`040000003oool000000?ooo`80000000<0oooo0000
003oool05P3oool001D0oooo00<000000?ooo`3oool0lP3oool01`000000oooo0?ooo`000000oooo
0000003oool00P0000001@3oool000000?ooo`000000oooo0080000000@0oooo0000003oool00000
0P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?ooo`X0
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`003@3oool4000000@0oooo
00<000000?ooo`3oool0o`3oool90?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool200000?l0oooo2P3oool0
00l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003@3oool010000000oooo0?ooo`00003o0?oo
oa00oooo000>0?ooo`800000o`3ooolA0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.124011, -0.255212, \
0.00581601, 0.0133985}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(FindRoot :: \\\"lstol\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.0561849 0.280925 [
[.12943 .04368 -9 -9 ]
[.12943 .04368 9 0 ]
[.25887 .04368 -9 -9 ]
[.25887 .04368 9 0 ]
[.3883 .04368 -9 -9 ]
[.3883 .04368 9 0 ]
[.51774 .04368 -9 -9 ]
[.51774 .04368 9 0 ]
[.64717 .04368 -3 -9 ]
[.64717 .04368 3 0 ]
[.77661 .04368 -9 -9 ]
[.77661 .04368 9 0 ]
[.90604 .04368 -9 -9 ]
[.90604 .04368 9 0 ]
[-0.0125 .19665 -18 -4.5 ]
[-0.0125 .19665 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .05618 m
.12943 .06243 L
s
[(0.2)] .12943 .04368 0 1 Mshowa
.25887 .05618 m
.25887 .06243 L
s
[(0.4)] .25887 .04368 0 1 Mshowa
.3883 .05618 m
.3883 .06243 L
s
[(0.6)] .3883 .04368 0 1 Mshowa
.51774 .05618 m
.51774 .06243 L
s
[(0.8)] .51774 .04368 0 1 Mshowa
.64717 .05618 m
.64717 .06243 L
s
[(1)] .64717 .04368 0 1 Mshowa
.77661 .05618 m
.77661 .06243 L
s
[(1.2)] .77661 .04368 0 1 Mshowa
.90604 .05618 m
.90604 .06243 L
s
[(1.4)] .90604 .04368 0 1 Mshowa
.125 Mabswid
.03236 .05618 m
.03236 .05993 L
s
.06472 .05618 m
.06472 .05993 L
s
.09708 .05618 m
.09708 .05993 L
s
.16179 .05618 m
.16179 .05993 L
s
.19415 .05618 m
.19415 .05993 L
s
.22651 .05618 m
.22651 .05993 L
s
.29123 .05618 m
.29123 .05993 L
s
.32359 .05618 m
.32359 .05993 L
s
.35595 .05618 m
.35595 .05993 L
s
.42066 .05618 m
.42066 .05993 L
s
.45302 .05618 m
.45302 .05993 L
s
.48538 .05618 m
.48538 .05993 L
s
.5501 .05618 m
.5501 .05993 L
s
.58246 .05618 m
.58246 .05993 L
s
.61482 .05618 m
.61482 .05993 L
s
.67953 .05618 m
.67953 .05993 L
s
.71189 .05618 m
.71189 .05993 L
s
.74425 .05618 m
.74425 .05993 L
s
.80897 .05618 m
.80897 .05993 L
s
.84133 .05618 m
.84133 .05993 L
s
.87369 .05618 m
.87369 .05993 L
s
.9384 .05618 m
.9384 .05993 L
s
.97076 .05618 m
.97076 .05993 L
s
.25 Mabswid
0 .05618 m
1 .05618 L
s
0 .19665 m
.00625 .19665 L
s
[(0.5)] -0.0125 .19665 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(1)] -0.0125 .33711 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(1.5)] -0.0125 .47757 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
0 .05619 m
.01 .05945 L
.02 .06275 L
.03 .06608 L
.04 .06944 L
.05 .07282 L
.06 .07624 L
.07 .07969 L
.08 .08317 L
.09 .08667 L
.1 .09022 L
.11 .09379 L
.12 .09739 L
.13 .10103 L
.14 .1047 L
.15 .10841 L
.16 .11215 L
.17 .11592 L
.18 .11973 L
.19 .12357 L
.2 .12745 L
.21 .13137 L
.22 .13532 L
.23 .13932 L
.24 .14335 L
.25 .14741 L
.26 .15152 L
.27 .15566 L
.28 .15985 L
.29 .16408 L
.3 .16834 L
.31 .17265 L
.32 .177 L
.33 .1814 L
.34 .18584 L
.35 .19032 L
.36 .19484 L
.37 .19942 L
.38 .20403 L
.39 .2087 L
.4 .21341 L
.41 .21817 L
.42 .22298 L
.43 .22783 L
.44 .23274 L
.45 .2377 L
.46 .24271 L
.47 .24777 L
.48 .25289 L
.49 .25805 L
Mistroke
.5 .26328 L
.51 .26856 L
.52 .27389 L
.53 .27928 L
.54 .28473 L
.55 .29024 L
.56 .29581 L
.57 .30144 L
.58 .30713 L
.59 .31289 L
.6 .31871 L
.61 .32459 L
.62 .33054 L
.63 .33655 L
.64 .34264 L
.65 .34879 L
.66 .35501 L
.67 .3613 L
.68 .36767 L
.69 .37411 L
.7 .38062 L
.71 .38721 L
.72 .39387 L
.73 .40062 L
.74 .40744 L
.75 .41435 L
.76 .42134 L
.77 .42841 L
.78 .43557 L
.79 .44281 L
.8 .45014 L
.81 .45757 L
.82 .46508 L
.83 .47269 L
.84 .48039 L
.85 .48819 L
.86 .49609 L
.87 .50408 L
.88 .51218 L
.89 .52039 L
.9 .52869 L
.91 .53711 L
.92 .54563 L
.93 .55427 L
.94 .56302 L
.95 .57189 L
.96 .58087 L
.97 .58998 L
.98 .5992 L
.99 .60855 L
Mistroke
1 .61803 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000000<0
oooo1000000D0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000103oool2000000<0
oooo0`00000D0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`D000005`3oool500000080
oooo0P0000030?ooo`@000004`3oool500000080oooo0P0000050?ooo`<000004@3oool001D0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`00
5@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo1@00000A0?ooo`005@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203o
ool3000001<0oooo00@000000?ooo`3oool000002@3oool2000001`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000B0?ooo`005@3oool2000001P0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004P3oool001D0oooo00<000000?ooo`3oool0603oool2000000X0
oooo0P00000E0?ooo`8000002`3oool2000001<0oooo0P00000:0?ooo`<000004`3oool2000000X0
oooo0P00000K0?ooo`8000006P3oool2000000X0oooo0P00000E0?ooo`8000002`3oool200000180
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooool000003000000001D0oooo00@000000?ooo`3oool0oooo0`00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00<000000?ooo`3oool0103oool200000?l0oooo0`3oool001D0oooo00<000000?oo
o`3oool01P3oool300000?l0oooo000E0?ooo`030000003oool0oooo00T0oooo0`00003l0?ooo`00
5@3oool00`000000oooo0?ooo`0<0?ooo`800000nP3oool001D0oooo00<000000?ooo`3oool03P3o
ool300000?L0oooo000E0?ooo`8000004P3oool300000?@0oooo000E0?ooo`030000003oool0oooo
01@0oooo0P00003b0?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`<00000k`3oool001D0oooo
00<000000?ooo`3oool06@3oool300000>`0oooo000E0?ooo`030000003oool0oooo01`0oooo0P00
003Z0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`H00000i03oool001D0oooo00<000000?oo
o`3oool0903oool200000>80oooo000E0?ooo`030000003oool0oooo02H0oooo0`00003O0?ooo`00
5@3oool2000002X0oooo0`00003L0?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`800000fP3o
ool001D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3G0?ooo`005@3oool00`00
0000oooo0?ooo`0_0?ooo`800000e`3oool001D0oooo00<000000?ooo`3oool0<@3oool300000=@0
oooo000E0?ooo`030000003oool0oooo03@0oooo0P00003B0?ooo`005@3oool00`000000oooo0?oo
o`0f0?ooo`<00000c`3oool001D0oooo0P00000j0?ooo`<00000c03oool001D0oooo00<000000?oo
o`3oool0?03oool200000<X0oooo000E0?ooo`030000003oool0oooo03h0oooo0`0000370?ooo`00
5@3oool00`000000oooo0?ooo`110?ooo`<00000a03oool001D0oooo00<000000?ooo`3oool0A03o
ool200000<80oooo000E0?ooo`030000003oool0oooo04H0oooo0`00002o0?ooo`005@3oool00`00
0000oooo0?ooo`190?ooo`<00000_03oool001D0oooo0P00001=0?ooo`800000^P3oool001D0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2g0?ooo`005@3oool00`000000oooo0?oo
o`1?0?ooo`800000]`3oool001D0oooo00<000000?ooo`3oool0D@3oool200000;D0oooo000E0?oo
o`030000003oool0oooo05<0oooo0`00002b0?ooo`005@3oool00`000000oooo0?ooo`1F0?ooo`<0
0000[`3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
F@3oool200000:d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1K0?ooo`800000Z`3oool000050?ooo`000000oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`020?ooo`800000GP3oool200000:T0oooo00001@3oool00000
0?ooo`3oool0000000T0oooo0P0000050?ooo`030000003oool0oooo05l0oooo0P00002W0?ooo`00
00D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0H@3oool200000:D0oooo00020?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0
H`3oool300000:80oooo000E0?ooo`030000003oool0oooo06H0oooo0P00002P0?ooo`005@3oool0
0`000000oooo0?ooo`1X0?ooo`800000WP3oool001D0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`2K0?ooo`005@3oool2000006`0oooo0`00002J0?ooo`005@3oool00`000000oooo
0?ooo`1^0?ooo`800000V03oool001D0oooo00<000000?ooo`3oool0L03oool2000009H0oooo000E
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0T`3oool001D0oooo00<000000?oo
o`3oool0L`3oool300000980oooo000E0?ooo`030000003oool0oooo07H0oooo0P00002@0?ooo`00
5@3oool00`000000oooo0?ooo`1h0?ooo`800000SP3oool001D0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`2;0?ooo`005@3oool2000007`0oooo0`00002:0?ooo`005@3oool00`00
0000oooo0?ooo`1n0?ooo`800000R03oool001D0oooo00<000000?ooo`3oool0P03oool2000008H0
oooo000E0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0P`3oool001D0oooo00<0
00000?ooo`3oool0P`3oool300000880oooo000E0?ooo`030000003oool0oooo08H0oooo0P000020
0?ooo`005@3oool00`000000oooo0?ooo`280?ooo`800000OP3oool001D0oooo0P00002;0?ooo`03
0000003oool0oooo07/0oooo000E0?ooo`030000003oool0oooo08/0oooo0P00001k0?ooo`005@3o
ool00`000000oooo0?ooo`2=0?ooo`800000N@3oool001D0oooo00<000000?ooo`3oool0S`3oool2
000007L0oooo000E0?ooo`030000003oool0oooo0940oooo0P00001e0?ooo`005@3oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0780oooo000E0?ooo`030000003oool0oooo09@0oooo
0P00001b0?ooo`005@3oool00`000000oooo0?ooo`2F0?ooo`800000L03oool001D0oooo0P00002I
0?ooo`800000KP3oool001D0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1[0?oo
o`005@3oool00`000000oooo0?ooo`2K0?ooo`800000J`3oool001D0oooo00<000000?ooo`3oool0
W@3oool2000006T0oooo000E0?ooo`030000003oool0oooo09l0oooo0P00001W0?ooo`003@3oool5
000000<0oooo00<000000?ooo`3oool0X@3oool2000006D0oooo000?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`1R0?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`800000Y@3oool00`000000oooo0?ooo`1Q0?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0:D0oooo0P00001Q0?ooo`003`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0:L0oooo0P00001O0?ooo`003P3oool2000000D0oooo00<00000
0?ooo`3oool0Z@3oool2000005d0oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool0FP3oool001D0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1I0?ooo`00
5@3oool00`000000oooo0?ooo`2]0?ooo`800000F@3oool001D0oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`1F0?ooo`005@3oool200000;40oooo0P00001F0?ooo`005@3oool00`00
0000oooo0?ooo`2b0?ooo`800000E03oool001D0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`1A0?ooo`005@3oool00`000000oooo0?ooo`2e0?ooo`800000D@3oool001D0oooo00<0
00000?ooo`3oool0]`3oool00`000000oooo0?ooo`1>0?ooo`005@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo04d0oooo000E0?ooo`030000003oool0oooo0;T0oooo0P00001=0?oo
o`005@3oool200000;`0oooo0P00001;0?ooo`005@3oool00`000000oooo0?ooo`2m0?ooo`800000
B@3oool001D0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`160?ooo`005@3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo04D0oooo000E0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0A03oool001D0oooo00<000000?ooo`3oool0`P3oool2000004@0
oooo000E0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0@@3oool001D0oooo00<0
00000?ooo`3oool0a@3oool200000440oooo000E0?ooo`800000b03oool00`000000oooo0?ooo`0n
0?ooo`005@3oool00`000000oooo0?ooo`380?ooo`800000?P3oool001D0oooo00<000000?ooo`3o
ool0bP3oool2000003`0oooo000E0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
>@3oool001D0oooo00<000000?ooo`3oool0c@3oool2000003T0oooo000E0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool0=P3oool001D0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`0e0?ooo`005@3oool200000=80oooo00<000000?ooo`3oool0=03oool001D0oooo
00<000000?ooo`3oool0dP3oool2000003@0oooo000E0?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool0<@3oool001D0oooo00<000000?ooo`3oool0e@3oool200000340oooo000E0?oo
o`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0;P3oool001D0oooo00<000000?ooo`3o
ool0f03oool00`000000oooo0?ooo`0]0?ooo`0000<0oooo0000000000000`0000020?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0/0?ooo`000`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
fP3oool2000002`0oooo00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool200000=d0oooo00<000000?ooo`3oool0:@3oool000<0oooo00<000000?ooo`3oool0203oool2
000000D0oooo00<000000?ooo`3oool0g@3oool2000002T0oooo00030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
02H0oooo00020?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`0U0?ooo`005@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo02@0oooo
000E0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool08`3oool001D0oooo00<00000
0?ooo`3oool0h`3oool00`000000oooo0?ooo`0R0?ooo`005@3oool200000>D0oooo00<000000?oo
o`3oool08@3oool001D0oooo00<000000?ooo`3oool0i@3oool200000240oooo000E0?ooo`030000
003oool0oooo0>L0oooo00<000000?ooo`3oool07P3oool001D0oooo00<000000?ooo`3oool0j03o
ool00`000000oooo0?ooo`0M0?ooo`005@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0
oooo01`0oooo000E0?ooo`030000003oool0oooo0>X0oooo0P00000L0?ooo`005@3oool00`000000
oooo0?ooo`3/0?ooo`030000003oool0oooo01T0oooo000E0?ooo`800000kP3oool2000001T0oooo
000E0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool05P3oool001D0oooo00<00000
0?ooo`3oool0l03oool00`000000oooo0?ooo`0E0?ooo`005@3oool00`000000oooo0?ooo`3`0?oo
o`030000003oool0oooo01D0oooo000E0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool0503oool001D0oooo00<000000?ooo`3oool0lP3oool2000001@0oooo000E0?ooo`030000003o
ool0oooo0?@0oooo00<000000?ooo`3oool04@3oool001D0oooo00<000000?ooo`3oool0m@3oool2
00000140oooo000E0?ooo`800000n03oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000
oooo0?ooo`3h0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0oooo0?P0oooo
00<000000?ooo`3oool03@3oool001D0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?oo
o`0<0?ooo`005@3oool00`000000oooo0?ooo`3j0?ooo`800000303oool001D0oooo00<000000?oo
o`3oool0o03oool00`000000oooo0?ooo`090?ooo`005@3oool00`000000oooo0?ooo`3m0?ooo`80
00002@3oool001D0oooo0P00003o0?ooo`40oooo00<000000?ooo`3oool01P3oool001D0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`80oooo00<000000?ooo`3oool0103oool001D0oooo00<000000?ooo`3oool0o`3oool30?ooo`80
0000103oool001D0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo0040oooo
000=0?ooo`@00000103oool00`000000oooo0?ooo`3o0?ooo`H0oooo0@0000010?ooo`40oooo000=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
00h0oooo00<000000?ooo`3oool0103oool200000?l0oooo2@3oool1000000003`3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo000=0?ooo`040000003oool0oooo00000?l0oooo403oool000h0oooo
0P00003o0?oooa40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.124011, -0.255212, \
0.00581601, 0.0133985}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.0561849 0.280925 [
[.12943 .04368 -9 -9 ]
[.12943 .04368 9 0 ]
[.25887 .04368 -9 -9 ]
[.25887 .04368 9 0 ]
[.3883 .04368 -9 -9 ]
[.3883 .04368 9 0 ]
[.51774 .04368 -9 -9 ]
[.51774 .04368 9 0 ]
[.64717 .04368 -3 -9 ]
[.64717 .04368 3 0 ]
[.77661 .04368 -9 -9 ]
[.77661 .04368 9 0 ]
[.90604 .04368 -9 -9 ]
[.90604 .04368 9 0 ]
[-0.0125 .19665 -18 -4.5 ]
[-0.0125 .19665 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .05618 m
.12943 .06243 L
s
[(0.2)] .12943 .04368 0 1 Mshowa
.25887 .05618 m
.25887 .06243 L
s
[(0.4)] .25887 .04368 0 1 Mshowa
.3883 .05618 m
.3883 .06243 L
s
[(0.6)] .3883 .04368 0 1 Mshowa
.51774 .05618 m
.51774 .06243 L
s
[(0.8)] .51774 .04368 0 1 Mshowa
.64717 .05618 m
.64717 .06243 L
s
[(1)] .64717 .04368 0 1 Mshowa
.77661 .05618 m
.77661 .06243 L
s
[(1.2)] .77661 .04368 0 1 Mshowa
.90604 .05618 m
.90604 .06243 L
s
[(1.4)] .90604 .04368 0 1 Mshowa
.125 Mabswid
.03236 .05618 m
.03236 .05993 L
s
.06472 .05618 m
.06472 .05993 L
s
.09708 .05618 m
.09708 .05993 L
s
.16179 .05618 m
.16179 .05993 L
s
.19415 .05618 m
.19415 .05993 L
s
.22651 .05618 m
.22651 .05993 L
s
.29123 .05618 m
.29123 .05993 L
s
.32359 .05618 m
.32359 .05993 L
s
.35595 .05618 m
.35595 .05993 L
s
.42066 .05618 m
.42066 .05993 L
s
.45302 .05618 m
.45302 .05993 L
s
.48538 .05618 m
.48538 .05993 L
s
.5501 .05618 m
.5501 .05993 L
s
.58246 .05618 m
.58246 .05993 L
s
.61482 .05618 m
.61482 .05993 L
s
.67953 .05618 m
.67953 .05993 L
s
.71189 .05618 m
.71189 .05993 L
s
.74425 .05618 m
.74425 .05993 L
s
.80897 .05618 m
.80897 .05993 L
s
.84133 .05618 m
.84133 .05993 L
s
.87369 .05618 m
.87369 .05993 L
s
.9384 .05618 m
.9384 .05993 L
s
.97076 .05618 m
.97076 .05993 L
s
.25 Mabswid
0 .05618 m
1 .05618 L
s
0 .19665 m
.00625 .19665 L
s
[(0.5)] -0.0125 .19665 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(1)] -0.0125 .33711 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(1.5)] -0.0125 .47757 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05618 L
.13 .05618 L
.14 .05618 L
.15 .05775 L
.16 .05976 L
.17 .06176 L
.18 .06262 L
.19 .064 L
.2 .06588 L
.21 .06713 L
.22 .06933 L
.23 .07273 L
.24 .07422 L
.25 .07855 L
.26 .08259 L
.27 .08581 L
.28 .09117 L
.29 .09531 L
.3 .09952 L
.31 .10418 L
.32 .10753 L
.33 .11193 L
.34 .11559 L
.35 .12046 L
.36 .12377 L
.37 .12936 L
.38 .13366 L
.39 .13604 L
.4 .14457 L
.41 .1496 L
.42 .15204 L
.43 .15974 L
.44 .16261 L
.45 .16881 L
.46 .1724 L
.47 .18007 L
.48 .18463 L
.49 .18563 L
Mistroke
.5 .19389 L
.51 .19491 L
.52 .20781 L
.53 .20998 L
.54 .21333 L
.55 .22786 L
.56 .23594 L
.57 .24064 L
.58 .24351 L
.59 .25337 L
.6 .25528 L
.61 .2688 L
.62 .2751 L
.63 .28427 L
.64 .28839 L
.65 .30328 L
.66 .30547 L
.67 .31112 L
.68 .32278 L
.69 .33452 L
.7 .34111 L
.71 .34906 L
.72 .35792 L
.73 .36957 L
.74 .37746 L
.75 .38572 L
.76 .39534 L
.77 .40383 L
.78 .42433 L
.79 .4316 L
.8 .4403 L
.81 .44777 L
.82 .45607 L
.83 .4589 L
.84 .46101 L
.85 .46766 L
.86 .46979 L
.87 .46981 L
.88 .46981 L
.89 .46981 L
.9 .46981 L
.91 .46981 L
.92 .46981 L
.93 .46981 L
.94 .46981 L
.95 .46981 L
.96 .46981 L
.97 .46981 L
.98 .46981 L
.99 .46981 L
Mistroke
1 .46981 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000000<0
oooo1000000D0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000103oool2000000<0
oooo0`00000D0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`D000005`3oool500000080
oooo0P0000030?ooo`@000004`3oool500000080oooo0P0000050?ooo`<000004@3oool001D0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`00
5@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo1@00000A0?ooo`005@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203o
ool3000001<0oooo00@000000?ooo`3oool000002@3oool2000001`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000B0?ooo`005@3oool2000001P0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004P3oool001D0oooo00<000000?ooo`3oool0603oool2000000X0
oooo0P00000E0?ooo`8000002`3oool2000001<0oooo0P00000:0?ooo`<000004`3oool2000000X0
oooo0P00000K0?ooo`8000006P3oool2000000X0oooo0P00000E0?ooo`8000002`3oool200000180
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooool000003000000001D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`8000000`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`005@3oool0
0`000000oooo0?ooo`0^0?ooo`040000003oool0oooo0?ooo`<00000d`3oool001D0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`3>0?ooo`005@3oool00`000000oooo0?ooo`0h0?oo
o`8000000`3oool00`000000oooo0?ooo`380?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0<L0oooo000E0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
``3oool001D0oooo0P0000130?ooo`800000a03oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`160?ooo`<00000_`3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`<00000^P3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1@0?ooo`800000]P3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool2000005H0oooo0P00002a0?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo05X0oooo0P00
002/0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
05l0oooo0P00002W0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo06@0oooo0P00002R0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1X0?ooo`800000WP3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1]0?ooo`800000
V@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo09<0oooo000E0?ooo`800000M03oool00`000000oooo0?ooo`2B0?oo
o`005@3oool00`000000oooo0?ooo`1f0?ooo`800000T03oool001D0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`2=0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0RP3oool001D0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`290?ooo`000P3oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`210?ooo`800000Q@3oool00005
0?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`800000o`3oool:0?oo
o`0000D0oooo0000003oool0oooo000000090?ooo`8000001@3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo0800oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo07l0oooo00020?ooo`80
00002P3oool3000000@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`1k0?ooo`00
5@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo07X0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1g
0?ooo`005@3oool2000008l0oooo00<000000?ooo`3oool0M`3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0940oooo0P00001e0?ooo`005@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo07<0oooo000E0?ooo`030000003oool0oooo09H0oooo0P00001`0?ooo`005@3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo06h0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool001D0oooo0P00002K0?ooo`<00000J`3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0I`3oool001D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`1V0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo0P00002S0?ooo`030000003oool0oooo06<0oooo000E0?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`3oool0HP3oool001D0oooo00<000000?ooo`3oool0
Y`3oool00`000000oooo0?ooo`1N0?ooo`005@3oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo05d0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo05/0
oooo000E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0FP3oool001D0oooo0P00
002`0?ooo`030000003oool0oooo05H0oooo000E0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool0E@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo1@00
00030?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0D`3oool000l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0580oooo000?0?oo
o`030000003oool0oooo00<0oooo0P00003o0?ooo`X0oooo000?0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0]P3oool200000500oooo000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`1>0?ooo`003P3oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo04/0oooo000E0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0BP3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`800000_`3oool00`000000oooo0?ooo`170?ooo`005@3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo04H0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`320?ooo`800000
A03oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`800000a`3oool00`000000oooo0?ooo`0o0?ooo`005@3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo03h0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo03/0oooo000E0?ooo`030000003oool0oooo0<X0oooo00<000000?oo
o`3oool0>`3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3<
0?ooo`800000>P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0
=@3oool001D0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`0d0?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000eP3oool00`000000oooo0?ooo`0`0?oo
o`005@3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo02l0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0f@3oool2000002d0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0gP3oool20000
00<0oooo0P0000030?ooo`<000000`3oool2000000<0oooo0P0000030?ooo`<000000`3oool20000
00<0oooo0P0000010?ooo`4000000@00000000030?ooo`000000000000<000000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0?l0oooo2@3oool000<0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo2@3oool000<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000o`3oool:0?ooo`000`3o
ool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0003
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00020?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0o`3oool90?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`80
0000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo
100000040?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo000>0?ooo`030000003oool0oooo00@0oooo0P00003o
0?ooo`X0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000d0oooo00@000000?ooo`3o
ool00000o`3oool@0?ooo`003P3oool200000?l0oooo4@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.124011, -0.255212, \
0.00581601, 0.0133985}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.0561849 0.280925 [
[.12943 .04368 -9 -9 ]
[.12943 .04368 9 0 ]
[.25887 .04368 -9 -9 ]
[.25887 .04368 9 0 ]
[.3883 .04368 -9 -9 ]
[.3883 .04368 9 0 ]
[.51774 .04368 -9 -9 ]
[.51774 .04368 9 0 ]
[.64717 .04368 -3 -9 ]
[.64717 .04368 3 0 ]
[.77661 .04368 -9 -9 ]
[.77661 .04368 9 0 ]
[.90604 .04368 -9 -9 ]
[.90604 .04368 9 0 ]
[-0.0125 .19665 -18 -4.5 ]
[-0.0125 .19665 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .05618 m
.12943 .06243 L
s
[(0.2)] .12943 .04368 0 1 Mshowa
.25887 .05618 m
.25887 .06243 L
s
[(0.4)] .25887 .04368 0 1 Mshowa
.3883 .05618 m
.3883 .06243 L
s
[(0.6)] .3883 .04368 0 1 Mshowa
.51774 .05618 m
.51774 .06243 L
s
[(0.8)] .51774 .04368 0 1 Mshowa
.64717 .05618 m
.64717 .06243 L
s
[(1)] .64717 .04368 0 1 Mshowa
.77661 .05618 m
.77661 .06243 L
s
[(1.2)] .77661 .04368 0 1 Mshowa
.90604 .05618 m
.90604 .06243 L
s
[(1.4)] .90604 .04368 0 1 Mshowa
.125 Mabswid
.03236 .05618 m
.03236 .05993 L
s
.06472 .05618 m
.06472 .05993 L
s
.09708 .05618 m
.09708 .05993 L
s
.16179 .05618 m
.16179 .05993 L
s
.19415 .05618 m
.19415 .05993 L
s
.22651 .05618 m
.22651 .05993 L
s
.29123 .05618 m
.29123 .05993 L
s
.32359 .05618 m
.32359 .05993 L
s
.35595 .05618 m
.35595 .05993 L
s
.42066 .05618 m
.42066 .05993 L
s
.45302 .05618 m
.45302 .05993 L
s
.48538 .05618 m
.48538 .05993 L
s
.5501 .05618 m
.5501 .05993 L
s
.58246 .05618 m
.58246 .05993 L
s
.61482 .05618 m
.61482 .05993 L
s
.67953 .05618 m
.67953 .05993 L
s
.71189 .05618 m
.71189 .05993 L
s
.74425 .05618 m
.74425 .05993 L
s
.80897 .05618 m
.80897 .05993 L
s
.84133 .05618 m
.84133 .05993 L
s
.87369 .05618 m
.87369 .05993 L
s
.9384 .05618 m
.9384 .05993 L
s
.97076 .05618 m
.97076 .05993 L
s
.25 Mabswid
0 .05618 m
1 .05618 L
s
0 .19665 m
.00625 .19665 L
s
[(0.5)] -0.0125 .19665 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(1)] -0.0125 .33711 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(1.5)] -0.0125 .47757 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05618 L
.13 .06812 L
.14 .07478 L
.15 .07802 L
.16 .07975 L
.17 .0819 L
.18 .08511 L
.19 .08895 L
.2 .09117 L
.21 .09564 L
.22 .10302 L
.23 .10545 L
.24 .11108 L
.25 .11752 L
.26 .12445 L
.27 .13036 L
.28 .13634 L
.29 .13928 L
.3 .14676 L
.31 .15539 L
.32 .15982 L
.33 .16477 L
.34 .17247 L
.35 .18022 L
.36 .18491 L
.37 .18973 L
.38 .19828 L
.39 .20425 L
.4 .21037 L
.41 .21778 L
.42 .22368 L
.43 .23099 L
.44 .23965 L
.45 .24946 L
.46 .25408 L
.47 .26667 L
.48 .27772 L
.49 .28044 L
Mistroke
.5 .28792 L
.51 .30747 L
.52 .31004 L
.53 .3149 L
.54 .32473 L
.55 .33224 L
.56 .34471 L
.57 .35055 L
.58 .37207 L
.59 .37601 L
.6 .3835 L
.61 .39137 L
.62 .40299 L
.63 .41245 L
.64 .42458 L
.65 .43692 L
.66 .45051 L
.67 .46099 L
.68 .47625 L
.69 .49438 L
.7 .50346 L
.71 .51313 L
.72 .53304 L
.73 .53966 L
.74 .55489 L
.75 .57045 L
.76 .58502 L
.77 .59397 L
.78 .60599 L
.79 .61704 L
Mfstroke
.79 .61704 m
.79079 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000000<0
oooo1000000D0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000103oool2000000<0
oooo0`00000D0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`D000005`3oool500000080
oooo0P0000030?ooo`@000004`3oool500000080oooo0P0000050?ooo`<000004@3oool001D0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`00
5@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo1@00000A0?ooo`005@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203o
ool3000001<0oooo00@000000?ooo`3oool000002@3oool2000001`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000B0?ooo`005@3oool2000001P0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004P3oool001D0oooo00<000000?ooo`3oool0603oool2000000X0
oooo0P00000E0?ooo`8000002`3oool2000001<0oooo0P00000:0?ooo`<000004`3oool2000000X0
oooo0P00000K0?ooo`8000006P3oool2000000X0oooo0P00000E0?ooo`8000002`3oool200000180
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooool000003000000001D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
01D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0>D0oooo000E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
i03oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3P0?ooo`005@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=l0oooo000E0?ooo`800000:`3oool20000
0=`0oooo000E0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0eP3oool001D0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3E0?ooo`005@3oool00`000000oooo0?oo
o`0d0?ooo`800000dP3oool001D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3@
0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0<`0oooo000E0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0b`3oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool2000003l0oooo00<000000?ooo`3oool0a`3oool001D0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`360?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000E0?ooo`030000003oool0oooo0480oooo0P0000340?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0AP3oool300000;l0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0;X0oooo000E0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0^@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0;H0oooo000E0?ooo`030000003oool0oooo
0500oooo0P00002f0?ooo`005@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0;40
oooo000E0?ooo`800000EP3oool00`000000oooo0?ooo`2`0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0F03oool200000:h0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2X0?ooo`000P3oool2000000@0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0:L0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
0P3oool200000680oooo0P00002U0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`800000
1@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0:<0oooo00001@3oool000000?oo
o`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00020?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`2O0?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09h0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`2K0?ooo`005@3oool2000006`0oooo00<000000?ooo`3oool0VP3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo09H0oooo000E0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0U@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0980oooo000E0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0T@3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool2000007P0oooo00<000000?oo
o`3oool0SP3oool001D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2=0?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool001D0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2;0?ooo`005@3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo08X0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo0P0000200?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0Q@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0880
oooo00<000000?ooo`3oool0P`3oool001D0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`220?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo0P0000270?ooo`800000P03oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07/0oooo
000E0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0NP3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`003@3oool5000000<0oooo00<000000?ooo`3oool0o`3oool90?oo
o`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08h0oooo0P00001h0?ooo`00
3`3oool00`000000oooo0?ooo`030?ooo`800000o`3oool:0?ooo`003`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo2@3oool000l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo07<0oooo000>0?ooo`8000001@3oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo0780oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0700oooo000E0?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0K`3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`1]0?ooo`005@3o
ool00`000000oooo0?ooo`2I0?ooo`800000K@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo06P0oooo000E0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0I`3oool001D0oooo0P00003o0?ooo`X0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`1T0?ooo`005@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
06@0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`1Q0?ooo`005@3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo0600oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?oo
o`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`1M0?ooo`005@3oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo05d0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo05X0
oooo000E0?ooo`800000[@3oool00`000000oooo0?ooo`1I0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0[P3oool2000005P0oooo000E0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0EP3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`0000<0oooo0000000000000`00
00020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool90?ooo`000`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1D0?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo0P00002c0?ooo`030000003oool0oooo05<0oooo00030?ooo`030000003oool0oooo
00P0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo2@3oool000<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool00080oooo
0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0D@3oool001D0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`1@0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`80
0000^@3oool00`000000oooo0?ooo`1=0?ooo`005@3oool00`000000oooo0?ooo`2i0?ooo`030000
003oool0oooo04`0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool0BP3oool001D0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`1:0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`2n0?ooo`800000B03oool001D0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`160?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`140?ooo`005@3oool00`000000oooo0?ooo`320?oo
o`030000003oool0oooo04<0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0@@3o
ool001D0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`100?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000<P0oooo0P00000o0?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0j0?ooo`005@3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo03T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool000d0oooo100000040?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03L0oooo000>0?ooo`03
0000003oool0oooo00@0oooo0P00003@0?ooo`030000003oool0oooo03H0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000d0oooo00@000000?ooo`3oool00000o`3oool@0?ooo`003P3o
ool200000?l0oooo4@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.124011, -0.255212, \
0.00581601, 0.0133985}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.14419e-017 0.647175 0.0561849 0.280925 [
[.12943 .04368 -9 -9 ]
[.12943 .04368 9 0 ]
[.25887 .04368 -9 -9 ]
[.25887 .04368 9 0 ]
[.3883 .04368 -9 -9 ]
[.3883 .04368 9 0 ]
[.51774 .04368 -9 -9 ]
[.51774 .04368 9 0 ]
[.64717 .04368 -3 -9 ]
[.64717 .04368 3 0 ]
[.77661 .04368 -9 -9 ]
[.77661 .04368 9 0 ]
[.90604 .04368 -9 -9 ]
[.90604 .04368 9 0 ]
[-0.0125 .19665 -18 -4.5 ]
[-0.0125 .19665 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12943 .05618 m
.12943 .06243 L
s
[(0.2)] .12943 .04368 0 1 Mshowa
.25887 .05618 m
.25887 .06243 L
s
[(0.4)] .25887 .04368 0 1 Mshowa
.3883 .05618 m
.3883 .06243 L
s
[(0.6)] .3883 .04368 0 1 Mshowa
.51774 .05618 m
.51774 .06243 L
s
[(0.8)] .51774 .04368 0 1 Mshowa
.64717 .05618 m
.64717 .06243 L
s
[(1)] .64717 .04368 0 1 Mshowa
.77661 .05618 m
.77661 .06243 L
s
[(1.2)] .77661 .04368 0 1 Mshowa
.90604 .05618 m
.90604 .06243 L
s
[(1.4)] .90604 .04368 0 1 Mshowa
.125 Mabswid
.03236 .05618 m
.03236 .05993 L
s
.06472 .05618 m
.06472 .05993 L
s
.09708 .05618 m
.09708 .05993 L
s
.16179 .05618 m
.16179 .05993 L
s
.19415 .05618 m
.19415 .05993 L
s
.22651 .05618 m
.22651 .05993 L
s
.29123 .05618 m
.29123 .05993 L
s
.32359 .05618 m
.32359 .05993 L
s
.35595 .05618 m
.35595 .05993 L
s
.42066 .05618 m
.42066 .05993 L
s
.45302 .05618 m
.45302 .05993 L
s
.48538 .05618 m
.48538 .05993 L
s
.5501 .05618 m
.5501 .05993 L
s
.58246 .05618 m
.58246 .05993 L
s
.61482 .05618 m
.61482 .05993 L
s
.67953 .05618 m
.67953 .05993 L
s
.71189 .05618 m
.71189 .05993 L
s
.74425 .05618 m
.74425 .05993 L
s
.80897 .05618 m
.80897 .05993 L
s
.84133 .05618 m
.84133 .05993 L
s
.87369 .05618 m
.87369 .05993 L
s
.9384 .05618 m
.9384 .05993 L
s
.97076 .05618 m
.97076 .05993 L
s
.25 Mabswid
0 .05618 m
1 .05618 L
s
0 .19665 m
.00625 .19665 L
s
[(0.5)] -0.0125 .19665 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(1)] -0.0125 .33711 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(1.5)] -0.0125 .47757 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05632 L
.13 .059 L
.14 .06547 L
.15 .0677 L
.16 .06923 L
.17 .07115 L
.18 .07343 L
.19 .07573 L
.2 .07818 L
.21 .08098 L
.22 .08464 L
.23 .08885 L
.24 .09314 L
.25 .09765 L
.26 .10223 L
.27 .10765 L
.28 .11355 L
.29 .11781 L
.3 .12293 L
.31 .1287 L
.32 .13366 L
.33 .13832 L
.34 .14368 L
.35 .14859 L
.36 .15434 L
.37 .1601 L
.38 .16534 L
.39 .17147 L
.4 .17832 L
.41 .18407 L
.42 .18888 L
.43 .19553 L
.44 .20141 L
.45 .20783 L
.46 .21397 L
.47 .22252 L
.48 .22958 L
.49 .23663 L
Mistroke
.5 .24442 L
.51 .25199 L
.52 .25829 L
.53 .26509 L
.54 .2738 L
.55 .28198 L
.56 .28992 L
.57 .29641 L
.58 .30521 L
.59 .31496 L
.6 .3215 L
.61 .33119 L
.62 .34003 L
.63 .3485 L
.64 .35823 L
.65 .36911 L
.66 .37879 L
.67 .38715 L
.68 .39872 L
.69 .41065 L
.7 .4204 L
.71 .43214 L
.72 .44247 L
.73 .4549 L
.74 .46583 L
.75 .47619 L
.76 .48595 L
.77 .49866 L
.78 .5114 L
.79 .52247 L
.8 .53286 L
.81 .54147 L
.82 .54768 L
.83 .55389 L
.84 .55724 L
.85 .56058 L
.86 .56346 L
.87 .56554 L
.88 .56689 L
.89 .56802 L
.9 .57002 L
.91 .57084 L
.92 .57157 L
.93 .57163 L
.94 .57163 L
.95 .5719 L
.96 .57208 L
.97 .57208 L
.98 .57208 L
.99 .57208 L
Mistroke
1 .57417 L
Mfstroke
.003 w
[ ] 0 setdash
0 .05619 m
.01 .05945 L
.02 .06275 L
.03 .06608 L
.04 .06944 L
.05 .07282 L
.06 .07624 L
.07 .07969 L
.08 .08317 L
.09 .08667 L
.1 .09022 L
.11 .09379 L
.12 .09739 L
.13 .10103 L
.14 .1047 L
.15 .10841 L
.16 .11215 L
.17 .11592 L
.18 .11973 L
.19 .12357 L
.2 .12745 L
.21 .13137 L
.22 .13532 L
.23 .13932 L
.24 .14335 L
.25 .14741 L
.26 .15152 L
.27 .15566 L
.28 .15985 L
.29 .16408 L
.3 .16834 L
.31 .17265 L
.32 .177 L
.33 .1814 L
.34 .18584 L
.35 .19032 L
.36 .19484 L
.37 .19942 L
.38 .20403 L
.39 .2087 L
.4 .21341 L
.41 .21817 L
.42 .22298 L
.43 .22783 L
.44 .23274 L
.45 .2377 L
.46 .24271 L
.47 .24777 L
.48 .25289 L
.49 .25805 L
Mistroke
.5 .26328 L
.51 .26856 L
.52 .27389 L
.53 .27928 L
.54 .28473 L
.55 .29024 L
.56 .29581 L
.57 .30144 L
.58 .30713 L
.59 .31289 L
.6 .31871 L
.61 .32459 L
.62 .33054 L
.63 .33655 L
.64 .34264 L
.65 .34879 L
.66 .35501 L
.67 .3613 L
.68 .36767 L
.69 .37411 L
.7 .38062 L
.71 .38721 L
.72 .39387 L
.73 .40062 L
.74 .40744 L
.75 .41435 L
.76 .42134 L
.77 .42841 L
.78 .43557 L
.79 .44281 L
.8 .45014 L
.81 .45757 L
.82 .46508 L
.83 .47269 L
.84 .48039 L
.85 .48819 L
.86 .49609 L
.87 .50408 L
.88 .51218 L
.89 .52039 L
.9 .52869 L
.91 .53711 L
.92 .54563 L
.93 .55427 L
.94 .56302 L
.95 .57189 L
.96 .58087 L
.97 .58998 L
.98 .5992 L
.99 .60855 L
Mistroke
1 .61803 L
Mfstroke
.001 w
[ .005 .015 ] 0 setdash
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05618 L
.13 .05618 L
.14 .05618 L
.15 .05775 L
.16 .05976 L
.17 .06176 L
.18 .06262 L
.19 .064 L
.2 .06588 L
.21 .06713 L
.22 .06933 L
.23 .07273 L
.24 .07422 L
.25 .07855 L
.26 .08259 L
.27 .08581 L
.28 .09117 L
.29 .09531 L
.3 .09952 L
.31 .10418 L
.32 .10753 L
.33 .11193 L
.34 .11559 L
.35 .12046 L
.36 .12377 L
.37 .12936 L
.38 .13366 L
.39 .13604 L
.4 .14457 L
.41 .1496 L
.42 .15204 L
.43 .15974 L
.44 .16261 L
.45 .16881 L
.46 .1724 L
.47 .18007 L
.48 .18463 L
.49 .18563 L
Mistroke
.5 .19389 L
.51 .19491 L
.52 .20781 L
.53 .20998 L
.54 .21333 L
.55 .22786 L
.56 .23594 L
.57 .24064 L
.58 .24351 L
.59 .25337 L
.6 .25528 L
.61 .2688 L
.62 .2751 L
.63 .28427 L
.64 .28839 L
.65 .30328 L
.66 .30547 L
.67 .31112 L
.68 .32278 L
.69 .33452 L
.7 .34111 L
.71 .34906 L
.72 .35792 L
.73 .36957 L
.74 .37746 L
.75 .38572 L
.76 .39534 L
.77 .40383 L
.78 .42433 L
.79 .4316 L
.8 .4403 L
.81 .44777 L
.82 .45607 L
.83 .4589 L
.84 .46101 L
.85 .46766 L
.86 .46979 L
.87 .46981 L
.88 .46981 L
.89 .46981 L
.9 .46981 L
.91 .46981 L
.92 .46981 L
.93 .46981 L
.94 .46981 L
.95 .46981 L
.96 .46981 L
.97 .46981 L
.98 .46981 L
.99 .46981 L
Mistroke
1 .46981 L
Mfstroke
0 .05618 m
.01 .05618 L
.02 .05618 L
.03 .05618 L
.04 .05618 L
.05 .05618 L
.06 .05618 L
.07 .05618 L
.08 .05618 L
.09 .05618 L
.1 .05618 L
.11 .05618 L
.12 .05618 L
.13 .06812 L
.14 .07478 L
.15 .07802 L
.16 .07975 L
.17 .0819 L
.18 .08511 L
.19 .08895 L
.2 .09117 L
.21 .09564 L
.22 .10302 L
.23 .10545 L
.24 .11108 L
.25 .11752 L
.26 .12445 L
.27 .13036 L
.28 .13634 L
.29 .13928 L
.3 .14676 L
.31 .15539 L
.32 .15982 L
.33 .16477 L
.34 .17247 L
.35 .18022 L
.36 .18491 L
.37 .18973 L
.38 .19828 L
.39 .20425 L
.4 .21037 L
.41 .21778 L
.42 .22368 L
.43 .23099 L
.44 .23965 L
.45 .24946 L
.46 .25408 L
.47 .26667 L
.48 .27772 L
.49 .28044 L
Mistroke
.5 .28792 L
.51 .30747 L
.52 .31004 L
.53 .3149 L
.54 .32473 L
.55 .33224 L
.56 .34471 L
.57 .35055 L
.58 .37207 L
.59 .37601 L
.6 .3835 L
.61 .39137 L
.62 .40299 L
.63 .41245 L
.64 .42458 L
.65 .43692 L
.66 .45051 L
.67 .46099 L
.68 .47625 L
.69 .49438 L
.7 .50346 L
.71 .51313 L
.72 .53304 L
.73 .53966 L
.74 .55489 L
.75 .57045 L
.76 .58502 L
.77 .59397 L
.78 .60599 L
.79 .61704 L
Mfstroke
.79 .61704 m
.79079 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000000<0
oooo1000000D0?ooo`800000103oool2000000D0oooo0`00000B0?ooo`800000103oool2000000<0
oooo0`00000D0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`D000005`3oool500000080
oooo0P0000030?ooo`@000004`3oool500000080oooo0P0000050?ooo`<000004@3oool001D0oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`00
5@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool04`3oool010000000oooo0?ooo`0000080?ooo`D000004@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo1@00000A0?ooo`005@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000203o
ool3000001<0oooo00@000000?ooo`3oool000002@3oool2000001`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000B0?ooo`005@3oool2000001P0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004P3oool001D0oooo00<000000?ooo`3oool0603oool2000000X0
oooo0P00000E0?ooo`8000002`3oool2000001<0oooo0P00000:0?ooo`<000004`3oool2000000X0
oooo0P00000K0?ooo`8000006P3oool2000000X0oooo0P00000E0?ooo`8000002`3oool200000180
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooool000003000000001D0oooo00@000000?ooo`3oool0oooo0`00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0000000000070?ooo`8000000`3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`00
5@3oool00`000000oooo0?ooo`040?ooo`8000006`3oool2000000030?ooo`000000oooo00P0oooo
00@000000?ooo`3oool0oooo0`00003C0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`<00000
5`3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P00000=0?ooo`030000003oool0
oooo0<h0oooo000E0?ooo`030000003oool0oooo00T0oooo0`00000E0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000002P3oool2000000<0oooo00<000000?ooo`3oool0b03oool001D0
oooo00<000000?ooo`3oool0303oool2000001L0oooo00<000000?ooo`3oool01`3oool200000003
0?ooo`000000oooo00X0oooo00<000000?ooo`3oool0a`3oool001D0oooo00<000000?ooo`3oool0
3P3oool3000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000=0?ooo`030000
003oool0oooo0<<0oooo000E0?ooo`8000004P3oool3000001H0oooo0P00000:0?ooo`8000002P3o
ool200000<@0oooo000E0?ooo`030000003oool0oooo01@0oooo0P00000I0?ooo`030000003oool0
oooo00H0oooo0P00003>0?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`<000005`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0`00002o0?ooo`005@3oool00`000000
oooo0?ooo`0I0?ooo`<00000603oool2000000L0oooo00<000000?ooo`3oool0b03oool001D0oooo
00<000000?ooo`3oool0703oool2000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`<00000^P3oool001D0oooo00<000000?ooo`3oool07P3oool6000001D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`005@3oool00`000000oooo0?ooo`0T
0?ooo`800000503oool00`000000oooo0?ooo`060?ooo`8000002`3oool200000;H0oooo000E0?oo
o`030000003oool0oooo02H0oooo0`00000L0?ooo`800000`@3oool001D0oooo0P00000Z0?ooo`<0
00004P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo0P00002a0?ooo`00
5@3oool00`000000oooo0?ooo`0/0?ooo`8000004@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0;/0oooo000E0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0;0?ooo`800000[03oool001D0oooo00<000000?ooo`3oool0;`3oool2
00000140oooo0P00000:0?ooo`030000003oool0oooo0;L0oooo000E0?ooo`030000003oool0oooo
0340oooo0`00000L0?ooo`030000003oool0oooo00`0oooo0P00002W0?ooo`005@3oool00`000000
oooo0?ooo`0d0?ooo`800000703oool00`000000oooo0?ooo`2c0?ooo`005@3oool00`000000oooo
0?ooo`0f0?ooo`<000003@3oool3000000T0oooo00<000000?ooo`0000003`3oool200000:80oooo
000E0?ooo`800000>P3oool3000001T0oooo00<000000?ooo`3oool0/03oool001D0oooo00<00000
0?ooo`3oool0?03oool2000000d0oooo00<000000?ooo`3oool0203oool200000;00oooo000E0?oo
o`030000003oool0oooo03h0oooo0`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool2000009h0oooo000E0?ooo`030000003oool0oooo0440oooo0`00000G0?ooo`03
0000003oool0oooo0:X0oooo000E0?ooo`030000003oool0oooo04@0oooo0P0000090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool2000009T0oooo000E0?ooo`030000003o
ool0oooo04H0oooo0`0000070?ooo`8000003@3oool00`000000oooo0?ooo`2V0?ooo`005@3oool0
0`000000oooo0?ooo`190?ooo`<00000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0T`3oool001D0oooo0P00001=0?ooo`8000001`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0TP3oool001D0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100
oooo0P00002@0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`800000503oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo08d0oooo000E0?ooo`030000003oool0oooo0540oooo0P00
00050?ooo`8000003@3oool00`000000oooo0?ooo`2N0?ooo`005@3oool00`000000oooo0?ooo`1C
0?ooo`<000004`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08X0oooo000E0?oo
o`030000003oool0oooo05H0oooo0`0000040?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`290?ooo`000P3oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1I0?ooo`8000000`3oool00`000000oooo0?ooo`2W0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0F`3oool200000100oooo0P00000B0?ooo`800000Q@3oool000050?ooo`000000oooo0?oo
o`0000002`3oool00`000000oooo0?ooo`020?ooo`800000GP3oool200000080oooo0P00000<0?oo
o`800000U`3oool000050?ooo`000000oooo0?ooo`0000002@3oool2000000D0oooo00<000000?oo
o`3oool0G`3oool2000000030?ooo`000000oooo00d0oooo0P00000B0?ooo`030000003oool0oooo
0800oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1Q0?ooo`800000403oool200000140oooo00<000000?ooo`3oool0O`3oool00080
oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`1S0?ooo`@000008`3oool00`000000
oooo0?ooo`1k0?ooo`005@3oool00`000000oooo0?ooo`1V0?ooo`8000003@3oool2000001@0oooo
00<000000?ooo`3oool0NP3oool001D0oooo00<000000?ooo`3oool0J03oool2000000d0oooo0P00
002?0?ooo`005@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`005@3oool2000006`0oooo0`00000;0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool001D0oooo00<000000?ooo`3o
ool0KP3oool2000000/0oooo00<000000?ooo`3oool0RP3oool001D0oooo00<000000?ooo`3oool0
K`3oool3000000/0oooo00<000000?ooo`3oool0R03oool001D0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0000000N0?ooo`800000M@3oool001D0oooo00<000000?ooo`3oool0L`3oool3
000000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1c0?ooo`005@3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`0C0?oo
o`800000L03oool001D0oooo00<000000?ooo`3oool0M03oool010000000oooo0?ooo`3oool20000
00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1^0?ooo`005@3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0P@3oool001D0oooo
0P00001h0?ooo`040000003oool0oooo0?ooo`<00000703oool3000006/0oooo000E0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0
O`3oool001D0oooo00<000000?ooo`3oool0P03oool2000000H0oooo00<000000?ooo`3oool0O@3o
ool001D0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0I`3oool001D0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`060?ooo`<000006@3oool00`000000oooo0?ooo`1V0?ooo`005@3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo07T0
oooo000E0?ooo`030000003oool0oooo08P0oooo0P0000030?ooo`030000003oool0oooo07P0oooo
000E0?ooo`800000P03oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
4`3oool00`000000oooo0?ooo`1S0?ooo`005@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0HP3o
ool001D0oooo00<000000?ooo`3oool0S@3oool200000080oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1N0?ooo`005@3oool00`000000oooo0?ooo`2?0?ooo`<000005P3oool00`00
0000oooo0?ooo`1M0?ooo`005@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00`0
oooo0`00001d0?ooo`005@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`000000LP3oool001D0oooo00<000000?ooo`3oool0U03oool2000001@0oooo00<0
00000?ooo`3oool0F`3oool001D0oooo00<000000?ooo`3oool0UP3oool2000001<0oooo00<00000
0?ooo`3oool0FP3oool001D0oooo0P0000270?ooo`800000403oool2000001D0oooo00<000000?oo
o`3oool0EP3oool001D0oooo00<000000?ooo`3oool0V@3oool2000001D0oooo00<000000?ooo`3o
ool0E@3oool001D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0=0?ooo`<00000
J`3oool001D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0>0?ooo`<00000J@3o
ool001D0oooo00<000000?ooo`3oool0W`3oool2000006L0oooo000=0?ooo`D000000`3oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo008000003`3oool00`000000oooo0?ooo`1C0?oo
o`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08h0oooo0P00000C0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0DP3oool000l0oooo00<000000?ooo`3oool0
0`3oool200000:40oooo00D000000?ooo`3oool0oooo0000001S0?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool00P00000?0?ooo`800000
D03oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0180oooo0P00000>0?ooo`030000003oool0oooo04h0oooo000>0?ooo`8000001@3oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`800000G@3oool0
01D0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0B`3oool001D0oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04X0oooo000E0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`800000F@3oool001D0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo000E
0?ooo`800000ZP3oool00`000000oooo0?ooo`040?ooo`800000303oool00`000000oooo0?ooo`17
0?ooo`005@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00D0oooo0P00000;0?oo
o`030000003oool0oooo04H0oooo000E0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo000E0?ooo`030000
003oool0oooo09T0oooo0P00000A0?ooo`030000003oool0oooo00H0oooo0P00001A0?ooo`005@3o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo00P0oooo0P0000140?ooo`005@3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1=0?ooo`005@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool2000004d0oooo000E0?ooo`800000/@3oool00`000000
oooo0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`0o0?ooo`005@3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo03h0oooo
000E0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`160?ooo`005@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`005@3oool00`000000oooo0?ooo`310?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool001D0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo0P0000060?ooo`03
0000003oool0oooo03/0oooo000E0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0440oooo000E0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0303oool200000440oooo000E0?ooo`800000^03oool2
000000h0oooo00<000000?ooo`3oool0?P3oool001D0oooo00<000000?ooo`3oool0b03oool20000
0080oooo0P00000j0?ooo`005@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool2000003`0oooo000E0?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0i0?ooo`005@3oool00`000000oooo0?oo
o`2k0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000?ooo`0f0?ooo`005@3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0000003H0oooo000E0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03D0oooo000E0?ooo`800000[@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000b0?ooo`005@3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo0140oooo0P0000020?ooo`030000003oool0oooo02l0oooo000E0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0a0?ooo`005@3o
ool00`000000oooo0?ooo`2^0?ooo`8000009@3oool200000080oooo0P00000]0?ooo`005@3oool0
0`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0^0?ooo`005@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`8000000`3oool3000000<0oooo0P0000030?ooo`8000000`3oool30000
00<0oooo0P0000030?ooo`8000000@3oool100000040000000000`3oool000000000000300000080
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0;03oool000<0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0C0?ooo`800000;03oool000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`800000/`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0:@3oool000<0oooo00<000000?ooo`3oool0203oool2000000D0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0D0?ooo`800000:@3oool000<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=l0oooo00<00000
0?ooo`3oool09P3oool00080oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool09@3oool001D0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02@0oooo000E0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02<0oooo000E0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool08P3o
ool001D0oooo0P00002i0?ooo`030000003oool0oooo00l0oooo0P00000H0?ooo`030000003oool0
oooo0240oooo000E0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0:@3oool20000
0240oooo000E0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0N0?ooo`005@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool07@3oool001D0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?oo
o`0L0?ooo`005@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0603oool2000001`0oooo000E0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0I0?ooo`005@3oool200000=80oooo00<000000?ooo`3o
ool06@3oool2000001T0oooo000E0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`2n0?ooo`8000004`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo000E0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool04P3oool2000001X0oooo00<000000?ooo`3oool05@3oool0
01D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool05P3oool2000001@0
oooo000E0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool05@3oool00`000000oooo
0000000H0?ooo`030000003oool0oooo0140oooo000E0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`8000004@3oool001D0oooo0P00003P
0?ooo`80000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`00
0000oooo0?ooo`3R0?ooo`040000003oool000000?ooo`800000403oool00`000000oooo0?ooo`0=
0?ooo`005@3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0280oooo00@000000?oo
o`000000oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00d0oooo000E0?oo
o`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0:P3oool01`000000oooo0?ooo`000000
oooo0000003oool00P0000001@3oool000000?ooo`000000oooo0080000000@0oooo0000003oool0
00000P3oool001D0oooo00<000000?ooo`3oool0nP3oool2000000`0oooo000E0?ooo`030000003o
ool0oooo0?`0oooo00<000000?ooo`3oool02@3oool001D0oooo00<000000?ooo`3oool0o@3oool2
000000T0oooo000E0?ooo`800000b03oool2000003H0oooo00<000000?ooo`3oool01P3oool001D0
oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool001D0oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`0c0?ooo`800000103oool001D0oooo00<000000?oo
o`3oool0o`3oool50?ooo`030000003oool0oooo0040oooo000=0?ooo`@00000103oool00`000000
oooo0?ooo`3o0?ooo`H0oooo0@0000010?ooo`40oooo000=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0e0?ooo`4000000@3oool000h0oooo00<0
00000?ooo`3oool0103oool200000=00oooo00<000000?ooo`3oool0=@3oool1000000003`3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000=0?ooo`040000003oool0oooo00000?l0oooo403oool0
00h0oooo0P00003o0?oooa40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.124011, -0.255212, \
0.00581601, 0.0133985}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.103006 0.515028 [
[.125 .09051 -12 -9 ]
[.125 .09051 12 0 ]
[.25 .09051 -9 -9 ]
[.25 .09051 9 0 ]
[.375 .09051 -12 -9 ]
[.375 .09051 12 0 ]
[.5 .09051 -3 -9 ]
[.5 .09051 3 0 ]
[.625 .09051 -12 -9 ]
[.625 .09051 12 0 ]
[.75 .09051 -9 -9 ]
[.75 .09051 9 0 ]
[.875 .09051 -12 -9 ]
[.875 .09051 12 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .10301 m
.125 .10926 L
s
[(0.25)] .125 .09051 0 1 Mshowa
.25 .10301 m
.25 .10926 L
s
[(0.5)] .25 .09051 0 1 Mshowa
.375 .10301 m
.375 .10926 L
s
[(0.75)] .375 .09051 0 1 Mshowa
.5 .10301 m
.5 .10926 L
s
[(1)] .5 .09051 0 1 Mshowa
.625 .10301 m
.625 .10926 L
s
[(1.25)] .625 .09051 0 1 Mshowa
.75 .10301 m
.75 .10926 L
s
[(1.5)] .75 .09051 0 1 Mshowa
.875 .10301 m
.875 .10926 L
s
[(1.75)] .875 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(2)] 1 .09051 0 1 Mshowa
.125 Mabswid
.025 .10301 m
.025 .10676 L
s
.05 .10301 m
.05 .10676 L
s
.075 .10301 m
.075 .10676 L
s
.1 .10301 m
.1 .10676 L
s
.15 .10301 m
.15 .10676 L
s
.175 .10301 m
.175 .10676 L
s
.2 .10301 m
.2 .10676 L
s
.225 .10301 m
.225 .10676 L
s
.275 .10301 m
.275 .10676 L
s
.3 .10301 m
.3 .10676 L
s
.325 .10301 m
.325 .10676 L
s
.35 .10301 m
.35 .10676 L
s
.4 .10301 m
.4 .10676 L
s
.425 .10301 m
.425 .10676 L
s
.45 .10301 m
.45 .10676 L
s
.475 .10301 m
.475 .10676 L
s
.525 .10301 m
.525 .10676 L
s
.55 .10301 m
.55 .10676 L
s
.575 .10301 m
.575 .10676 L
s
.6 .10301 m
.6 .10676 L
s
.65 .10301 m
.65 .10676 L
s
.675 .10301 m
.675 .10676 L
s
.7 .10301 m
.7 .10676 L
s
.725 .10301 m
.725 .10676 L
s
.775 .10301 m
.775 .10676 L
s
.8 .10301 m
.8 .10676 L
s
.825 .10301 m
.825 .10676 L
s
.85 .10301 m
.85 .10676 L
s
.9 .10301 m
.9 .10676 L
s
.925 .10301 m
.925 .10676 L
s
.95 .10301 m
.95 .10676 L
s
.975 .10301 m
.975 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .10301 m
.01 .10892 L
.02 .11477 L
.03 .12459 L
.04 .13418 L
.05 .14091 L
.06 .14682 L
.07 .15067 L
.08 .15589 L
.09 .16133 L
.1 .16421 L
.11 .17022 L
.12 .1741 L
.13 .17966 L
.14 .18606 L
.15 .19043 L
.16 .19484 L
.17 .19996 L
.18 .20392 L
.19 .20793 L
.2 .21205 L
.21 .21594 L
.22 .21952 L
.23 .22474 L
.24 .22926 L
.25 .23455 L
.26 .23726 L
.27 .24072 L
.28 .246 L
.29 .24895 L
.3 .25479 L
.31 .25738 L
.32 .26097 L
.33 .26427 L
.34 .26862 L
.35 .27063 L
.36 .2744 L
.37 .27775 L
.38 .28199 L
.39 .28635 L
.4 .29327 L
.41 .29913 L
.42 .30283 L
.43 .30717 L
.44 .31071 L
.45 .31276 L
.46 .3179 L
.47 .32048 L
.48 .32211 L
.49 .32368 L
Mistroke
.5 .33027 L
.51 .33366 L
.52 .33789 L
.53 .34057 L
.54 .34538 L
.55 .34956 L
.56 .3535 L
.57 .35825 L
.58 .36091 L
.59 .36334 L
.6 .36678 L
.61 .37126 L
.62 .37508 L
.63 .37772 L
.64 .38129 L
.65 .38307 L
.66 .38464 L
.67 .38629 L
.68 .38817 L
.69 .39039 L
.7 .39177 L
.71 .39694 L
.72 .3997 L
.73 .40524 L
.74 .4095 L
.75 .41168 L
.76 .415 L
.77 .41754 L
.78 .41849 L
.79 .42006 L
.8 .42335 L
.81 .42594 L
.82 .42803 L
.83 .43385 L
.84 .4372 L
.85 .4436 L
.86 .44861 L
.87 .45113 L
.88 .45632 L
.89 .4588 L
.9 .46637 L
.91 .472 L
.92 .47755 L
.93 .49539 L
.94 .50275 L
.95 .51564 L
.96 .52564 L
.97 .53263 L
.98 .53658 L
.99 .53677 L
Mistroke
1 .53847 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo1@00000B0?ooo`D000000P3o
ool2000000<0oooo100000030?ooo`8000003P3oool500000080oooo0P0000040?ooo`8000003P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`@000000P3o
ool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003P3o
ool010000000oooo0?ooo`0000090?ooo`8000003P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0203oool20000
0100oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000001L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo0P00000D0?ooo`8000002P3oool2000000@0oooo0`00000>0?ooo`8000002P3o
ool3000000h0oooo0P0000090?ooo`@000000`3oool3000001@0oooo0P00000E0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`8000002P3oool3000000h0oooo0P0000090?ooo`@000000`3o
ool3000001D0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000003000000<0oooo000K0?ooo`800000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?oo
o`006`3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3m0?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?d0oooo000K0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0n`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool2000000H0oooo0P00003k0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?P0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3f0?ooo`006`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?@0oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0lP3oool001/0oooo0P00000@0?ooo`030000003oool0oooo0?00oooo000K0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0kP3oool001/0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3/0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`800000j`3oool0
01/0oooo00<000000?ooo`3oool05`3oool200000>T0oooo000K0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0i@3oool001/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3S0?ooo`006`3oool2000001l0oooo00<000000?ooo`3oool0h@3oool001/0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3O0?ooo`006`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0=d0oooo000K0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0f`3oool001/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3I0?ooo`00203o
ool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0=L0oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=D0oooo00070?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool2000002d0oooo00<000000?ooo`000000d`3o
ool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`000000d03oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
c03oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0<X0oooo000K0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0b03oool0
01/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`360?ooo`006`3oool2000003`0
oooo00<000000?ooo`3oool0a03oool001/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`320?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`80000000<0oooo0000003oool0_P3o
ool001/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`006`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0;T0oooo000K0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0]`3oool001/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`2e0?ooo`006`3oool2000004d0oooo00<000000?ooo`3oool0/`3oool001/0oooo00<00000
0?ooo`3oool0CP3oool2000000030?ooo`000000oooo0:l0oooo000K0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0[03oool001/0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0000002Z0?ooo`006`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:H0oooo
000K0?ooo`030000003oool0oooo05/0oooo0P00002U0?ooo`006`3oool2000005l0oooo00<00000
0?ooo`3oool0X@3oool001/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2O0?oo
o`006`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo09d0oooo000K0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0V`3oool001/0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`2I0?ooo`00203oool2000000@0oooo0P0000050?ooo`<000000`3oool0
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo09L0oooo00070?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo09D0oooo00070?ooo`040000003oool0oooo000000P0oooo1@0000030?ooo`800000K@3oool0
0`000000oooo0?ooo`2C0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0KP3oool400000900oooo00070?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo08`0oooo00080?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0000002:0?ooo`006`3oool00`000000oooo0?ooo`1i0?ooo`800000Q`3oool001/0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`230?ooo`006`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0840oooo000K0?ooo`800000P@3oool200000800oooo000K
0?ooo`030000003oool0oooo0880oooo0P0000000`3oool000000?ooo`1k0?ooo`006`3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo07P0oooo000K0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0MP3oool001/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`1d0?ooo`006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0780oooo000K
0?ooo`800000T03oool010000000oooo00000000001_0?ooo`006`3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo06/0oooo000K0?ooo`030000003oool0oooo09H0oooo00<000000?oo
o`000000J@3oool001/0oooo00<000000?ooo`3oool0V03oool00`000000oooo0000001W0?ooo`00
6`3oool00`000000oooo0?ooo`2L0?ooo`800000I03oool001/0oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`1P0?ooo`006`3oool00`000000oooo0?ooo`2Q0?ooo`040000003oool0
00000?ooo`800000F`3oool001/0oooo0P00002Y0?ooo`030000003oool0000005L0oooo000K0?oo
o`030000003oool0oooo0:`0oooo00H000000?ooo`00000000000?ooo`00001@0?ooo`006`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0000004h0oooo000K0?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`000000C03oool000P0oooo0P0000040?ooo`8000000`3oool3000000D0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`180?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`160?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo0P00002l0?ooo`030000003oool0oooo04@0oooo00070?ooo`040000003oool0oooo
000000P0oooo0`0000050?ooo`030000003oool0oooo0;d0oooo0P0000000`3oool000000?ooo`10
0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0`P3oool010000000oooo0000003oool2000003X0oooo00080?ooo`8000002P3oool3
000000@0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0f0?ooo`006`3oool00`00
0000oooo0?ooo`3;0?ooo`030000003oool0000003@0oooo000K0?ooo`030000003oool0oooo0<l0
oooo0P00000a0?ooo`006`3oool00`000000oooo0?ooo`3A0?ooo`800000;`3oool001/0oooo0P00
003E0?ooo`030000003oool0oooo02/0oooo000K0?ooo`030000003oool0oooo0=H0oooo00<00000
0?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0W0?oo
o`006`3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo02D0oooo000K0?ooo`030000
003oool0oooo0=`0oooo00<000000?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0gP3o
ool00`000000oooo0000000Q0?ooo`006`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0
oooo01d0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3T0?ooo`03
0000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0
6@3oool001/0oooo00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`0G0?ooo`006`3oool0
0`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo01D0oooo000K0?ooo`030000003oool0oooo
0>X0oooo00<000000?ooo`3oool05@3oool001/0oooo0P00003/0?ooo`030000003oool0oooo01@0
oooo000K0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0503oool001/0oooo00<0
00000?ooo`3oool0k03oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool04@3oool000P0
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0k`3oool00`000000
oooo0?ooo`0@0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`0?0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00003b0?ooo`030000003oool0
oooo00h0oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0?80oooo0P00000>0?ooo`00203oool2000000X0oooo0P000005
0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0m03oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`3f0?ooo`03
0000003oool0000000T0oooo000K0?ooo`030000003oool0oooo0?T0oooo00D000000?ooo`000000
oooo000000040?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool20000
0?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001<0oooo1@000003
0?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo0P00003o0?ooo`@0
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`00503oool200000?l0oooo2`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.268941, \
0.00778854, 0.00756128}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.103006 0.515028 [
[.125 .09051 -12 -9 ]
[.125 .09051 12 0 ]
[.25 .09051 -9 -9 ]
[.25 .09051 9 0 ]
[.375 .09051 -12 -9 ]
[.375 .09051 12 0 ]
[.5 .09051 -3 -9 ]
[.5 .09051 3 0 ]
[.625 .09051 -12 -9 ]
[.625 .09051 12 0 ]
[.75 .09051 -9 -9 ]
[.75 .09051 9 0 ]
[.875 .09051 -12 -9 ]
[.875 .09051 12 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .10301 m
.125 .10926 L
s
[(0.25)] .125 .09051 0 1 Mshowa
.25 .10301 m
.25 .10926 L
s
[(0.5)] .25 .09051 0 1 Mshowa
.375 .10301 m
.375 .10926 L
s
[(0.75)] .375 .09051 0 1 Mshowa
.5 .10301 m
.5 .10926 L
s
[(1)] .5 .09051 0 1 Mshowa
.625 .10301 m
.625 .10926 L
s
[(1.25)] .625 .09051 0 1 Mshowa
.75 .10301 m
.75 .10926 L
s
[(1.5)] .75 .09051 0 1 Mshowa
.875 .10301 m
.875 .10926 L
s
[(1.75)] .875 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(2)] 1 .09051 0 1 Mshowa
.125 Mabswid
.025 .10301 m
.025 .10676 L
s
.05 .10301 m
.05 .10676 L
s
.075 .10301 m
.075 .10676 L
s
.1 .10301 m
.1 .10676 L
s
.15 .10301 m
.15 .10676 L
s
.175 .10301 m
.175 .10676 L
s
.2 .10301 m
.2 .10676 L
s
.225 .10301 m
.225 .10676 L
s
.275 .10301 m
.275 .10676 L
s
.3 .10301 m
.3 .10676 L
s
.325 .10301 m
.325 .10676 L
s
.35 .10301 m
.35 .10676 L
s
.4 .10301 m
.4 .10676 L
s
.425 .10301 m
.425 .10676 L
s
.45 .10301 m
.45 .10676 L
s
.475 .10301 m
.475 .10676 L
s
.525 .10301 m
.525 .10676 L
s
.55 .10301 m
.55 .10676 L
s
.575 .10301 m
.575 .10676 L
s
.6 .10301 m
.6 .10676 L
s
.65 .10301 m
.65 .10676 L
s
.675 .10301 m
.675 .10676 L
s
.7 .10301 m
.7 .10676 L
s
.725 .10301 m
.725 .10676 L
s
.775 .10301 m
.775 .10676 L
s
.8 .10301 m
.8 .10676 L
s
.825 .10301 m
.825 .10676 L
s
.85 .10301 m
.85 .10676 L
s
.9 .10301 m
.9 .10676 L
s
.925 .10301 m
.925 .10676 L
s
.95 .10301 m
.95 .10676 L
s
.975 .10301 m
.975 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
0 .10301 m
.01 .10816 L
.02 .11331 L
.03 .11846 L
.04 .12361 L
.05 .12876 L
.06 .13391 L
.07 .13906 L
.08 .14421 L
.09 .14936 L
.1 .15451 L
.11 .15966 L
.12 .16481 L
.13 .16996 L
.14 .17511 L
.15 .18026 L
.16 .18541 L
.17 .19056 L
.18 .19571 L
.19 .20086 L
.2 .20601 L
.21 .21116 L
.22 .21631 L
.23 .22146 L
.24 .22661 L
.25 .23176 L
.26 .23691 L
.27 .24206 L
.28 .24721 L
.29 .25236 L
.3 .25751 L
.31 .26266 L
.32 .26781 L
.33 .27297 L
.34 .27812 L
.35 .28327 L
.36 .28842 L
.37 .29357 L
.38 .29872 L
.39 .30387 L
.4 .30902 L
.41 .31417 L
.42 .31932 L
.43 .32447 L
.44 .32962 L
.45 .33477 L
.46 .33992 L
.47 .34507 L
.48 .35022 L
.49 .35537 L
Mistroke
.5 .36052 L
.51 .36567 L
.52 .37082 L
.53 .37597 L
.54 .38112 L
.55 .38627 L
.56 .39142 L
.57 .39657 L
.58 .40172 L
.59 .40687 L
.6 .41202 L
.61 .41717 L
.62 .42232 L
.63 .42747 L
.64 .43262 L
.65 .43777 L
.66 .44292 L
.67 .44807 L
.68 .45322 L
.69 .45838 L
.7 .46353 L
.71 .46868 L
.72 .47383 L
.73 .47898 L
.74 .48413 L
.75 .48928 L
.76 .49443 L
.77 .49958 L
.78 .50473 L
.79 .50988 L
.8 .51503 L
.81 .52018 L
.82 .52533 L
.83 .53048 L
.84 .53563 L
.85 .54078 L
.86 .54593 L
.87 .55108 L
.88 .55623 L
.89 .56138 L
.9 .56653 L
.91 .57168 L
.92 .57683 L
.93 .58198 L
.94 .58713 L
.95 .59228 L
.96 .59743 L
.97 .60258 L
.98 .60773 L
.99 .61288 L
Mistroke
1 .61803 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo1@00000B0?ooo`D000000P3o
ool2000000<0oooo100000030?ooo`8000003P3oool500000080oooo0P0000040?ooo`8000003P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`@000000P3o
ool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003P3o
ool010000000oooo0?ooo`0000090?ooo`8000003P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0203oool20000
0100oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000001L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo0P00000D0?ooo`8000002P3oool2000000@0oooo0`00000>0?ooo`8000002P3o
ool3000000h0oooo0P0000090?ooo`@000000`3oool3000001@0oooo0P00000E0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`8000002P3oool3000000h0oooo0P0000090?ooo`@000000`3o
ool3000001D0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000003000000<0oooo000K0?ooo`<000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?oo
o`006`3oool00`000000oooo0?ooo`02000001/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?d0oooo
000K0?ooo`030000003oool0oooo00<0oooo0`00003l0?ooo`006`3oool00`000000oooo0?ooo`06
0?ooo`800000nP3oool001/0oooo00<000000?ooo`3oool0203oool200000?P0oooo000K0?ooo`80
00002`3oool00`000000oooo0?ooo`3e0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`<00000
m03oool001/0oooo00<000000?ooo`3oool03P3oool200000?80oooo000K0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0k`3oool001/0oooo00<000000?ooo`3oool04@3oool20000
0>l0oooo000K0?ooo`030000003oool0oooo01<0oooo0P00003]0?ooo`006`3oool2000001H0oooo
0P00003[0?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`800000j@3oool001/0oooo00<00000
0?ooo`3oool06@3oool200000>L0oooo000K0?ooo`030000003oool0oooo01/0oooo0P00003U0?oo
o`006`3oool00`000000oooo0?ooo`0M0?ooo`800000h`3oool001/0oooo00<000000?ooo`3oool0
7`3oool200000>40oooo000K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0gP3o
ool001/0oooo0P00000S0?ooo`<00000g@3oool001/0oooo00<000000?ooo`3oool09@3oool20000
0=/0oooo000K0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0f03oool001/0oooo
00<000000?ooo`3oool0:03oool200000=P0oooo000K0?ooo`030000003oool0oooo02X0oooo0`00
003E0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`0]
0?ooo`800000d`3oool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0d03oool000L0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000<@3oool200000=00oooo00070?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b
0?ooo`800000cP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo03@0oooo0P00003<0?ooo`00203oool2000000X0oooo0P000005
0?ooo`030000003oool0oooo03H0oooo0P00003:0?ooo`006`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0<L0oooo000K0?ooo`030000003oool0oooo03T0oooo0`0000360?ooo`00
6`3oool2000003d0oooo0P0000340?ooo`006`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0<40oooo000K0?ooo`030000003oool0oooo03l0oooo0P0000310?ooo`006`3oool00`00
0000oooo0?ooo`110?ooo`<00000_P3oool001/0oooo00<000000?ooo`3oool0A03oool200000;`0
oooo000K0?ooo`030000003oool0oooo04H0oooo0P00002j0?ooo`006`3oool00`000000oooo0?oo
o`180?ooo`800000^03oool001/0oooo0P00001;0?ooo`030000003oool0oooo0;D0oooo000K0?oo
o`030000003oool0oooo04/0oooo0`00002d0?ooo`006`3oool00`000000oooo0?ooo`1>0?ooo`80
0000/P3oool001/0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2_0?ooo`006`3o
ool00`000000oooo0?ooo`1A0?ooo`800000[`3oool001/0oooo00<000000?ooo`3oool0D`3oool3
00000:`0oooo000K0?ooo`800000E`3oool200000:X0oooo000K0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0Y`3oool001/0oooo00<000000?ooo`3oool0F@3oool200000:L0oooo
000K0?ooo`030000003oool0oooo05/0oooo0P00002U0?ooo`006`3oool00`000000oooo0?ooo`1M
0?ooo`800000X`3oool000P0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?oo
o`3oool0G`3oool200000:40oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo09h0oooo00070?ooo`04
0000003oool0oooo000000P0oooo1@0000030?ooo`800000H`3oool3000009d0oooo00070?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U
0?ooo`800000V`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo00000004
0?ooo`030000003oool0oooo06L0oooo0P00002I0?ooo`00203oool2000000/0oooo0P0000040?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0UP3oool001/0oooo00<000000?ooo`3o
ool0JP3oool3000009D0oooo000K0?ooo`030000003oool0oooo06d0oooo0P00002C0?ooo`006`3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0900oooo000K0?ooo`800000L@3oool2
00000900oooo000K0?ooo`030000003oool0oooo0780oooo0P00002>0?ooo`006`3oool00`000000
oooo0?ooo`1d0?ooo`800000S03oool001/0oooo00<000000?ooo`3oool0MP3oool2000008X0oooo
000K0?ooo`030000003oool0oooo07P0oooo0P0000280?ooo`006`3oool00`000000oooo0?ooo`1j
0?ooo`800000QP3oool001/0oooo0P00001m0?ooo`800000Q03oool001/0oooo00<000000?ooo`3o
ool0OP3oool200000880oooo000K0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
O`3oool001/0oooo00<000000?ooo`3oool0P@3oool3000007h0oooo000K0?ooo`030000003oool0
oooo08@0oooo0P00001l0?ooo`006`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
07T0oooo000K0?ooo`030000003oool0oooo08L0oooo0P00001i0?ooo`006`3oool2000008X0oooo
0`00001f0?ooo`006`3oool00`000000oooo0?ooo`2<0?ooo`800000M03oool001/0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`1a0?ooo`006`3oool00`000000oooo0?ooo`2?0?oo
o`800000L@3oool000P0oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3o
ool0T@3oool2000006l0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`2C0?ooo`<00000K03oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`800000U`3oool2000006X0oooo00070?oo
o`040000003oool0oooo000000P0oooo0`0000050?ooo`030000003oool0oooo09P0oooo00<00000
0?ooo`3oool0I`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo09T0oooo0P00001W0?ooo`00203oool2000000X0oooo0`0000040?oo
o`030000003oool0oooo09/0oooo0P00001U0?ooo`006`3oool00`000000oooo0?ooo`2M0?ooo`80
0000H`3oool001/0oooo00<000000?ooo`3oool0W`3oool200000640oooo000K0?ooo`030000003o
ool0oooo0:40oooo0P00001O0?ooo`006`3oool200000:@0oooo0P00001M0?ooo`006`3oool00`00
0000oooo0?ooo`2U0?ooo`800000F`3oool001/0oooo00<000000?ooo`3oool0Y`3oool2000005T0
oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0EP3oool001/0oooo00<0
00000?ooo`3oool0ZP3oool3000005D0oooo000K0?ooo`030000003oool0oooo0:d0oooo0P00001C
0?ooo`006`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0500oooo000K0?ooo`80
0000/@3oool200000500oooo000K0?ooo`030000003oool0oooo0;80oooo0`00001=0?ooo`006`3o
ool00`000000oooo0?ooo`2e0?ooo`800000B`3oool001/0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`180?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`800000B03oool001/0
oooo00<000000?ooo`3oool0^P3oool2000004H0oooo000K0?ooo`800000_@3oool2000004@0oooo
000K0?ooo`030000003oool0oooo0;h0oooo0P0000120?ooo`006`3oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo03l0oooo000K0?ooo`030000003oool0oooo0<40oooo0`00000n0?oo
o`006`3oool00`000000oooo0?ooo`340?ooo`800000?03oool000P0oooo0P0000040?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0aP3oool2000003X0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`380?ooo`03
0000003oool0oooo03L0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool200000<X0oooo0`00000f0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`8000001@3oool00`000000oooo0?ooo`3<0?ooo`800000=03oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool0<@3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3?0?oo
o`800000<@3oool001/0oooo00<000000?ooo`3oool0d@3oool2000002l0oooo000K0?ooo`030000
003oool0oooo0=<0oooo0P00000]0?ooo`006`3oool00`000000oooo0?ooo`3E0?ooo`800000:`3o
ool001/0oooo0P00003H0?ooo`800000:@3oool001/0oooo00<000000?ooo`3oool0f@3oool20000
02L0oooo000K0?ooo`030000003oool0oooo0=/0oooo0P00000U0?ooo`006`3oool00`000000oooo
0?ooo`3M0?ooo`8000008`3oool001/0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?oo
o`0P0?ooo`006`3oool00`000000oooo0?ooo`3P0?ooo`<000007`3oool001/0oooo0P00003T0?oo
o`8000007@3oool001/0oooo00<000000?ooo`3oool0i@3oool2000001/0oooo000K0?ooo`030000
003oool0oooo0>L0oooo0P00000I0?ooo`006`3oool00`000000oooo0?ooo`3Y0?ooo`8000005`3o
ool001/0oooo00<000000?ooo`3oool0j`3oool2000001D0oooo000K0?ooo`030000003oool0oooo
0>d0oooo0P00000C0?ooo`006`3oool00`000000oooo0?ooo`3_0?ooo`8000004@3oool001/0oooo
0P00003b0?ooo`030000003oool0oooo00h0oooo000K0?ooo`030000003oool0oooo0?80oooo0`00
000=0?ooo`006`3oool00`000000oooo0?ooo`3e0?ooo`8000002`3oool001/0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`080?ooo`004`3oool5000000<0oooo00<000000?ooo`3o
ool0n03oool2000000P0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
nP3oool3000000D0oooo000E0?ooo`030000003oool0oooo00<0oooo0P00003n0?ooo`8000000`3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000D0?ooo`800000o`3oool;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.268941, \
0.00778854, 0.00756128}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.103006 0.515028 [
[.125 .09051 -12 -9 ]
[.125 .09051 12 0 ]
[.25 .09051 -9 -9 ]
[.25 .09051 9 0 ]
[.375 .09051 -12 -9 ]
[.375 .09051 12 0 ]
[.5 .09051 -3 -9 ]
[.5 .09051 3 0 ]
[.625 .09051 -12 -9 ]
[.625 .09051 12 0 ]
[.75 .09051 -9 -9 ]
[.75 .09051 9 0 ]
[.875 .09051 -12 -9 ]
[.875 .09051 12 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .10301 m
.125 .10926 L
s
[(0.25)] .125 .09051 0 1 Mshowa
.25 .10301 m
.25 .10926 L
s
[(0.5)] .25 .09051 0 1 Mshowa
.375 .10301 m
.375 .10926 L
s
[(0.75)] .375 .09051 0 1 Mshowa
.5 .10301 m
.5 .10926 L
s
[(1)] .5 .09051 0 1 Mshowa
.625 .10301 m
.625 .10926 L
s
[(1.25)] .625 .09051 0 1 Mshowa
.75 .10301 m
.75 .10926 L
s
[(1.5)] .75 .09051 0 1 Mshowa
.875 .10301 m
.875 .10926 L
s
[(1.75)] .875 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(2)] 1 .09051 0 1 Mshowa
.125 Mabswid
.025 .10301 m
.025 .10676 L
s
.05 .10301 m
.05 .10676 L
s
.075 .10301 m
.075 .10676 L
s
.1 .10301 m
.1 .10676 L
s
.15 .10301 m
.15 .10676 L
s
.175 .10301 m
.175 .10676 L
s
.2 .10301 m
.2 .10676 L
s
.225 .10301 m
.225 .10676 L
s
.275 .10301 m
.275 .10676 L
s
.3 .10301 m
.3 .10676 L
s
.325 .10301 m
.325 .10676 L
s
.35 .10301 m
.35 .10676 L
s
.4 .10301 m
.4 .10676 L
s
.425 .10301 m
.425 .10676 L
s
.45 .10301 m
.45 .10676 L
s
.475 .10301 m
.475 .10676 L
s
.525 .10301 m
.525 .10676 L
s
.55 .10301 m
.55 .10676 L
s
.575 .10301 m
.575 .10676 L
s
.6 .10301 m
.6 .10676 L
s
.65 .10301 m
.65 .10676 L
s
.675 .10301 m
.675 .10676 L
s
.7 .10301 m
.7 .10676 L
s
.725 .10301 m
.725 .10676 L
s
.775 .10301 m
.775 .10676 L
s
.8 .10301 m
.8 .10676 L
s
.825 .10301 m
.825 .10676 L
s
.85 .10301 m
.85 .10676 L
s
.9 .10301 m
.9 .10676 L
s
.925 .10301 m
.925 .10676 L
s
.95 .10301 m
.95 .10676 L
s
.975 .10301 m
.975 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .07609 m
.01 .0985 L
.02 .10217 L
.03 .10679 L
.04 .11313 L
.05 .11869 L
.06 .12349 L
.07 .12781 L
.08 .13347 L
.09 .1347 L
.1 .13808 L
.11 .14153 L
.12 .14353 L
.13 .15033 L
.14 .15406 L
.15 .15687 L
.16 .16015 L
.17 .16326 L
.18 .16756 L
.19 .17142 L
.2 .17631 L
.21 .18285 L
.22 .18525 L
.23 .18618 L
.24 .19039 L
.25 .19573 L
.26 .19704 L
.27 .19947 L
.28 .20295 L
.29 .20499 L
.3 .20991 L
.31 .21112 L
.32 .21987 L
.33 .22136 L
.34 .22203 L
.35 .2265 L
.36 .2265 L
.37 .23235 L
.38 .23666 L
.39 .2401 L
.4 .24355 L
.41 .24928 L
.42 .25155 L
.43 .25479 L
.44 .25805 L
.45 .26029 L
.46 .26605 L
.47 .26869 L
.48 .26951 L
.49 .27453 L
Mistroke
.5 .27782 L
.51 .27982 L
.52 .28463 L
.53 .28845 L
.54 .29207 L
.55 .29363 L
.56 .29992 L
.57 .30025 L
.58 .30157 L
.59 .30388 L
.6 .3081 L
.61 .31089 L
.62 .31195 L
.63 .31875 L
.64 .32159 L
.65 .32432 L
.66 .33095 L
.67 .33722 L
.68 .33789 L
.69 .33722 L
.7 .34095 L
.71 .34437 L
.72 .34499 L
.73 .34612 L
.74 .3482 L
.75 .34947 L
.76 .35332 L
.77 .35422 L
.78 .35458 L
.79 .35485 L
.8 .359 L
.81 .35929 L
.82 .36108 L
.83 .3673 L
.84 .3673 L
.85 .36999 L
.86 .37171 L
.87 .37164 L
.88 .37171 L
.89 .3718 L
.9 .37552 L
.91 .37552 L
.92 .37552 L
.93 .37369 L
.94 .37369 L
.95 .38331 L
.96 .37864 L
.97 .37705 L
.98 .37369 L
.99 .37369 L
Mistroke
1 .37369 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo1@00000B0?ooo`D000000P3o
ool2000000<0oooo100000030?ooo`8000003P3oool500000080oooo0P0000040?ooo`8000003P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`@000000P3o
ool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003P3o
ool010000000oooo0?ooo`0000090?ooo`8000003P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0203oool20000
0100oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000001L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo0P00000D0?ooo`8000002P3oool2000000@0oooo0`00000>0?ooo`8000002P3o
ool3000000h0oooo0P0000090?ooo`@000000`3oool3000001@0oooo0P00000E0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`8000002P3oool3000000h0oooo0P0000090?ooo`@000000`3o
ool3000001D0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`000000o`3oool30?ooo`00
6`3oool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`030000003oool000000?l0oooo0`3o
ool001/0ooooo`000003000000<0oooo000K0?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?oo
o`006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool01`3oool200000?T0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool02`3oool200000?D0oooo000K0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0lP3oool001/0oooo0P00000A0?ooo`03
0000003oool0oooo0>l0oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
kP3oool001/0oooo00<000000?ooo`3oool05@3oool200000>/0oooo000K0?ooo`030000003oool0
oooo01X0oooo0P00003V0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0h@3oool001/0oooo0P00000P0?ooo`800000
h@3oool001/0oooo00<000000?ooo`3oool08`3oool200000=d0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0:03oool200000=P0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0;@3oool200000=<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00000b0?ooo`030000003oool0
oooo0<h0oooo000K0?ooo`030000003oool0oooo0380oooo0P0000020?ooo`<00000b@3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0<@0oooo000K0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0oooo
000000310?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0;h0oooo00070?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`800000^`3oool000L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`001`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0BP3o
ool200000;H0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`8000002P3oool2000000D0oooo00<0
00000?ooo`3oool0CP3oool200000;80oooo000K0?ooo`030000003oool0oooo05<0oooo0P00002]
0?ooo`006`3oool00`000000oooo0?ooo`1H0?ooo`800000Z03oool001/0oooo0P00003o0?ooo`@0
oooo000K0?ooo`030000003oool0oooo05d0oooo0P00002S0?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0640oooo0`00002N0?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo06H0oooo0P00002J0?ooo`00
6`3oool00`000000oooo0?ooo`1[0?ooo`800000U@3oool001/0oooo0P00001a0?ooo`030000003o
ool0oooo08l0oooo000K0?ooo`030000003oool0oooo0700oooo0P00002@0?ooo`006`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo08X0oooo000K0?ooo`030000003oool0oooo07D0
oooo0P00002;0?ooo`006`3oool00`000000oooo0?ooo`1i0?ooo`<00000QP3oool001/0oooo00<0
00000?ooo`3oool0OP3oool200000880oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`220?ooo`<00000O@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`270?ooo`800000N@3oool001/0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`1c0?ooo`00203oool2000000@0oooo0P0000050?ooo`<000000`3oool0
0`000000oooo0?ooo`2=0?ooo`040000003oool0oooo0?ooo`800000K`3oool000L0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0J@3oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00
002H0?ooo`030000003oool0oooo06P0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`2K0?ooo`800000I@3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo
0`3oool000P0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`2O0?ooo`<00000H03o
ool001/0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1K0?ooo`006`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo05X0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo0P00002Z0?ooo`8000000`3oool00`000000oooo0?ooo`1A0?ooo`006`3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0500oooo000K0?ooo`030000003oool0
oooo0;80oooo0`00001=0?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`8000000`3oool00`00
0000oooo0?ooo`120?ooo`006`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0440
oooo000K0?ooo`030000003oool0oooo0<80oooo0P0000030?ooo`800000>@3oool001/0oooo0P00
003=0?ooo`800000=03oool001/0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0_
0?ooo`006`3oool00`000000oooo0?ooo`3A0?ooo`8000000P3oool00`000000oooo0?ooo`0Z0?oo
o`006`3oool00`000000oooo0?ooo`3F0?ooo`8000000P3oool300000080oooo0`00000P0?ooo`00
6`3oool00`000000oooo0?ooo`3T0?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool0
1P3oool2000000P0oooo000K0?ooo`030000003oool0oooo0>l0oooo00@000000?ooo`3oool0oooo
0P00000=0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool4
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000@0oooo0P00
00030?ooo`<000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool200000?l0
oooo103oool000L0oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000X0oooo0`0000040?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo0P00003o0?ooo`@0oooo00070?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool000P0oooo
0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`004`3o
ool5000000<0oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool20000
0?l0oooo103oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000D0?ooo`800000o`3oool;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.268941, \
0.00778854, 0.00756128}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.103006 0.515028 [
[.125 .09051 -12 -9 ]
[.125 .09051 12 0 ]
[.25 .09051 -9 -9 ]
[.25 .09051 9 0 ]
[.375 .09051 -12 -9 ]
[.375 .09051 12 0 ]
[.5 .09051 -3 -9 ]
[.5 .09051 3 0 ]
[.625 .09051 -12 -9 ]
[.625 .09051 12 0 ]
[.75 .09051 -9 -9 ]
[.75 .09051 9 0 ]
[.875 .09051 -12 -9 ]
[.875 .09051 12 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .10301 m
.125 .10926 L
s
[(0.25)] .125 .09051 0 1 Mshowa
.25 .10301 m
.25 .10926 L
s
[(0.5)] .25 .09051 0 1 Mshowa
.375 .10301 m
.375 .10926 L
s
[(0.75)] .375 .09051 0 1 Mshowa
.5 .10301 m
.5 .10926 L
s
[(1)] .5 .09051 0 1 Mshowa
.625 .10301 m
.625 .10926 L
s
[(1.25)] .625 .09051 0 1 Mshowa
.75 .10301 m
.75 .10926 L
s
[(1.5)] .75 .09051 0 1 Mshowa
.875 .10301 m
.875 .10926 L
s
[(1.75)] .875 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(2)] 1 .09051 0 1 Mshowa
.125 Mabswid
.025 .10301 m
.025 .10676 L
s
.05 .10301 m
.05 .10676 L
s
.075 .10301 m
.075 .10676 L
s
.1 .10301 m
.1 .10676 L
s
.15 .10301 m
.15 .10676 L
s
.175 .10301 m
.175 .10676 L
s
.2 .10301 m
.2 .10676 L
s
.225 .10301 m
.225 .10676 L
s
.275 .10301 m
.275 .10676 L
s
.3 .10301 m
.3 .10676 L
s
.325 .10301 m
.325 .10676 L
s
.35 .10301 m
.35 .10676 L
s
.4 .10301 m
.4 .10676 L
s
.425 .10301 m
.425 .10676 L
s
.45 .10301 m
.45 .10676 L
s
.475 .10301 m
.475 .10676 L
s
.525 .10301 m
.525 .10676 L
s
.55 .10301 m
.55 .10676 L
s
.575 .10301 m
.575 .10676 L
s
.6 .10301 m
.6 .10676 L
s
.65 .10301 m
.65 .10676 L
s
.675 .10301 m
.675 .10676 L
s
.7 .10301 m
.7 .10676 L
s
.725 .10301 m
.725 .10676 L
s
.775 .10301 m
.775 .10676 L
s
.8 .10301 m
.8 .10676 L
s
.825 .10301 m
.825 .10676 L
s
.85 .10301 m
.85 .10676 L
s
.9 .10301 m
.9 .10676 L
s
.925 .10301 m
.925 .10676 L
s
.95 .10301 m
.95 .10676 L
s
.975 .10301 m
.975 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .10301 m
.01 .1215 L
.02 .13923 L
.03 .15312 L
.04 .15941 L
.05 .16419 L
.06 .1744 L
.07 .17658 L
.08 .18302 L
.09 .18719 L
.1 .1935 L
.11 .20176 L
.12 .20579 L
.13 .21218 L
.14 .22037 L
.15 .2259 L
.16 .2305 L
.17 .23604 L
.18 .23977 L
.19 .24295 L
.2 .25001 L
.21 .25344 L
.22 .2584 L
.23 .2634 L
.24 .26794 L
.25 .27711 L
.26 .27951 L
.27 .28273 L
.28 .29064 L
.29 .30017 L
.3 .30513 L
.31 .30717 L
.32 .3087 L
.33 .31014 L
.34 .31392 L
.35 .33093 L
.36 .33273 L
.37 .33917 L
.38 .34112 L
.39 .34458 L
.4 .34802 L
.41 .3517 L
.42 .35748 L
.43 .35943 L
.44 .36517 L
.45 .36656 L
.46 .37605 L
.47 .37733 L
.48 .37743 L
.49 .37911 L
Mistroke
.5 .38223 L
.51 .38996 L
.52 .39126 L
.53 .39818 L
.54 .40616 L
.55 .40739 L
.56 .40866 L
.57 .41246 L
.58 .41515 L
.59 .41773 L
.6 .42032 L
.61 .4254 L
.62 .42982 L
.63 .43254 L
.64 .4344 L
.65 .43477 L
.66 .43966 L
.67 .44202 L
.68 .44868 L
.69 .45539 L
.7 .4569 L
.71 .46208 L
.72 .46942 L
.73 .47555 L
.74 .49306 L
.75 .53658 L
.76 .54866 L
.77 .55568 L
.78 .55842 L
.79 .56136 L
.8 .5639 L
.81 .57088 L
.82 .57195 L
.83 .57772 L
.84 .57811 L
.85 .57881 L
.86 .57943 L
.87 .57943 L
.88 .58192 L
.89 .58307 L
.9 .58374 L
.91 .58431 L
.92 .58438 L
.93 .58438 L
.94 .58438 L
.95 .58438 L
.96 .58438 L
.97 .58677 L
.98 .5869 L
.99 .5869 L
Mistroke
1 .58798 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo1@00000B0?ooo`D000000P3o
ool2000000<0oooo100000030?ooo`8000003P3oool500000080oooo0P0000040?ooo`8000003P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`@000000P3o
ool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003P3o
ool010000000oooo0?ooo`0000090?ooo`8000003P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0203oool20000
0100oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000001L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo0P00000D0?ooo`8000002P3oool2000000@0oooo0`00000>0?ooo`8000002P3o
ool3000000h0oooo0P0000090?ooo`@000000`3oool3000001@0oooo0P00000E0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`8000002P3oool3000000h0oooo0P0000090?ooo`@000000`3o
ool3000001D0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0ooooo`000003000000<0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`000000o`3oool30?ooo`006`3oool00`000000oooo0000003o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`050000
003oool0oooo0?ooo`000000o`3oool10?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?d0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?/0oooo000K0?ooo`8000001@3oool200000?`0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3g0?ooo`006`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?H0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3c0?ooo`00
6`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?80oooo000K0?ooo`8000004P3o
ool00`000000oooo0?ooo`3^0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`800000k`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`80
0000j`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000@0oooo0P00
00030?ooo`@00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`<00000iP3o
ool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3o
ool40?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3Q0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`3P0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3M0?ooo`006`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0=`0oooo000K0?ooo`800000:03oool00`000000
oooo0?ooo`3H0?ooo`006`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0=L0oooo
000K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0e03oool001/0oooo00<00000
0?ooo`3oool0;03oool200000=@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0<03oool200000=00oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo0P00000f0?ooo`800000b`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`800000a`3oool001/0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`350?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo03d0oooo0`0000320?ooo`006`3oool2000004<0oooo00<00000
0?ooo`3oool0_@3oool001/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2l0?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2i0?ooo`00203oool2
000000@0oooo0P0000050?ooo`<000000`3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0;P0oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1;0?ooo`800000]@3oool000L0oooo00@000000?ooo`3oool00000203oool5
000000<0oooo0P00001A0?ooo`800000/03oool000L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0Z`3oool000P0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0:X0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`1G0?ooo`800000
Z@3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo05`0oooo0P00002T
0?ooo`006`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo09h0oooo000K0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0W@3oool001/0oooo00<000000?ooo`3oool0
IP3oool2000009X0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00001[
0?ooo`800000UP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`1_0?ooo`800000T@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`1c0?ooo`800000S@3oool001/0oooo00<000000?ooo`3oool0N03oool2
000008P0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0P@3oool001/0
oooo0P0000200?ooo`030000003oool0oooo0800oooo000K0?ooo`030000003oool0oooo0880oooo
00<000000?ooo`3oool0O@3oool001/0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`1l0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`800000103oool20000
00<0oooo0`0000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0N@3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo08L0oooo00D000000?ooo`3oool0oooo0000001f0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo0P00002=0?ooo`800000M03oool000L0oooo00@0
00000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool0T03oool200000700oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo06X0oooo00080?ooo`8000002P3oool3000000@0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`1Y0?ooo`006`3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo06D0oooo000K0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0I03oool001/0oooo00<000000?ooo`3oool0W`3oool2000000<0oooo00<000000?ooo`3o
ool0F`3oool001/0oooo0P00002V0?ooo`030000003oool0oooo05X0oooo000K0?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool0EP3oool001/0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`1E0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool0DP3oool001/0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`1A0?ooo`006`3oool00`000000oooo0?ooo`2b0?ooo`800000CP3o
ool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool0B@3oool001/0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`180?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`160?ooo`006`3oool20000
0;/0oooo00<000000?ooo`3oool0A@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`140?ooo`00203oool20000
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo
04<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000103oool200000?l0oooo103oool000L0oooo00@000000?ooo`3oool000002@3o
ool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0_03oool00`000000oooo
0?ooo`130?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0;d0oooo00<0
00000?ooo`3oool0@P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0@@3oool001/0oooo0P0000300?ooo`030000003oool0oooo0400oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo03d0oooo000K0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0?03oool001/0oooo00<000000?ooo`3oool0a`3oool2000003T0oooo
000K0?ooo`800000c03oool00`000000oooo0?ooo`0d0?ooo`006`3oool00`000000oooo0?ooo`3<
0?ooo`030000003oool0oooo03<0oooo000K0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool0;`3oool001/0oooo00<000000?ooo`3oool0d@3oool010000000oooo0?ooo`3oool20000
00<0oooo0P00000V0?ooo`006`3oool00`000000oooo0?ooo`3O0?ooo`8000008@3oool001/0oooo
00<000000?ooo`3oool0i03oool2000000<0oooo0`0000020?ooo`<000000`3oool2000000<0oooo
0P0000070?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool4
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`004`3oool5000000<0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool200000?l0oooo103oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000D0?ooo`800000o`3oool;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.268941, \
0.00778854, 0.00756128}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0.103006 0.515028 [
[.125 .09051 -12 -9 ]
[.125 .09051 12 0 ]
[.25 .09051 -9 -9 ]
[.25 .09051 9 0 ]
[.375 .09051 -12 -9 ]
[.375 .09051 12 0 ]
[.5 .09051 -3 -9 ]
[.5 .09051 3 0 ]
[.625 .09051 -12 -9 ]
[.625 .09051 12 0 ]
[.75 .09051 -9 -9 ]
[.75 .09051 9 0 ]
[.875 .09051 -12 -9 ]
[.875 .09051 12 0 ]
[1 .09051 -3 -9 ]
[1 .09051 3 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 .10301 m
.125 .10926 L
s
[(0.25)] .125 .09051 0 1 Mshowa
.25 .10301 m
.25 .10926 L
s
[(0.5)] .25 .09051 0 1 Mshowa
.375 .10301 m
.375 .10926 L
s
[(0.75)] .375 .09051 0 1 Mshowa
.5 .10301 m
.5 .10926 L
s
[(1)] .5 .09051 0 1 Mshowa
.625 .10301 m
.625 .10926 L
s
[(1.25)] .625 .09051 0 1 Mshowa
.75 .10301 m
.75 .10926 L
s
[(1.5)] .75 .09051 0 1 Mshowa
.875 .10301 m
.875 .10926 L
s
[(1.75)] .875 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(2)] 1 .09051 0 1 Mshowa
.125 Mabswid
.025 .10301 m
.025 .10676 L
s
.05 .10301 m
.05 .10676 L
s
.075 .10301 m
.075 .10676 L
s
.1 .10301 m
.1 .10676 L
s
.15 .10301 m
.15 .10676 L
s
.175 .10301 m
.175 .10676 L
s
.2 .10301 m
.2 .10676 L
s
.225 .10301 m
.225 .10676 L
s
.275 .10301 m
.275 .10676 L
s
.3 .10301 m
.3 .10676 L
s
.325 .10301 m
.325 .10676 L
s
.35 .10301 m
.35 .10676 L
s
.4 .10301 m
.4 .10676 L
s
.425 .10301 m
.425 .10676 L
s
.45 .10301 m
.45 .10676 L
s
.475 .10301 m
.475 .10676 L
s
.525 .10301 m
.525 .10676 L
s
.55 .10301 m
.55 .10676 L
s
.575 .10301 m
.575 .10676 L
s
.6 .10301 m
.6 .10676 L
s
.65 .10301 m
.65 .10676 L
s
.675 .10301 m
.675 .10676 L
s
.7 .10301 m
.7 .10676 L
s
.725 .10301 m
.725 .10676 L
s
.775 .10301 m
.775 .10676 L
s
.8 .10301 m
.8 .10676 L
s
.825 .10301 m
.825 .10676 L
s
.85 .10301 m
.85 .10676 L
s
.9 .10301 m
.9 .10676 L
s
.925 .10301 m
.925 .10676 L
s
.95 .10301 m
.95 .10676 L
s
.975 .10301 m
.975 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.4)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.8)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .10301 m
.01 .10892 L
.02 .11477 L
.03 .12459 L
.04 .13418 L
.05 .14091 L
.06 .14682 L
.07 .15067 L
.08 .15589 L
.09 .16133 L
.1 .16421 L
.11 .17022 L
.12 .1741 L
.13 .17966 L
.14 .18606 L
.15 .19043 L
.16 .19484 L
.17 .19996 L
.18 .20392 L
.19 .20793 L
.2 .21205 L
.21 .21594 L
.22 .21952 L
.23 .22474 L
.24 .22926 L
.25 .23455 L
.26 .23726 L
.27 .24072 L
.28 .246 L
.29 .24895 L
.3 .25479 L
.31 .25738 L
.32 .26097 L
.33 .26427 L
.34 .26862 L
.35 .27063 L
.36 .2744 L
.37 .27775 L
.38 .28199 L
.39 .28635 L
.4 .29327 L
.41 .29913 L
.42 .30283 L
.43 .30717 L
.44 .31071 L
.45 .31276 L
.46 .3179 L
.47 .32048 L
.48 .32211 L
.49 .32368 L
Mistroke
.5 .33027 L
.51 .33366 L
.52 .33789 L
.53 .34057 L
.54 .34538 L
.55 .34956 L
.56 .3535 L
.57 .35825 L
.58 .36091 L
.59 .36334 L
.6 .36678 L
.61 .37126 L
.62 .37508 L
.63 .37772 L
.64 .38129 L
.65 .38307 L
.66 .38464 L
.67 .38629 L
.68 .38817 L
.69 .39039 L
.7 .39177 L
.71 .39694 L
.72 .3997 L
.73 .40524 L
.74 .4095 L
.75 .41168 L
.76 .415 L
.77 .41754 L
.78 .41849 L
.79 .42006 L
.8 .42335 L
.81 .42594 L
.82 .42803 L
.83 .43385 L
.84 .4372 L
.85 .4436 L
.86 .44861 L
.87 .45113 L
.88 .45632 L
.89 .4588 L
.9 .46637 L
.91 .472 L
.92 .47755 L
.93 .49539 L
.94 .50275 L
.95 .51564 L
.96 .52564 L
.97 .53263 L
.98 .53658 L
.99 .53677 L
Mistroke
1 .53847 L
Mfstroke
.003 w
[ ] 0 setdash
0 .10301 m
.01 .10816 L
.02 .11331 L
.03 .11846 L
.04 .12361 L
.05 .12876 L
.06 .13391 L
.07 .13906 L
.08 .14421 L
.09 .14936 L
.1 .15451 L
.11 .15966 L
.12 .16481 L
.13 .16996 L
.14 .17511 L
.15 .18026 L
.16 .18541 L
.17 .19056 L
.18 .19571 L
.19 .20086 L
.2 .20601 L
.21 .21116 L
.22 .21631 L
.23 .22146 L
.24 .22661 L
.25 .23176 L
.26 .23691 L
.27 .24206 L
.28 .24721 L
.29 .25236 L
.3 .25751 L
.31 .26266 L
.32 .26781 L
.33 .27297 L
.34 .27812 L
.35 .28327 L
.36 .28842 L
.37 .29357 L
.38 .29872 L
.39 .30387 L
.4 .30902 L
.41 .31417 L
.42 .31932 L
.43 .32447 L
.44 .32962 L
.45 .33477 L
.46 .33992 L
.47 .34507 L
.48 .35022 L
.49 .35537 L
Mistroke
.5 .36052 L
.51 .36567 L
.52 .37082 L
.53 .37597 L
.54 .38112 L
.55 .38627 L
.56 .39142 L
.57 .39657 L
.58 .40172 L
.59 .40687 L
.6 .41202 L
.61 .41717 L
.62 .42232 L
.63 .42747 L
.64 .43262 L
.65 .43777 L
.66 .44292 L
.67 .44807 L
.68 .45322 L
.69 .45838 L
.7 .46353 L
.71 .46868 L
.72 .47383 L
.73 .47898 L
.74 .48413 L
.75 .48928 L
.76 .49443 L
.77 .49958 L
.78 .50473 L
.79 .50988 L
.8 .51503 L
.81 .52018 L
.82 .52533 L
.83 .53048 L
.84 .53563 L
.85 .54078 L
.86 .54593 L
.87 .55108 L
.88 .55623 L
.89 .56138 L
.9 .56653 L
.91 .57168 L
.92 .57683 L
.93 .58198 L
.94 .58713 L
.95 .59228 L
.96 .59743 L
.97 .60258 L
.98 .60773 L
.99 .61288 L
Mistroke
1 .61803 L
Mfstroke
.001 w
[ .005 .015 ] 0 setdash
0 .07609 m
.01 .0985 L
.02 .10217 L
.03 .10679 L
.04 .11313 L
.05 .11869 L
.06 .12349 L
.07 .12781 L
.08 .13347 L
.09 .1347 L
.1 .13808 L
.11 .14153 L
.12 .14353 L
.13 .15033 L
.14 .15406 L
.15 .15687 L
.16 .16015 L
.17 .16326 L
.18 .16756 L
.19 .17142 L
.2 .17631 L
.21 .18285 L
.22 .18525 L
.23 .18618 L
.24 .19039 L
.25 .19573 L
.26 .19704 L
.27 .19947 L
.28 .20295 L
.29 .20499 L
.3 .20991 L
.31 .21112 L
.32 .21987 L
.33 .22136 L
.34 .22203 L
.35 .2265 L
.36 .2265 L
.37 .23235 L
.38 .23666 L
.39 .2401 L
.4 .24355 L
.41 .24928 L
.42 .25155 L
.43 .25479 L
.44 .25805 L
.45 .26029 L
.46 .26605 L
.47 .26869 L
.48 .26951 L
.49 .27453 L
Mistroke
.5 .27782 L
.51 .27982 L
.52 .28463 L
.53 .28845 L
.54 .29207 L
.55 .29363 L
.56 .29992 L
.57 .30025 L
.58 .30157 L
.59 .30388 L
.6 .3081 L
.61 .31089 L
.62 .31195 L
.63 .31875 L
.64 .32159 L
.65 .32432 L
.66 .33095 L
.67 .33722 L
.68 .33789 L
.69 .33722 L
.7 .34095 L
.71 .34437 L
.72 .34499 L
.73 .34612 L
.74 .3482 L
.75 .34947 L
.76 .35332 L
.77 .35422 L
.78 .35458 L
.79 .35485 L
.8 .359 L
.81 .35929 L
.82 .36108 L
.83 .3673 L
.84 .3673 L
.85 .36999 L
.86 .37171 L
.87 .37164 L
.88 .37171 L
.89 .3718 L
.9 .37552 L
.91 .37552 L
.92 .37552 L
.93 .37369 L
.94 .37369 L
.95 .38331 L
.96 .37864 L
.97 .37705 L
.98 .37369 L
.99 .37369 L
Mistroke
1 .37369 L
Mfstroke
0 .10301 m
.01 .1215 L
.02 .13923 L
.03 .15312 L
.04 .15941 L
.05 .16419 L
.06 .1744 L
.07 .17658 L
.08 .18302 L
.09 .18719 L
.1 .1935 L
.11 .20176 L
.12 .20579 L
.13 .21218 L
.14 .22037 L
.15 .2259 L
.16 .2305 L
.17 .23604 L
.18 .23977 L
.19 .24295 L
.2 .25001 L
.21 .25344 L
.22 .2584 L
.23 .2634 L
.24 .26794 L
.25 .27711 L
.26 .27951 L
.27 .28273 L
.28 .29064 L
.29 .30017 L
.3 .30513 L
.31 .30717 L
.32 .3087 L
.33 .31014 L
.34 .31392 L
.35 .33093 L
.36 .33273 L
.37 .33917 L
.38 .34112 L
.39 .34458 L
.4 .34802 L
.41 .3517 L
.42 .35748 L
.43 .35943 L
.44 .36517 L
.45 .36656 L
.46 .37605 L
.47 .37733 L
.48 .37743 L
.49 .37911 L
Mistroke
.5 .38223 L
.51 .38996 L
.52 .39126 L
.53 .39818 L
.54 .40616 L
.55 .40739 L
.56 .40866 L
.57 .41246 L
.58 .41515 L
.59 .41773 L
.6 .42032 L
.61 .4254 L
.62 .42982 L
.63 .43254 L
.64 .4344 L
.65 .43477 L
.66 .43966 L
.67 .44202 L
.68 .44868 L
.69 .45539 L
.7 .4569 L
.71 .46208 L
.72 .46942 L
.73 .47555 L
.74 .49306 L
.75 .53658 L
.76 .54866 L
.77 .55568 L
.78 .55842 L
.79 .56136 L
.8 .5639 L
.81 .57088 L
.82 .57195 L
.83 .57772 L
.84 .57811 L
.85 .57881 L
.86 .57943 L
.87 .57943 L
.88 .58192 L
.89 .58307 L
.9 .58374 L
.91 .58431 L
.92 .58438 L
.93 .58438 L
.94 .58438 L
.95 .58438 L
.96 .58438 L
.97 .58677 L
.98 .5869 L
.99 .5869 L
Mistroke
1 .58798 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000o`3oool:0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo2`3oool000L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000o`3oool40?ooo`00
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`8000000`3o
ool4000000<0oooo0P00000?0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo1@00000B0?ooo`D000000P3o
ool2000000<0oooo100000030?ooo`8000003P3oool500000080oooo0P0000040?ooo`8000003P3o
ool500000080oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`@000000P3o
ool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo000K0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000003P3o
ool010000000oooo0?ooo`0000090?ooo`8000003P3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0203oool20000
0100oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3oool2000001L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo0P00000D0?ooo`8000002P3oool2000000@0oooo0`00000>0?ooo`8000002P3o
ool3000000h0oooo0P0000090?ooo`@000000`3oool3000001@0oooo0P00000E0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`8000002P3oool3000000h0oooo0P0000090?ooo`@000000`3o
ool3000001D0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`000000o`3oool30?ooo`00
6`3oool00`000000oooo0000003o0?ooo`<0oooo000K0?ooo`030000003oool000000?l0oooo0`3o
ool001/0ooooo`000003000000<0oooo000K0?ooo`<000000`3oool2000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo008000006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool200000?T0oooo
000K0?ooo`030000003oool000000080oooo1000003l0?ooo`006`3oool00`000000oooo00000004
0?ooo`040000003oool00000000000<0oooo0P00003e0?ooo`006`3oool00`000000oooo0?ooo`08
0?ooo`8000000`3oool00`000000oooo0?ooo`3b0?ooo`006`3oool2000000H0oooo0P0000030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0k`3oool001/0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`3^
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000050?oo
o`800000j`3oool001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo0P00003V0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo0P00003_0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0h@3o
ool001/0oooo0P0000050?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`800000203oool2
00000>40oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool20000
00X0oooo0P00003M0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool200000>L0oooo000K0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool2000000@0oooo0P00000;0?ooo`800000f03oool001/0oooo00<0
00000?ooo`3oool05`3oool2000000@0oooo0P00003S0?ooo`006`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000`0oooo0P00003C
0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3N0?ooo`006`3oool200000180oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`3oool3000000`0oooo00<000000?ooo`3oool0cP3oool001/0
oooo00<000000?ooo`3oool04@3oool2000000d0oooo00<000000?ooo`3oool00P3oool2000000/0
oooo0P0000020?ooo`<00000b@3oool001/0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0=P0oooo000K0?ooo`030000003oool0oooo01D0oooo0P00
000=0?ooo`040000003oool0oooo0?ooo`8000004@3oool00`000000oooo0?ooo`340?ooo`006`3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo0?ooo`<000003`3oool01@000000oooo
0?ooo`3oool000000<40oooo00080?ooo`800000103oool2000000<0oooo100000040?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool200000180oooo00<000000?ooo`3oool0
_P3oool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01T0oooo0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4`3oool200000;/0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool2000002d0oooo00@000000?ooo`000000oooo0P00003@0?ooo`001`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool00000008000005P3oool200000;H0oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0140oooo0`00003<0?ooo`00203oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo03D0oooo0`00000F0?ooo`800000/P3oool001/0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0B0?ooo`8000006P3oool200000:d0oooo000K0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool04`3oool3000001`0oooo0P00002X0?ooo`006`3oool2
000002P0oooo00<000000?ooo`3oool04@3oool300000<@0oooo000K0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool04P3oool2000001h0oooo0P00002S0?ooo`006`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo0P0000000`3oool000000?ooo`2n0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`8000004`3oool4000001`0oooo0`00002N0?ooo`006`3o
ool00`000000oooo0?ooo`140?ooo`<00000^`3oool001/0oooo00<000000?ooo`3oool0<03oool2
000001@0oooo0`00000M0?ooo`800000VP3oool001/0oooo00<000000?ooo`3oool0B03oool30000
0200oooo0P00002E0?ooo`006`3oool2000003H0oooo0P00000C0?ooo`030000003oool0000002<0
oooo00<000000?ooo`3oool0S`3oool001/0oooo00<000000?ooo`3oool0B`3oool5000000030?oo
o`000000oooo01d0oooo0P00002@0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`8000004`3o
ool2000000<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2:0?ooo`006`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000M0?ooo`800000R`3oool001/0oooo00<000000?ooo`3oool0D@3oool20000
00H0oooo00<000000?ooo`3oool07@3oool3000008H0oooo000K0?ooo`030000003oool0oooo03d0
oooo0`00000C0?ooo`<000001@3oool200000240oooo0P0000220?ooo`006`3oool2000004<0oooo
00<000000?ooo`3oool04@3oool2000000H0oooo00<000000?ooo`3oool0X@3oool001/0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool07`3oool3000007d0oooo000K0?ooo`030000003oool0oooo05T0oooo0P000007
0?ooo`030000003oool0oooo09d0oooo000K0?ooo`030000003oool0oooo05/0oooo0P0000070?oo
o`030000003oool0oooo0200oooo0P00001i0?ooo`006`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo0P0000070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0L`3oool000P0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0E0?ooo`8000001`3oool00`000000oooo0?ooo`0R0?ooo`040000
003oool0oooo0?ooo`800000K`3oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04/0oooo0P00000D0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1Y0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`D000000`3oool200000540oooo0P00000@0?ooo`<000001`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo06P0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U0?ooo`8000001`3oool40000
02T0oooo0P00001U0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0@0?ooo`8000002P3oool00`00
0000oooo0?ooo`2<0?ooo`00203oool2000000/0oooo0P0000040?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0000002L0
oooo0`00001P0?ooo`006`3oool00`000000oooo0?ooo`1Z0?ooo`<00000303oool2000002T0oooo
00<000000?ooo`3oool0F`3oool001/0oooo00<000000?ooo`3oool0K@3oool2000000d0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1J0?ooo`006`3oool00`000000oooo0?ooo`1G
0?ooo`8000005P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0840oooo000K0?oo
o`800000L@3oool2000000h0oooo0P00000W0?ooo`8000000`3oool00`000000oooo0?ooo`1A0?oo
o`006`3oool00`000000oooo0?ooo`1L0?ooo`800000503oool2000000h0oooo0P0000000`3oool0
00000?ooo`0X0?ooo`030000003oool0oooo0500oooo000K0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0403oool200000140oooo00<000000?ooo`3oool0:03oool3000004d0oooo
000K0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool04@3oool200000140oooo00<0
00000?ooo`3oool0;03oool2000000<0oooo00<000000?ooo`3oool0@P3oool001/0oooo00<00000
0?ooo`3oool0IP3oool200000100oooo0P00000A0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0@@3oool001/0oooo00<000000?ooo`3oool0NP3oool200000140oooo00<000000?oo
o`3oool0<P3oool2000000<0oooo0P00000i0?ooo`006`3oool2000006/0oooo0P00000@0?ooo`80
00004@3oool010000000oooo00000000000i0?ooo`800000=03oool001/0oooo00<000000?ooo`3o
ool0OP3oool2000001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0_0?ooo`00
6`3oool00`000000oooo0?ooo`1_0?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0000003P0oooo0P0000020?ooo`030000003oool0oooo02X0oooo000K0?ooo`030000003o
ool0oooo0840oooo0`00000D0?ooo`030000003oool0000003/0oooo0P0000020?ooo`<000000P3o
ool300000200oooo000K0?ooo`030000003oool0oooo07<0oooo0P00000?0?ooo`8000005P3oool2
000004H0oooo0`0000030?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`800000203oool0
01/0oooo00<000000?ooo`3oool0N03oool2000000`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1=0?ooo`040000003oool0oooo0?ooo`8000003@3oool001/0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`060?ooo`800000603oool010000000oooo0000003oool2
000005/0oooo000K0?ooo`800000P03oool00`000000oooo0?ooo`070?ooo`<00000703oool00`00
0000oooo0000001G0?ooo`006`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00L0
oooo0P00000N0?ooo`060000003oool000000000003oool00000D03oool001/0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?oo
o`000000CP3oool001/0oooo00<000000?ooo`3oool0S`3oool200000280oooo00<000000?ooo`00
0000C03oool000P0oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`080?ooo`800000903oool00`000000oooo0?ooo`180?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0Q`3oool01@000000oooo0?ooo`3oool0000000L0oooo0`00000S0?ooo`030000003oool0oooo
04H0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool2
000008d0oooo0P0000080?ooo`8000008`3oool00`000000oooo0?ooo`140?ooo`001`3oool01000
0000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`8000001P3oool0
0`000000oooo0?ooo`0R0?ooo`80000000<0oooo0000003oool0@03oool000L0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09D0oooo00@00000
0?ooo`3oool0oooo0P00000W0?ooo`040000003oool000000?ooo`800000>P3oool000P0oooo0P00
000:0?ooo`<00000103oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0080oooo0P00
000/0?ooo`030000003oool0oooo03H0oooo000K0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool00P00000/0?ooo`030000003oool0000003@0oooo000K0?ooo`030000003oool0oooo
09/0oooo00@000000?ooo`3oool0oooo0P00000^0?ooo`800000<@3oool001/0oooo00<000000?oo
o`3oool0W`3oool4000000030?ooo`000000oooo02/0oooo0P00000_0?ooo`006`3oool200000:@0
oooo0`00000^0?ooo`030000003oool0oooo02/0oooo000K0?ooo`030000003oool0oooo0:D0oooo
0P0000020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool001/0oooo00<0
00000?ooo`3oool0Y`3oool2000000030?ooo`000000oooo02`0oooo00<000000?ooo`3oool09`3o
ool001/0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02D0oooo000K0?ooo`030000003oool0oooo0:X0oooo1000000^0?ooo`030000003oool0oooo
02<0oooo000K0?ooo`030000003oool0oooo0:d0oooo0P00000_0?ooo`030000003oool000000240
oooo000K0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool00P00000^0?ooo`030000
003oool0oooo01d0oooo000K0?ooo`800000/@3oool200000500oooo000K0?ooo`030000003oool0
oooo0;80oooo0`0000000`3oool000000?ooo`0/0?ooo`030000003oool0oooo01/0oooo000K0?oo
o`030000003oool0oooo0;D0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000K0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`00
6`3oool00`000000oooo0?ooo`2h0?ooo`800000<03oool00`000000oooo0?ooo`0E0?ooo`006`3o
ool00`000000oooo0?ooo`2i0?ooo`<00000;P3oool00`000000oooo0?ooo`0E0?ooo`006`3oool2
00000;/0oooo00@000000?ooo`0000000000;@3oool00`000000oooo0?ooo`0D0?ooo`006`3oool0
0`000000oooo0?ooo`2n0?ooo`800000:`3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`00
0000oooo0?ooo`300?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool001/0
oooo00<000000?ooo`3oool0`@3oool3000003h0oooo000K0?ooo`030000003oool0oooo0;/0oooo
00<000000?ooo`3oool01P3oool2000002P0oooo00<000000?ooo`3oool04@3oool000P0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`070?ooo`8000009`3oool00`000000oooo0?ooo`0@0?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0b03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool200000<X0oooo0`00000U0?ooo`030000003oool0oooo00h0
oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0<`0
oooo0P00000d0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0240oooo0P00000>0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool03`3oool2000002<0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0d@3oool200000240oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool0d`3oool200000240oooo00<000000?ooo`0000002@3oool001/0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`8000008P3oool01@000000oooo0000003o
ool0000000@0oooo000K0?ooo`800000`03oool00`000000oooo0?ooo`0E0?ooo`800000:@3oool0
01/0oooo00<000000?ooo`3oool0f@3oool2000002L0oooo000K0?ooo`030000003oool0oooo0=/0
oooo0P00000U0?ooo`006`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo01P0oooo
0P00000S0?ooo`006`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0803oool001/0oooo00<000000?ooo`3oool0a`3oool2000001L0oooo0`00000O
0?ooo`006`3oool200000<`0oooo00<000000?ooo`3oool05@3oool2000001d0oooo000K0?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool05P3oool2000001/0oooo000K0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool0503oool2000001T0oooo000K0?ooo`030000003o
ool0oooo0=40oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000003@3oool2000001L0oooo
000K0?ooo`030000003oool0oooo0=l0oooo0P00000:0?ooo`8000005@3oool001/0oooo00<00000
0?ooo`3oool0i03oool2000000<0oooo0`0000000`3oool0000000000002000000<0oooo0P000003
0?ooo`8000001`3oool001/0oooo00<000000?ooo`3oool0k`3oool200000140oooo000K0?ooo`80
0000lP3oool00`000000oooo0?ooo`0>0?ooo`006`3oool00`000000oooo0?ooo`3b0?ooo`<00000
3@3oool001/0oooo00<000000?ooo`3oool0m@3oool2000000/0oooo000K0?ooo`030000003oool0
oooo0?L0oooo00<000000?ooo`3oool0203oool001<0oooo1@0000030?ooo`030000003oool0oooo
0?P0oooo0P0000080?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?X0
oooo0`0000050?ooo`005@3oool00`000000oooo0?ooo`030?ooo`800000oP3oool2000000<0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00503oool200000?l0oooo2`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.211935, -0.268941, \
0.00778854, 0.00756128}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.0824045 0.412023 [
[.13789 .0699 -9 -9 ]
[.13789 .0699 9 0 ]
[.27578 .0699 -9 -9 ]
[.27578 .0699 9 0 ]
[.41368 .0699 -9 -9 ]
[.41368 .0699 9 0 ]
[.55157 .0699 -9 -9 ]
[.55157 .0699 9 0 ]
[.68946 .0699 -3 -9 ]
[.68946 .0699 3 0 ]
[.82735 .0699 -9 -9 ]
[.82735 .0699 9 0 ]
[.96525 .0699 -9 -9 ]
[.96525 .0699 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .16481 -18 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -18 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .0824 m
.13789 .08865 L
s
[(0.2)] .13789 .0699 0 1 Mshowa
.27578 .0824 m
.27578 .08865 L
s
[(0.4)] .27578 .0699 0 1 Mshowa
.41368 .0824 m
.41368 .08865 L
s
[(0.6)] .41368 .0699 0 1 Mshowa
.55157 .0824 m
.55157 .08865 L
s
[(0.8)] .55157 .0699 0 1 Mshowa
.68946 .0824 m
.68946 .08865 L
s
[(1)] .68946 .0699 0 1 Mshowa
.82735 .0824 m
.82735 .08865 L
s
[(1.2)] .82735 .0699 0 1 Mshowa
.96525 .0824 m
.96525 .08865 L
s
[(1.4)] .96525 .0699 0 1 Mshowa
.125 Mabswid
.03447 .0824 m
.03447 .08615 L
s
.06895 .0824 m
.06895 .08615 L
s
.10342 .0824 m
.10342 .08615 L
s
.17237 .0824 m
.17237 .08615 L
s
.20684 .0824 m
.20684 .08615 L
s
.24131 .0824 m
.24131 .08615 L
s
.31026 .0824 m
.31026 .08615 L
s
.34473 .0824 m
.34473 .08615 L
s
.3792 .0824 m
.3792 .08615 L
s
.44815 .0824 m
.44815 .08615 L
s
.48262 .0824 m
.48262 .08615 L
s
.5171 .0824 m
.5171 .08615 L
s
.58604 .0824 m
.58604 .08615 L
s
.62051 .0824 m
.62051 .08615 L
s
.65499 .0824 m
.65499 .08615 L
s
.72393 .0824 m
.72393 .08615 L
s
.75841 .0824 m
.75841 .08615 L
s
.79288 .0824 m
.79288 .08615 L
s
.86183 .0824 m
.86183 .08615 L
s
.8963 .0824 m
.8963 .08615 L
s
.93077 .0824 m
.93077 .08615 L
s
.99972 .0824 m
.99972 .08615 L
s
.25 Mabswid
0 .0824 m
1 .0824 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(0.2)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(0.6)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.8)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(1)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(1.2)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .0824 m
.01 .08549 L
.02 .08868 L
.03 .09189 L
.04 .09497 L
.05 .09837 L
.06 .10178 L
.07 .10511 L
.08 .10843 L
.09 .11128 L
.1 .11434 L
.11 .11806 L
.12 .12186 L
.13 .12555 L
.14 .1288 L
.15 .13223 L
.16 .13539 L
.17 .13908 L
.18 .14257 L
.19 .14577 L
.2 .14908 L
.21 .15313 L
.22 .15725 L
.23 .16125 L
.24 .16525 L
.25 .16894 L
.26 .17343 L
.27 .17722 L
.28 .18139 L
.29 .18537 L
.3 .18903 L
.31 .19321 L
.32 .19738 L
.33 .20161 L
.34 .20574 L
.35 .20977 L
.36 .21402 L
.37 .2186 L
.38 .22323 L
.39 .22766 L
.4 .2317 L
.41 .23599 L
.42 .24077 L
.43 .24546 L
.44 .24976 L
.45 .25452 L
.46 .25924 L
.47 .26432 L
.48 .26926 L
.49 .27478 L
Mistroke
.5 .2801 L
.51 .28488 L
.52 .29028 L
.53 .29523 L
.54 .30003 L
.55 .30512 L
.56 .31048 L
.57 .31568 L
.58 .32094 L
.59 .32649 L
.6 .33172 L
.61 .33774 L
.62 .34364 L
.63 .3491 L
.64 .35469 L
.65 .36022 L
.66 .36574 L
.67 .37108 L
.68 .37684 L
.69 .38247 L
.7 .38925 L
.71 .39545 L
.72 .40103 L
.73 .40755 L
.74 .41376 L
.75 .42004 L
.76 .42617 L
.77 .4323 L
.78 .43841 L
.79 .44475 L
.8 .45121 L
.81 .45713 L
.82 .46343 L
.83 .4697 L
.84 .47577 L
.85 .48158 L
.86 .48766 L
.87 .49358 L
.88 .49876 L
.89 .50399 L
.9 .50905 L
.91 .51411 L
.92 .51861 L
.93 .52271 L
.94 .52635 L
.95 .52965 L
.96 .53323 L
.97 .53588 L
.98 .53748 L
.99 .53884 L
Mistroke
1 .53916 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
o`3oool:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo
2`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
o`3oool40?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo0P000004
0?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P000004
0?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo1000000C
0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool2000001X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203o
ool5000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`D000000P3oool001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000D0?ooo`040000003oool0oooo000000P0oooo0`00000E0?ooo`040000003oool0oooo0000
00T0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
01/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000D0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool2000001D0oooo0P00000;
0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo0P00000L
0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0ooooo`000006000000006`3oool2000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool100000040oooo000K0?ooo`060000003oool0oooo0000003o
ool000007P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`080?ooo`006`3oool00`000000oooo0?ooo`040?ooo`80
0000o03oool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000003h0?ooo`006`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?@0oooo000K0?ooo`8000003P3oool2
00000?<0oooo000K0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000?ooo`3^0?oo
o`006`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0>/0oooo000K0?ooo`030000
003oool0oooo01H0oooo00@000000?ooo`0000000000j03oool001/0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3T0?ooo`006`3oool2000001h0oooo00<000000?ooo`3oool0hP3o
ool001/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3P0?ooo`006`3oool00`00
0000oooo0?ooo`0Q0?ooo`040000003oool0000000000=d0oooo000K0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0f@3oool001/0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`3G0?ooo`006`3oool2000002/0oooo00@000000?ooo`0000000000e03oool001/0oooo
00<000000?ooo`3oool0;P3oool200000=80oooo000K0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0cP3oool001/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3<
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`0e0?oo
o`030000003oool000000<X0oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0g0?ooo`040000003oool0000000000<L0oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000003d0oooo00<00000
0?ooo`3oool0``3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0`@3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0_`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo0;d0oooo000K0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0^`3oool001/0oooo0P0000170?ooo`80000000<0oooo0000003oool0]`3oool001/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2d0?ooo`006`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0;80oooo000K0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0/03oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2^0?oo
o`006`3oool00`000000oooo0?ooo`1C0?ooo`800000[@3oool001/0oooo0P00001G0?ooo`030000
003oool0oooo0:T0oooo000K0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`000000Y`3o
ool001/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0000002U0?ooo`006`3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool000000:<0oooo000K0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`000000X@3oool001/0oooo0P00001S0?ooo`800000WP3oool001/0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`2J0?ooo`006`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo09P0oooo00080?ooo`800000103oool2000000D0oooo0`0000030?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0UP3oool000L0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0U03oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00001^0?oo
o`030000003oool0oooo0980oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0900oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1a
0?ooo`800000S`3oool000P0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`1c0?oo
o`800000S@3oool001/0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`290?ooo`00
6`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo08L0oooo000K0?ooo`800000N`3o
ool00`000000oooo0?ooo`250?ooo`006`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo08<0oooo000K0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0PP3oool001/0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`200?ooo`006`3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo07h0oooo000K0?ooo`800000Q03oool00`000000oooo0?oo
o`1l0?ooo`006`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo07X0oooo000K0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0N03oool001/0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`1f0?ooo`006`3oool00`000000oooo0?ooo`2;0?ooo`800000
M@3oool001/0oooo0P00002>0?ooo`800000L`3oool001/0oooo00<000000?ooo`3oool0S`3oool2
00000740oooo000K0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0K@3oool001/0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1]0?ooo`00203oool2000000@0oooo
0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo06/0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo06T0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool2000009T0oooo00<000000?ooo`3oool0I`3oool000L0
oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`1U0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`1S0?ooo`00203oool2000000X0
oooo0`0000040?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0H@3oool001/0oooo
00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1O0?ooo`006`3oool200000:40oooo00<0
00000?ooo`3oool0G`3oool001/0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`1M
0?ooo`006`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo05/0oooo000K0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`1G0?ooo`006`3oool200000:/0oooo00<000000?ooo`3oool0E@3o
ool001/0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1C0?ooo`006`3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0540oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1?0?ooo`006`3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04d0oooo000K0?ooo`800000]@3oool0
0`000000oooo0?ooo`1;0?ooo`006`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
04T0oooo000K0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0A`3oool000P0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`170?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00002m0?ooo`030000003oool0oooo
04<0oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0@@3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0?`3oool0
00P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
03l0oooo000K0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0?@3oool001/0oooo
0P0000350?ooo`030000003oool0oooo03/0oooo000K0?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`3oool0>@3oool001/0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0g
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool0=@3oool001/0oooo00<000000?ooo`3oool0c03oool00`000000oooo
0?ooo`0c0?ooo`006`3oool200000<l0oooo00<000000?ooo`3oool0<@3oool001/0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0_0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0;@3oool001/0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0[0?ooo`006`3oool200000=L0oooo00<0
00000?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0W
0?ooo`006`3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo02D0oooo000C0?ooo`D0
00000`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`800000g`3oool00`000000oooo0?ooo`0Q0?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool07`3oool001D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo01d0oooo000D0?ooo`80
00001@3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000
003oool0oooo0>H0oooo00<000000?ooo`3oool06@3oool001/0oooo00<000000?ooo`3oool0j03o
ool00`000000oooo0?ooo`0G0?ooo`006`3oool200000>/0oooo0P00000F0?ooo`006`3oool00`00
0000oooo0?ooo`3/0?ooo`800000503oool001/0oooo00<000000?ooo`3oool0k`3oool00`000000
oooo0?ooo`0@0?ooo`006`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0000000h0oooo
000K0?ooo`030000003oool0oooo0?<0oooo00@000000?ooo`00000000002`3oool001/0oooo0P00
003i0?ooo`030000003oool0000000L0oooo000K0?ooo`030000003oool0oooo0?`0oooo00@00000
0?ooo`3oool000000P3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`D0
00000P3oool2000000<0oooo100000040?ooo`030000003oool0oooo0?l0oooo0`3oool000T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
0`3oool000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`800000o`3o
ool40?ooo`002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`002@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000X0oooo0P0000050?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.29766, \
0.00558385, 0.00934377}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(FindRoot::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the merit \
function.  You may need more than \\!\\(MachinePrecision\\) digits of working \
precision to meet these tolerances. \
\\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(FindRoot :: \\\"lstol\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"Plus\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.0824045 0.412023 [
[.13789 .0699 -9 -9 ]
[.13789 .0699 9 0 ]
[.27578 .0699 -9 -9 ]
[.27578 .0699 9 0 ]
[.41368 .0699 -9 -9 ]
[.41368 .0699 9 0 ]
[.55157 .0699 -9 -9 ]
[.55157 .0699 9 0 ]
[.68946 .0699 -3 -9 ]
[.68946 .0699 3 0 ]
[.82735 .0699 -9 -9 ]
[.82735 .0699 9 0 ]
[.96525 .0699 -9 -9 ]
[.96525 .0699 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .16481 -18 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -18 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .0824 m
.13789 .08865 L
s
[(0.2)] .13789 .0699 0 1 Mshowa
.27578 .0824 m
.27578 .08865 L
s
[(0.4)] .27578 .0699 0 1 Mshowa
.41368 .0824 m
.41368 .08865 L
s
[(0.6)] .41368 .0699 0 1 Mshowa
.55157 .0824 m
.55157 .08865 L
s
[(0.8)] .55157 .0699 0 1 Mshowa
.68946 .0824 m
.68946 .08865 L
s
[(1)] .68946 .0699 0 1 Mshowa
.82735 .0824 m
.82735 .08865 L
s
[(1.2)] .82735 .0699 0 1 Mshowa
.96525 .0824 m
.96525 .08865 L
s
[(1.4)] .96525 .0699 0 1 Mshowa
.125 Mabswid
.03447 .0824 m
.03447 .08615 L
s
.06895 .0824 m
.06895 .08615 L
s
.10342 .0824 m
.10342 .08615 L
s
.17237 .0824 m
.17237 .08615 L
s
.20684 .0824 m
.20684 .08615 L
s
.24131 .0824 m
.24131 .08615 L
s
.31026 .0824 m
.31026 .08615 L
s
.34473 .0824 m
.34473 .08615 L
s
.3792 .0824 m
.3792 .08615 L
s
.44815 .0824 m
.44815 .08615 L
s
.48262 .0824 m
.48262 .08615 L
s
.5171 .0824 m
.5171 .08615 L
s
.58604 .0824 m
.58604 .08615 L
s
.62051 .0824 m
.62051 .08615 L
s
.65499 .0824 m
.65499 .08615 L
s
.72393 .0824 m
.72393 .08615 L
s
.75841 .0824 m
.75841 .08615 L
s
.79288 .0824 m
.79288 .08615 L
s
.86183 .0824 m
.86183 .08615 L
s
.8963 .0824 m
.8963 .08615 L
s
.93077 .0824 m
.93077 .08615 L
s
.99972 .0824 m
.99972 .08615 L
s
.25 Mabswid
0 .0824 m
1 .0824 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(0.2)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(0.6)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.8)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(1)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(1.2)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.003 w
0 .08241 m
.01 .0849 L
.02 .08743 L
.03 .08997 L
.04 .09253 L
.05 .09511 L
.06 .09772 L
.07 .10035 L
.08 .103 L
.09 .10567 L
.1 .10836 L
.11 .11108 L
.12 .11382 L
.13 .11658 L
.14 .11937 L
.15 .12218 L
.16 .12501 L
.17 .12787 L
.18 .13076 L
.19 .13367 L
.2 .1366 L
.21 .13956 L
.22 .14255 L
.23 .14556 L
.24 .1486 L
.25 .15167 L
.26 .15476 L
.27 .15789 L
.28 .16104 L
.29 .16421 L
.3 .16742 L
.31 .17066 L
.32 .17392 L
.33 .17722 L
.34 .18055 L
.35 .1839 L
.36 .18729 L
.37 .19071 L
.38 .19416 L
.39 .19765 L
.4 .20116 L
.41 .20471 L
.42 .2083 L
.43 .21192 L
.44 .21557 L
.45 .21926 L
.46 .22298 L
.47 .22674 L
.48 .23053 L
.49 .23437 L
Mistroke
.5 .23824 L
.51 .24214 L
.52 .24609 L
.53 .25008 L
.54 .2541 L
.55 .25817 L
.56 .26227 L
.57 .26642 L
.58 .27061 L
.59 .27484 L
.6 .27912 L
.61 .28344 L
.62 .2878 L
.63 .29221 L
.64 .29667 L
.65 .30117 L
.66 .30572 L
.67 .31031 L
.68 .31496 L
.69 .31965 L
.7 .3244 L
.71 .32919 L
.72 .33404 L
.73 .33894 L
.74 .34389 L
.75 .3489 L
.76 .35396 L
.77 .35908 L
.78 .36425 L
.79 .36948 L
.8 .37477 L
.81 .38012 L
.82 .38553 L
.83 .391 L
.84 .39653 L
.85 .40213 L
.86 .40779 L
.87 .41352 L
.88 .41931 L
.89 .42517 L
.9 .4311 L
.91 .43709 L
.92 .44316 L
.93 .44931 L
.94 .45552 L
.95 .46181 L
.96 .46818 L
.97 .47462 L
.98 .48114 L
.99 .48774 L
Mistroke
1 .49443 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
o`3oool:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo
2`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
o`3oool40?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo0P000004
0?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P000004
0?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo1000000C
0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool2000001X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203o
ool5000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`D000000P3oool001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000D0?ooo`040000003oool0oooo000000P0oooo0`00000E0?ooo`040000003oool0oooo0000
00T0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
01/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000D0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool2000001D0oooo0P00000;
0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo0P00000L
0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0ooooo`000006000000006`3oool4000000D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo000K0?ooo`040000003oool0oooo0?ooo`D000006`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`080?ooo`006`3oool00`000000oooo0?ooo`060?ooo`<00000n@3oool001/0oooo00<0
00000?ooo`3oool02@3oool500000?@0oooo000K0?ooo`030000003oool0oooo00h0oooo0`00003a
0?ooo`006`3oool200000180oooo1@00003/0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`80
0000jP3oool001/0oooo00<000000?ooo`3oool0603oool300000>L0oooo000K0?ooo`030000003o
ool0oooo01/0oooo1@00003R0?ooo`006`3oool00`000000oooo0?ooo`0P0?ooo`<00000g`3oool0
01/0oooo0P00000T0?ooo`D00000fP3oool001/0oooo00<000000?ooo`3oool0:03oool300000=L0
oooo000K0?ooo`030000003oool0oooo02/0oooo0P00003E0?ooo`006`3oool00`000000oooo0?oo
o`0]0?ooo`D00000d03oool001/0oooo00<000000?ooo`3oool0<P3oool300000<d0oooo000K0?oo
o`800000=P3oool200000</0oooo000K0?ooo`030000003oool0oooo03L0oooo0`0000380?ooo`00
6`3oool00`000000oooo0?ooo`0j0?ooo`D00000``3oool001/0oooo00<000000?ooo`3oool0?`3o
ool300000<00oooo00080?ooo`800000103oool2000000<0oooo100000040?ooo`030000003oool0
oooo0480oooo0P00002n0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0A03oool300000;/0oooo00070?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool2000004P0oooo1@00002f0?ooo`001`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool3
00000;<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1?0?ooo`800000/@3oool000P0oooo0P00000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`1A0?ooo`<00000[P3oool001/0oooo00<000000?ooo`3oool0E03oool30000
0:/0oooo000K0?ooo`800000F03oool200000:T0oooo000K0?ooo`030000003oool0oooo05T0oooo
0`00002V0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`D00000X@3oool001/0oooo00<00000
0?ooo`3oool0H@3oool3000009h0oooo000K0?ooo`030000003oool0oooo06@0oooo0P00002L0?oo
o`006`3oool00`000000oooo0?ooo`1V0?ooo`<00000V@3oool001/0oooo0P00001Z0?ooo`800000
U`3oool001/0oooo00<000000?ooo`3oool0J`3oool3000009@0oooo000K0?ooo`030000003oool0
oooo06h0oooo0`00002A0?ooo`006`3oool00`000000oooo0?ooo`1a0?ooo`800000S`3oool001/0
oooo00<000000?ooo`3oool0L`3oool3000008`0oooo000K0?ooo`800000M`3oool2000008X0oooo
000K0?ooo`030000003oool0oooo07P0oooo0`0000270?ooo`006`3oool00`000000oooo0?ooo`1k
0?ooo`<00000Q03oool000P0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?oo
o`3oool0OP3oool200000880oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`200?ooo`<00000O`3oool000L0oooo00@000000?ooo`3o
ool00000203oool5000000<0oooo0P0000240?ooo`800000O@3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08D0oooo0`00001j
0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0R03oool3000007L0oooo00080?ooo`8000002`3oool2000000@0oooo00<000000?oo
o`3oool0R`3oool2000007D0oooo000K0?ooo`030000003oool0oooo08d0oooo0`00001b0?ooo`00
6`3oool00`000000oooo0?ooo`2@0?ooo`800000L03oool001/0oooo0P00002C0?ooo`<00000K@3o
ool001/0oooo00<000000?ooo`3oool0U@3oool2000006/0oooo000K0?ooo`030000003oool0oooo
09L0oooo0P00001Y0?ooo`006`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo06H0
oooo000K0?ooo`030000003oool0oooo09X0oooo0`00001U0?ooo`006`3oool2000009h0oooo0P00
001S0?ooo`006`3oool00`000000oooo0?ooo`2O0?ooo`<00000H03oool001/0oooo00<000000?oo
o`3oool0XP3oool3000005d0oooo000K0?ooo`030000003oool0oooo0:D0oooo0P00001K0?ooo`00
6`3oool00`000000oooo0?ooo`2W0?ooo`800000F@3oool001/0oooo0P00002Z0?ooo`800000E`3o
ool001/0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1D0?ooo`006`3oool00`00
0000oooo0?ooo`2/0?ooo`<00000D`3oool001/0oooo00<000000?ooo`3oool0[`3oool300000500
oooo00080?ooo`800000103oool2000000<0oooo0`0000050?ooo`030000003oool0oooo0;80oooo
0P00001>0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`1;0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00002f0?ooo`800000B`3oool000L0
oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3oool0]`3oool20000
04T0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2i0?ooo`<00000AP3oool000P0oooo0P00000:0?ooo`<00000103oool00`000000
oooo0?ooo`2l0?ooo`800000A03oool001/0oooo00<000000?ooo`3oool0_P3oool200000480oooo
000K0?ooo`800000`@3oool00`000000oooo0?ooo`0o0?ooo`006`3oool00`000000oooo0?ooo`31
0?ooo`<00000?P3oool001/0oooo00<000000?ooo`3oool0a03oool2000003`0oooo000K0?ooo`03
0000003oool0oooo0<H0oooo00<000000?ooo`3oool0>@3oool001/0oooo00<000000?ooo`3oool0
a`3oool2000003T0oooo000K0?ooo`800000bP3oool3000003H0oooo000K0?ooo`030000003oool0
oooo0<`0oooo0P00000d0?ooo`006`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
0340oooo000K0?ooo`030000003oool0oooo0<l0oooo0P00000a0?ooo`006`3oool00`000000oooo
0?ooo`3A0?ooo`800000;`3oool001/0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`0/0?ooo`006`3oool200000=D0oooo0P00000/0?ooo`006`3oool00`000000oooo0?ooo`3F0?oo
o`<00000:@3oool001/0oooo00<000000?ooo`3oool0f@3oool2000002L0oooo00080?ooo`800000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0
903oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0=`0oooo0P00000T0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000@0oooo0P00003O0?ooo`8000008P3oool000L0oooo00@000000?ooo`3o
ool000002@3oool2000000D0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0O0?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0h@3oool2000001l0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool0h`3oool2000001d0oooo000K0?ooo`030000003oool0oooo0>D0oooo0P00000K0?ooo`00
6`3oool200000>P0oooo00<000000?ooo`3oool0603oool001/0oooo00<000000?ooo`3oool0j03o
ool00`000000oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`3Y0?ooo`8000005`3oool0
01/0oooo00<000000?ooo`3oool0j`3oool2000001D0oooo000K0?ooo`030000003oool0oooo0>d0
oooo00<000000?ooo`3oool04P3oool001/0oooo00<000000?ooo`3oool0kP3oool200000180oooo
000K0?ooo`800000l@3oool200000100oooo000K0?ooo`030000003oool0oooo0?80oooo0P00000>
0?ooo`006`3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00/0oooo000K0?ooo`03
0000003oool0oooo0?D0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
mP3oool2000000X0oooo000K0?ooo`800000n@3oool2000000P0oooo000K0?ooo`030000003oool0
oooo0?X0oooo00<000000?ooo`3oool01@3oool001/0oooo00<000000?ooo`3oool0n`3oool00`00
0000oooo0?ooo`040?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool0o03oool2000000@0
oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0oP3oool200000080oooo
000E0?ooo`030000003oool0oooo00<0oooo0P00003o0?ooo`80oooo0P00000001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503oool2000000D0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o
0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo00070?ooo`D000000P3oool2000000<0oooo100000040?ooo`030000003o
ool0oooo0?l0oooo0`3oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0oooo0`3oool000T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`800000o`3oool40?ooo`002@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`002@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.29766, \
0.00558385, 0.00934377}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.0824045 0.412023 [
[.13789 .0699 -9 -9 ]
[.13789 .0699 9 0 ]
[.27578 .0699 -9 -9 ]
[.27578 .0699 9 0 ]
[.41368 .0699 -9 -9 ]
[.41368 .0699 9 0 ]
[.55157 .0699 -9 -9 ]
[.55157 .0699 9 0 ]
[.68946 .0699 -3 -9 ]
[.68946 .0699 3 0 ]
[.82735 .0699 -9 -9 ]
[.82735 .0699 9 0 ]
[.96525 .0699 -9 -9 ]
[.96525 .0699 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .16481 -18 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -18 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .0824 m
.13789 .08865 L
s
[(0.2)] .13789 .0699 0 1 Mshowa
.27578 .0824 m
.27578 .08865 L
s
[(0.4)] .27578 .0699 0 1 Mshowa
.41368 .0824 m
.41368 .08865 L
s
[(0.6)] .41368 .0699 0 1 Mshowa
.55157 .0824 m
.55157 .08865 L
s
[(0.8)] .55157 .0699 0 1 Mshowa
.68946 .0824 m
.68946 .08865 L
s
[(1)] .68946 .0699 0 1 Mshowa
.82735 .0824 m
.82735 .08865 L
s
[(1.2)] .82735 .0699 0 1 Mshowa
.96525 .0824 m
.96525 .08865 L
s
[(1.4)] .96525 .0699 0 1 Mshowa
.125 Mabswid
.03447 .0824 m
.03447 .08615 L
s
.06895 .0824 m
.06895 .08615 L
s
.10342 .0824 m
.10342 .08615 L
s
.17237 .0824 m
.17237 .08615 L
s
.20684 .0824 m
.20684 .08615 L
s
.24131 .0824 m
.24131 .08615 L
s
.31026 .0824 m
.31026 .08615 L
s
.34473 .0824 m
.34473 .08615 L
s
.3792 .0824 m
.3792 .08615 L
s
.44815 .0824 m
.44815 .08615 L
s
.48262 .0824 m
.48262 .08615 L
s
.5171 .0824 m
.5171 .08615 L
s
.58604 .0824 m
.58604 .08615 L
s
.62051 .0824 m
.62051 .08615 L
s
.65499 .0824 m
.65499 .08615 L
s
.72393 .0824 m
.72393 .08615 L
s
.75841 .0824 m
.75841 .08615 L
s
.79288 .0824 m
.79288 .08615 L
s
.86183 .0824 m
.86183 .08615 L
s
.8963 .0824 m
.8963 .08615 L
s
.93077 .0824 m
.93077 .08615 L
s
.99972 .0824 m
.99972 .08615 L
s
.25 Mabswid
0 .0824 m
1 .0824 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(0.2)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(0.6)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.8)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(1)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(1.2)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .0824 m
.01 .0824 L
.02 .0824 L
.03 .0824 L
.04 .0824 L
.05 .0824 L
.06 .0824 L
.07 .0824 L
.08 .08439 L
.09 .08508 L
.1 .08728 L
.11 .08819 L
.12 .08989 L
.13 .09039 L
.14 .09404 L
.15 .09628 L
.16 .09879 L
.17 .10025 L
.18 .10141 L
.19 .10408 L
.2 .10441 L
.21 .10914 L
.22 .11298 L
.23 .11555 L
.24 .118 L
.25 .12135 L
.26 .12789 L
.27 .12937 L
.28 .13242 L
.29 .13493 L
.3 .13782 L
.31 .14027 L
.32 .1437 L
.33 .14444 L
.34 .14922 L
.35 .15093 L
.36 .15582 L
.37 .15854 L
.38 .16089 L
.39 .16361 L
.4 .16505 L
.41 .1705 L
.42 .17525 L
.43 .17985 L
.44 .18304 L
.45 .18872 L
.46 .19024 L
.47 .19272 L
.48 .19869 L
.49 .20309 L
Mistroke
.5 .20636 L
.51 .20768 L
.52 .20812 L
.53 .2113 L
.54 .21637 L
.55 .22287 L
.56 .22778 L
.57 .23485 L
.58 .23965 L
.59 .24389 L
.6 .24389 L
.61 .25067 L
.62 .25749 L
.63 .26181 L
.64 .26688 L
.65 .27295 L
.66 .27608 L
.67 .27905 L
.68 .27997 L
.69 .29165 L
.7 .29869 L
.71 .30188 L
.72 .30756 L
.73 .31456 L
.74 .31893 L
.75 .31988 L
.76 .3258 L
.77 .33538 L
.78 .34175 L
.79 .34657 L
.8 .35458 L
.81 .36027 L
.82 .36443 L
.83 .3701 L
.84 .37386 L
.85 .38165 L
.86 .39168 L
.87 .39581 L
.88 .39866 L
.89 .40943 L
.9 .417 L
.91 .4226 L
.92 .43157 L
.93 .43593 L
.94 .44418 L
.95 .4564 L
.96 .4692 L
.97 .47723 L
.98 .48456 L
.99 .49443 L
Mistroke
1 .49443 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
o`3oool:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo
2`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
o`3oool40?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo0P000004
0?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P000004
0?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo1000000C
0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool2000001X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203o
ool5000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`D000000P3oool001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000D0?ooo`040000003oool0oooo000000P0oooo0`00000E0?ooo`040000003oool0oooo0000
00T0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
01/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000D0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool2000001D0oooo0P00000;
0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo0P00000L
0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0ooooo`000006000000006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`800000
0`3oool2000000030?ooo`000000oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0h03oool001/0oooo00<000000?ooo`3oool08`3oool200000=d0oooo000K0?oo
o`030000003oool0oooo02P0oooo0P00003H0?ooo`006`3oool2000002h0oooo0P00003C0?ooo`00
6`3oool00`000000oooo0?ooo`0b0?ooo`800000cP3oool001/0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`006`3oool00`000000oooo0?ooo`0g0?ooo`800000b@3oool001/0oooo00<000000?oo
o`3oool0?03oool200000<@0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo
0?ooo`110?ooo`800000_`3oool001/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`2i0?ooo`006`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0;P0oooo000K0?oo
o`030000003oool0oooo04/0oooo0P00002e0?ooo`006`3oool200000540oooo0P00002`0?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo05D0oooo0P00
002[0?ooo`006`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0:D0oooo00080?oo
o`800000103oool2000000<0oooo100000040?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0Y03oool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo05l0oooo0P00002Q0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo0P00001U0?ooo`800000W03oool000L0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo06P0oooo0P00002H0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0K@3oool2000009<0oooo000K0?ooo`800000
o`3oool40?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`800000SP3oool001/0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`280?ooo`006`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo08L0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0N`3oool2000008D0oooo000K0?ooo`800000P@3oool200000800oooo000K
0?ooo`030000003oool0oooo08D0oooo0P00001k0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0M@3oool001/0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1d0?ooo`006`3oool2000008l0oooo00<0
00000?ooo`3oool0L@3oool001/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1`
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`800000103oool2000000D0
oooo0`0000030?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0K03oool000L0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09@0
oooo00@000000?ooo`3oool0oooo0P00001X0?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`D000000`3oool2000009X0oooo00<000000?ooo`3oool0IP3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool0
00L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0H`3oool000P0oooo0P00000;0?ooo`800000103oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo0680oooo000K0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0GP3oool001/0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`1M0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0Y@3oool2
000005/0oooo000K0?ooo`030000003oool0oooo0:X0oooo0P00001F0?ooo`006`3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo05@0oooo000K0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0D03oool001/0oooo0P00002`0?ooo`030000003oool0oooo0500oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`2c0?ooo`800000C@3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool200000;P0oooo0P0000190?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0@`3oool001/0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`120?ooo`00203oool2000000@0oooo
0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`310?ooo`800000?`3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0
oooo0`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`800000o`3oool40?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`00
0000oooo0?ooo`350?ooo`030000003oool0oooo03X0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo
03T0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`390?ooo`800000=`3oool001/0oooo0P00003o0?ooo`@0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0c@3oool20000
03<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
dP3oool2000002h0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo02P0oooo000K0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`3oool09`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`3K0?ooo`030000003oool0oooo02@0oooo000K0?ooo`030000003oool0oooo0=`0oooo00<0
00000?ooo`3oool08`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo
0=l0oooo0P00000Q0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00080?ooo`800000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0><0
oooo0P00000M0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo0P00003U0?ooo`030000003oool0oooo01/0oooo00070?ooo`040000003oool0oooo0000
00T0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>L0oooo0P00000I
0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000>`0oooo0P00000E0?ooo`006`3o
ool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo0180oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0l03oool200000100oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool200000?@0oooo00<000000?ooo`3oool0303oool001/0oooo00<000000?ooo`3oool0m03oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0m`3oool00`000000oooo
0?ooo`080?ooo`006`3oool200000?T0oooo00<000000?ooo`3oool01`3oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000C0?ooo`D0
00000`3oool00`000000oooo0?ooo`3k0?ooo`8000001@3oool001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo0P00
003o0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?l0oooo0`3oool001@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`800000o`3oool40?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3o
ool500000080oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`3o0?ooo`<0oooo0009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo00090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool20000
0?l0oooo103oool000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?l0oooo0`3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool000P0oooo0P00000:0?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.29766, \
0.00558385, 0.00934377}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.0824045 0.412023 [
[.13789 .0699 -9 -9 ]
[.13789 .0699 9 0 ]
[.27578 .0699 -9 -9 ]
[.27578 .0699 9 0 ]
[.41368 .0699 -9 -9 ]
[.41368 .0699 9 0 ]
[.55157 .0699 -9 -9 ]
[.55157 .0699 9 0 ]
[.68946 .0699 -3 -9 ]
[.68946 .0699 3 0 ]
[.82735 .0699 -9 -9 ]
[.82735 .0699 9 0 ]
[.96525 .0699 -9 -9 ]
[.96525 .0699 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .16481 -18 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -18 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .0824 m
.13789 .08865 L
s
[(0.2)] .13789 .0699 0 1 Mshowa
.27578 .0824 m
.27578 .08865 L
s
[(0.4)] .27578 .0699 0 1 Mshowa
.41368 .0824 m
.41368 .08865 L
s
[(0.6)] .41368 .0699 0 1 Mshowa
.55157 .0824 m
.55157 .08865 L
s
[(0.8)] .55157 .0699 0 1 Mshowa
.68946 .0824 m
.68946 .08865 L
s
[(1)] .68946 .0699 0 1 Mshowa
.82735 .0824 m
.82735 .08865 L
s
[(1.2)] .82735 .0699 0 1 Mshowa
.96525 .0824 m
.96525 .08865 L
s
[(1.4)] .96525 .0699 0 1 Mshowa
.125 Mabswid
.03447 .0824 m
.03447 .08615 L
s
.06895 .0824 m
.06895 .08615 L
s
.10342 .0824 m
.10342 .08615 L
s
.17237 .0824 m
.17237 .08615 L
s
.20684 .0824 m
.20684 .08615 L
s
.24131 .0824 m
.24131 .08615 L
s
.31026 .0824 m
.31026 .08615 L
s
.34473 .0824 m
.34473 .08615 L
s
.3792 .0824 m
.3792 .08615 L
s
.44815 .0824 m
.44815 .08615 L
s
.48262 .0824 m
.48262 .08615 L
s
.5171 .0824 m
.5171 .08615 L
s
.58604 .0824 m
.58604 .08615 L
s
.62051 .0824 m
.62051 .08615 L
s
.65499 .0824 m
.65499 .08615 L
s
.72393 .0824 m
.72393 .08615 L
s
.75841 .0824 m
.75841 .08615 L
s
.79288 .0824 m
.79288 .08615 L
s
.86183 .0824 m
.86183 .08615 L
s
.8963 .0824 m
.8963 .08615 L
s
.93077 .0824 m
.93077 .08615 L
s
.99972 .0824 m
.99972 .08615 L
s
.25 Mabswid
0 .0824 m
1 .0824 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(0.2)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(0.6)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.8)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(1)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(1.2)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .005 .015 ] 0 setdash
0 .0824 m
.01 .09308 L
.02 .09941 L
.03 .10451 L
.04 .11178 L
.05 .11768 L
.06 .12106 L
.07 .12536 L
.08 .12866 L
.09 .132 L
.1 .136 L
.11 .14151 L
.12 .14737 L
.13 .15051 L
.14 .15476 L
.15 .15975 L
.16 .16409 L
.17 .17053 L
.18 .1731 L
.19 .17717 L
.2 .18099 L
.21 .18383 L
.22 .19138 L
.23 .1957 L
.24 .19968 L
.25 .20374 L
.26 .21038 L
.27 .21419 L
.28 .21865 L
.29 .22271 L
.3 .22864 L
.31 .23371 L
.32 .23996 L
.33 .24406 L
.34 .24774 L
.35 .25155 L
.36 .25781 L
.37 .26248 L
.38 .26698 L
.39 .27167 L
.4 .2781 L
.41 .28309 L
.42 .28963 L
.43 .29419 L
.44 .29906 L
.45 .30658 L
.46 .31131 L
.47 .31729 L
.48 .32395 L
.49 .33125 L
Mistroke
.5 .33922 L
.51 .34368 L
.52 .34894 L
.53 .35545 L
.54 .35984 L
.55 .36586 L
.56 .37068 L
.57 .37716 L
.58 .38267 L
.59 .38865 L
.6 .39546 L
.61 .40295 L
.62 .41115 L
.63 .41933 L
.64 .42642 L
.65 .43416 L
.66 .43978 L
.67 .44706 L
.68 .4522 L
.69 .46017 L
.7 .46637 L
.71 .4733 L
.72 .47784 L
.73 .48825 L
.74 .49443 L
.75 .49443 L
.76 .50543 L
.77 .51176 L
.78 .52011 L
.79 .52953 L
.8 .535 L
.81 .54172 L
.82 .54923 L
.83 .55478 L
.84 .56029 L
.85 .56341 L
.86 .56999 L
.87 .5737 L
.88 .5765 L
.89 .58061 L
.9 .58431 L
.91 .58843 L
.92 .59155 L
.93 .59239 L
.94 .59519 L
.95 .59726 L
.96 .5981 L
.97 .5988 L
.98 .59959 L
.99 .60175 L
Mistroke
1 .60175 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
o`3oool:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo
2`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
o`3oool40?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo0P000004
0?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P000004
0?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo1000000C
0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool2000001X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203o
ool5000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`D000000P3oool001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000D0?ooo`040000003oool0oooo000000P0oooo0`00000E0?ooo`040000003oool0oooo0000
00T0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
01/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000D0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool2000001D0oooo0P00000;
0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo0P00000L
0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0ooooo`000006000000006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`006`3oool200000280oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
203oool001/0oooo00<000000?ooo`000000o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000K0?ooo`030000003oool0oooo0080oooo0P00003n0?ooo`006`3oool200000?l0
oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`060?ooo`<00000n@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`0;0?ooo`800000m@3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000
003oool0oooo0100oooo0P00003`0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01D0oooo0P00003[0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`8000006P3oool00`000000oooo0?ooo`3V0?ooo`006`3oool00`000000oooo
0?ooo`0J0?ooo`800000iP3oool001/0oooo00<000000?ooo`3oool07P3oool200000>80oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool000P0oooo0P0000040?ooo`8000000`3oool40000
00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3L0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`3K0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo0P00000X0?ooo`030000003oool0oooo0=P0oooo00070?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`800000f03oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0d`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0=80oooo000K0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0cP3oool001/0oooo0P00000c0?ooo`030000003oool0oooo0<d0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0=P3oool2
00000<X0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3o
ool0>P3oool300000<D0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
00100?ooo`030000003oool0oooo0<00oooo000K0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0_`3oool001/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?oo
o`006`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0;X0oooo000K0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0]`3oool001/0oooo0P00001:0?ooo`800000]`3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`1=0?oo
o`800000/`3oool000P0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2]0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`D000000`3oool2000005@0oooo00<000000?ooo`3oool0[03oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
05H0oooo0`00002Y0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203oool2000000/0oooo0P0000040?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0Y03oool001/0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`2S0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`800000H@3oool200000:00oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0I03oool2000009`0oooo000K0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0VP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool2
000006X0oooo0P00002G0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0TP3oool001/0oooo00<000000?ooo`3oool0
KP3oool200000980oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00001c
0?ooo`800000SP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`1f0?ooo`800000RP3oool001/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`280?ooo`00203oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo08@0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool2000007d0oooo00<000000?ooo`3o
ool0P`3oool000L0oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`220?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`210?ooo`00
203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0PP3oool2000007h0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo07T0oooo000K0?ooo`030000003oool0oooo08L0
oooo0P00001i0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo08/0oooo0P00001e0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`1_0?ooo`006`3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo06h0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1[0?ooo`006`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo06X0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`000000
oooo0?ooo`2H0?ooo`800000J03oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00203o
ool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo0680oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool2000009l0oooo00<000000?ooo`3oool0H@3oool000L0oooo
00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`1N0?ooo`00203oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool0G@3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool200000:H0oooo00<000000?ooo`3oool0FP3oool001/0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`1I0?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0EP3oool001/0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1E0?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`800000[`3oool200000580oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo
0?ooo`2b0?ooo`800000CP3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool2
00000;L0oooo00<000000?ooo`3oool0B@3oool001/0oooo00<000000?ooo`3oool0]`3oool00`00
0000oooo0?ooo`180?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000C0?ooo`D00000
0`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0^P3oool2000004H0oooo000E0?ooo`030000003oool0oooo00<0oooo0P000030
0?ooo`800000@@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo03l0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`00503oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`330?ooo`800000?@3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0h0?ooo`006`3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03L0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0d0?ooo`006`3oool200000<d0oooo00<000000?ooo`3oool0<`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3?0?ooo`030000
003oool0oooo0300oooo000K0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0;`3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000=@0oooo0`00000/0?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0=P0oooo
0P00000X0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`D000000P3oool2
000000<0oooo100000040?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool08P3oool0
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0=h0oooo00<000000?ooo`3oool08@3oool000T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`800000h`3oool2000001h0oooo00090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00090?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3V0?ooo`<00000
6@3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0>/0oooo0`00000D0?ooo`006`3oool200000?40oooo0`0000030?oo
o`8000002P3oool001/0oooo00<000000?ooo`3oool0n`3oool2000000<0oooo0P00000001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.29766, \
0.00558385, 0.00934377}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.52366e-017 0.689461 0.0824045 0.412023 [
[.13789 .0699 -9 -9 ]
[.13789 .0699 9 0 ]
[.27578 .0699 -9 -9 ]
[.27578 .0699 9 0 ]
[.41368 .0699 -9 -9 ]
[.41368 .0699 9 0 ]
[.55157 .0699 -9 -9 ]
[.55157 .0699 9 0 ]
[.68946 .0699 -3 -9 ]
[.68946 .0699 3 0 ]
[.82735 .0699 -9 -9 ]
[.82735 .0699 9 0 ]
[.96525 .0699 -9 -9 ]
[.96525 .0699 9 0 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .16481 -18 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -18 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13789 .0824 m
.13789 .08865 L
s
[(0.2)] .13789 .0699 0 1 Mshowa
.27578 .0824 m
.27578 .08865 L
s
[(0.4)] .27578 .0699 0 1 Mshowa
.41368 .0824 m
.41368 .08865 L
s
[(0.6)] .41368 .0699 0 1 Mshowa
.55157 .0824 m
.55157 .08865 L
s
[(0.8)] .55157 .0699 0 1 Mshowa
.68946 .0824 m
.68946 .08865 L
s
[(1)] .68946 .0699 0 1 Mshowa
.82735 .0824 m
.82735 .08865 L
s
[(1.2)] .82735 .0699 0 1 Mshowa
.96525 .0824 m
.96525 .08865 L
s
[(1.4)] .96525 .0699 0 1 Mshowa
.125 Mabswid
.03447 .0824 m
.03447 .08615 L
s
.06895 .0824 m
.06895 .08615 L
s
.10342 .0824 m
.10342 .08615 L
s
.17237 .0824 m
.17237 .08615 L
s
.20684 .0824 m
.20684 .08615 L
s
.24131 .0824 m
.24131 .08615 L
s
.31026 .0824 m
.31026 .08615 L
s
.34473 .0824 m
.34473 .08615 L
s
.3792 .0824 m
.3792 .08615 L
s
.44815 .0824 m
.44815 .08615 L
s
.48262 .0824 m
.48262 .08615 L
s
.5171 .0824 m
.5171 .08615 L
s
.58604 .0824 m
.58604 .08615 L
s
.62051 .0824 m
.62051 .08615 L
s
.65499 .0824 m
.65499 .08615 L
s
.72393 .0824 m
.72393 .08615 L
s
.75841 .0824 m
.75841 .08615 L
s
.79288 .0824 m
.79288 .08615 L
s
.86183 .0824 m
.86183 .08615 L
s
.8963 .0824 m
.8963 .08615 L
s
.93077 .0824 m
.93077 .08615 L
s
.99972 .0824 m
.99972 .08615 L
s
.25 Mabswid
0 .0824 m
1 .0824 L
s
0 0 m
.00625 0 L
s
[(-0.2)] -0.0125 0 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(0.2)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(0.6)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.8)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(1)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(1.2)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
[ .001 .008 ] 0 setdash
0 .0824 m
.01 .08549 L
.02 .08868 L
.03 .09189 L
.04 .09497 L
.05 .09837 L
.06 .10178 L
.07 .10511 L
.08 .10843 L
.09 .11128 L
.1 .11434 L
.11 .11806 L
.12 .12186 L
.13 .12555 L
.14 .1288 L
.15 .13223 L
.16 .13539 L
.17 .13908 L
.18 .14257 L
.19 .14577 L
.2 .14908 L
.21 .15313 L
.22 .15725 L
.23 .16125 L
.24 .16525 L
.25 .16894 L
.26 .17343 L
.27 .17722 L
.28 .18139 L
.29 .18537 L
.3 .18903 L
.31 .19321 L
.32 .19738 L
.33 .20161 L
.34 .20574 L
.35 .20977 L
.36 .21402 L
.37 .2186 L
.38 .22323 L
.39 .22766 L
.4 .2317 L
.41 .23599 L
.42 .24077 L
.43 .24546 L
.44 .24976 L
.45 .25452 L
.46 .25924 L
.47 .26432 L
.48 .26926 L
.49 .27478 L
Mistroke
.5 .2801 L
.51 .28488 L
.52 .29028 L
.53 .29523 L
.54 .30003 L
.55 .30512 L
.56 .31048 L
.57 .31568 L
.58 .32094 L
.59 .32649 L
.6 .33172 L
.61 .33774 L
.62 .34364 L
.63 .3491 L
.64 .35469 L
.65 .36022 L
.66 .36574 L
.67 .37108 L
.68 .37684 L
.69 .38247 L
.7 .38925 L
.71 .39545 L
.72 .40103 L
.73 .40755 L
.74 .41376 L
.75 .42004 L
.76 .42617 L
.77 .4323 L
.78 .43841 L
.79 .44475 L
.8 .45121 L
.81 .45713 L
.82 .46343 L
.83 .4697 L
.84 .47577 L
.85 .48158 L
.86 .48766 L
.87 .49358 L
.88 .49876 L
.89 .50399 L
.9 .50905 L
.91 .51411 L
.92 .51861 L
.93 .52271 L
.94 .52635 L
.95 .52965 L
.96 .53323 L
.97 .53588 L
.98 .53748 L
.99 .53884 L
Mistroke
1 .53916 L
Mfstroke
.003 w
[ ] 0 setdash
0 .08241 m
.01 .0849 L
.02 .08743 L
.03 .08997 L
.04 .09253 L
.05 .09511 L
.06 .09772 L
.07 .10035 L
.08 .103 L
.09 .10567 L
.1 .10836 L
.11 .11108 L
.12 .11382 L
.13 .11658 L
.14 .11937 L
.15 .12218 L
.16 .12501 L
.17 .12787 L
.18 .13076 L
.19 .13367 L
.2 .1366 L
.21 .13956 L
.22 .14255 L
.23 .14556 L
.24 .1486 L
.25 .15167 L
.26 .15476 L
.27 .15789 L
.28 .16104 L
.29 .16421 L
.3 .16742 L
.31 .17066 L
.32 .17392 L
.33 .17722 L
.34 .18055 L
.35 .1839 L
.36 .18729 L
.37 .19071 L
.38 .19416 L
.39 .19765 L
.4 .20116 L
.41 .20471 L
.42 .2083 L
.43 .21192 L
.44 .21557 L
.45 .21926 L
.46 .22298 L
.47 .22674 L
.48 .23053 L
.49 .23437 L
Mistroke
.5 .23824 L
.51 .24214 L
.52 .24609 L
.53 .25008 L
.54 .2541 L
.55 .25817 L
.56 .26227 L
.57 .26642 L
.58 .27061 L
.59 .27484 L
.6 .27912 L
.61 .28344 L
.62 .2878 L
.63 .29221 L
.64 .29667 L
.65 .30117 L
.66 .30572 L
.67 .31031 L
.68 .31496 L
.69 .31965 L
.7 .3244 L
.71 .32919 L
.72 .33404 L
.73 .33894 L
.74 .34389 L
.75 .3489 L
.76 .35396 L
.77 .35908 L
.78 .36425 L
.79 .36948 L
.8 .37477 L
.81 .38012 L
.82 .38553 L
.83 .391 L
.84 .39653 L
.85 .40213 L
.86 .40779 L
.87 .41352 L
.88 .41931 L
.89 .42517 L
.9 .4311 L
.91 .43709 L
.92 .44316 L
.93 .44931 L
.94 .45552 L
.95 .46181 L
.96 .46818 L
.97 .47462 L
.98 .48114 L
.99 .48774 L
Mistroke
1 .49443 L
Mfstroke
.001 w
[ .005 .015 ] 0 setdash
0 .0824 m
.01 .0824 L
.02 .0824 L
.03 .0824 L
.04 .0824 L
.05 .0824 L
.06 .0824 L
.07 .0824 L
.08 .08439 L
.09 .08508 L
.1 .08728 L
.11 .08819 L
.12 .08989 L
.13 .09039 L
.14 .09404 L
.15 .09628 L
.16 .09879 L
.17 .10025 L
.18 .10141 L
.19 .10408 L
.2 .10441 L
.21 .10914 L
.22 .11298 L
.23 .11555 L
.24 .118 L
.25 .12135 L
.26 .12789 L
.27 .12937 L
.28 .13242 L
.29 .13493 L
.3 .13782 L
.31 .14027 L
.32 .1437 L
.33 .14444 L
.34 .14922 L
.35 .15093 L
.36 .15582 L
.37 .15854 L
.38 .16089 L
.39 .16361 L
.4 .16505 L
.41 .1705 L
.42 .17525 L
.43 .17985 L
.44 .18304 L
.45 .18872 L
.46 .19024 L
.47 .19272 L
.48 .19869 L
.49 .20309 L
Mistroke
.5 .20636 L
.51 .20768 L
.52 .20812 L
.53 .2113 L
.54 .21637 L
.55 .22287 L
.56 .22778 L
.57 .23485 L
.58 .23965 L
.59 .24389 L
.6 .24389 L
.61 .25067 L
.62 .25749 L
.63 .26181 L
.64 .26688 L
.65 .27295 L
.66 .27608 L
.67 .27905 L
.68 .27997 L
.69 .29165 L
.7 .29869 L
.71 .30188 L
.72 .30756 L
.73 .31456 L
.74 .31893 L
.75 .31988 L
.76 .3258 L
.77 .33538 L
.78 .34175 L
.79 .34657 L
.8 .35458 L
.81 .36027 L
.82 .36443 L
.83 .3701 L
.84 .37386 L
.85 .38165 L
.86 .39168 L
.87 .39581 L
.88 .39866 L
.89 .40943 L
.9 .417 L
.91 .4226 L
.92 .43157 L
.93 .43593 L
.94 .44418 L
.95 .4564 L
.96 .4692 L
.97 .47723 L
.98 .48456 L
.99 .49443 L
Mistroke
1 .49443 L
Mfstroke
0 .0824 m
.01 .09308 L
.02 .09941 L
.03 .10451 L
.04 .11178 L
.05 .11768 L
.06 .12106 L
.07 .12536 L
.08 .12866 L
.09 .132 L
.1 .136 L
.11 .14151 L
.12 .14737 L
.13 .15051 L
.14 .15476 L
.15 .15975 L
.16 .16409 L
.17 .17053 L
.18 .1731 L
.19 .17717 L
.2 .18099 L
.21 .18383 L
.22 .19138 L
.23 .1957 L
.24 .19968 L
.25 .20374 L
.26 .21038 L
.27 .21419 L
.28 .21865 L
.29 .22271 L
.3 .22864 L
.31 .23371 L
.32 .23996 L
.33 .24406 L
.34 .24774 L
.35 .25155 L
.36 .25781 L
.37 .26248 L
.38 .26698 L
.39 .27167 L
.4 .2781 L
.41 .28309 L
.42 .28963 L
.43 .29419 L
.44 .29906 L
.45 .30658 L
.46 .31131 L
.47 .31729 L
.48 .32395 L
.49 .33125 L
Mistroke
.5 .33922 L
.51 .34368 L
.52 .34894 L
.53 .35545 L
.54 .35984 L
.55 .36586 L
.56 .37068 L
.57 .37716 L
.58 .38267 L
.59 .38865 L
.6 .39546 L
.61 .40295 L
.62 .41115 L
.63 .41933 L
.64 .42642 L
.65 .43416 L
.66 .43978 L
.67 .44706 L
.68 .4522 L
.69 .46017 L
.7 .46637 L
.71 .4733 L
.72 .47784 L
.73 .48825 L
.74 .49443 L
.75 .49443 L
.76 .50543 L
.77 .51176 L
.78 .52011 L
.79 .52953 L
.8 .535 L
.81 .54172 L
.82 .54923 L
.83 .55478 L
.84 .56029 L
.85 .56341 L
.86 .56999 L
.87 .5737 L
.88 .5765 L
.89 .58061 L
.9 .58431 L
.91 .58843 L
.92 .59155 L
.93 .59239 L
.94 .59519 L
.95 .59726 L
.96 .5981 L
.97 .5988 L
.98 .59959 L
.99 .60175 L
Mistroke
1 .60175 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000
o`3oool:0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0?l0oooo
2`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
o`3oool40?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`8000000`3oool4000001@0oooo0P000004
0?ooo`8000001@3oool3000001@0oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P000004
0?ooo`800000103oool2000001/0oooo1@00000I0?ooo`D000000P3oool2000000<0oooo1000000C
0?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`006`3oool2000001X0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool06@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203o
ool5000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`D000000P3oool001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000D0?ooo`040000003oool0oooo000000P0oooo0`00000E0?ooo`040000003oool0oooo0000
00T0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
01/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000D0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
00030?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool2000001D0oooo0P00000;
0?ooo`8000005@3oool2000000X0oooo0`00000E0?ooo`8000002P3oool2000001`0oooo0P00000L
0?ooo`8000002P3oool2000001D0oooo0P00000;0?ooo`8000000`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0ooooo`000006000000006`3oool4000000D0oooo00<000000?ooo`3o
ool01P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo000K0?ooo`80000000<0oooo0000000000001000000C0?ooo`800000
0`3oool2000000030?ooo`000000oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000K0?ooo`030000003oool0000000@0oooo1@00
000F0?ooo`030000003oool0oooo0>00oooo000K0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001000000E0?ooo`800000g@3oool001/0oooo00<000000?ooo`3oool00P3oool20000
00L0oooo00<000000?ooo`3oool00`00000G0?ooo`800000f03oool001/0oooo0P00000>0?ooo`80
00000P3oool5000001L0oooo0P00003C0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`800000
00<0oooo0000003oool00P3oool2000001X0oooo0P00003>0?ooo`006`3oool00`000000oooo0?oo
o`060?ooo`<000002`3oool010000000oooo0?ooo`3oool300000>L0oooo000K0?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`00000000000?ooo`05000001L0oooo0P0000390?ooo`006`3o
ool00`000000oooo0?ooo`0;0?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`<000006@3o
ool200000<@0oooo000K0?ooo`8000007P3oool00`000000oooo0?ooo`030?ooo`D00000fP3oool0
01/0oooo00<000000?ooo`3oool0403oool2000000d0oooo00<000000?ooo`3oool01P3oool30000
01H0oooo0P00002o0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool000000000
00H0oooo0P00000I0?ooo`030000003oool0oooo0;T0oooo000K0?ooo`030000003oool0oooo01D0
oooo0P00000?0?ooo`030000003oool0oooo00@0oooo1@00000E0?ooo`030000003oool0oooo0;P0
oooo000K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool3000001H0oooo
0P00002e0?ooo`006`3oool2000001X0oooo00<000000?ooo`3oool03P3oool010000000oooo0000
000000070?ooo`8000006@3oool200000;00oooo000K0?ooo`030000003oool0oooo01X0oooo0P00
000B0?ooo`8000001`3oool300000<P0oooo000K0?ooo`030000003oool0oooo01h0oooo0P00000A
0?ooo`030000003oool0oooo00H0oooo1@00000F0?ooo`800000Z`3oool001/0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`090?ooo`<00000603oool00`000000oooo0?ooo`2U0?oo
o`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`0000002P3oool2000001L0oooo00<000000?ooo`3o
ool0Y03oool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0403oool010000000oooo0000000000090?oo
o`<00000603oool200000:40oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0103oool2000002P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?oo
o`D00000603oool2000009`0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`800000503oool00`000000oooo0?ooo`0;0?oo
o`<00000/`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<
0?ooo`8000005`3oool2000009P0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo0`00002^0?oo
o`006`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03@3oool3000001H0oooo0P00002C0?ooo`006`3oool2000003<0oooo00<000000?ooo`3oool0
4@3oool2000000030?ooo`000000oooo00`0oooo0P00002Y0?ooo`006`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo00/0oooo0`00000F0?ooo`800000SP3oool001/0oooo00<00000
0?ooo`3oool0=P3oool2000001D0oooo00<000000?ooo`3oool0303oool5000001H0oooo00<00000
0?ooo`3oool0R03oool001/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0?0?oo
o`<00000503oool00`000000oooo0?ooo`270?ooo`006`3oool00`000000oooo0?ooo`0j0?ooo`<0
0000503oool00`000000oooo0?ooo`0@0?ooo`800000W03oool001/0oooo00<000000?ooo`3oool0
D`3oool200000140oooo0`00000B0?ooo`800000Q@3oool001/0oooo0P0000100?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0403oool2000001D0oooo0P0000200?ooo`006`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`000000403oool3
000001L0oooo0P00001k0?ooo`006`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`0000004@3oool300000940oooo000K0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0503oool00`000000oooo0000000B0?ooo`8000005`3oool00`000000
oooo0?ooo`1e0?ooo`006`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`0000004P3oool3000001D0oooo00<000000?ooo`3oool0M03oool001/0oooo0P00
001:0?ooo`8000005`3oool200000180oooo0P00000F0?ooo`030000003oool0oooo0740oooo000K
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0403oool3000001@0oooo00<00000
0?ooo`3oool0L03oool001/0oooo00<000000?ooo`3oool0C@3oool2000001P0oooo00<000000?oo
o`3oool04@3oool3000008@0oooo00080?ooo`800000103oool2000000D0oooo0`0000030?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool04P3oool2000001<0oooo00<000000?ooo`3o
ool0K03oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`<0
00004@3oool010000000oooo0?ooo`3oool2000006P0oooo00070?ooo`040000003oool0oooo0000
00P0oooo1@0000030?ooo`800000E03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01<0oooo0P00000D0?ooo`030000003oool0oooo06H0oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`<000005P3oool0
0`000000oooo0?ooo`0C0?ooo`<00000NP3oool000L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0740oooo0P00000E0?ooo`<000004@3oool0
0`000000oooo0?ooo`1S0?ooo`00203oool2000000/0oooo0P0000040?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool05@3oool2000001H0oooo0P00000@0?ooo`030000003oool0oooo
0680oooo000K0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0D0?ooo`<000004@3oool00`000000oooo0?ooo`1N0?ooo`006`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo01D0oooo0P00000@0?ooo`030000003oool0oooo05d0oooo
000K0?ooo`800000H@3oool2000001P0oooo00<000000?ooo`3oool05@3oool3000006d0oooo000K
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool05P3oool2000000h0oooo0P00001K
0?ooo`006`3oool00`000000oooo0?ooo`1T0?ooo`8000005`3oool00`000000oooo0?ooo`0G0?oo
o`8000004@3oool2000005H0oooo000K0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0E03oool001/0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0F0?ooo`<00000
4P3oool00`000000oooo0?ooo`1@0?ooo`006`3oool2000006X0oooo0P00000H0?ooo`030000003o
ool0oooo01L0oooo0P00000@0?ooo`030000003oool0oooo0500oooo000K0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool05`3oool300000600oooo000K0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`<00000G@3oool001/0
oooo00<000000?ooo`3oool0KP3oool2000001T0oooo00<000000?ooo`3oool06@3oool2000000`0
oooo0P00001=0?ooo`006`3oool00`000000oooo0?ooo`2;0?ooo`8000006P3oool2000005T0oooo
000K0?ooo`800000L`3oool2000001T0oooo0P00000J0?ooo`800000303oool2000004T0oooo000K
0?ooo`030000003oool0oooo08l0oooo0P00000J0?ooo`030000003oool0oooo05@0oooo000K0?oo
o`030000003oool0oooo07H0oooo0P00000J0?ooo`030000003oool0oooo01L0oooo0`00000=0?oo
o`030000003oool0oooo04<0oooo000K0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0J0?ooo`<000002`3oool00`000000oooo0?ooo`120?ooo`00
203oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo01/0oooo0P00000=0?ooo`800000?`3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04/0oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool2000007d0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`800000B`3oool000L0oooo00@000000?ooo`3o
ool00000203oool3000000D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo0P00000<0?ooo`030000003oool0oooo03X0oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool3000000X0oooo00<000000?oo
o`3oool0>@3oool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo01/0oooo0P0000140?ooo`006`3oool00`000000oooo0?ooo`220?ooo`800000
703oool00`000000oooo0?ooo`0K0?ooo`8000002@3oool2000003L0oooo000K0?ooo`800000X@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03l0oooo000K0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`<00000?P3oool0
01/0oooo00<000000?ooo`3oool0Q`3oool2000001/0oooo00<000000?ooo`3oool07@3oool20000
00L0oooo0P00000c0?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0>@3oool001/0oooo00<000000?ooo`3oool0R`3oool2000001/0oooo
00<000000?ooo`3oool0703oool2000000T0oooo0P00000^0?ooo`006`3oool200000:/0oooo00<0
00000?ooo`3oool0703oool3000003H0oooo000K0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`8000002@3oool00`000000oooo0?ooo`0X
0?ooo`006`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02L0oooo000K0?ooo`03
0000003oool0oooo0<l0oooo0P00000a0?ooo`006`3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool07P3oool2000000P0oooo00<000000?ooo`3oool0
903oool001/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`006`3oool2
00000;D0oooo00<000000?ooo`3oool07@3oool2000002`0oooo000K0?ooo`030000003oool0oooo
09P0oooo0P00000L0?ooo`030000003oool0oooo01d0oooo0`0000060?ooo`8000008@3oool001/0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0N0?ooo`8000009`3oool000P0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02@0oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool07`3oool2000000D0oooo0P00000M0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00002O0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool07`3oool2000000@0oooo00<000000?ooo`3oool06`3oool000L0
oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool07P3oool2000000@0oooo0P00000I0?ooo`00203oool20000
00X0oooo0P0000050?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0P0?ooo`8000007@3oool001/0oooo00<000000?ooo`3oool0`P3oool00`000000
oooo0?ooo`0P0?ooo`8000006`3oool001/0oooo0P00002V0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0803oool010000000oooo0?ooo`3oool2000001D0oooo000K0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool001/0oooo00<000000?ooo`3oool0b03o
ool00`000000oooo0?ooo`0N0?ooo`8000005`3oool001/0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0o0?ooo`8000000`3oool200000100oooo000K0?ooo`030000003oool0oooo
0:X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0180oooo000K0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool07`3oool200000180
oooo000K0?ooo`800000[`3oool2000001h0oooo00<000000?ooo`3oool07`3oool2000000030?oo
o`000000oooo00d0oooo000K0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool07`3o
ool3000000d0oooo000K0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool02`3oool0
01/0oooo00<000000?ooo`3oool0/P3oool2000001h0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo01l0
oooo0P00000:0?ooo`006`3oool200000;L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0O0?ooo`800000203oool001/0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool001/0oooo00<00000
0?ooo`3oool0fP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo000C0?oo
o`D000000`3oool00`000000oooo0?ooo`3k0?ooo`<00000103oool001D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2j0?ooo`800000803oool00`000000oooo0?ooo`0O0?ooo`80
00000P3oool001D0oooo00<000000?ooo`3oool00`3oool200000<00oooo0P00000M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`0000000@00000001D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07`3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0
oooo01d0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo
01/0oooo000K0?ooo`030000003oool0oooo0<<0oooo0P00000Q0?ooo`030000003oool0oooo01T0
oooo000K0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool05`3oool001/0oooo0P00
003[0?ooo`8000005P3oool001/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0R
0?ooo`800000503oool001/0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`00
00003P3oool001/0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0U0?ooo`040000
003oool00000000000/0oooo000K0?ooo`800000c@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0000000L0oooo000K0?ooo`030000003oool0oooo0?`0oooo00@000000?ooo`3oool00000
0P3oool001/0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0`0?ooo`006`3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo02l0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo0P00003D0?ooo`<00000;03oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3H0?ooo`800000:03oool001/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`001`3oool500000080oooo0P0000030?ooo`@00000103oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo0280oooo00090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo0240
oooo00090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool200000><0oooo
0P00000N0?ooo`002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`002@3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0iP3oool3000001T0oooo00080?ooo`8000002P3oool2
000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3[0?oo
o`<00000503oool001/0oooo0P00003a0?ooo`<000000`3oool2000000X0oooo000K0?ooo`030000
003oool0oooo0?/0oooo0P0000030?ooo`800000000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.15215, -0.29766, \
0.00558385, 0.00934377}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 951}},
WindowSize->{1272, 924},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 2054, 35, 324, "Input"],
Cell[3811, 88, 5339, 95, 1230, "Input"],
Cell[9153, 185, 7324, 143, 1610, "Input"],

Cell[CellGroupData[{
Cell[16502, 332, 13238, 250, 2480, "Input"],
Cell[29743, 584, 19603, 542, 186, 4758, 354, "GraphicsData", "PostScript", \
"Graphics"],
Cell[49349, 1128, 522, 8, 37, "Message"],
Cell[49874, 1138, 522, 8, 37, "Message"],
Cell[50399, 1148, 522, 8, 37, "Message"],
Cell[50924, 1158, 333, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[51282, 1167, 17077, 511, 186, 4768, 355, "GraphicsData", "PostScript", \
"Graphics"],
Cell[68362, 1680, 18175, 527, 186, 4813, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[86540, 2209, 17059, 512, 186, 4790, 356, "GraphicsData", "PostScript", \
"Graphics"],
Cell[103602, 2723, 29790, 936, 186, 8765, 672, "GraphicsData", "PostScript", \
"Graphics"],
Cell[133395, 3661, 18045, 514, 186, 4982, 348, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[151455, 4178, 522, 8, 37, "Message"],
Cell[151980, 4188, 522, 8, 37, "Message"],
Cell[152505, 4198, 522, 8, 37, "Message"],
Cell[153030, 4208, 333, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[153388, 4217, 17260, 503, 186, 4951, 347, "GraphicsData", "PostScript", \
"Graphics"],
Cell[170651, 4722, 17428, 506, 186, 4981, 348, "GraphicsData", "PostScript", \
"Graphics"],
Cell[188082, 5230, 17422, 506, 186, 4983, 348, "GraphicsData", "PostScript", \
"Graphics"],
Cell[205507, 5738, 27302, 872, 186, 9626, 649, "GraphicsData", "PostScript", \
"Graphics"],
Cell[232812, 6612, 20025, 603, 186, 5209, 416, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[252852, 7218, 278, 4, 35, "Message"],
Cell[253133, 7224, 278, 4, 35, "Message"],
Cell[253414, 7230, 311, 5, 22, "Message"],
Cell[253728, 7237, 335, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[254088, 7246, 19641, 598, 186, 5185, 415, "GraphicsData", "PostScript", \
"Graphics"],
Cell[273732, 7846, 19020, 591, 186, 5212, 416, "GraphicsData", "PostScript", \
"Graphics"],
Cell[292755, 8439, 19032, 570, 186, 4892, 391, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[311802, 9012, 335, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[312162, 9021, 28946, 959, 186, 8889, 707, "GraphicsData", "PostScript", \
"Graphics"],
Cell[341111, 9982, 17562, 506, 186, 4560, 341, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[358688, 10491, 522, 8, 37, "Message"],
Cell[359213, 10501, 522, 8, 37, "Message"],
Cell[359738, 10511, 522, 8, 37, "Message"],
Cell[360263, 10521, 333, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[360621, 10530, 17202, 501, 186, 4540, 340, "GraphicsData", "PostScript", \
"Graphics"],
Cell[377826, 11033, 16528, 493, 186, 4563, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[394357, 11528, 16664, 479, 186, 4322, 322, "GraphicsData", "PostScript", \
"Graphics"],
Cell[411024, 12009, 26990, 873, 186, 8326, 638, "GraphicsData", "PostScript", \
"Graphics"],
Cell[438017, 12884, 19563, 574, 186, 4920, 389, "GraphicsData", "PostScript", \
"Graphics"],
Cell[457583, 13460, 18740, 563, 186, 4911, 388, "GraphicsData", "PostScript", \
"Graphics"],
Cell[476326, 14025, 18359, 559, 186, 4923, 389, "GraphicsData", "PostScript", \
"Graphics"],
Cell[494688, 14586, 18903, 566, 186, 4920, 389, "GraphicsData", "PostScript", \
"Graphics"],
Cell[513594, 15154, 28020, 945, 186, 8926, 705, "GraphicsData", "PostScript", \
"Graphics"],
Cell[541617, 16101, 19005, 549, 186, 4943, 371, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[560637, 16653, 522, 8, 37, "Message"],
Cell[561162, 16663, 522, 8, 37, "Message"],
Cell[561687, 16673, 522, 8, 37, "Message"],
Cell[562212, 16683, 333, 5, 22, "Message"],

Cell[CellGroupData[{
Cell[562570, 16692, 17712, 533, 186, 4913, 370, "GraphicsData", "PostScript", \
"Graphics"],
Cell[580285, 17227, 17782, 534, 186, 4931, 371, "GraphicsData", "PostScript", \
"Graphics"],
Cell[598070, 17763, 18025, 537, 186, 4935, 371, "GraphicsData", "PostScript", \
"Graphics"],
Cell[616098, 18302, 27573, 922, 186, 8926, 687, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

